package com.nordicpeak.flowengine.addflowinstanceasmanager;

import java.io.IOException;
import java.lang.reflect.Field;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;

import org.apache.log4j.Level;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.GroupMultiListSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.LinkTag;
import se.unlogic.hierarchy.core.beans.MutableUser;
import se.unlogic.hierarchy.core.beans.ScriptTag;
import se.unlogic.hierarchy.core.beans.SimpleAccessInterface;
import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.exceptions.ModuleConfigurationException;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.interfaces.AccessInterface;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.ModuleUtils;
import se.unlogic.hierarchy.core.utils.ModuleViewFragmentTransformer;
import se.unlogic.hierarchy.core.utils.ViewFragmentModule;
import se.unlogic.hierarchy.core.utils.extensionlinks.ExtensionLink;
import se.unlogic.hierarchy.core.utils.extensionlinks.ExtensionLinkProvider;
import se.unlogic.hierarchy.core.utils.usergrouplist.UserGroupListConnector;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;
import se.unlogic.hierarchy.foregroundmodules.staticcontent.StaticContentModule;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfile;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.enums.Order;
import se.unlogic.standardutils.populators.EnumPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.populators.SwedishSocialSecurity12DigitsPopulator;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLGeneratorDocument;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.HTTPUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.validation.ValidationUtils;

import com.nordicpeak.flowengine.FlowAdminModule;
import com.nordicpeak.flowengine.FlowInstanceAdminModule;
import com.nordicpeak.flowengine.addflowinstance.AddFlowInstanceModule;
import com.nordicpeak.flowengine.beans.Flow;
import com.nordicpeak.flowengine.beans.FlowAdminExtensionShowView;
import com.nordicpeak.flowengine.beans.FlowFamily;
import com.nordicpeak.flowengine.beans.FlowType;
import com.nordicpeak.flowengine.beans.RequestMetadata;
import com.nordicpeak.flowengine.dao.FlowEngineDAOFactory;
import com.nordicpeak.flowengine.enums.ManagerAccess;
import com.nordicpeak.flowengine.interfaces.FlowAdminExtensionViewProvider;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowFamily;
import com.nordicpeak.flowengine.utils.FlowInstanceEventGenerator;
import com.nordicpeak.personprovider.Person;
import com.nordicpeak.personprovider.PersonProvider;

public class AddFlowInstanceAsManagerModule extends AnnotatedForegroundModule implements FlowAdminExtensionViewProvider, ExtensionLinkProvider, ViewFragmentModule<ForegroundModuleDescriptor> {

	private static final AnnotatedRequestPopulator<FlowFamilyAddInstanceSettings> POPULATOR = new AnnotatedRequestPopulator<FlowFamilyAddInstanceSettings>(FlowFamilyAddInstanceSettings.class);
	private static final EnumPopulator<AddFlowInstanceAsManagerUserType> USERTYPE_POPULATOR = new EnumPopulator<>(AddFlowInstanceAsManagerUserType.class);

	protected static final List<Field> LIST_FLOW_FAMILIES_IGNORED_FIELDS = Arrays.asList(FlowType.ALLOWED_ADMIN_GROUPS_RELATION, FlowType.ALLOWED_QUERIES_RELATION, FlowType.ALLOWED_ADMIN_USERS_RELATION, FlowType.CATEGORIES_RELATION, Flow.STATUSES_RELATION, Flow.DEFAULT_FLOW_STATE_MAPPINGS_RELATION, Flow.STEPS_RELATION, Flow.TAGS_RELATION, FlowFamily.MANAGER_USERS_RELATION, FlowFamily.MANAGER_GROUPS_RELATION);

	protected static final ValidationError FLOW_FAMILY_NOT_FOUND_VALIDATION_ERROR = new ValidationError("FlowFamilyNotFound");
	protected static final ValidationError FLOW_FAMILY_ACCESS_DENIED_VALIDATION_ERROR = new ValidationError("FlowFamilyAccessDenied");
	protected static final ValidationError SIZE_LIMIT_EXCEEDED_VALIDATION_ERROR = new ValidationError("SizeLimitExceeded");
	protected static final ValidationError UNABLE_TO_PARSE_REQUEST_VALIDATION_ERROR = new ValidationError("UnableToParseRequest");

	@XSLVariable(prefix = "java.")
	private String overviewExtensionLinkTitle = "Add flow instance";

	@XSLVariable(prefix = "java.")
	private String adminExtensionViewTitle = "Add flow instances as manager settings";

	@XSLVariable(prefix = "java.")
	protected String preparedByManger = "Prepared by manager";

	@XSLVariable(prefix = "java.")
	protected String submittedByManger = "Submitted by manager";

	@XSLVariable(prefix = "java.")
	protected String submittedByMangerSigningSkipped = "Submitted by manager (no signing)";

	@ModuleSetting(allowsNull = true)
	@GroupMultiListSettingDescriptor(name = "Global access groups", description = "Groups with access to submit all flows")
	protected List<Integer> globalAccessGroups;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable fragment XML debug", description = "Enables debugging of fragment XML")
	private boolean debugFragmententXML;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "User class to use when creating new users", description = "User class to use when creating new users")
	protected String classForNewUsers;
	
	@ModuleSetting(allowsNull=true)
	@GroupMultiListSettingDescriptor(name="Default groups", description="Groups added to new users")
	private List<Integer> defaultGroups;
	
	@ModuleSetting(allowsNull=true)
	@GroupMultiListSettingDescriptor(name="User search groups", description="Groups used when searching for user by username")
	private List<Integer> userSearchGroups;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Citizen identifier attribute", description = "Attribute name where citizen identifier is searched, default is 'citizenIdentifier'")
	protected String citizenIdentifierAttribute = "citizenIdentifier";
	
	@InstanceManagerDependency(required = true)
	protected AddFlowInstanceModule addFlowInstanceModule;

	@InstanceManagerDependency
	protected PersonProvider personProvider;

	protected FlowAdminModule flowAdminModule;
	protected FlowInstanceAdminModule flowInstanceAdminModule;
	protected StaticContentModule staticContentModule;

	private ModuleViewFragmentTransformer<ForegroundModuleDescriptor> viewFragmentTransformer;

	protected AccessInterface globalAccess;

	private AnnotatedDAO<FlowFamilyAddInstanceSettings> settingsDAO;
	private QueryParameterFactory<FlowFamilyAddInstanceSettings, Integer> flowFamilyIDParamFactory;
	protected QueryParameterFactory<FlowFamily, Integer> flowFlowFamilyIDParamFactory;

	protected FlowInstanceEventGenerator flowInstanceEventGenerator;

	protected ExtensionLink overviewExtensionLink;
	
	protected UserGroupListConnector userGroupListConnector;

	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {

		viewFragmentTransformer = new ModuleViewFragmentTransformer<ForegroundModuleDescriptor>(sectionInterface.getForegroundModuleXSLTCache(), this, sectionInterface.getSystemInterface().getEncoding());

		super.init(moduleDescriptor, sectionInterface, dataSource);
		
		userGroupListConnector = new UserGroupListConnector(systemInterface);
		userGroupListConnector.setUserGroupFilter(userSearchGroups);
		userGroupListConnector.setRequireUsername(true);
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, AddFlowInstanceAsManagerModule.class.getName(), new XMLDBScriptProvider(AddFlowInstanceAsManagerModule.class.getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		SimpleAnnotatedDAOFactory daoFactory = new SimpleAnnotatedDAOFactory(dataSource);

		settingsDAO = daoFactory.getDAO(FlowFamilyAddInstanceSettings.class);
		flowFamilyIDParamFactory = settingsDAO.getParamFactory("flowFamilyID", Integer.class);

		FlowEngineDAOFactory daoFactory2 = new FlowEngineDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler());
		flowInstanceEventGenerator = new FlowInstanceEventGenerator(daoFactory2);
	}

	@Override
	protected void moduleConfigured() throws Exception {

		this.globalAccess = new SimpleAccessInterface(globalAccessGroups, null);

		if (ModuleUtils.checkRequiredModuleSettings(moduleDescriptor, this, systemInterface, Level.ERROR)) {

			generateOverviewExtensionLink(staticContentModule);
		}
		
		if (userGroupListConnector != null) {

			userGroupListConnector.setUserGroupFilter(userSearchGroups);
		}
	}

	@Override
	public void unload() throws Exception {

		if (flowInstanceAdminModule != null) {

			flowInstanceAdminModule.removeOverviewExtensionLinkProvider(this);
		}
		
		if (flowAdminModule != null) {

			this.flowAdminModule.removeExtensionViewProvider(this);
		}

		super.unload();
	}

	public FlowFamilyAddInstanceSettings getSetting(ImmutableFlowFamily flowFamily) throws SQLException {

		HighLevelQuery<FlowFamilyAddInstanceSettings> query = new HighLevelQuery<FlowFamilyAddInstanceSettings>();

		query.addParameter(flowFamilyIDParamFactory.getParameter(flowFamily.getFlowFamilyID()));

		return settingsDAO.get(query);
	}

	@Override
	public ForegroundModuleResponse defaultMethod(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return listFlowFamilies(req, res, user, uriParser, null);
	}

	public ForegroundModuleResponse listFlowFamilies(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, ValidationError validationError) throws ModuleConfigurationException, SQLException {

		log.info("User " + user + " listing families");

		Document doc = this.createDocument(req, uriParser, user);

		Element listFamiliesElement = doc.createElement("ListFamilies");
		doc.getDocumentElement().appendChild(listFamiliesElement);

		XMLGeneratorDocument generatorDocument = new XMLGeneratorDocument(doc);
		generatorDocument.setIgnoredFields(LIST_FLOW_FAMILIES_IGNORED_FIELDS);

		boolean hasGlobalAccess = AccessUtils.checkAccess(user, globalAccess);
		
		Collection<FlowFamily> flowFamilies = flowAdminModule.getCachedFlowFamilies();
		
		for(FlowFamily flowFamily : flowFamilies) {
			
			//TODO cache settings!
			FlowFamilyAddInstanceSettings settings = getSetting(flowFamily);
			
			if(settings == null) {
				
				continue;
			}
			
			if(!hasGlobalAccess && !hasAccess(user, flowFamily, settings)) {
				
				continue;
			}
			
			List<Flow> flowVersions = flowAdminModule.getFlowVersions(flowFamily, Order.DESC);
			
			Flow flow = getMatchingFlowVersion(settings, flowVersions);
			
			if(flow == null) {
				
				continue;
			}
			
			Element flowElement = flow.toXML(generatorDocument);
			listFamiliesElement.appendChild(flowElement);

			flowAdminModule.appendFamilyInformation(generatorDocument, flowElement, flow, flowVersions);
		}

		if (validationError != null) {

			XMLUtils.append(doc, listFamiliesElement, validationError);
		}

		return new SimpleForegroundModuleResponse(doc, this.getDefaultBreadcrumb());
	}

	private Flow getMatchingFlowVersion(FlowFamilyAddInstanceSettings settings, List<Flow> flowVersions) {

		for(Flow flow : flowVersions) {
			
			if(!flow.isEnabled()) {
				
				continue;
			}
			
			if(settings.isRequirePublishedFlow() && !flow.isPublished()) {
				
				continue;
			}
			
			return flow;
		}
		
		return null;
	}
	
	@WebPublic
	public ForegroundModuleResponse add(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws URINotFoundException, IOException, ModuleConfigurationException, SQLException, AccessDeniedException {

		Integer flowFamilyID;
		FlowFamily flowFamily;
		FlowFamilyAddInstanceSettings setting;

		if (uriParser.size() == 3 && (flowFamilyID = uriParser.getInt(2)) != null && (flowFamily = flowAdminModule.getFlowFamily(flowFamilyID)) != null && (setting = getSetting(flowFamily)) != null) {

			if (!AccessUtils.checkAccess(user, globalAccess) && !hasAccess(user, flowFamily, setting)) {
				
				throw new AccessDeniedException("User does not have access to flow family " + flowFamily);
			}
			
			List<Flow> flows = flowAdminModule.getFlowVersions(flowFamily, Order.DESC);

			Flow latestEnabledFlow = getMatchingFlowVersion(setting, flows);

			if(latestEnabledFlow == null) {
				
				if(setting.isRequirePublishedFlow()) {
					
					log.warn("Found no published flow for flowFamilyID " + flowFamilyID);
					
					return listFlowFamilies(req, res, user, uriParser, new ValidationError("NoPublishedFlows"));
					
				}else {
					
					log.warn("Found no enabled flow for flowFamilyID " + flowFamilyID);
					
					return listFlowFamilies(req, res, user, uriParser, new ValidationError("NoEnabledFlows"));
				}
			}
			
			Integer flowID = latestEnabledFlow.getFlowID();
			String submitEventText = latestEnabledFlow.requiresSigning() ? submittedByMangerSigningSkipped : submittedByManger;
			RequestMetadata requestMetadata = new RequestMetadata(false);
			requestMetadata.getAttributeHandler().setAttribute("AddFlowInstanceAsManager", true);
			
			if (allowEarlyAdd(latestEnabledFlow, flowFamily, setting, req)) {
				
				return addFlowInstanceModule.createAddFlowInstanceRequest(req, res, flowID, user, null, true, true, null, null, requestMetadata, new AddFlowInstanceCallback(setting, null, user, submitEventText, preparedByManger, systemInterface.getContextPath() + getFullAlias() + "/add/" + flowFamily.getFlowFamilyID()), null);
			}
			
			int possibleUserTypes = 0;

			if (setting.isAllowAnonymous()) {
				possibleUserTypes++;
			}

			if (setting.isAllowInternalUsers()) {
				possibleUserTypes++;
			}

			if (setting.isAllowExistingUsers() || setting.isAllowCreatingUsers()) {
				possibleUserTypes++;
			}

			List<ValidationError> validationErrors = null;

			if (req.getMethod().equalsIgnoreCase("POST")) {

				validationErrors = new ArrayList<ValidationError>();

				AddFlowInstanceAsManagerUserType userType = ValidationUtils.validateParameter("userType", req, possibleUserTypes > 1, USERTYPE_POPULATOR, validationErrors);
				SiteProfile profile = populateProfile(latestEnabledFlow, flowFamily, user, req, validationErrors, setting);
				
				if (validationErrors.isEmpty()) {
					
					if (userType == null && possibleUserTypes == 1) {
						
						if (setting.isAllowAnonymous()) {
							
							userType = AddFlowInstanceAsManagerUserType.ANONYMOUS;
							
						} else if (setting.isAllowInternalUsers()) {
							
							userType = AddFlowInstanceAsManagerUserType.USERNAME;
							
						} else if (setting.isAllowExistingUsers() || setting.isAllowCreatingUsers()) {
							
							userType = AddFlowInstanceAsManagerUserType.CITIZENID;
						}
					}
					
					if (userType == AddFlowInstanceAsManagerUserType.ANONYMOUS && setting.isAllowAnonymous()) {
						
						return addFlowInstanceModule.createAddFlowInstanceRequest(req, res, flowID, user, null, true, true, profile, null, requestMetadata, new AddFlowInstanceCallback(setting, null, user, submitEventText, preparedByManger, systemInterface.getContextPath() + getFullAlias() + "/add/" + flowFamily.getFlowFamilyID()), null);
						
					} else if (userType == AddFlowInstanceAsManagerUserType.CITIZENID && (setting.isAllowExistingUsers() || setting.isAllowCreatingUsers())) {
						
						String citizenID = ValidationUtils.validateParameter("citizenID", req, true, SwedishSocialSecurity12DigitsPopulator.getPopulator(), validationErrors);
						
						if (validationErrors.isEmpty()) {
							
							citizenID = citizenID.replace("-", "");
							
							User poster = systemInterface.getUserHandler().getUserByAttribute(citizenIdentifierAttribute, citizenID, false, true);
							
							if (poster == null) {
								
								if (setting.isAllowCreatingUsers() && personProvider != null && !StringUtils.isEmpty(classForNewUsers)) {
									
									Person person = personProvider.getPerson(citizenID);
									
									if (person != null) {
										
										try {
											MutableUser newUser = (MutableUser) Class.forName(classForNewUsers).newInstance();
											
											newUser.setFirstname(person.getFirstname());
											newUser.setLastname(person.getLastname());
											
											newUser.getAttributeHandler().setAttribute(citizenIdentifierAttribute, person.getCitizenIdentifier());
											
											newUser.getAttributeHandler().setAttribute("careOf", person.getCareOf());
											newUser.getAttributeHandler().setAttribute("address", person.getAddress());
											newUser.getAttributeHandler().setAttribute("zipCode", person.getZipCode());
											newUser.getAttributeHandler().setAttribute("postalAddress", person.getPostalAddress());

											newUser.getAttributeHandler().setAttribute("official.careOf", person.getOfficialCareOf());
											newUser.getAttributeHandler().setAttribute("official.address", person.getOfficialAddress());
											newUser.getAttributeHandler().setAttribute("official.zipCode", person.getOfficialZipCode());
											newUser.getAttributeHandler().setAttribute("official.postalAddress", person.getOfficialPostalAddress());
											newUser.getAttributeHandler().setAttribute("official.kommunKod", person.getOfficialMunicipalityCode());
											
											newUser.setEnabled(true);
											
											if (defaultGroups != null) {

												newUser.setGroups(systemInterface.getGroupHandler().getGroups(defaultGroups, true));
											}
											
											systemInterface.getUserHandler().addUser(newUser);
											
											poster = newUser;
											
										} catch (Exception e) {
											
											log.error("Error creating new user with class \"" + classForNewUsers + "\"", e);
											validationErrors.add(new ValidationError("UserNotFound"));
										}
										
									} else {
										
										validationErrors.add(new ValidationError("UserNotFoundByCitizenID"));
									}
									
								} else {
									
									validationErrors.add(new ValidationError("UserNotFoundByCitizenID"));
								}
								
							} else if (!setting.isAllowExistingUsers()) {
								
								validationErrors.add(new ValidationError("UserFound"));
							}
							
							if (validationErrors.isEmpty()) {
								
								return addFlowInstanceModule.createAddFlowInstanceRequest(req, res, flowID, user, poster, true, true, profile, null, requestMetadata, new AddFlowInstanceCallback(setting, poster, user, submitEventText, preparedByManger, systemInterface.getContextPath() + getFullAlias() + "/add/" + flowFamily.getFlowFamilyID()), null);
							}
						}
						
					} else if (userType == AddFlowInstanceAsManagerUserType.USERNAME && setting.isAllowInternalUsers()) {
						
						String username = ValidationUtils.validateParameter("username", req, true, 1, 255, StringPopulator.getPopulator(), validationErrors);
						
						if (validationErrors.isEmpty()) {
							
							User poster = systemInterface.getUserHandler().getUserByUsername(username, false, true);
							
							if (poster == null) {
								
								validationErrors.add(new ValidationError("UserNotFoundByUsername"));
							}
							
							if (validationErrors.isEmpty()) {
								
								return addFlowInstanceModule.createAddFlowInstanceRequest(req, res, flowID, user, poster, true, true, profile, null, requestMetadata, new AddFlowInstanceCallback(setting, poster, user, submitEventText, preparedByManger, systemInterface.getContextPath() + getFullAlias() + "/add/" + flowFamily.getFlowFamilyID()), null);
							}
						}
					}
				}
			}

			log.info("User " + user + " requested add flow instance  " + latestEnabledFlow);

			Document doc = this.createDocument(req, uriParser, user);

			Element choosePosterElement = doc.createElement("ChoosePoster");
			doc.getDocumentElement().appendChild(choosePosterElement);

			choosePosterElement.appendChild(setting.toXML(doc));
			choosePosterElement.appendChild(latestEnabledFlow.toXML(doc));
			
			addAppendExtra(doc, choosePosterElement, latestEnabledFlow, flowFamily, setting, user, req);
			
			XMLUtils.appendNewElement(doc, choosePosterElement, "PossibleUserTypes", possibleUserTypes);
			
			if (req.getParameter("added") != null) {

				XMLUtils.appendNewElement(doc, choosePosterElement, "Added", req.getParameter("added"));
			}

			if (Boolean.parseBoolean(req.getParameter("saved"))) {

				XMLUtils.appendNewElement(doc, choosePosterElement, "Saved");
			}

			if (!CollectionUtils.isEmpty(validationErrors)) {
				
				choosePosterElement.appendChild(RequestUtils.getRequestParameters(req, doc));
				XMLUtils.append(doc, choosePosterElement, "ValidationErrors", validationErrors);
			}
			
			return new SimpleForegroundModuleResponse(doc, this.getDefaultBreadcrumb());
		}
		
		return listFlowFamilies(req, res, user, uriParser, FLOW_FAMILY_NOT_FOUND_VALIDATION_ERROR);
	}
	
	protected boolean allowEarlyAdd(Flow flow, FlowFamily flowFamily, FlowFamilyAddInstanceSettings setting, HttpServletRequest req) {
		
		return req.getParameter("added") == null && req.getParameter("saved") == null && setting.isAllowAnonymous() && !setting.isAllowInternalUsers() && !setting.isAllowExistingUsers() && !setting.isAllowCreatingUsers();
	}
	
	protected SiteProfile populateProfile(Flow latestEnabledFlow, FlowFamily flowFamily, User user, HttpServletRequest req, List<ValidationError> validationErrors, FlowFamilyAddInstanceSettings settings) {
		return null;
	}
	
	protected void addAppendExtra(Document doc, Element choosePosterElement, Flow latestEnabledFlow, FlowFamily flowFamily, FlowFamilyAddInstanceSettings setting, User user, HttpServletRequest req) {
		
	}
	
	public Document createDocument(HttpServletRequest req, URIParser uriParser, User user) {
		
		Document doc = XMLUtils.createDomDocument();
		Element documentElement = doc.createElement("Document");
		documentElement.appendChild(RequestUtils.getRequestInfoAsXML(doc, req, uriParser));
		documentElement.appendChild(this.moduleDescriptor.toXML(doc));
		
		XMLUtils.appendNewElement(doc, documentElement, "fullAlias", getFullAlias());
		XMLUtils.appendNewElement(doc, documentElement, "ModuleURI", req.getContextPath() + getFullAlias());
		XMLUtils.appendNewElement(doc, documentElement, "StaticContentURL", staticContentModule.getModuleContentURL(moduleDescriptor));

		doc.appendChild(documentElement);
		return doc;
	}

	@WebPublic(alias = "icon")
	public ForegroundModuleResponse getFlowIcon(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws URINotFoundException, AccessDeniedException, ModuleConfigurationException, SQLException, IOException {

		return flowAdminModule.getFlowIcon(req, res, user, uriParser);
	}

	@InstanceManagerDependency(required = true)
	public void setFlowAdminModule(FlowAdminModule flowAdminModule) {

		if (flowAdminModule == null && this.flowAdminModule != null) {

			this.flowAdminModule.removeExtensionViewProvider(this);
		}

		this.flowAdminModule = flowAdminModule;

		if (this.flowAdminModule != null) {

			this.flowAdminModule.addExtensionViewProvider(this);
		}
	}

	@InstanceManagerDependency
	public void setFlowInstanceAdminModule(FlowInstanceAdminModule flowInstanceAdminModule) {

		if (flowInstanceAdminModule != null) {

			flowInstanceAdminModule.addOverviewExtensionLinkProvider(this);

		} else if (this.flowInstanceAdminModule != null) {

			this.flowInstanceAdminModule.removeOverviewExtensionLinkProvider(this);
		}

		this.flowInstanceAdminModule = flowInstanceAdminModule;
	}

	private void generateOverviewExtensionLink(StaticContentModule staticContentModule) {

		if (staticContentModule != null) {

			overviewExtensionLink = new ExtensionLink(overviewExtensionLinkTitle, systemInterface.getContextPath() + this.getFullAlias(), staticContentModule.getModuleContentURL(moduleDescriptor) + "/pics/page_text_add.png", "top-right");

		} else {

			overviewExtensionLink = null;
		}
	}

	@InstanceManagerDependency(required = true)
	public void setStaticContentModule(StaticContentModule staticContentModule) {

		generateOverviewExtensionLink(staticContentModule);

		this.staticContentModule = staticContentModule;
	}

	@Override
	public AccessInterface getAccessInterface() {

		return moduleDescriptor;
	}

	@Override
	public ExtensionLink getExtensionLink(User user) {

		if (hasRequiredDependencies) {

			return overviewExtensionLink;
		}

		return null;
	}

	protected boolean hasAccess(User user, FlowFamily flowFamily, FlowFamilyAddInstanceSettings settings) {

		ManagerAccess access = flowFamily.getManagerAccess(user);
		
		if (access == ManagerAccess.FULL || (access == ManagerAccess.RESTRICTED && settings.isAllowRestrictedManagers())) {
			return true;
		}
		
		return false;
	}

	@Override
	public int getPriority() {

		return 0;
	}

	@Override
	public FlowAdminExtensionShowView getShowView(Flow flow, HttpServletRequest req, User user, URIParser uriParser) throws TransformerConfigurationException, TransformerException, SQLException {

		Document doc = createDocument(req, uriParser, user);

		Element showViewElement = doc.createElement("ShowSettings");
		doc.getDocumentElement().appendChild(showViewElement);

		showViewElement.appendChild(flow.toXML(doc));

		FlowFamilyAddInstanceSettings informerSettings = getSetting(flow.getFlowFamily());
		
		boolean enabled = false;
		
		if(informerSettings != null) {
		
			XMLUtils.append(doc, showViewElement, informerSettings);
			
			enabled = true;
		}

		return new FlowAdminExtensionShowView(viewFragmentTransformer.createViewFragment(doc, true), enabled);
	}

	@Override
	public String getExtensionViewTitle() {

		return adminExtensionViewTitle;
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse updateFlowSettings(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		Flow flow = flowAdminModule.getRequestedFlow(req, user, uriParser);

		if (flow == null) {

			return flowAdminModule.list(req, res, user, uriParser, new ValidationError("FlowNotFound"));

		} else if (!flowAdminModule.hasFlowAccess(user, flow)) {

			throw new AccessDeniedException("User does not have access to flow type " + flow.getFlowType());
		}

		FlowFamilyAddInstanceSettings setting = getSetting(flow.getFlowFamily());

		List<ValidationError> validationErrors = null;

		if (req.getMethod().equalsIgnoreCase("POST")) {

			validationErrors = new ArrayList<ValidationError>();

			if (setting == null) {

				setting = new FlowFamilyAddInstanceSettings();
			}

			try {
				POPULATOR.populate(setting, req);

				if (CollectionUtils.isEmpty(validationErrors)) {

					log.info("User " + user + " updated add flow instance as manager settings for flow " + flow);

					if (setting.isEmpty()) {

						if (setting.getFlowFamilyID() != null) {
							settingsDAO.delete(setting);
						}

					} else {

						if (setting.getFlowFamilyID() != null) {
							settingsDAO.update(setting);

						} else {

							setting.setFlowFamilyID(flow.getFlowFamily().getFlowFamilyID());
							settingsDAO.add(setting);
						}
					}

					flowAdminModule.redirectToMethod(req, res, "/showflow/" + flow.getFlowID() + "#addflowinstanceasmanagersettings");
					return null;
				}

			} catch (ValidationException e) {

				validationErrors.addAll(e.getErrors());
			}
		}

		log.info("User " + user + " requesting update add flow instance as manager settings form for flow " + flow);

		Document doc = createDocument(req, uriParser, user);

		Element settingsElement = doc.createElement("UpdateSettings");
		doc.getDocumentElement().appendChild(settingsElement);

		settingsElement.appendChild(flow.toXML(doc));

		XMLUtils.append(doc, settingsElement, setting);

		if (validationErrors != null) {

			XMLUtils.append(doc, settingsElement, "ValidationErrors", validationErrors);
			settingsElement.appendChild(RequestUtils.getRequestParameters(req, doc));
		}

		SimpleForegroundModuleResponse response = new SimpleForegroundModuleResponse(doc, this.getDefaultBreadcrumb());
		//		response.addScripts(updateScriptTags);

		return response;
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse deleteFlowSettings(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		if(!HTTPUtils.isPost(req)) {
			
			throw new AccessDeniedException("Delete flow settings requests using method " + req.getMethod() + " are not allowed.");
		}
		
		Flow flow = flowAdminModule.getRequestedFlow(req, user, uriParser);

		if (flow == null) {

			return flowAdminModule.list(req, res, user, uriParser, new ValidationError("FlowNotFound"));

		} else if (!flowAdminModule.hasFlowAccess(user, flow)) {

			throw new AccessDeniedException("User does not have access to flow type " + flow.getFlowType());
		}

		FlowFamilyAddInstanceSettings addInstanceSettings = getSetting(flow.getFlowFamily());

		if (addInstanceSettings != null) {

			log.info("User " + user + " deleting add flow instance as manager settings for flow " + flow);

			settingsDAO.delete(addInstanceSettings);

		} else {

			log.warn("User " + user + " trying to delete add flow instance as manager settings for flow " + flow + " which has no settings");
		}

		flowAdminModule.redirectToMethod(req, res, "/showflow/" + flow.getFlowID() + "#addflowinstanceasmanager");

		return null;
	}

	@Override
	public ForegroundModuleDescriptor getModuleDescriptor() {

		return moduleDescriptor;
	}

	@Override
	public List<LinkTag> getLinkTags() {

		return links;
	}

	@Override
	public List<ScriptTag> getScriptTags() {

		return scripts;
	}
	
	@Override
	public int getModuleID() {

		return moduleDescriptor.getModuleID();
	}
	
	@WebPublic(alias = "users")
	public ForegroundModuleResponse getUsers(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		if(this.flowInstanceAdminModule == null || !AccessUtils.checkAccess(user, flowInstanceAdminModule.getModuleDescriptor())) {
			
			throw new AccessDeniedException("User does not have access to list users via this module");
		}
		
		return userGroupListConnector.getUsers(req, res, user, uriParser);
	}
}
