<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl"/>
	
	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/js/confirmpost.js
		/tablesorter/js/jquery.tablesorter.min.js
	</xsl:variable>
	
	<xsl:variable name="scripts">
		/js/flowengine.tablesorter.js
		/js/flowengine.tablefilter.js
		/js/flowengine.js?v=1
		/js/addflowinstanceasmanager.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css
		/css/UserGroupList.css?v=1
	</xsl:variable>

	<xsl:template match="Document">
		
		<xsl:choose>
			<xsl:when test="ListFamilies">
			
				<div id="FlowBrowser" class="contentitem errands-wrapper">
					<xsl:apply-templates select="ListFamilies" />
				</div>
			
			</xsl:when>
			<xsl:when test="ShowSettings or UpdateSettings">
				
				<xsl:apply-templates select="ShowSettings" />
				<xsl:apply-templates select="UpdateSettings" />
			
			</xsl:when>
			<xsl:otherwise>
			
				<xsl:if test="ChoosePoster/Added or ChoosePoster/Saved">
				
					<div class="contentitem">
				
						<xsl:if test="ChoosePoster/Added">
							<section class="modal success">
								<span data-icon-before="c">
									<xsl:value-of select="$i18n.FlowInstanceSubmitted.1" />
									<xsl:text> </xsl:text>
									<xsl:value-of select="ChoosePoster/Added"/>
									<xsl:text> </xsl:text>
									<xsl:value-of select="$i18n.FlowInstanceSubmitted.2" />
								</span>
								<i class="icon close">x</i>
							</section>
						</xsl:if>
						
						<xsl:if test="ChoosePoster/Saved">
							<section class="modal success">
								<span data-icon-before="c">
									<xsl:value-of select="$i18n.FlowInstanceSaved" />
								</span>
								<i class="icon close">x</i>
							</section>
						</xsl:if>
						
					</div>
				</xsl:if>
			
				<div class="contentitem errands-wrapper">
					<xsl:apply-templates select="ChoosePoster" />
				</div>
			
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="ShowSettings">
	
		<a name="addflowinstanceasmanagersettings" />
		
		<xsl:choose>
			<xsl:when test="Settings">
				<xsl:value-of select="$i18n.UsesManagerAddFlowInstances" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$i18n.NoSettings" />
			</xsl:otherwise>
		</xsl:choose>
		
		<a href="{/Document/ModuleURI}/updateflowsettings/{Flow/flowID}" class="floatright">
			<xsl:value-of select="$i18n.UpdateSettings" />
			<img class="marginleft vertical-align-sub" src="{/Document/StaticContentURL}/pics/pen.png" alt="" />
		</a>
		
		<xsl:if test="Settings">
			<a href="{/Document/ModuleURI}/deleteflowsettings/{Flow/flowID}" class="floatright clearboth" onclick="return confirmPost(this.href, '{$i18n.DeleteSettings.Confirm}');">
				<xsl:value-of select="$i18n.DeleteSettings" />
				<img class="marginleft vertical-align-sub" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
			</a>
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="UpdateSettings">
		
		<div id="AddFlowInstanceAsManager" class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.UpdateSettings.Title"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
			</h1>
	
			<xsl:apply-templates select="ValidationErrors/validationError"/>
	
			<p>
				<xsl:value-of select="$i18n.UpdateSettings.description" />
			</p>
	
			<form method="post" action="{/Document/ModuleURI}/updateflowsettings/{Flow/flowID}">
				
				<fieldset>
					<legend> <xsl:value-of select="$i18n.Settings.AnonymousBased" /></legend>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'allowAnonymous'" />
								<xsl:with-param name="name" select="'allowAnonymous'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="allowAnonymous">
								<xsl:value-of select="$i18n.Settings.allowAnonymous" />
							</label>
						</div>
		
					</div>
				</fieldset>
				
				<fieldset>
					<legend> <xsl:value-of select="$i18n.Settings.UsernameBased" /></legend>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'allowInternalUsers'" />
								<xsl:with-param name="name" select="'allowInternalUsers'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="allowInternalUsers">
								<xsl:value-of select="$i18n.Settings.allowInternalUsers" />
							</label>
						</div>
		
					</div>
					
				</fieldset>
				
				<fieldset>
					<legend> <xsl:value-of select="$i18n.Settings.CitizenIDBased" /></legend>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'allowExistingUsers'" />
								<xsl:with-param name="name" select="'allowExistingUsers'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="allowExistingUsers">
								<xsl:value-of select="$i18n.Settings.allowExistingUsers" />
							</label>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'allowCreatingUsers'" />
								<xsl:with-param name="name" select="'allowCreatingUsers'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="allowCreatingUsers">
								<xsl:value-of select="$i18n.Settings.allowCreatingUsers" />
							</label>
						</div>
		
					</div>
					
				</fieldset>
				
				<fieldset>
					<legend> <xsl:value-of select="$i18n.Settings.Other" /></legend>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'allowRestrictedManagers'" />
								<xsl:with-param name="name" select="'allowRestrictedManagers'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="allowRestrictedManagers">
								<xsl:value-of select="$i18n.Settings.allowRestrictedManagers" />
							</label>
						</div>
		
					</div>
					
				</fieldset>
				
				<fieldset>
					<legend> <xsl:value-of select="$i18n.Settings.version" /></legend>
					
					<div class="floatleft full bigmarginbottom">
						<div class="floatleft full">
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'requirePublishedFlowFalse'" />
								<xsl:with-param name="name" select="'requirePublishedFlow'" />
								<xsl:with-param name="value" select="'false'" />
								<xsl:with-param name="element" select="Settings" />
								<xsl:with-param name="checked" select="'true'"/>
							</xsl:call-template>
							
							<label for="requirePublishedFlowFalse">
								<xsl:value-of select="$i18n.Settings.useLatestEnabledFlow" />
							</label>
						</div>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<div class="floatleft full">
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'requirePublishedFlowTrue'" />
								<xsl:with-param name="name" select="'requirePublishedFlow'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="requirePublishedFlowTrue">
								<xsl:value-of select="$i18n.Settings.useLatestEnabledAndPublishedFlow" />
							</label>
						</div>
					</div>
					
				</fieldset>				
				
				<fieldset>
					<legend> <xsl:value-of select="$i18n.Settings.Notifications" /></legend>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'suppressSubmittedUserSubmitNotification'" />
								<xsl:with-param name="name" select="'suppressSubmittedUserSubmitNotification'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="suppressSubmittedUserSubmitNotification">
								<xsl:value-of select="$i18n.Settings.suppressSubmittedUserSubmitNotification" />
							</label>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'suppressManagersSubmitNotification'" />
								<xsl:with-param name="name" select="'suppressManagersSubmitNotification'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="suppressManagersSubmitNotification">
								<xsl:value-of select="$i18n.Settings.suppressManagersSubmitNotification" />
							</label>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'suppressArchiveNotification'" />
								<xsl:with-param name="name" select="'suppressArchiveNotification'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
							
							<label for="suppressArchiveNotification">
								<xsl:value-of select="$i18n.Settings.suppressArchiveNotification" />
							</label>
						</div>
		
					</div>
					
				</fieldset>
				
				<div class="floatright clearboth bigmargintop">
					<input type="submit" value="{$i18n.SaveChanges}" />
				</div>
			
			</form>
		
		</div>

	</xsl:template>

	<xsl:template match="ListFamilies">
	
		<div class="floatright marginbottom">
			<label for="name" class="marginright margintop"><xsl:value-of select="$i18n.Filter" />:</label>
			<input type="text" size="20" name="filter-input" class="filter-input" data-tableid="flowlist" /> 
		</div>
	
		<h1><xsl:value-of select="$i18n.Flowslist.title" /></h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<p>
			<xsl:value-of select="$i18n.Flowlist.description" />
		</p>
		
		<table id="flowlist" class="full coloredtable oep-table" cellspacing="0">
			<thead class="sortable">	
				<tr>
					<th width="25" class="no-sort"></th>
					<th class="default-sort"><xsl:value-of select="$i18n.flowName" /></th>
					<th><xsl:value-of select="$i18n.flowType" /></th>
					<th><xsl:value-of select="$i18n.versions" /></th>
					<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
					<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
				</tr>
			</thead>
			<tbody>
				<xsl:choose>
					<xsl:when test="not(Flow)">
						<tr>
							<td class="icon"></td>
							<td colspan="7">
								<xsl:value-of select="$i18n.noFlowsFound" />
							</td>
						</tr>
					</xsl:when>
					<xsl:otherwise>
						
						<xsl:apply-templates select="Flow" mode="list"/>
						
					</xsl:otherwise>
				</xsl:choose>
			</tbody>
		</table>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list">
		
		<tr>
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td data-title="{$i18n.flowName}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add/{FlowFamily/flowFamilyID}"><xsl:value-of select="name" /></a>
			</td>
			<td data-title="{$i18n.flowType}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add/{FlowFamily/flowFamilyID}"><xsl:value-of select="FlowType/name" /></a>
			</td>
			<td data-title="{$i18n.versions}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add/{FlowFamily/flowFamilyID}"><xsl:value-of select="VersionCount" /></a>
			</td>
			<td data-title="{$i18n.SubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add/{FlowFamily/flowFamilyID}"><xsl:value-of select="SubmittedInstanceCount" /></a>
			</td>
			<td data-title="{$i18n.NotSubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add/{FlowFamily/flowFamilyID}"><xsl:value-of select="InstanceCount - SubmittedInstanceCount" /></a>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ChoosePoster">
	
		<h1>
			<xsl:value-of select="$i18n.Add.title" />
			<xsl:text>: </xsl:text>
			<xsl:value-of select="Flow/name" />
		</h1>
		
		<xsl:apply-templates select="ValidationErrors/validationError"/>
		
		<form name="chooseposter" method="POST" action="{/Document/requestinfo/uri}">
		
			<xsl:call-template name="ChoosePosterFormExtra" />
		
			<xsl:if test="PossibleUserTypes > 1">
				
				<label class="floatleft full">
					<xsl:value-of select="$i18n.Add.description" />
				</label>
				
				<xsl:if test="Settings/allowAnonymous = 'true'">
					<div class="floatleft full">
						
						<div class="floatleft full">
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'anonymous'"/>
								<xsl:with-param name="name" select="'userType'"/>
								<xsl:with-param name="value" select="'ANONYMOUS'"/>
							</xsl:call-template>
							
							<label for="anonymous">
								<xsl:value-of select="$i18n.Add.Anonymous" />
							</label>
						</div>
					</div>
				</xsl:if>
				
				<xsl:if test="Settings/allowInternalUsers = 'true'">
					<div class="floatleft full">
						
						<div class="floatleft full">
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'typeUsername'"/>
								<xsl:with-param name="name" select="'userType'"/>
								<xsl:with-param name="value" select="'USERNAME'"/>
							</xsl:call-template>
							
							<label for="typeUsername">
								<xsl:value-of select="$i18n.Add.NotAnonymous" />
								
								<xsl:if test="Settings/allowExistingUsers = 'true' or Settings/allowCreatingUsers = 'true'">
									<xsl:value-of select="$i18n.Add.UserByUsername" />
								</xsl:if>
							</label>
						</div>
					</div>
				</xsl:if>
				
				<xsl:if test="Settings/allowExistingUsers = 'true' or Settings/allowCreatingUsers = 'true'">
					<div class="floatleft full">
						
						<div class="floatleft full">
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'typeCitizenID'"/>
								<xsl:with-param name="name" select="'userType'"/>
								<xsl:with-param name="value" select="'CITIZENID'"/>
							</xsl:call-template>
							
							<label for="typeCitizenID">
								<xsl:value-of select="$i18n.Add.NotAnonymous" />
								
								<xsl:if test="Settings/allowInternalUsers = 'true'">
									<xsl:value-of select="$i18n.Add.UserByCitizenID" />
								</xsl:if>
							</label>
						</div>
					</div>
				</xsl:if>
				
				<xsl:if test="Settings/allowExistingUsers = 'true' or Settings/allowCreatingUsers = 'true'">
					<script type="text/javascript">
						$(function() {
							
							var showHideCitizenID = function() {
								var useCitizenID = $("input[name='userType']:checked").val() == "CITIZENID";
								$("#citizenID").attr("disabled", !useCitizenID).parent().toggle(useCitizenID);
							};
							
							showHideCitizenID();
							$("input[name='userType']").on("change", showHideCitizenID);
						});
					</script>
				</xsl:if>
				
				<xsl:if test="Settings/allowInternalUsers = 'true'">
					<script type="text/javascript">
						$(function() {
							
							var showHideUsername = function() {
								var userUsername = $("input[name='userType']:checked").val() == "USERNAME";
								$("#username").attr("disabled", !userUsername).parent().toggle(userUsername);
							};
							
							showHideUsername();
							$("input[name='userType']").on("change", showHideUsername);
						});
					</script>
				</xsl:if>
				
				<div class="bigmarginbottom" />
				
			</xsl:if>
			
			<xsl:if test="Settings/allowExistingUsers = 'true' or Settings/allowCreatingUsers = 'true'">
				
				<div class="floatleft full">
					
					<label for="citizenID">
						<xsl:value-of select="$i18n.Add.citizenID" />
					</label>
					
					<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'citizenID'" />
							<xsl:with-param name="id" select="'citizenID'" />
					</xsl:call-template>
				</div>
				
			</xsl:if>
			
			<xsl:if test="Settings/allowInternalUsers = 'true'">
				
				<div class="floatleft full">
					
					<label for="username">
						<xsl:value-of select="$i18n.Add.username" />
					</label>
					
					<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'username'" />
							<xsl:with-param name="id" select="'username'" />
					</xsl:call-template>
					
					<input name="connectorURL" disabled="true" hidden="true" value="{/Document/requestinfo/currentURI}/{/Document/module/alias}/users"/>
				</div>
				
			</xsl:if>
			
			<div class="clearboth floatright marginright bigmargintop">
				
				<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}" title="{$i18n.Back}">
					<xsl:value-of select="$i18n.Back"/>
				</a>
				
				<input class="btn btn-green btn-inline" type="submit" value="{$i18n.Add}" title="{$i18n.Add}"/>
			</div>
		
		</form>
		
	</xsl:template>
	
	<xsl:template name="ChoosePosterFormExtra"/>
	
	<xsl:template match="validationError[messageKey='UserNotFoundByCitizenID']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.UserNotFoundByCitizenID"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='UserNotFoundByUsername']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.UserNotFoundByUsername"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='UserFound']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.UserFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoEnabledFlows']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.NoEnabledFlows"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoPublishedFlows']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.NoPublishedFlows"/>
		</p>
	</xsl:template>	
	
	<xsl:template match="validationError[messageKey='FlowFamilyNotFound']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.FlowFamilyNotFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyAccessDenied']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.FlowFamilyAccessDenied"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError">
	
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="fieldName = 'userType'">
						<xsl:value-of select="$i18n.Add.description"/>
					</xsl:when>
					<xsl:when test="fieldName = 'citizenID'">
						<xsl:value-of select="$i18n.Add.citizenID"/>
					</xsl:when>
					<xsl:when test="fieldName = 'username'">
						<xsl:value-of select="$i18n.Add.username"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="fieldName" mode="common" />!
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="fieldName" mode="common">
		<xsl:value-of select="." />
	</xsl:template>
	
</xsl:stylesheet>