<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-migrate.js?v=1
	</xsl:variable>

	<xsl:variable name="scripts">
		/js/jquery.blockui.js
		/js/flowengine.helpdialog.js
		/js/flowengine.js?v=1
		/js/flowengine.step-navigator.js
		/js/jquery.expander.min.js
		/js/flowinstancebrowser.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css
	</xsl:variable>

	<xsl:template match="Document">
		
		<div id="FlowBrowser" class="contentitem">
			<xsl:apply-templates select="FlowInstanceManagerForm"/>
			<xsl:apply-templates select="FlowInstanceManagerPreview"/>
			<xsl:apply-templates select="SigningForm"/>
			<xsl:apply-templates select="MultiSigningStatusForm"/>
			<xsl:apply-templates select="ShowErrors"/>
		</div>
		
	</xsl:template>
	
	<xsl:template match="ShowErrors">
		
		<xsl:apply-templates select="validationError" />
		
	</xsl:template>
	
	<xsl:template match="FlowInstanceManagerForm">
	
		<xsl:if test="FlowInstance/Status/contentType != 'NEW'">
			<xsl:call-template name="showFlowInstanceControlPanel">
				<xsl:with-param name="flowInstance" select="FlowInstance" />
				<xsl:with-param name="view" select="'FLOWINSTANCE'" />
			</xsl:call-template>
		</xsl:if>
	
		<xsl:apply-imports/>
	
	</xsl:template>
	
	<xsl:template match="FlowInstanceManagerPreview">
	
		<xsl:if test="FlowInstance/Status/contentType != 'NEW'">
			<xsl:call-template name="showFlowInstanceControlPanel">
				<xsl:with-param name="flowInstance" select="FlowInstance" />
				<xsl:with-param name="view" select="'FLOWINSTANCE'" />
			</xsl:call-template>
		</xsl:if>
	
		<xsl:apply-imports/>
	
	</xsl:template>
	
	<xsl:template name="createFlowInstanceManagerFormHeader">
		
		<xsl:param name="showSaveButton" select="'true'"/>
		
		<div class="section-inside step">
			<div class="heading-wrapper">
				<div class="inner">
					<figure>
 						<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{FlowInstance/Flow/flowID}?{FlowInstance/Flow/IconLastModified}" alt="" />
	 				</figure>
	 				<div class="heading">
						<h1 class="xl"><xsl:value-of select="FlowInstance/Flow/name"/></h1>
					</div>
				</div>
			</div>
		</div>
		
		<xsl:if test="loggedIn and $showSaveButton = 'true'">
			<div class="aside-inside step hide-mobile hide-tablet">
				<div class="section yellow">
					<div class="inner" style="padding-right: 275px">
						<xsl:value-of select="$i18n.SaveBoxDescription" />
						<a class="btn btn-green btn-inline xl" id="save_errand" href="#" onclick="if(confirm('{$i18n.SaveAndClose.confirm}')) submitStep('save-close', event);"><xsl:value-of select="$i18n.SaveAndClose" /></a>
					</div>
				</div>
			</div>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template name="createFlowInstanceManagerPreviewHeader">
	
		<xsl:param name="showSaveButton" select="'true'"/>
		<xsl:param name="showFlowInstanceID" select="'true'"/>
	
		<div class="section-inside step">
			<div class="heading-wrapper">
				<div class="inner">
					<figure>
 						<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{FlowInstance/Flow/flowID}?{FlowInstance/Flow/IconLastModified}" alt="" />
	 				</figure>
	 				<div class="heading">
						<h1 class="xl"><xsl:value-of select="FlowInstance/Flow/name"/></h1>
						<xsl:if test="$showFlowInstanceID = 'true' and FlowInstance/flowInstanceID and FlowInstance/firstSubmitted">
							<span class="errandno"><xsl:value-of select="$i18n.FlowInstanceID" /><xsl:text>:&#160;</xsl:text><xsl:value-of select="FlowInstance/flowInstanceID" /></span>
						</xsl:if>
					</div>
				</div>
			</div>
		</div>
		
		<xsl:if test="loggedIn and $showSaveButton = 'true'">
			<div class="aside-inside step hide-mobile hide-tablet">
				<div class="section yellow">
					<div class="inner">
						<xsl:value-of select="$i18n.SaveBoxDescription" />
						<a class="btn btn-green btn-inline xl" id="save_errand" href="#" onclick="if(confirm('{$i18n.SaveAndClose.confirm}')) submitStep('save-close', event);"><xsl:value-of select="$i18n.SaveAndClose" /></a>
					</div>
				</div>
			</div>
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template name="createMobileSavePanel">
		
		<div class="panel-wrapper yellow hide-desktop">
	 		<div class="inner">
	 			<div class="current-step" style="margin-right: 115px;">
	 				<xsl:value-of select="$i18n.ShortSaveBoxDescription" />
	 			</div>
	 			<div class="buttons">
	 				<a class="btn btn-green" data-action="save_errand" href="#" onclick="if(confirm('{$i18n.SaveAndClose.confirm}')) submitStep('save-close', event);"><xsl:value-of select="$i18n.SaveAndClose" /></a>
	 			</div>
	 		</div>
	 	</div>
		
	</xsl:template>
	
	<xsl:template name="FlowInstanceManagerFormFollower">
	 	
	 	<xsl:param name="currentStepID"/>
		<xsl:param name="totalStepCount"/>
	
		<div class="panel-wrapper follow" style="display: none">
	 		<div class="inner">
	 			<div class="current-step" data-step="1">
	 				<xsl:value-of select="$i18n.StepDescription.Part1" />
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="ManagerResponse/currentStepIndex + 1" />
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="$i18n.StepDescription.Part2" />
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="$totalStepCount" />
					<xsl:text>:&#160;</xsl:text>
					<xsl:value-of select="FlowInstance/Flow/Steps/Step[stepID = $currentStepID]/name" />
	 			</div>
	 			<div class="buttons">
	 				<a href="#" class="btn btn-green" onclick="if(confirm('{$i18n.SaveAndClose.confirm}')) submitStep('save-close', event);"><xsl:value-of select="$i18n.SaveAndClose" /></a>
	 			</div>
	 		</div>
	 	</div>
	
	</xsl:template>
	
</xsl:stylesheet>