package com.nordicpeak.flowengine.evaluators.agequerystateevaluator;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationErrorType;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;

import com.nordicpeak.flowengine.evaluators.basequerystateevaluator.BaseQueryStateEvaluationCRUD;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.queries.textfieldquery.TextField;
import com.nordicpeak.flowengine.queries.textfieldquery.TextFieldQuery;

public class AgeQueryStateEvaluatorCRUD extends BaseQueryStateEvaluationCRUD<AgeQueryStateEvaluator, AgeQueryStateEvaluationProviderModule> {
	
	
	private static final AnnotatedRequestPopulator<AgeQueryStateEvaluator> POPULATOR = new AnnotatedRequestPopulator<AgeQueryStateEvaluator>(AgeQueryStateEvaluator.class);
	
	public AgeQueryStateEvaluatorCRUD(Class<AgeQueryStateEvaluator> beanClass, AnnotatedDAOWrapper<AgeQueryStateEvaluator, Integer> evaluatorDAO, AgeQueryStateEvaluationProviderModule callback) {
		
		super(beanClass, evaluatorDAO, POPULATOR, "AgeQueryStateEvaluator", "age query state evaluator", null, callback);
	}
	
	@Override
	protected AgeQueryStateEvaluator populateFromUpdateRequest(AgeQueryStateEvaluator bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {
		
		AgeQueryStateEvaluator evaluator = super.populateFromUpdateRequest(bean, req, user, uriParser);
		
		return evaluator;
	}
	
	@Override
	protected void appendUpdateFormData(AgeQueryStateEvaluator bean, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {
		
		super.appendUpdateFormData(bean, doc, updateTypeElement, user, req, uriParser);
		
		Query query = callback.getQueryHandler().getQuery((MutableQueryDescriptor) bean.getEvaluatorDescriptor().getQueryDescriptor(), false);
		
		if (query instanceof TextFieldQuery) {
			
			TextFieldQuery textFieldQuery = (TextFieldQuery) query;
			
			Element fieldsElement = doc.createElement("TextFields");
			updateTypeElement.appendChild(fieldsElement);
			
			List<TextField> fields = textFieldQuery.getFields();
			
			if (fields != null) {
				
				for (TextField field : fields) {
					
					Element fieldElement = doc.createElement("TextField");
					fieldsElement.appendChild(fieldElement);
					
					XMLUtils.appendNewElement(doc, fieldElement, "fieldID", field.getTextFieldID());
					XMLUtils.appendNewCDATAElement(doc, fieldElement, "name", field.getLabel());
				}
				
			}
		}
	}
	
	@Override
	protected void validateUpdatePopulation(AgeQueryStateEvaluator bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, SQLException, Exception {
		
		List<ValidationError> errors = new ArrayList<ValidationError>();
		
		if (bean.getFromValue() != null && bean.getToValue() != null && bean.getFromValue() > bean.getToValue()) {
			
			errors.add(new ValidationError("FromValueBiggerThanToValue"));
		}
		
		Query query = callback.getQueryHandler().getQuery((MutableQueryDescriptor) bean.getEvaluatorDescriptor().getQueryDescriptor(), false);
		
		if (query instanceof TextFieldQuery) {
			
			Integer textFieldID = bean.getTextFieldID();
			
			if (textFieldID == null) {
				
				errors.add(new ValidationError("textFieldID", ValidationErrorType.RequiredField));
				
			} else {
				
				boolean found = false;
				
				TextFieldQuery textFieldQuery = (TextFieldQuery) query;
				
				if (textFieldQuery.getFields() != null) {
					
					for (TextField field : textFieldQuery.getFields()) {
						
						if (field.getTextFieldID().equals(textFieldID)) {
							
							found = true;
						}
					}
					
				}
				
				if (!found) {
					
					errors.add(new ValidationError("TextFieldNotFound"));
				}
			}
		}
		
		if (!errors.isEmpty()) {
			
			throw new ValidationException(errors);
		}
		
	}
	
}
