package com.nordicpeak.flowengine.queries.alternativelistpriorityquery;

import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListInstance;
import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListQuery;
import com.nordicpeak.flowengine.annotations.TextTagReplace;
import com.nordicpeak.flowengine.interfaces.ExportAlternativeID;
import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesBaseQuery;

@Table(name = "alternative_list_priority_queries")
@XMLElement
public class AlternativeListPriorityQuery extends FixedAlternativesBaseQuery implements AlternativeListQuery,ExportAlternativeID {
	
	private static final long serialVersionUID = -842191226937409416L;
	
	@DAOManaged
	@Key
	@XMLElement
	private Integer queryID;
	
	@TextTagReplace
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String shortDescription;
	
	@DAOManaged
	@WebPopulate(maxLength = 255, required = true)
	@XMLElement
	private String listName;
	
	@TextTagReplace
	@DAOManaged
	@WebPopulate(maxLength = 65535)
	@XMLElement
	private String emptyListDescription;
	
	@WebPopulate(required = true)
	@DAOManaged
	@XMLElement
	private Integer minChoices;
	
	@WebPopulate(required = true)
	@DAOManaged
	@XMLElement
	private Integer maxChoices;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean setAsAttribute;
	
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "setAsAttribute")
	@XMLElement
	private String attributeName;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean exportAlternativeID;
	
	@DAOManaged
	@OneToMany
	@XMLElement
	private List<AlternativeListPriorityQueryInstance> instances;
	
	private AlternativeListInstance alternativeList;
	
	@Override
	public Integer getQueryID() {
		
		return queryID;
	}
	
	@Override
	public List<? extends ImmutableAlternative> getAlternatives() {
		
		if (alternativeList != null) {
			
			return alternativeList.getAlternatives();
		}
		
		return null;
	}
	
	public String getListName() {
		return listName;
	}
	
	public void setListName(String listIdentifier) {
		this.listName = listIdentifier;
	}
	
	public AlternativeListInstance getAlternativeList() {
		return alternativeList;
	}
	
	public void setAlternativeList(AlternativeListInstance alternativeList) {
		this.alternativeList = alternativeList;
	}
	
	public Integer getMinChoices() {
		
		return minChoices;
	}
	
	public void setMinChoices(Integer minChoices) {
		
		this.minChoices = minChoices;
	}
	
	public Integer getMaxChoices() {
		
		return maxChoices;
	}
	
	public void setMaxChoices(Integer maxChoices) {
		
		this.maxChoices = maxChoices;
	}
	
	public List<AlternativeListPriorityQueryInstance> getInstances() {
		
		return instances;
	}
	
	public void setInstances(List<AlternativeListPriorityQueryInstance> instances) {
		
		this.instances = instances;
	}
	
	public void setQueryID(int queryID) {
		
		this.queryID = queryID;
	}
	
	public String getShortDescription() {
		
		return shortDescription;
	}
	
	public void setShortDescription(String shortDescription) {
		
		this.shortDescription = shortDescription;
	}
	
	@Override
	public String toString() {
		
		if (this.queryDescriptor != null) {
			
			return queryDescriptor.getName() + " (queryID: " + queryID + ")";
		}
		
		return getClass().getSimpleName() + " (queryID: " + queryID + ")";
	}
	
	@Override
	public String getXSDTypeName() {
		
		return "AlternativeListPriorityQuery" + queryID;
	}
	
	@Override
	public void toXSD(Document doc) {
		
		toXSD(doc, minChoices, maxChoices);
	}
	
	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {
		
		List<ValidationError> errors = new ArrayList<>();
		
		shortDescription = XMLValidationUtils.validateParameter("shortDescription", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		description = XMLValidationUtils.validateParameter("description", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		minChoices = XMLValidationUtils.validateParameter("minChoices", xmlParser, false, 1, 255, IntegerPopulator.getPopulator(), errors);
		maxChoices = XMLValidationUtils.validateParameter("maxChoices", xmlParser, false, 1, 255, IntegerPopulator.getPopulator(), errors);
		listName = XMLValidationUtils.validateParameter("listName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		emptyListDescription = XMLValidationUtils.validateParameter("emptyListDescription", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		
		attributeName = XMLValidationUtils.validateParameter("attributeName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		
		if (attributeName != null) {
			
			setAsAttribute = xmlParser.getPrimitiveBoolean("setAsAttribute");
		}
		
		exportAlternativeID  = xmlParser.getPrimitiveBoolean("exportAlternativeID");
		
		if (!errors.isEmpty()) {
			
			throw new ValidationException(errors);
		}
		
	}
	
	@Override
	public Element toXML(Document doc) {
		
		Element element = super.toXML(doc);
		
		if (alternativeList != null) {
			
			//TODO don't append alternatives on export
			XMLUtils.append(doc, element, "Alternatives", alternativeList.getAlternatives());
		}
		
		return element;
	}
	
	@Override
	public String getFreeTextAlternative() {
		
		return null;
	}
	
	public boolean isSetAsAttribute() {
		
		return setAsAttribute;
	}
	
	public void setSetAsAttribute(boolean setAsAttribute) {
		
		this.setAsAttribute = setAsAttribute;
	}
	
	public String getAttributeName() {
		
		return attributeName;
	}
	
	public void setAttributeName(String attributeName) {
		
		this.attributeName = attributeName;
	}
	
	@Override
	public boolean isExportAlternativeID() {
		
		return exportAlternativeID;
	}

	
	public void setExportAlternativeID(boolean exportAlternativeID) {
	
		this.exportAlternativeID = exportAlternativeID;
	}
	
	@Override
	public String getAlternativeListName() {
		return listName;
	}
	
}
