package com.nordicpeak.flowengine.queries.alternativelistpriorityquery;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.alternativelist.beans.AlternativeListDescriptor;
import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListProvider;
import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUD;

public class AlternativeListPriorityQueryCRUD extends BaseQueryCRUD<AlternativeListPriorityQuery, AlternativeListPriorityQueryProviderModule> {
	
	
	protected AnnotatedDAOWrapper<AlternativeListPriorityQuery, Integer> queryDAO;
	
	public AlternativeListPriorityQueryCRUD(AnnotatedDAOWrapper<AlternativeListPriorityQuery, Integer> queryDAO, BeanRequestPopulator<AlternativeListPriorityQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, AlternativeListPriorityQueryProviderModule callback) {
		
		super(AlternativeListPriorityQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);
		
		this.queryDAO = queryDAO;
	}
	
	@Override
	protected void appendUpdateFormData(AlternativeListPriorityQuery query, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {
		
		super.appendUpdateFormData(query, doc, updateTypeElement, user, req, uriParser);
		
		Element listsElement = XMLUtils.appendNewElement(doc, updateTypeElement, "Lists");
		
		for (AlternativeListDescriptor list : callback.getAlternativeLists()) {
			
			AlternativeListProvider provider = callback.getAlternativeListProvider(list.getProviderID());
			
			Element providerElement = XMLUtils.appendNewElement(doc, listsElement, "List");
			
			XMLUtils.appendNewElement(doc, providerElement, "Name", provider.getProviderName() + ": " + list.getName());
			XMLUtils.appendNewElement(doc, providerElement, "ID", list.getName());
		}
		
		AlternativeListDescriptor currentListDescriptor = callback.getAlternativeListDescriptor(query);
		
		if (currentListDescriptor != null) {
			
			XMLUtils.appendNewElement(doc, updateTypeElement, "CurrentList", currentListDescriptor.getName());
			
		} else if (!StringUtils.isEmpty(query.getListName())) {
			
			Element providerElement = XMLUtils.appendNewElement(doc, listsElement, "List");
			
			XMLUtils.appendNewElement(doc, providerElement, "Name", callback.getMissingAlternativeList() + query.getListName());
			XMLUtils.appendNewElement(doc, providerElement, "ID", query.getListName());
		}
	}
	
	@Override
	protected AlternativeListPriorityQuery populateFromUpdateRequest(AlternativeListPriorityQuery oldQuery, HttpServletRequest req, User user, URIParser uriParser) throws Exception {
		
		AlternativeListPriorityQuery query = super.populateFromUpdateRequest(oldQuery, req, user, uriParser);
		
		List<ValidationError> validationErrors = new ArrayList<>();
		
		populateQueryDescriptor((QueryDescriptor) query.getQueryDescriptor(), req, validationErrors);
		
		Integer minChoices = query.getMinChoices();
		Integer maxChoices = query.getMaxChoices();
		
		if (minChoices < 1) {
			validationErrors.add(new ValidationError("MinChoicesTooSmall"));
		}
		
		if (minChoices != null && maxChoices != null && (minChoices > maxChoices)) {
			validationErrors.add(new ValidationError("MinChoicesBiggerThanMaxChoices"));
		}
		
		if(maxChoices != null && maxChoices > 255) {
			validationErrors.add(new ValidationError("MaxChoicesOutOfRange"));
		}
		
		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}
		
		return query;
	}
	
}
