package com.nordicpeak.flowengine.queries.alternativelistpriorityquery;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.hierarchy.core.utils.FCKUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.MySQLRowLimiter;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.RelationQuery;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.dao.querys.ArrayListQuery;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationErrorType;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.url.URLRewriter;

import com.nordicpeak.flowengine.alternativelist.AlternativeListHandlerModule;
import com.nordicpeak.flowengine.alternativelist.beans.AlternativeListDescriptor;
import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListInstance;
import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListProvider;
import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListQuery;
import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListQueryProvider;
import com.nordicpeak.flowengine.beans.Flow;
import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.beans.QueryResponse;
import com.nordicpeak.flowengine.beans.Step;
import com.nordicpeak.flowengine.dao.FlowEngineDAOFactory;
import com.nordicpeak.flowengine.enums.QueryState;
import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryInstance;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.MutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryContentFilter;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUDCallback;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryProviderModule;
import com.nordicpeak.flowengine.queries.checkboxquery.validationerrors.TooFewAlternativesSelectedValidationError;
import com.nordicpeak.flowengine.queries.checkboxquery.validationerrors.TooManyAlternativesSelectedValidationError;
import com.nordicpeak.flowengine.utils.JTidyUtils;
import com.nordicpeak.flowengine.utils.TextTagReplacer;

public class AlternativeListPriorityQueryProviderModule extends BaseQueryProviderModule<AlternativeListPriorityQueryInstance> implements BaseQueryCRUDCallback, AlternativeListQueryProvider {
	
	
	@XSLVariable(prefix = "java.")
	private String missingList = "Missing";
	
	@XSLVariable(prefix = "java.")
	private String countText = "Count";
	
	@XSLVariable(prefix = "java.")
	private String alternativesText = "Alternative";
	
	private AnnotatedDAO<AlternativeListPriorityQuery> queryDAO;
	private AnnotatedDAO<AlternativeListPriorityQueryInstance> queryInstanceDAO;
	private AnnotatedDAOWrapper<QueryDescriptor, Integer> queryDescriptorDAOWrapper;
	
	private AlternativeListPriorityQueryCRUD queryCRUD;
	
	private QueryParameterFactory<AlternativeListPriorityQuery, Integer> queryIDParamFactory;
	private QueryParameterFactory<AlternativeListPriorityQuery, String> listNameParamFactory;
	private QueryParameterFactory<AlternativeListPriorityQueryInstance, Integer> queryInstanceIDParamFactory;
	
	@InstanceManagerDependency(required = true)
	private AlternativeListHandlerModule alternativeListHandlerModule;
	
	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {
		
		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, AlternativeListPriorityQueryProviderModule.class.getName(), new XMLDBScriptProvider(AlternativeListPriorityQueryProviderModule.class.getResourceAsStream("DB script.xml")));
		
		if (upgradeResult.isUpgrade()) {
			
			log.info(upgradeResult.toString());
		}
		
		SimpleAnnotatedDAOFactory daoFactory = new SimpleAnnotatedDAOFactory(dataSource);
		
		queryDAO = daoFactory.getDAO(AlternativeListPriorityQuery.class);
		queryInstanceDAO = daoFactory.getDAO(AlternativeListPriorityQueryInstance.class);
		
		queryCRUD = new AlternativeListPriorityQueryCRUD(queryDAO.getWrapper(Integer.class), new AnnotatedRequestPopulator<>(AlternativeListPriorityQuery.class), AlternativeListPriorityQuery.class.getSimpleName(), "query", null, this);
		
		queryIDParamFactory = queryDAO.getParamFactory("queryID", Integer.class);
		listNameParamFactory = queryDAO.getParamFactory("listName", String.class);
		queryInstanceIDParamFactory = queryInstanceDAO.getParamFactory("queryInstanceID", Integer.class);
		
		FlowEngineDAOFactory flowDAOFactory = new FlowEngineDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler());
		
		queryDescriptorDAOWrapper = flowDAOFactory.getQueryDescriptorDAO().getWrapper(Integer.class);
		queryDescriptorDAOWrapper.addRelations(QueryDescriptor.STEP_RELATION, Step.FLOW_RELATION, Flow.FLOW_TYPE_RELATION, Flow.CATEGORY_RELATION);
		queryDescriptorDAOWrapper.setUseRelationsOnGet(true);
	}
	
	@Override
	public Query createQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {
		
		AlternativeListPriorityQuery query = new AlternativeListPriorityQuery();
		
		query.setQueryID(descriptor.getQueryID());
		
		queryDAO.add(query, transactionHandler, null);
		
		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());
		
		return query;
	}
	
	@Override
	public Query importQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap, QueryContentFilter contentFilter) throws Throwable {
		
		AlternativeListPriorityQuery query = new AlternativeListPriorityQuery();
		
		query.setQueryID(descriptor.getQueryID());
		
		query.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(query.getClass())));
		
		contentFilter.filterHTML(query);
		
		queryDAO.add(query, transactionHandler, null);
		
		return query;
	}
	
	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, boolean extraData) throws SQLException {
		
		AlternativeListPriorityQuery query = getQuery(descriptor.getQueryID(), extraData);
		
		if (query == null) {
			
			return null;
		}
		
		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());
		
		return query;
	}
	
	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {
		
		AlternativeListPriorityQuery query = getQuery(descriptor.getQueryID(), true, transactionHandler);
		
		if (query == null) {
			
			return null;
		}
		
		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());
		
		return query;
	}
	
	@Override
	public QueryInstance getQueryInstance(MutableQueryInstanceDescriptor descriptor, String instanceManagerID, HttpServletRequest req, User user, User poster, InstanceMetadata instanceMetadata) throws SQLException {
		
		AlternativeListPriorityQueryInstance queryInstance;
		
		//Check if we should create a new instance or get an existing one
		if (descriptor.getQueryInstanceID() == null) {
			
			queryInstance = new AlternativeListPriorityQueryInstance();
			
		} else {
			
			queryInstance = getQueryInstance(descriptor.getQueryInstanceID());
			
			if (queryInstance == null) {
				
				return null;
			}
		}
		
		queryInstance.setQuery(getQuery(descriptor.getQueryDescriptor().getQueryID(), true));
		
		if (queryInstance.getQuery() == null) {
			
			return null;
		}
		
		if (req != null) {
			
			FCKUtils.setAbsoluteFileUrls(queryInstance.getQuery(), RequestUtils.getFullContextPathURL(req) + ckConnectorModuleAlias);
			
			URLRewriter.setAbsoluteLinkUrls(queryInstance.getQuery(), req, true);
		}
		
		queryInstance.getQuery().scanAttributeTags();
		
		TextTagReplacer.replaceTextTags(queryInstance.getQuery(), instanceMetadata.getSiteProfile());
		
		queryInstance.set(descriptor);
		
		//If this is a new query instance copy the default values
		if (descriptor.getQueryInstanceID() == null) {
			
			queryInstance.copyQueryValues();
			
		} else {
			
			if (!CollectionUtils.isEmpty(queryInstance.getAlternatives())) {
				
				Collections.sort(queryInstance.getAlternatives());
			}
		}
		
		return queryInstance;
	}
	
	@Override
	public ImmutableQueryInstance getImmutableQueryInstance(MutableQueryInstanceDescriptor descriptor, HttpServletRequest req, InstanceMetadata instanceMetadata) throws Throwable {
		
		if (descriptor.getQueryInstanceID() == null) {
			return null;
		}
		
		AlternativeListPriorityQueryInstance queryInstance = getQueryInstance(descriptor.getQueryInstanceID());
		
		if (queryInstance == null) {
			return null;
		}
		
		queryInstance.setQuery(getQuery(descriptor.getQueryDescriptor().getQueryID(), false));
		
		if (queryInstance.getQuery() == null) {
			return null;
		}
		
		if (req != null) {
			
			FCKUtils.setAbsoluteFileUrls(queryInstance.getQuery(), RequestUtils.getFullContextPathURL(req) + ckConnectorModuleAlias);
			
			URLRewriter.setAbsoluteLinkUrls(queryInstance.getQuery(), req, true);
		}
		
		queryInstance.getQuery().scanAttributeTags();
		
		TextTagReplacer.replaceTextTags(queryInstance.getQuery(), instanceMetadata.getSiteProfile());
		
		queryInstance.set(descriptor);
		
		return queryInstance;
	}
	
	@Override
	public QueryResponse getFormHTML(AlternativeListPriorityQueryInstance queryInstance, HttpServletRequest req, User user, User poster, List<ValidationError> validationErrors, boolean enableAjaxPosting, String queryRequestURL, InstanceRequestMetadata requestMetadata, AttributeHandler attributeHandler) throws Throwable {
		
		if (queryInstance.getQuery().getAlternativeList() == null || queryInstance.getQuery().getAlternativeList().requiresReload(attributeHandler)) {
			
			queryInstance.getQuery().setAlternativeList(getAlternativeListInstance(queryInstance.getQuery(), attributeHandler, poster));
		}
		
		return super.getFormHTML(queryInstance, req, user, poster, validationErrors, enableAjaxPosting, queryRequestURL, requestMetadata, attributeHandler);
	}
	
	public AlternativeListPriorityQuery getQuery(Integer queryID, boolean withAlternativeList) throws SQLException {
		
		HighLevelQuery<AlternativeListPriorityQuery> getQuery = new HighLevelQuery<>();
		
		getQuery.addParameter(queryIDParamFactory.getParameter(queryID));
		
		AlternativeListPriorityQuery query = queryDAO.get(getQuery);
		
		if (query != null && withAlternativeList) {
			query.setAlternativeList(getAlternativeListInstance(query, null, null));
		}
		
		return query;
	}
	
	public AlternativeListPriorityQuery getQuery(Integer queryID, boolean withAlternativeList, TransactionHandler transactionHandler) throws SQLException {
		
		HighLevelQuery<AlternativeListPriorityQuery> getQuery = new HighLevelQuery<>();
		
		getQuery.addParameter(queryIDParamFactory.getParameter(queryID));
		
		AlternativeListPriorityQuery query = queryDAO.get(getQuery, transactionHandler);
		
		if (query != null && withAlternativeList) {
			query.setAlternativeList(getAlternativeListInstance(query, null, null));
		}
		
		return query;
	}
	
	private AlternativeListPriorityQueryInstance getQueryInstance(Integer queryInstanceID) throws SQLException {
		
		HighLevelQuery<AlternativeListPriorityQueryInstance> query = new HighLevelQuery<>(AlternativeListPriorityQueryInstance.ALTERNATIVES_RELATION, AlternativeListPriorityQueryInstance.QUERY_RELATION);
		
		query.addParameter(queryInstanceIDParamFactory.getParameter(queryInstanceID));
		
		return queryInstanceDAO.get(query);
	}
	
	@Override
	public void save(AlternativeListPriorityQueryInstance queryInstance, TransactionHandler transactionHandler, InstanceRequestMetadata requestMetadata) throws Throwable {
		
		HighLevelQuery<AlternativeListPriorityQueryInstance> query = new HighLevelQuery<>(AlternativeListPriorityQueryInstance.ALTERNATIVES_RELATION);
		
		if (queryInstance.getQueryInstanceID() == null || !queryInstance.getQueryInstanceID().equals(queryInstance.getQueryInstanceDescriptor().getQueryInstanceID())) {
			
			queryInstance.setQueryInstanceID(queryInstance.getQueryInstanceDescriptor().getQueryInstanceID());
			
			queryInstanceDAO.add(queryInstance, transactionHandler, query);
			
		} else {
			
			queryInstanceDAO.update(queryInstance, transactionHandler, query);
		}
	}
	
	@Override
	public void populate(AlternativeListPriorityQueryInstance queryInstance, HttpServletRequest req, User user, User poster, boolean allowPartialPopulation, MutableAttributeHandler attributeHandler, InstanceRequestMetadata requestMetadata) throws ValidationException {
		
		List<? extends ImmutableAlternative> availableAlternatives = null;
		
		if (queryInstance.getQuery().getAlternativeList() != null) {
			
			availableAlternatives = queryInstance.getQuery().getAlternativeList().getAlternatives();
		}
		
		if (CollectionUtils.isEmpty(availableAlternatives)) { // If the parent query doesn't have any alternatives then there is no population to do
			
			if (queryInstance.getQueryInstanceDescriptor().getQueryState() == QueryState.VISIBLE_REQUIRED && !allowPartialPopulation) {
				
				throw new ValidationException(new ValidationError("RequiredQuery"));
				
			} else {
			
				queryInstance.reset(attributeHandler);
				return;
			}
		}
		
		List<ValidationError> validationErrors = new ArrayList<>();
		
		int submittedAlternativesCount = 0;
		List<AlternativeListPriorityAlternative> selectedAlternatives = new ArrayList<>();
		
		for (int alternativIndex = 0; alternativIndex < Math.min(availableAlternatives.size(), queryInstance.getQuery().getMaxChoices()); alternativIndex++) {
			
			String alternativeName = "q" + queryInstance.getQuery().getQueryID() + "_alternative_" + alternativIndex;
			
			Integer alternativeID = NumberUtils.toInt(req.getParameter(alternativeName));
			
			if (alternativeID != null) {
				
				for (ImmutableAlternative alternative : availableAlternatives) {
					
					if (alternative.getAlternativeID().equals(alternativeID)) {
						
						submittedAlternativesCount++;
						
						AlternativeListPriorityAlternative priorityAlternative = new AlternativeListPriorityAlternative(alternative, alternativIndex);
						
						if (selectedAlternatives.contains(priorityAlternative)) {
							validationErrors.add(new ValidationError("CanOnlyChooseAlternativeOnce", "", alternativeName));
							break;
						}
						
						selectedAlternatives.add(priorityAlternative);
						break;
					}
				}
				
			} else {
				
				String nextAlternativeName = "q" + queryInstance.getQuery().getQueryID() + "_alternative_" + (alternativIndex + 1);
				
				if (NumberUtils.toInt(req.getParameter(nextAlternativeName)) != null) {
					
					validationErrors.add(new ValidationError("q" + queryInstance.getQuery().getQueryID() + "_alternative_" + alternativIndex, ValidationErrorType.RequiredField));
				}
			}
		}
		
		//If partial population is allowed, skip validation
		if (allowPartialPopulation && validationErrors.isEmpty()) {
			
			queryInstance.setAlternatives(selectedAlternatives);
			queryInstance.getQueryInstanceDescriptor().setPopulated(!selectedAlternatives.isEmpty());
			queryInstance.setAttributes(attributeHandler);
			return;
		}
		
		Integer minChoices = getMinChoices(queryInstance);
		
		//Check if this query is required or if the user has selected any alternatives anyway
		if (queryInstance.getQueryInstanceDescriptor().getQueryState() == QueryState.VISIBLE_REQUIRED || !selectedAlternatives.isEmpty()) {
			
			if (minChoices != null && submittedAlternativesCount < minChoices) {
				
				validationErrors.add(new TooFewAlternativesSelectedValidationError(submittedAlternativesCount, minChoices));
				
			} else if (queryInstance.getQuery().getMaxChoices() != null && submittedAlternativesCount > queryInstance.getQuery().getMaxChoices()) {
				
				validationErrors.add(new TooManyAlternativesSelectedValidationError(submittedAlternativesCount, queryInstance.getQuery().getMaxChoices()));
				
			} else if (queryInstance.getQueryInstanceDescriptor().getQueryState() == QueryState.VISIBLE_REQUIRED && selectedAlternatives.isEmpty()) {
				
				validationErrors.add(new ValidationError("RequiredQuery"));
			}
		}
		
		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}
		
		queryInstance.setAlternatives(selectedAlternatives);
		queryInstance.getQueryInstanceDescriptor().setPopulated(!selectedAlternatives.isEmpty());
		queryInstance.setAttributes(attributeHandler);
	}
	
	protected Integer getMinChoices(AlternativeListPriorityQueryInstance queryInstance) {
		
		return queryInstance.getQuery().getMinChoices();
	}
	
	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureQuery(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {
		
		return queryCRUD.update(req, res, user, uriParser);
	}
	
	@Override
	public boolean deleteQuery(ImmutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {
		
		AlternativeListPriorityQuery query = getQuery(descriptor.getQueryID(), false);
		
		if (query == null) {
			
			return false;
		}
		
		queryDAO.delete(query, transactionHandler);
		
		return true;
	}
	
	@Override
	public boolean deleteQueryInstance(ImmutableQueryInstanceDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {
		
		AlternativeListPriorityQueryInstance queryInstance = getQueryInstance(descriptor.getQueryInstanceID());
		
		if (queryInstance == null) {
			
			return false;
		}
		
		queryInstanceDAO.delete(queryInstance, transactionHandler);
		
		return true;
	}
	
	@Override
	public String getTitlePrefix() {
		
		return moduleDescriptor.getName();
	}
	
	@Override
	public void copyQuery(MutableQueryDescriptor sourceQueryDescriptor, MutableQueryDescriptor copyQueryDescriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap) throws SQLException {
		
		AlternativeListPriorityQuery query = getQuery(sourceQueryDescriptor.getQueryID(), false, transactionHandler);
		
		query.setQueryID(copyQueryDescriptor.getQueryID());
		
		queryDAO.add(query, transactionHandler, new RelationQuery());
	}
	
	@Override
	protected void appendPDFData(Document doc, Element showQueryValuesElement, AlternativeListPriorityQueryInstance queryInstance, AttributeHandler attributeHandler) {
		
		super.appendPDFData(doc, showQueryValuesElement, queryInstance, attributeHandler);
		
		if (queryInstance.getQuery().getDescription() != null) {
			
			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "Description", JTidyUtils.getXHTML(queryInstance.getQuery().getDescription(attributeHandler), systemInterface.getEncoding()));
			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "isHTMLDescription", queryInstance.getQuery().getDescription().contains("<") && queryInstance.getQuery().getDescription().contains(">"));
		}
	}
	
	@Override
	protected Class<AlternativeListPriorityQueryInstance> getQueryInstanceClass() {
		
		return AlternativeListPriorityQueryInstance.class;
	}
	
	public String getMissingAlternativeList() {
		
		return missingList;
	}
	
	protected Collection<AlternativeListDescriptor> getAlternativeLists() {
		
		return alternativeListHandlerModule.getAlternativeLists();
	}
	
	protected AlternativeListProvider getAlternativeListProvider(String providerID) {
		
		return alternativeListHandlerModule.getProvider(providerID);
	}
	
	protected AlternativeListDescriptor getAlternativeListDescriptor(AlternativeListQuery query) {
		
		if (!StringUtils.isEmpty(query.getAlternativeListName())) {
			
			return alternativeListHandlerModule.getAlternativeList(query.getAlternativeListName());
		}
		
		return null;
	}
	
	protected AlternativeListInstance getAlternativeListInstance(AlternativeListQuery query, AttributeHandler attributeHandler, User poster) {
		
		AlternativeListDescriptor descriptor = getAlternativeListDescriptor(query);
		
		if (descriptor != null) {
			
			return alternativeListHandlerModule.getListInstance(descriptor, attributeHandler, poster);
		}
		
		return null;
	}
	
	@Override
	public Collection<? extends AlternativeListQuery> getQueriesUsingAlternativeList(AlternativeListDescriptor descriptor) {
		
		try {
			ArrayListQuery<Integer> idQuery = new ArrayListQuery<>(queryDAO.getDataSource(), "SELECT queryID FROM " + queryDAO.getTableName() + " WHERE listName = ?", IntegerPopulator.getPopulator());
			idQuery.setString(1, descriptor.getName());
			
			List<Integer> queryIDs = idQuery.executeQuery();
			
			if (!CollectionUtils.isEmpty(queryIDs)) {
				
				List<AlternativeListPriorityQuery> queries = new ArrayList<>(queryIDs.size());
				
				for (Integer queryID : queryIDs) {
					
					QueryDescriptor queryDescriptor = queryDescriptorDAOWrapper.get(queryID);
					
					if (queryDescriptor != null) {
						
						queries.add((AlternativeListPriorityQuery) getQuery(queryDescriptor, false));
					}
				}
				
				return queries;
			}
			
		} catch (SQLException e) {
			
			log.error("Unable to get queries using alternative list " + descriptor, e);
		}
		
		return null;
	}

	@Override
	public boolean hasQueriesUsingAlternativeList(AlternativeListDescriptor descriptor) throws SQLException {

		HighLevelQuery<AlternativeListPriorityQuery> query = new HighLevelQuery<>();
		query.addParameter(listNameParamFactory.getParameter(descriptor.getName()));
		query.setRowLimiter(MySQLRowLimiter.SINGLE_ROW);
		return queryDAO.getBoolean(query);
	}	
	
}
