package com.nordicpeak.flowengine.evaluators.anonymousposterevaluator;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.NonNegativeStringIntegerPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;
import com.nordicpeak.flowengine.evaluators.querystateevaluator.SelectionMode;

@Table(name = "anonymous_poster_evaluators")
@XMLElement
public class AnonymousPosterEvaluator extends BaseEvaluator {
	
	private static final long serialVersionUID = 5501896243489595373L;
	
	@DAOManaged
	@WebPopulate(required = true)
	@XMLElement
	private SelectionMode selectionMode;
	
	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "anonymous_poster_evaluator_alternatives", remoteValueColumnName = "alternativeID")
	@WebPopulate(paramName = "alternativeID")
	@XMLElement(fixCase = true, childName = "alternativeID")
	private List<Integer> alternativeIDs;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean freeTextAlternative;
	
	public SelectionMode getSelectionMode() {
		
		return selectionMode;
	}
	
	public void setSelectionMode(SelectionMode selectionMode) {
		
		this.selectionMode = selectionMode;
	}
	
	public List<Integer> getAlternativeIDs() {
		return alternativeIDs;
	}
	
	public void setAlternativeIDs(List<Integer> alternativeIDs) {
		this.alternativeIDs = alternativeIDs;
	}
	
	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {
		
		List<ValidationError> errors = new ArrayList<ValidationError>();
		
		Integer alternativeID = XMLValidationUtils.validateParameter("alternativeID", xmlParser, false, NonNegativeStringIntegerPopulator.getPopulator(), errors);
		
		if (alternativeID != null) {
			
			alternativeIDs = Collections.singletonList(alternativeID);
			selectionMode = SelectionMode.ANY;
			
		} else {
			
			alternativeIDs = xmlParser.getIntegers("AlternativeIDs/alternativeID");
			selectionMode = XMLValidationUtils.validateParameter("selectionMode", xmlParser, true, AnonymousPosterEvaluatorCRUD.SELECTIONMODE_POPULATOR, errors);
		}
		
		freeTextAlternative = xmlParser.getPrimitiveBoolean("freeTextAlternative");
		
		if (!errors.isEmpty()) {
			
			throw new ValidationException(errors);
		}
	}
	
	public boolean isFreeTextAlternative() {

		return freeTextAlternative;
	}

	public void setFreeTextAlternative(boolean freeTextAlternative) {

		this.freeTextAlternative = freeTextAlternative;
	}
	
	@Override
	public String toString() {
		
		return evaluatorDescriptor.toString();
	}
	
}
