package com.nordicpeak.flowengine.evaluators.anonymousposterevaluator;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.populators.EnumPopulator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluatorCRUD;
import com.nordicpeak.flowengine.evaluators.querystateevaluator.SelectionMode;
import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesQuery;

public class AnonymousPosterEvaluatorCRUD extends BaseEvaluatorCRUD<AnonymousPosterEvaluator, AnonymousPosterEvaluationProviderModule> {
	
	private static final BeanRequestPopulator<AnonymousPosterEvaluator> POPULATOR = new AnnotatedRequestPopulator<AnonymousPosterEvaluator>(AnonymousPosterEvaluator.class);
	
	protected static EnumPopulator<SelectionMode> SELECTIONMODE_POPULATOR = new EnumPopulator<SelectionMode>(SelectionMode.class);
	
	public AnonymousPosterEvaluatorCRUD(Class<AnonymousPosterEvaluator> beanClass, AnnotatedDAOWrapper<AnonymousPosterEvaluator, Integer> evaluatorDAO, AnonymousPosterEvaluationProviderModule callback) {
		
		super(beanClass, evaluatorDAO, POPULATOR, "AnonymousPosterEvaluator", "anonymise flow instance evaluator", null, callback);
	}
	
	@Override
	protected void appendUpdateFormData(AnonymousPosterEvaluator evaluator, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {
		
		super.appendUpdateFormData(evaluator, doc, updateTypeElement, user, req, uriParser);
		
		FixedAlternativesQuery query = (FixedAlternativesQuery) callback.getQueryHandler().getQuery((MutableQueryDescriptor) evaluator.getEvaluatorDescriptor().getQueryDescriptor(), true);
		
		List<? extends ImmutableAlternative> alternatives = query.getAlternatives();
		
		if (alternatives != null) {
			
			Element alternativesElement = doc.createElement("Alternatives");
			updateTypeElement.appendChild(alternativesElement);
			
			for (ImmutableAlternative alternative : alternatives) {
				
				Element alternativeElement = doc.createElement("Alternative");
				alternativesElement.appendChild(alternativeElement);
				
				XMLUtils.appendNewElement(doc, alternativeElement, "alternativeID", alternative.getAlternativeID());
				XMLUtils.appendNewCDATAElement(doc, alternativeElement, "name", alternative.getName());
			}
			
			XMLUtils.appendNewCDATAElement(doc, alternativesElement, "FreeTextAlternative", query.getFreeTextAlternative());
		}
	}
	
}
