package com.nordicpeak.flowengine.queries.attributesumlimitquery;

import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.hierarchy.core.utils.FCKUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.dao.querys.ArrayListQuery;
import se.unlogic.standardutils.date.DateUtils;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.url.URLRewriter;

import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.QueryResponse;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.MutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryContentFilter;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.queries.attributesumlimitquery.api.AttributeSumLimitAPIRequestException;
import com.nordicpeak.flowengine.queries.attributesumlimitquery.api.AttributeSumLimitEndpointAdminModule;
import com.nordicpeak.flowengine.queries.attributesumlimitquery.api.beans.AttributeSumLimitEndpoint;
import com.nordicpeak.flowengine.queries.attributesumlimitquery.api.interfaces.LimitProvider;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUDCallback;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryProviderModule;
import com.nordicpeak.flowengine.utils.JTidyUtils;
import com.nordicpeak.flowengine.utils.TextTagReplacer;

public class AttributeSumLimitQueryProviderModule extends BaseQueryProviderModule<AttributeSumLimitQueryInstance> implements BaseQueryCRUDCallback {

	@InstanceManagerDependency
	private AttributeSumLimitEndpointAdminModule apiModule;

	private AnnotatedDAO<AttributeSumLimitQuery> queryDAO;

	private AttributeSumLimitQueryCRUD queryCRUD;

	private QueryParameterFactory<AttributeSumLimitQuery, Integer> queryIDParamFactory;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, AttributeSumLimitQueryProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		SimpleAnnotatedDAOFactory daoFactory = new SimpleAnnotatedDAOFactory(dataSource);

		queryDAO = daoFactory.getDAO(AttributeSumLimitQuery.class);

		queryCRUD = new AttributeSumLimitQueryCRUD(queryDAO.getWrapper(Integer.class), new AnnotatedRequestPopulator<AttributeSumLimitQuery>(AttributeSumLimitQuery.class), "AttributeSumLimitQuery", "query", null, this);

		queryIDParamFactory = queryDAO.getParamFactory("queryID", Integer.class);
	}

	@Override
	public Query createQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {

		AttributeSumLimitQuery query = new AttributeSumLimitQuery();

		query.setQueryID(descriptor.getQueryID());

		this.queryDAO.add(query, transactionHandler, null);

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public Query importQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap, QueryContentFilter contentFilter) throws Throwable {

		AttributeSumLimitQuery query = new AttributeSumLimitQuery();

		query.setQueryID(descriptor.getQueryID());

		query.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(query.getClass())));
		
		contentFilter.filterHTML(query);

		this.queryDAO.add(query, transactionHandler, null);

		return query;
	}

	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, boolean extraData) throws SQLException {

		AttributeSumLimitQuery query = this.getQuery(descriptor.getQueryID());

		if (query == null) {

			return null;
		}

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		AttributeSumLimitQuery query = this.getQuery(descriptor.getQueryID(), transactionHandler);

		if (query == null) {

			return null;
		}

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public QueryInstance getQueryInstance(MutableQueryInstanceDescriptor descriptor, String instanceManagerID, HttpServletRequest req, User user, User poster, InstanceMetadata instanceMetadata) throws SQLException {

		AttributeSumLimitQueryInstance queryInstance = new AttributeSumLimitQueryInstance();

		queryInstance.setQuery(getQuery(descriptor.getQueryDescriptor().getQueryID()));

		if (queryInstance.getQuery() == null) {

			return null;
		}

		if (req != null) {

			FCKUtils.setAbsoluteFileUrls(queryInstance.getQuery(), RequestUtils.getFullContextPathURL(req) + ckConnectorModuleAlias);

			URLRewriter.setAbsoluteLinkUrls(queryInstance.getQuery(), req, true);
		}

		queryInstance.getQuery().scanAttributeTags();

		TextTagReplacer.replaceTextTags(queryInstance.getQuery(), instanceMetadata.getSiteProfile());

		queryInstance.set(descriptor);
		
		return queryInstance;
	}

	private LimitProvider getLimitProvider(AttributeSumLimitQuery query, User poster, AttributeHandler attributeHandler) {

		if(query.isUseEndpoint()) {
			
			if(query.getEndpoint() != null && apiModule != null) {
			
				try {
					return apiModule.getAttributeSumLimit(query.getEndpoint(), poster, attributeHandler);
					
				} catch (AttributeSumLimitAPIRequestException e) {

					log.warn("Error getting limits from endpoint for query " + queryDescription, e);
				}
			}
			
			return null;
			
		}else {

			return query;
		}
	}

	private AttributeSumLimitQuery getQuery(Integer queryID) throws SQLException {

		HighLevelQuery<AttributeSumLimitQuery> query = new HighLevelQuery<AttributeSumLimitQuery>();

		query.addParameter(queryIDParamFactory.getParameter(queryID));

		return queryDAO.get(query);
	}

	private AttributeSumLimitQuery getQuery(Integer queryID, TransactionHandler transactionHandler) throws SQLException {

		HighLevelQuery<AttributeSumLimitQuery> query = new HighLevelQuery<AttributeSumLimitQuery>();

		query.addParameter(queryIDParamFactory.getParameter(queryID));

		return queryDAO.get(query, transactionHandler);
	}

	@Override
	public void save(AttributeSumLimitQueryInstance queryInstance, TransactionHandler transactionHandler, InstanceRequestMetadata requestMetadata) throws Throwable {}

	@Override
	public QueryResponse getFormHTML(AttributeSumLimitQueryInstance queryInstance, HttpServletRequest req, User user, User poster, List<ValidationError> validationErrors, boolean enableAjaxPosting, String queryRequestURL, InstanceRequestMetadata requestMetadata, AttributeHandler attributeHandler) throws Throwable {

		if(queryInstance.getLimitProvider() == null && CollectionUtils.isEmpty(validationErrors)) {
			
			queryInstance.setLimitProvider(getLimitProvider(queryInstance.getQuery(), poster, attributeHandler));
			
			if(queryInstance.getLimitProvider() == null) {
				
				validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, new ValidationError("NoLimiterFound"));
			
			}else {
				
				queryInstance.setRemainingAmount(getRemainingAmount(queryInstance));
			}
						
		}else if (queryInstance.getSubmitValidationError() != null) {

			validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, queryInstance.getSubmitValidationError());
			queryInstance.setSubmitValidationError(null);
		}

		return super.getFormHTML(queryInstance, req, user, poster, validationErrors, enableAjaxPosting, queryRequestURL, requestMetadata, attributeHandler);
	}

	@Override
	public void populate(AttributeSumLimitQueryInstance queryInstance, HttpServletRequest req, User user, User poster, boolean allowPartialPopulation, MutableAttributeHandler attributeHandler, InstanceRequestMetadata requestMetadata) throws ValidationException {

		if(queryInstance.getLimitProvider() == null){
			
			throw new ValidationException(new ValidationError("NoLimiterFound"));
		}
		
		AttributeSumLimitQuery query = queryInstance.getQuery();

		if (queryInstance.getRemainingAmount() != null) {

			Integer requestedAmount = attributeHandler.getInt(query.getAttributeName());

			if (requestedAmount != null && requestedAmount > queryInstance.getRemainingAmount()) {

				if (allowPartialPopulation) {
					
					queryInstance.getQueryInstanceDescriptor().setPopulated(false);
					return;
				}
				
				throw new ValidationException(new ValidationError("LimitExceeded"));
			}
		}

		queryInstance.getQueryInstanceDescriptor().setPopulated(true);
		return;
	}

	public boolean isValidForSubmit(MutableAttributeHandler attributeHandler, AttributeSumLimitQueryInstance queryInstance, User poster) {

		try {
		
			if(queryInstance.getLimitProvider() == null) {
				
				queryInstance.setLimitProvider(getLimitProvider(queryInstance.getQuery(), poster, attributeHandler));
				
				if(queryInstance.getLimitProvider() == null) {
					
					return false;
				}
			}
			
			AttributeSumLimitQuery query = queryInstance.getQuery();
		
			Integer remainingAmount = getRemainingAmount(queryInstance);
			
			queryInstance.setRemainingAmount(remainingAmount);

			if (remainingAmount == null) {
				return true;
			}

			Integer requestedAmount = attributeHandler.getInt(query.getAttributeName());

			if (requestedAmount != null && requestedAmount > queryInstance.getRemainingAmount()) {

				queryInstance.setSubmitValidationError(new ValidationError("LimitExceeded", Integer.toString(remainingAmount)));
				return false;

			} else {

				queryInstance.setSubmitValidationError(null);
				return true;
			}

		} catch (SQLException e) {

			log.error("Error checking if query is valid for submit " + queryInstance, e);
			return false;
		}
	}
	
	private Integer getRemainingAmount(AttributeSumLimitQueryInstance queryInstance) throws SQLException {

		Integer flowInstanceID = queryInstance.getQueryInstanceDescriptor().getFlowInstanceID();
		
		int flowFamilyID = queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getStep().getFlow().getFlowFamily().getFlowFamilyID();
		
		AttributeSumLimitQuery query = queryInstance.getQuery();

		if (query.getAttributeName() == null || (query.getLimit() == null && !query.isUseEndpoint())) {
			
			return null;
		}

		StringBuilder sql = new StringBuilder("SELECT fa.value FROM flowengine_flow_instance_attributes fa");
		sql.append(" INNER JOIN flowengine_flow_instances fi ON fa.flowInstanceID = fi.flowInstanceID");
		sql.append(" INNER JOIN flowengine_flows f ON f.flowID = fi.flowID");
		sql.append(" WHERE f.flowFamilyID = ? AND fi.firstSubmitted IS NOT NULL AND fa.name = ?");

		if (flowInstanceID != null) {
			sql.append(" AND fa.flowInstanceID != ?");
		}

		if (queryInstance.getLimitProvider().getMinDate() != null) {
			sql.append(" AND fi.firstSubmitted >= ?");
		}

		if (queryInstance.getLimitProvider().getMaxDate() != null) {
			sql.append(" AND fi.firstSubmitted <= ?");
		}

		ArrayListQuery<String> daoQuery = new ArrayListQuery<String>(dataSource, sql.toString(), StringPopulator.getPopulator());

		int paramIndex = 1;

		daoQuery.setInt(paramIndex++, flowFamilyID);

		daoQuery.setString(paramIndex++, query.getAttributeName());

		if (flowInstanceID != null) {
			
			daoQuery.setInt(paramIndex++, flowInstanceID);
		}

		if (queryInstance.getLimitProvider().getMinDate()!= null) {
			
			daoQuery.setTimestamp(paramIndex++, DateUtils.setTimeToMidnight(new Timestamp(queryInstance.getLimitProvider().getMinDate().getTime())));
		}

		if (queryInstance.getLimitProvider().getMaxDate() != null) {
			
			daoQuery.setTimestamp(paramIndex++, DateUtils.setTimeToMaximum(new Timestamp(queryInstance.getLimitProvider().getMaxDate().getTime())));
		}

		ArrayList<String> values = daoQuery.executeQuery();

		int usedAmount = 0;

		if (values != null) {

			for (String value : values) {

				Integer parsedValue = NumberUtils.toInt(value);

				if (parsedValue != null) {

					usedAmount += parsedValue;
				}
			}
		}

		return queryInstance.getLimitProvider().getLimit() - usedAmount;
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureQuery(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.queryCRUD.update(req, res, user, uriParser);
	}

	@Override
	public boolean deleteQuery(ImmutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {

		AttributeSumLimitQuery query = getQuery(descriptor.getQueryID());

		if (query == null) {

			return false;
		}

		this.queryDAO.delete(query, transactionHandler);

		return true;
	}

	@Override
	public boolean deleteQueryInstance(ImmutableQueryInstanceDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		return true;
	}

	@Override
	public String getTitlePrefix() {

		return this.moduleDescriptor.getName();
	}

	@Override
	public void copyQuery(MutableQueryDescriptor sourceQueryDescriptor, MutableQueryDescriptor copyQueryDescriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap) throws SQLException {

		AttributeSumLimitQuery query = getQuery(sourceQueryDescriptor.getQueryID(), transactionHandler);

		query.setQueryID(copyQueryDescriptor.getQueryID());

		queryDAO.add(query, transactionHandler, null);
	}

	@Override
	protected void appendPDFData(Document doc, Element showQueryValuesElement, AttributeSumLimitQueryInstance queryInstance, AttributeHandler attributeHandler) {

		super.appendPDFData(doc, showQueryValuesElement, queryInstance, attributeHandler);

		if (queryInstance.getQuery().getDescription() != null) {

			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "Description", JTidyUtils.getXHTML(queryInstance.getQuery().getDescription(attributeHandler), systemInterface.getEncoding()));
			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "isHTMLDescription", queryInstance.getQuery().getDescription().contains("<") && queryInstance.getQuery().getDescription().contains(">"));
		}
	}

	@Override
	protected Class<AttributeSumLimitQueryInstance> getQueryInstanceClass() {

		return AttributeSumLimitQueryInstance.class;
	}

	public AttributeSumLimitEndpointAdminModule getApiModule() {

		return apiModule;
	}

	public AttributeSumLimitEndpoint getEndpoint(Integer endpointID) throws SQLException {

		if (this.apiModule != null) {

			return apiModule.getEndpoint(endpointID);
		}

		return null;
	}
}
