package com.nordicpeak.flowengine.queries.basetablequery;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.FCKContent;
import se.unlogic.standardutils.annotations.PopulateOnlyIfSet;
import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.numbers.NumberStringyfier;
import se.unlogic.standardutils.populators.NonNegativeStringIntegerPopulator;
import se.unlogic.standardutils.populators.PercentageStringIntegerPopulator;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLParserPopulateable;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLValidationUtils;
import se.unlogic.webutils.annotations.URLRewrite;

import com.nordicpeak.flowengine.alternativelist.interfaces.AlternativeListInstance;
import com.nordicpeak.flowengine.annotations.TextTagReplace;
import com.nordicpeak.flowengine.queries.basetablequery.interfaces.TableColumn;

@XMLElement(name = "Column")
public abstract class BaseTableColumn<DropAlternative extends BaseDropDownAlternative, Column extends BaseTableColumn<DropAlternative, Column, Query>, Query extends BaseTableQuery<DropAlternative, Query, Column>> extends GeneratedElementable implements Serializable, XMLParserPopulateable, TableColumn {

	private static final long serialVersionUID = 8962793710793622131L;

	public static NumberStringyfier NUMBER_STRINGIFYER_WITH_DECIMALS = new NumberStringyfier(2, 2, false);
	public static NumberStringyfier NUMBER_STRINGIFYER_WITHOUT_DECIMALS = new NumberStringyfier(0, 0, false);

	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	private Integer columnID;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String label;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean required;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean summarise;

	private BigDecimal sum;

	@DAOManaged
	@WebPopulate(populator = PercentageStringIntegerPopulator.class)
	@XMLElement
	private Integer width;

	@DAOManaged
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer minContentLength;

	@DAOManaged
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer maxContentLength;

	@DAOManaged
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer textAreaRows;

	@DAOManaged
	@OrderBy
	@XMLElement
	private Integer sortIndex;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private String formatValidator;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "formatValidator")
	@XMLElement
	private String invalidFormatMessage;

	@FCKContent
	@TextTagReplace
	@URLRewrite
	@DAOManaged
	@WebPopulate(maxLength = 65535)
	@XMLElement
	private String helpText;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String dropdownChooseText;

	@DAOManaged
	@WebPopulate(required = true)
	@XMLElement
	private ColumnType columnType;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "columnType", paramValues = { "DROPDOWN_ALTERNATIVE_LIST", "LIST_SEARCH" })
	@XMLElement
	private String listName;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	@PopulateOnlyIfSet(paramNames = "columnType", paramValues = "LIST_SEARCH")
	private boolean showExactMatchesFirst;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	@PopulateOnlyIfSet(paramNames = "columnType", paramValues = "LIST_SEARCH")
	private String placeholderText;

	@DAOManaged
	@WebPopulate
	@XMLElement
	@PopulateOnlyIfSet(paramNames = "columnType", paramValues = "LIST_SEARCH")
	private boolean showAlternativesOnEmptySearch;

	private AlternativeListInstance alternativeList;

	@Override
	public Integer getColumnID() {

		return columnID;
	}

	public void setColumnID(Integer columnID) {

		this.columnID = columnID;
	}

	@Override
	public String getLabel() {

		return label;
	}

	public void setLabel(String name) {

		this.label = name;
	}

	@Override
	public String toString() {

		return label + " (columnID: " + columnID + ")";
	}

	public boolean isRequired() {

		return required;
	}

	public void setRequired(boolean required) {

		this.required = required;
	}

	public Integer getWidth() {

		return width;
	}

	public void setWidth(Integer width) {

		this.width = width;
	}

	public Integer getSortIndex() {

		return sortIndex;
	}

	public void setSortIndex(Integer sortIndex) {

		this.sortIndex = sortIndex;
	}

	public String getFormatValidator() {

		return formatValidator;
	}

	public void setFormatValidator(String formatValidator) {

		this.formatValidator = formatValidator;
	}

	public Integer getMaxContentLength() {

		return maxContentLength;
	}

	public void setMaxContentLength(Integer maxContentLength) {

		this.maxContentLength = maxContentLength;
	}

	public Integer getMinContentLength() {

		return minContentLength;
	}

	public void setMinContentLength(Integer minContentLength) {

		this.minContentLength = minContentLength;
	}

	public String getInvalidFormatMessage() {

		return invalidFormatMessage;
	}

	public void setInvalidFormatMessage(String invalidFormatMessage) {

		this.invalidFormatMessage = invalidFormatMessage;
	}

	public Integer getTextAreaRows() {

		return textAreaRows;
	}

	public void setTextAreaRows(Integer textAreaRows) {

		this.textAreaRows = textAreaRows;
	}

	@Override
	public Element toXML(Document doc) {

		Element element = super.toXML(doc);

		XMLUtils.appendNewElement(doc, element, "sum", getSumString());

		if (alternativeList != null) {

			//TODO don't append alternatives on export
			XMLUtils.append(doc, element, "AlternativeListAlternatives", alternativeList.getAlternatives());
		}

		return element;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<>();

		columnID = XMLValidationUtils.validateParameter("columnID", xmlParser, true, PositiveStringIntegerPopulator.getPopulator(), errors);
		label = XMLValidationUtils.validateParameter("label", xmlParser, true, 1, 255, StringPopulator.getPopulator(), errors);
		required = xmlParser.getPrimitiveBoolean("required");
		summarise = xmlParser.getPrimitiveBoolean("summarise");

		width = XMLValidationUtils.validateParameter("width", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);
		minContentLength = XMLValidationUtils.validateParameter("minContentLength", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);
		maxContentLength = XMLValidationUtils.validateParameter("maxContentLength", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);

		sortIndex = XMLValidationUtils.validateParameter("sortIndex", xmlParser, true, NonNegativeStringIntegerPopulator.getPopulator(), errors);
		formatValidator = XMLValidationUtils.validateParameter("formatValidator", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		invalidFormatMessage = XMLValidationUtils.validateParameter("invalidFormatMessage", xmlParser, !StringUtils.isEmpty(formatValidator), 1, 255, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		dropdownChooseText = XMLValidationUtils.validateParameter("dropdownChooseText", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);

		columnType = XMLValidationUtils.validateParameter("columnType", xmlParser, true, TableColumnCRUD.COLUM_TYPE_POPULATOR, errors);

		if (columnType == ColumnType.DROPDOWN) {

			populateDropdownAlternatives(xmlParser, errors);
		}

		if (columnType == ColumnType.ROWSUM_ADD || columnType == ColumnType.ROWSUM_MULTIPLY) {

			setRowSumAddedColumns(XMLValidationUtils.validateParameters("RowSumAddedColumns/value", xmlParser, false, NonNegativeStringIntegerPopulator.getPopulator(), errors));
			setRowSumSubtractedColumns(XMLValidationUtils.validateParameters("RowSumSubtractedColumns/value", xmlParser, false, NonNegativeStringIntegerPopulator.getPopulator(), errors));
		}

		if (columnType == ColumnType.DROPDOWN_ALTERNATIVE_LIST || columnType == ColumnType.LIST_SEARCH) {

			listName = XMLValidationUtils.validateParameter("listName", xmlParser, true, 1, 255, StringPopulator.getPopulator(), errors);
		}

		if (columnType == ColumnType.LIST_SEARCH) {

			placeholderText = XMLValidationUtils.validateParameter("placeholderText", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
			showAlternativesOnEmptySearch = xmlParser.getPrimitiveBoolean("showAlternativesOnEmptySearch");
			showExactMatchesFirst = xmlParser.getPrimitiveBoolean("showExactMatchesFirst");
		}

		if (columnType == ColumnType.TEXTAREA) {

			textAreaRows = XMLValidationUtils.validateParameter("textAreaRows", xmlParser, false, 1, 255, PositiveStringIntegerPopulator.getPopulator(), errors);
		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	protected abstract void populateDropdownAlternatives(XMLParser xmlParser, List<ValidationError> errors) throws ValidationException;

	public String getHelpText() {

		return helpText;
	}

	public void setHelpText(String helpText) {

		this.helpText = helpText;
	}

	public ColumnType getColumnType() {

		return columnType;
	}

	public void setColumnType(ColumnType columnType) {

		this.columnType = columnType;
	}

	public String getPlaceholderText() {

		return placeholderText;
	}

	public void setPlaceholderText(String placeholderText) {

		this.placeholderText = placeholderText;
	}

	public boolean isShowAlternativesOnEmptySearch() {

		return showAlternativesOnEmptySearch;
	}

	public void setShowAlternativesOnEmptySearch(boolean showAlternativesOnEmptySearch) {

		this.showAlternativesOnEmptySearch = showAlternativesOnEmptySearch;
	}
	
	public boolean isShowExactMatchesFirst() {

		return showExactMatchesFirst;
	}

	public void setShowExactMatchesFirst(boolean showExactMatchesFirst) {

		this.showExactMatchesFirst = showExactMatchesFirst;
	}

	@Override
	public boolean isSummarise() {

		return summarise;
	}

	public void setSummarise(boolean summarise) {

		this.summarise = summarise;
	}

	/** Returns null if sum is not calculated or could not be calculated
	 * 
	 * @return */
	@Override
	public BigDecimal getSum() {

		return sum;
	}

	public void setSum(BigDecimal sum) {

		this.sum = sum;
	}

	public String getSumString() {

		if (sum == null) {

			return "0";
		}

		Integer decimals = getQuery().getDecimalsToShow();

		if (decimals != null) {

			return new NumberStringyfier(decimals, decimals, false).format(sum);
		}

		if (sum.scale() > 0) {

			return NUMBER_STRINGIFYER_WITH_DECIMALS.format(sum);
		}

		return NUMBER_STRINGIFYER_WITHOUT_DECIMALS.format(sum);
	}

	public String getDropdownChooseText() {

		return dropdownChooseText;
	}

	public void setDropdownChooseText(String dropdownChooseText) {

		this.dropdownChooseText = dropdownChooseText;
	}

	public abstract List<DropAlternative> getDropDownAlternatives();

	public abstract void setDropDownAlternatives(List<DropAlternative> alternatives);

	public DropAlternative getDropDownAlternativeByID(Integer id) {

		return CollectionUtils.find(getDropDownAlternatives(), a -> a.getAlternativeID().equals(id));
	}

	public abstract List<Integer> getRowSumAddedColumns();

	public abstract void setRowSumAddedColumns(List<Integer> addedColumns);

	public abstract List<Integer> getRowSumSubtractedColumns();

	public abstract void setRowSumSubtractedColumns(List<Integer> subtractedColumns);

	public abstract Query getQuery();

	public abstract void setQuery(Query query);

	public String getAlternativeListName() {

		return listName;
	}

	public AlternativeListInstance getAlternativeList() {

		return alternativeList;
	}

	public void setAlternativeList(AlternativeListInstance alternativeList) {

		this.alternativeList = alternativeList;
	}

}
