<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl"/>
	
	<xsl:variable name="linkPath"><xsl:value-of select="/Document/requestinfo/contextpath" />/static/f/<xsl:value-of select="/Document/module/sectionID" />/<xsl:value-of select="/Document/module/moduleID" />/css</xsl:variable>
	<xsl:variable name="scriptPath"><xsl:value-of select="/Document/requestinfo/contextpath" />/static/f/<xsl:value-of select="/Document/module/sectionID" />/<xsl:value-of select="/Document/module/moduleID" />/js</xsl:variable>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-migrate.js?v=1
		/jquery/jquery-ui.js?v=1
		/timepicker/js/jquery.timepicker.js?v=1
		/jquery/plugins/jquery.qloader.js
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
		/featherlight/js/featherlight.min.js
		/js/confirmpost.js
		/tablesorter/js/jquery.tablesorter.min.js
	</xsl:variable>
	
	<xsl:variable name="globallinks">
		/css/openhierarchy-jquery-ui.css
		/timepicker/css/jquery.timepicker.css
		/featherlight/css/featherlight.min.css?v=1
	</xsl:variable>
	
	<xsl:variable name="scripts">
		/js/jquery.ui.datepicker-sv.js
		/js/flowengine.tablesorter.js
		/js/flowengine.tablefilter.js
		/js/flowengine.js?v=1
		/js/jquery.qloader-init.js
		/js/UserGroupList.js
		/js/moment.min.js
		/js/moment.sv.js
		/js/handlebars.min.js
		/js/clndr.min.js
		/js/bookingslotadmin.js?v=6
		/js/js.cookie-2.0.4.min.js
		/js/messages.js?v=3
		/js/bookingcommon.js?v=2
	</xsl:variable>
	
	<xsl:variable name="links">
		/css/UserGroupList.css?v=1
		/css/flowengine.css
		/css/admincalendar.css
		/css/bookingslotadmin.css?v=2
		/css/buttonspinner.css
		/css/messages.css
		/css/bookingcommon.css
	</xsl:variable>

	<xsl:template match="Document">
		
		<div id="BookingSlotAdminModule" class="contentitem">
			<xsl:if test="ListCalendars or ListBookingSlots or ListArchivedBookingSlots or AddBookingSlot">
				<xsl:attribute name="class">contentitem errands-wrapper</xsl:attribute>
			</xsl:if>
			
			<xsl:apply-templates select="ListCalendars" />
			<xsl:apply-templates select="ListBookingSlots" />
			<xsl:apply-templates select="ExportCalendar" />
			
			<xsl:apply-templates select="AddBookingSlot" />
			<xsl:apply-templates select="ShowBookingSlot" />
			<xsl:apply-templates select="UpdateBookingSlot" />
			
			<xsl:apply-templates select="AddBooking" />
			<xsl:apply-templates select="ShowBooking" />
			
			<xsl:apply-templates select="UpdateContact" />
			<xsl:apply-templates select="SendMessageForm" />
			
			<xsl:apply-templates select="UpdateRepeating" />

		</div>
		
	</xsl:template>
	
	<xsl:template match="ListCalendars">
	
		<h1>
			<xsl:value-of select="/Document/module/name" />
		</h1>	
	
		<xsl:variable name="calendarIDParameters">
			<xsl:for-each select="Calendars/Calendar/calendarID">
				<xsl:text>c=</xsl:text>
				<xsl:value-of select="."/>	
				<xsl:if test="position() != last()">&amp;</xsl:if>
			</xsl:for-each>
		</xsl:variable>

		<div class="section-full padtop pull-left bigmarginbottom bigmargintop">
			<div class="split-left search-wrapper">
				<div class="search">
					<div class="input-wrapper">
						<input type="text" placeholder="{$i18n.SearchBookings}" name="search" class="noborder" id="calendar-search" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/searchbookings?{$calendarIDParameters}" tabindex="1" />
						<input type="button" value="s" class="btn btn-search"/>
					</div>
				</div>
			</div>
			
			<div class="floatright">
				<input type="text" class="filter-input nomargin" data-tableid="calendars" placeholder="{$i18n.FilterList}" tabindex="2"/>
			</div>					
		</div>
		
		<xsl:if test="validationError">
			<div class="bigmarginbottom">
				<xsl:apply-templates select="validationError"/>
			</div>
		</xsl:if>

		<xsl:call-template name="SearchResults"/>
	
		<table id="calendars" class="oep-table bigmarginbottom">
			<thead class="sortable">
				<tr>
					<th class="default-sort">
						<span><xsl:value-of select="$i18n.Calendar.Name" /></span>
					</th>
					<th>
						<span><xsl:value-of select="$i18n.Calendar.ActiveBookings" /></span>
					</th>
					<th>
						<span><xsl:value-of select="$i18n.Calendar.BookingSlotCount" /></span>
					</th>
				</tr>
			</thead>
			<tbody>
				
				<xsl:choose>
					<xsl:when test="Calendars/Calendar">
						<xsl:apply-templates select="Calendars/Calendar" mode="list" />
					</xsl:when>
					<xsl:otherwise>
						<tr>
							<td colspan="4"><xsl:value-of select="$i18n.NoBookings" /></td>
						</tr>
					</xsl:otherwise>
				</xsl:choose>
				
			</tbody>
		</table>
			
	</xsl:template>
	
	<xsl:template match="Calendar" mode="list">
	
		<tr>
			<td data-title="{$i18n.Calendar.Name}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{calendarID}">
					<xsl:value-of select="name" />
				</a>
			</td>
			<td data-title="{$i18n.Calendar.ActiveBookings}"><xsl:value-of select="activeBookings" /></td>
			<td data-title="{$i18n.Calendar.BookingSlotCount}"><xsl:value-of select="bookingSlotCount" /></td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ListBookingSlots">
	
		<a class="btn btn-light floatright marginbottom" id="view-toggler">
			<span><xsl:value-of select="$i18n.ViewAsList" /></span>
			<span style="display: none;"><xsl:value-of select="$i18n.ViewAsCalendar" /></span>
		</a>
	
		<h1>
			<xsl:value-of select="$i18n.ListBookingSlots.title" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="Calendar/name" />
		</h1>
		
		<div class="section-full padtop pull-left">
			<div class="split-left search-wrapper">
				<div class="search">
					<div class="input-wrapper">
						<input type="text" placeholder="{$i18n.SearchBookings}" name="search" class="noborder" id="calendar-search" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/searchbookings?c={Calendar/calendarID}" />
						<input type="button" value="s" class="btn btn-search"/>
					</div>
				</div>
			</div>
		</div>
		
		<xsl:if test="validationError">
			<div class="bigmarginbottom">
				<xsl:apply-templates select="validationError"/>
			</div>
		</xsl:if>
		
		<xsl:call-template name="SearchResults"/>
		
		<xsl:if test="Calendar/description">
			<p>
				<xsl:value-of select="Calendar/description"/>
			</p>
		</xsl:if>
		
		<div id="calendar-view">
		
			<div class="view-buttons">
				<a id="week-toggler" class="btn btn-light floatright">
					<span><xsl:value-of select="$i18n.WeekView" /></span>
					<span style="display: none;"><xsl:value-of select="$i18n.MonthView" /></span>
				</a>
				<a  id="go-to-today" class="btn btn-light floatright">
					<span><xsl:value-of select="$i18n.GoToToday" /></span>
				</a>
			</div>
			
			<div class="events-json" style="display: none;">
				<xsl:value-of select="BookingSlotsJSON" />
			</div>
			
			<div class="events-title-json" style="display: none;">
				<xsl:value-of select="BookingSlotsTitleJSON" />
			</div>
			
			<div class="calendar calendar-full block bigmarginbottom" data-showduration="{Calendar/showDuration}" data-showurl="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/">
	
				<div class="calendar-template" style="display: none;">
				
					<div class="month clndr-controls bigpaddingtop bigpaddingbottom">
					
						<div class="display-inline paddingbottom">
							<div><xsl:value-of select="$i18n.FilterManagers"/>: </div>
							<select class="managerfilter" onchange="bookingQueryUpdateManagerFilter(event, this)" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/getcalendarevents/{Calendar/calendarID}">
				
								<option value=""><xsl:value-of select="$i18n.FilterManagers.NoFilter"/></option>
								
								<xsl:for-each select="CalendarManagers/user">
								
									<option value="{userID}">
										<xsl:choose>
											<xsl:when test="CustomName"><xsl:value-of select="CustomName"/></xsl:when>
											<xsl:otherwise><xsl:value-of select="firstname"/>&#160;<xsl:value-of select="lastname"/></xsl:otherwise>
										</xsl:choose>
									</option>
								
								</xsl:for-each>
				
							</select>
						</div>
						
						<div class="bigpaddingtop">
							<a class="btn btn-light btn-inline clndr-previous-button" href="#" title="{$js.Calendar.PreviousMonth}">
								<img class="alignmiddle marginright" src="{$imagePath}/arrow_left.png" />
								<span><xsl:value-of select="$js.Calendar.PreviousMonthShort" /></span>
							</a>

							<a id="previous-week-button" class="hidden btn btn-light btn-inline" href="#" title="{$js.Calendar.PreviousWeek}">
								<img class="alignmiddle marginright" src="{$imagePath}/arrow_left.png" />
								<span><xsl:value-of select="$js.Calendar.PreviousWeekShort" /></span>
							</a>
							
							<h2 class="calendar-month bigmarginleft bigmarginright">{{month}} {{year}}</h2>
							
							<a class="btn btn-light btn-inline clndr-next-button" href="#" title="{$js.Calendar.NextMonth}">
								<span><xsl:value-of select="$js.Calendar.NextMonthShort" /></span>
								<img class="alignmiddle marginleft" src="{$imagePath}/arrow_right.png" />
							</a>

							<a id="next-week-button" class="hidden btn btn-light btn-inline" href="#" title="{$js.Calendar.NextWeek}">
								<span><xsl:value-of select="$js.Calendar.NextWeekShort" /></span>
								<img class="alignmiddle marginleft" src="{$imagePath}/arrow_right.png" />
							</a>
						</div>
						
						<div class="flex-padding" />
						<div class="flex-padding" />
					</div>
		
					<div class="days padding inner-padded-rbl clearboth">
						<div class="calendar-row calendar-row-header">
							<div>V</div>
							{{#each daysOfTheWeek}}
								<div>{{bookingQuerySafe_string this}}<span class="week-mode-date"></span></div>
							{{/each}}
						</div>
		
						{{#BookingQuery-Week days}}
							{{this}}
						{{/BookingQuery-Week}}
						<div class="calendar-day"></div>
					</div>
					
				</div>
				
				<div class="calendar-day-template" style="display: none;">
							
					<xsl:variable name="dateString">{{date}}</xsl:variable>
				
					<div class="calendar-day" data-date="{$dateString}">
						<div class="bigpaddingbottom">
							<div class="calendar-day-header bigpaddingtop bigpaddingleft bigpaddingright">
								<h2 class="bigpaddingtop bigpaddingbottom">{{day}}</h2>
							</div>
					
							<div class="event-list-container">
								{{#BookingQuery-Day events}}
									{{this}}
								{{/BookingQuery-Day}}
							</div>
							
							<xsl:if test="AddAccess">
								<a class="btn btn-green btn-inline bigmarginleft bigmargintop" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/addslot/{Calendar/calendarID}?date={$dateString}">
									<xsl:value-of select="$i18n.AddBookingSlot" />
								</a>
							</xsl:if>
						</div>
					</div>
					
				</div>
			
			</div>
			
			<script type="text/javascript">
					$(function(){
					
						Calendari18n = {
							OneSlot: "<xsl:value-of select="$js.Calendar.OneSlot" />",
							MultipleSlots: "<xsl:value-of select="$js.Calendar.MultipleSlots" />",
							Free: "<xsl:value-of select="$js.Calendar.Free" />",
							Booked: "<xsl:value-of select="$js.Calendar.Booked" />",
							DescriptionTitle: "<xsl:value-of select="$js.Calendar.DescriptionTitle" />",
							ManagersTitle: "<xsl:value-of select="$js.Calendar.ManagersTitle" />",
							LocationTitle: "<xsl:value-of select="$js.Calendar.LocationTitle" />",
							BookingsTitle: "<xsl:value-of select="$js.Calendar.BookingsTitle" />",
							And: "<xsl:value-of select="$i18n.And" />",
							XMore: "<xsl:value-of select="$i18n.XMore" />",
							Week: "<xsl:value-of select="$i18n.Week" />",
						}
					
						initBookingSlotAdminCalendar($("#calendar-view"));
					});
			</script>
		</div>
		
		<div class="tabs-content official" id="table-wrapper" style="display: none;">
			<div id="currentBookingSlots">
				<div id="listfilter" class="clearboth floatright marginbottom">
					<input type="text" size="20" class="filter-input" data-tableid="table-view" placeholder="{$i18n.FilterList}"/>
				</div>
				
				<div>
					<h1 class="bigpaddingtop">
						<xsl:value-of select="$i18n.BookingSlot.CurrentBookingSlots"/>
					</h1>
					
					<a href="#" id="showPassedBookingSlots"><xsl:value-of select="$i18n.BookingSlot.ShowPassedBookingSlots"/></a>
				</div>
				
				<table id="table-view" class="oep-table bigmarginbottom">
					<thead class="sortable">
						<tr>
							<th class="default-sort">
								<span><xsl:value-of select="$i18n.BookingSlot.DateAndTime" /></span>
							</th>
							<th>
								<span><xsl:value-of select="$i18n.BookingSlot.Location" /></span>
							</th>
							<th>
								<span><xsl:value-of select="$i18n.BookingSlot.Size" /></span>
							</th>
							<th class="hidden"/>
						</tr>
					</thead>
					<tbody>
						
						<xsl:choose>
							<xsl:when test="BookingSlots/BookingSlot">
								<xsl:apply-templates select="BookingSlots/BookingSlot[not(HasPassed)]" mode="list" />
							</xsl:when>
							<xsl:otherwise>
								<tr>
									<td colspan="6"><xsl:value-of select="$i18n.NoBookingSlots" /></td>
								</tr>
							</xsl:otherwise>
						</xsl:choose>
						
					</tbody>
				</table>
			</div>
			
			<div id="passedBookingSlots" style="display: none;">
				<div id="inactiveListfilter" class="clearboth floatright marginbottom">
					<input type="text" size="20" class="filter-input" data-tableid="inactive-table-view" placeholder="{$i18n.FilterList}"/>
				</div>
				
				<div>
					<h1 class="bigpaddingtop">
						<xsl:value-of select="$i18n.BookingSlot.PassedBookingSlots"/>
					</h1>
					
					<a href="#" id="showCurrentBookingSlots"><xsl:value-of select="$i18n.BookingSlot.ShowCurrentBookingSlots"/></a>
				</div>
				
				<table id="inactive-table-view" class="oep-table bigmarginbottom">
					<thead class="sortable">
						<tr>
							<th class="default-sort">
								<span><xsl:value-of select="$i18n.BookingSlot.DateAndTime" /></span>
							</th>
							<th>
								<span><xsl:value-of select="$i18n.BookingSlot.Location" /></span>
							</th>
							<th>
								<span><xsl:value-of select="$i18n.BookingSlot.Size" /></span>
							</th>
							<th class="hidden"/>
						</tr>
					</thead>
					<tbody>
						
						<xsl:choose>
							<xsl:when test="BookingSlots/BookingSlot">
								<xsl:apply-templates select="BookingSlots/BookingSlot[HasPassed]" mode="list" />
							</xsl:when>
							<xsl:otherwise>
								<tr>
									<td colspan="6"><xsl:value-of select="$i18n.NoBookingSlots" /></td>
								</tr>
							</xsl:otherwise>
						</xsl:choose>
						
					</tbody>
				</table>
			</div>
		</div>
		
		<article class="buttons floatright">
			
			<xsl:if test="AddAccess">
				<a class="btn btn-green btn-right next" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/addslot/{Calendar/calendarID}">
					<xsl:value-of select="$i18n.AddBookingSlot" />
				</a>
			</xsl:if>
			
			<a class="btn btn-blue btn-right bigmarginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/export/{Calendar/calendarID}">
				<xsl:value-of select="$i18n.ExportToExcel" />
				<span class="marginleft" data-icon-after="d" style="position: relative; top: -2px;"/>
			</a>
			
			<a class="btn btn-light btn-right bigmarginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/sendmessages/calendar/{Calendar/calendarID}">
				<xsl:value-of select="$i18n.SendMessages" />
			</a>
			
		</article>
		
	</xsl:template>
	
	<xsl:template match="BookingSlot" mode="list">
		<xsl:param name="calendar" select="../../Calendar"/>
	
		<tr>
			<td data-title="{$i18n.BookingSlot.DateAndTime}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{bookingSlotID}">
					<xsl:value-of select="startDate" />
					<xsl:text> </xsl:text>
					<xsl:call-template name="printBookingSlotTime">
						<xsl:with-param name="bookingSlot" select="."/>
						<xsl:with-param name="calendar" select="$calendar"/>
					</xsl:call-template>
					
					<xsl:if test="title or notBookableText">
						<xsl:text> (</xsl:text>
						<xsl:value-of select="title" />
						<xsl:if test="title and notBookableText">
							<xsl:text>, </xsl:text>
						</xsl:if>
						<xsl:value-of select="notBookableText" />
						<xsl:text>)</xsl:text>
					</xsl:if>
				</a>
			</td>
			<td data-title="{$i18n.BookingSlot.Location}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{bookingSlotID}">
					<xsl:value-of select="location" />
				</a>
			</td>
			<td data-title="{$i18n.BookingSlot.Size}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{bookingSlotID}">
					<xsl:value-of select="bookingsCount" />
					<xsl:text> / </xsl:text>
					<xsl:value-of select="size" />
				</a>
			</td>
			<td class="hidden"></td>
		</tr>
	
	</xsl:template>
	
	<xsl:template name="showBookingSlotControlPanel">
	
		<xsl:param name="bookingSlot" select="BookingSlot" />
		<xsl:param name="template" select="local-name()" />
	
		<div class="errand-menu buttons-in-desktop" data-menu="errand">
	  	<a class="btn btn-dark" data-toggle-menu="errand" href="#">
	  		<span data-icon-after="_">
	  			<xsl:choose>
	  				<xsl:when test="$template = 'ShowBookingSlot'"><xsl:value-of select="$i18n.ShowBookingSlot"/></xsl:when>
	  				<xsl:when test="$template = 'UpdateBookingSlot'"><xsl:value-of select="$i18n.UpdateBookingSlot"/></xsl:when>
	  				<xsl:otherwise><xsl:value-of select="$i18n.ShowCalendar"/></xsl:otherwise>
	  			</xsl:choose>
	  		</span>
	  	</a>
	  	<ul>
	 		
		  	<li>
  				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{$bookingSlot/Calendar/calendarID}" class="btn btn-light">
						<span data-icon-before="o"><xsl:value-of select="$i18n.ShowCalendar"/></span>
					</a>
	  			
	  		</li>
	  		
	  		<li>
	  			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{$bookingSlot/bookingSlotID}" class="btn btn-light">
	  				<xsl:if test="$template = 'ShowBookingSlot'"><xsl:attribute name="class">btn btn-light active</xsl:attribute></xsl:if>
						<span data-icon-before="s"><xsl:value-of select="$i18n.ShowBookingSlot"/></span>
					</a>
	  		</li>
	  		
	  		<li>
	  			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/updateslot/{$bookingSlot/bookingSlotID}" class="btn btn-light">
						<xsl:if test="$template = 'UpdateBookingSlot'"><xsl:attribute name="class">btn btn-light active</xsl:attribute></xsl:if>
						<span data-icon-before="w"><xsl:value-of select="$i18n.UpdateBookingSlot"/></span>
					</a>
	  		</li>
	  		
	  		<xsl:if test="$bookingSlot/Repeating/BookingSlots">
		  		<li>
	  				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/updaterepeating/{BookingSlot/Repeating/repeatID}" class="btn btn-light">
						<span data-icon-before="w"><xsl:value-of select="$i18n.UpdateRepeating"/></span>
					</a>
		  		</li>
		  	</xsl:if>
	  		
	  		<xsl:if test="DeleteAccess">
		  		<li>
		  			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/deleteslot/{$bookingSlot/bookingSlotID}" onclick="return confirmPost(this.href, '{$i18n.DeleteBookingSlotConfirm.1} {$bookingSlot/start} {$i18n.DeleteBookingSlotConfirm.2}?');" title="{$i18n.DeleteBookingSlot}: {$bookingSlot/start}" class="btn btn-light">
							<span data-icon-before="t"><xsl:value-of select="$i18n.DeleteBookingSlot"/></span>
						</a>
		  		</li>
		  		
		  		<xsl:if test="$bookingSlot/Repeating/BookingSlots">
			  		<li>
			  			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/deleterepeating/{$bookingSlot/Repeating/repeatID}" onclick="return confirmPost(this.href, '{$i18n.DeleteRepeatingConfirm}: {$bookingSlot/Repeating/fromDate} till {$bookingSlot/Repeating/toDate}?');" title="{$i18n.DeleteRepeating}: {$bookingSlot/start}" class="btn btn-light">
								<span data-icon-before="t"><xsl:value-of select="$i18n.DeleteRepeating"/></span>
							</a>
			  		</li>
			  	</xsl:if>
		  		
		  	</xsl:if>
	  			
	  	</ul>
		</div>
	
	</xsl:template>
	
	<xsl:template match="ExportCalendar">
	
		<script>
			$(function() {
				if (!Modernizr.inputtypes.date) {
					$( "#fromDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.Export.fromDate"/>',
						changeMonth: true,
						changeYear: true,
						showWeek: true,
					});
					
					$( "#toDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.Export.toDate"/>',
						changeMonth: true,
						changeYear: true,
						showWeek: true,
					});
				}
			});
		</script>
		
		<h1>
			<xsl:value-of select="Calendar/name"/>
		</h1>
		
		<xsl:apply-templates select="validationError"/>

		<p><xsl:value-of select="$i18n.Export.description"/></p>
		
		<form id="exportForm" method="POST">
		
			<div class="marginleft floatleft">
				
				<label for="fromDate" class="marginright">
					<xsl:value-of select="$i18n.Export.fromDate" />
				</label>
				
				<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'fromDate'" />
						<xsl:with-param name="id" select="'fromDate'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="type" select="'date'"/>
						<xsl:with-param name="class" select="'width-auto'"/>
				</xsl:call-template>
			</div>
			
			<div class="bigmarginleft floatleft">
				
				<label for="toDate" class="marginright">
					<xsl:value-of select="$i18n.Export.toDate" />
				</label>
				
				<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'toDate'" />
						<xsl:with-param name="id" select="'toDate'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="type" select="'date'"/>
						<xsl:with-param name="class" select="'width-auto'"/>
				</xsl:call-template>
			</div>
			
			<div class="floatright marginright bigmargintop">
				
				<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{Calendar/calendarID}" title="{$i18n.Back}">
					<xsl:value-of select="$i18n.Back"/>
				</a>
				
				<input class="btn btn-blue btn-inline marginright" type="submit" value="{$i18n.ExportToExcel}" title="{$i18n.ExportToExcel}"/>
			</div>
		
		</form>
		
	</xsl:template>

	<xsl:template match="ShowBookingSlot">
	
		<xsl:variable name="nonArchivedFound" select="//Booking[archived='false']/archived"/>
	
		<div class="panel-wrapper official">
			<xsl:call-template name="showBookingSlotControlPanel" />
		</div>

		<section class="child">
			<div class="section-inside step full">
				<div class="heading-wrapper">
					<div class="inner inner-less-padding">
						<div class="heading">

							<h1 class="xl">

								<xsl:value-of select="$i18n.ShowBookingSlot.title" />
								<xsl:text>:&#160;</xsl:text>
								<xsl:value-of select="BookingSlot/startDate" />
								<xsl:text> </xsl:text>
								<xsl:call-template name="printBookingSlotTime">
									<xsl:with-param name="bookingSlot" select="BookingSlot" />
									<xsl:with-param name="calendar" select="BookingSlot/Calendar" />
								</xsl:call-template>
								
								<xsl:if test="BookingSlot/title">
									<xsl:text> (</xsl:text>
									<xsl:value-of select="BookingSlot/title" />
									<xsl:text>)</xsl:text>
								</xsl:if>
							</h1>

							<div>
								<span class="errandno">

									<div>
										<xsl:value-of select="$i18n.Calendar.Name" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:value-of select="BookingSlot/Calendar/name" />
									</div>

									<div>
										<xsl:value-of select="$i18n.BookingSlot.Added" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:value-of select="BookingSlot/added" />

										<xsl:if test="BookingSlot/Poster/user">
											<xsl:text>&#160;</xsl:text>
											<xsl:value-of select="$i18n.By" />
											<xsl:text>&#160;</xsl:text>
											<xsl:call-template name="printUser">
												<xsl:with-param name="user" select="BookingSlot/Poster/user" />
											</xsl:call-template>
										</xsl:if>
									</div>

									<xsl:if test="BookingSlot/updated">

										<div>
											<xsl:value-of select="$i18n.BookingSlot.Updated" />
											<xsl:text>:&#160;</xsl:text>
											<xsl:value-of select="BookingSlot/updated" />

											<xsl:if test="BookingSlot/Updater/user">
												<xsl:text>&#160;</xsl:text>
												<xsl:value-of select="$i18n.By" />
												<xsl:text>&#160;</xsl:text>
												<xsl:call-template name="printUser">
													<xsl:with-param name="user" select="BookingSlot/Updater/user" />
												</xsl:call-template>
											</xsl:if>
										</div>

									</xsl:if>
																																		
									<xsl:if test="BookingSlot/notBookableText">

										<div class="bigmargintop">
											<xsl:value-of select="BookingSlot/notBookableText" />
										</div>
									
									</xsl:if>

									<br />

									<div>
										<xsl:value-of select="$i18n.BookingSlot.Size" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:value-of select="BookingSlot/size" />
									</div>

									<xsl:if test="BookingSlot/location">
										<div>
											<xsl:value-of select="$i18n.BookingSlot.Location" />
											<xsl:text>:&#160;</xsl:text>
											<xsl:value-of select="BookingSlot/location" />
										</div>
									</xsl:if>

									<div>
										<xsl:value-of select="$i18n.BookingSlot.Managers" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:apply-templates select="BookingSlot/Managers/user" mode="manager-admin" />
									</div>

								</span>

								<xsl:if test="BookingSlot/description">

									<div class="floatleft bigmarginbottom">

										<label class="floatleft full">
											<xsl:value-of select="$i18n.BookingSlot.Description" />
										</label>

										<p>
											<xsl:call-template name="replaceLineBreak">
												<xsl:with-param name="string" select="BookingSlot/description" />
											</xsl:call-template>
										</p>
									</div>

								</xsl:if>
							</div>

						</div>

						<xsl:if test="validationError">
							<div class="bigmarginbottom">
								<xsl:apply-templates select="validationError" />
							</div>
						</xsl:if>

					</div>
				</div>
			</div>

			<div id="tabs">
				<ul class="tabs">
					<li class="active">
						<a data-icon-before="o" href="#bookings">
							<xsl:value-of select="$i18n.Bookings" />
						</a>
					</li>

					<xsl:if test="BookingSlot/Repeating">

						<li>
							<a data-icon-before="o" href="#repeating">
								<xsl:value-of select="$i18n.BookingSlot.Repeating" />
							</a>
						</li>

					</xsl:if>

				</ul>

				<div id="bookings">

					<div class="tabs-content nopadding">

						<div class="errands-wrapper">

							<div class="heading-wrapper">
								<h2 class="nomargin">
									<xsl:value-of select="$i18n.Bookings" />
								</h2>
							</div>

							<table class="oep-table full bigmarginbottom">
								<thead class="sortable">
									<tr>
										<th style="width: 50%;">
											<span>
												<xsl:value-of select="$i18n.Booking.Poster" />
											</span>
										</th>
										<th class="default-sort">
											<span>
												<xsl:value-of select="$i18n.Booking.Added" />
											</span>
										</th>
										<th class="default-sort">
											<span>
												<xsl:value-of select="$i18n.Booking.Size" />
											</span>
										</th>
										<th>
											<span>
												<xsl:value-of select="$i18n.Booking.Digital" />
											</span>
										</th>
										<th>
											<span>
												<xsl:value-of select="$i18n.Booking.Archived" />
											</span>
										</th>
										<th></th>
										<th class="hidden" />
									</tr>
								</thead>
								<tbody>

									<xsl:choose>
										<xsl:when test="BookingSlot/Bookings/Booking">
											<xsl:apply-templates select="BookingSlot/Bookings/Booking" mode="list-bookingslot">
												<xsl:with-param name="calendar" select="BookingSlot/Calendar" />
											</xsl:apply-templates>
										</xsl:when>
										<xsl:otherwise>
											<tr>
												<td colspan="5">
													<xsl:value-of select="$i18n.NoBookings" />
												</td>
											</tr>
										</xsl:otherwise>
									</xsl:choose>

								</tbody>
							</table>

							<article class="buttons floatright">

								<xsl:if test="AddAccess">
								
								

									<xsl:choose>
										<xsl:when test="BookingSlot/HasPassed">
											<a class="btn btn-light btn-right bigmarginright" href="#" onclick="alert('{$i18n.AddBookingDisabled}'); return false;">
												<xsl:value-of select="$i18n.AddBooking" />
											</a>
										</xsl:when>
										<xsl:when test="0 >= (BookingSlot/size - count(BookingSlot/Bookings/Booking[not(archived = 'true')]))">
											<a class="btn btn-light btn-right bigmarginright" href="#" onclick="alert('{$i18n.AddBookingDisabledFull}'); return false;">
												<xsl:value-of select="$i18n.AddBooking" />
											</a>
										</xsl:when>
										<xsl:otherwise>
											<a class="btn btn-green btn-right bigmarginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add/{BookingSlot/bookingSlotID}">
												<xsl:value-of select="$i18n.AddBooking" />
											</a>
										</xsl:otherwise>
									</xsl:choose>
									
								</xsl:if>
								
								<a class="btn btn-blue btn-right bigmarginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/exportslot/{BookingSlot/bookingSlotID}">
									<xsl:value-of select="$i18n.ExportToExcel" />
									<span class="marginleft" data-icon-after="d" style="position: relative; top: -2px;"/>
								</a>
								
								<a class="btn btn-light btn-right bigmarginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/sendmessages/bookingslot/{BookingSlot/bookingSlotID}">
									<xsl:value-of select="$i18n.SendMessages" />
								</a>
								
								
								
								<xsl:choose>
								    <xsl:when test="$nonArchivedFound">
								      <a class="btn btn-green btn-right bigmarginright" href="#" onclick="commentModal(event, this,'#archiveAllForm')">
									  <xsl:value-of select="$i18n.ArchiveAllBookings" />
									  </a>
								    </xsl:when>
								    <xsl:otherwise>
								   	 <a class="btn btn-light btn-right bigmarginright" href="#" onclick="alert('{$i18n.ArchiveAllBookingsDisabled}'); return false;">
									  <xsl:value-of select="$i18n.ArchiveAllBookings" />
									  </a>
								    </xsl:otherwise>
								  </xsl:choose>
								
								<form id="archiveAllForm" action="{/Document/requestinfo/currentURI}/{/Document/module/alias}/archiveAllBookings/{BookingSlot/bookingSlotID}?show=t" method="post">
						
								<input type="hidden" name="comment" value="{DefaultArchiveText}" />
								
								<xsl:param name="booking" select="Booking" />
								
								<div style="display: none;">
							
									<div class="comment-modal contentitem">
										<div class="modal-content">
										
											<div class="modal-header bigmarginbottom">
												<h1>
													<xsl:value-of select="$i18n.ArchiveBooking"/>
													<xsl:text>: </xsl:text>
													<xsl:value-of select="$booking/BookingSlot/startDate"/>
												</h1>
											</div>
											
											<div class="modal-body">
											
												<xsl:if test="$booking/BookingSlot/Calendar/hideExternalMessages = 'false'">
												
													<div class="floatleft full bigmarginbottom">
													
														<p class="tiny floatleft full">
															<xsl:value-of select="$i18n.ArchiveBooking.Description" />
														</p>
													
														<label for="save-email" class="floatleft clearboth">
															<xsl:value-of select="$i18n.Comment" />
														</label>
														
														<div class="floatleft full">
															<xsl:call-template name="createTextArea">
																<xsl:with-param name="name" select="'message'"/>
																<xsl:with-param name="maxlength" select="'1024'"/>
															</xsl:call-template>
													  </div>
													</div>

												</xsl:if>
												
												<input class="btn btn-red close bigmargintop floatright" type="button" value="{$i18n.ArchiveBooking}"/>
												
											</div>
											
										</div>
									</div>
								
								</div>
								
								
								
							</form>
								

							</article>

						</div>

					</div>

				</div>

				<xsl:if test="BookingSlot/Repeating">

					<div id="repeating">

						<div class="tabs-content nopadding">

							<div class="errands-wrapper">

								<div class="heading-wrapper">
									<h2 class="nomargin">
										<xsl:value-of select="$i18n.BookingSlot.Repeating" />
									</h2>
								</div>

								<p>
									<xsl:value-of select="$i18n.BookingSlot.Repeating.1" />
									<xsl:text>&#160;</xsl:text>
									<xsl:value-of select="BookingSlot/Repeating/fromDate" />
									<xsl:text>&#160;</xsl:text>
									<xsl:value-of select="$i18n.BookingSlot.Repeating.2" />
									<xsl:text>&#160;</xsl:text>
									<xsl:value-of select="BookingSlot/Repeating/toDate" />
								</p>

								<table class="oep-table full bigmarginbottom">
									<thead class="sortable">
										<tr>
											<th class="default-sort">
												<span>
													<xsl:value-of select="$i18n.BookingSlot.DateAndTime" />
												</span>
											</th>
											<th>
												<span>
													<xsl:value-of select="$i18n.BookingSlot.Size" />
												</span>
											</th>
											<th class="hidden" />
										</tr>
									</thead>
									<tbody>

										<xsl:choose>
											<xsl:when test="BookingSlot/Repeating/BookingSlots/BookingSlot[not(bookingSlotID = current()/BookingSlot/bookingSlotID)]">
												<xsl:apply-templates select="BookingSlot/Repeating/BookingSlots/BookingSlot[not(bookingSlotID = current()/BookingSlot/bookingSlotID)]" mode="list">
													<xsl:with-param name="calendar" select="BookingSlot/Calendar" />
												</xsl:apply-templates>
											</xsl:when>
											<xsl:otherwise>
												<tr>
													<td colspan="4">
														<xsl:value-of select="$i18n.NoOtherBookingSlots" />
													</td>
												</tr>
											</xsl:otherwise>
										</xsl:choose>

									</tbody>
								</table>

							</div>

						</div>

					</div>

				</xsl:if>

			</div>

			<script type="text/javascript">

				$(function(){
					$("#tabs").tabs();
				});

			</script>

		</section>

	</xsl:template>
	
	<xsl:template match="Booking" mode="list-bookingslot">
		<xsl:param name="calendar" />
	
		<tr>
			<td data-title="{$i18n.Booking.Poster}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/show/{bookingID}">
					
					<xsl:choose>
						<xsl:when test="preliminary = 'true'">
							<xsl:value-of select="$i18n.Booking.Preliminary"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="printBookingUser"/>
						</xsl:otherwise>
					</xsl:choose>
					
				</a>
			</td>
			<td data-title="{$i18n.Booking.Added}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/show/{bookingID}">
					<xsl:value-of select="added" />
				</a>
			</td>
			<td data-title="{$i18n.Booking.Size}">
				<xsl:value-of select="size" />
			</td>
			<td data-title="{$i18n.Booking.Digital}">
				<xsl:choose>
					<xsl:when test="Digital">
					
						<xsl:value-of select="$i18n.Yes"/>
						
					</xsl:when>
					<xsl:when test="DigitalNotContactable">
					
						<xsl:value-of select="$i18n.Yes"/><xsl:text> (</xsl:text><xsl:value-of select="$i18n.Booking.DigitalNotContactable" /><xsl:text>)</xsl:text>
						
					</xsl:when>
					<xsl:otherwise>
					
						<xsl:value-of select="$i18n.No"/>
						
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td data-title="{$i18n.Booking.Archived}">
				<xsl:choose>
					<xsl:when test="archived = 'true'">
					
						<xsl:value-of select="$i18n.Yes"/>
						
					</xsl:when>
					<xsl:otherwise>
					
						<xsl:value-of select="$i18n.No"/>
						
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td>
				<xsl:if test="not(preliminary = 'true') and not(archived = 'true')">
					<a class="btn btn-light" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/resendbooking/{bookingID}" onclick="return confirmPost(this.href,'{$i18n.ResendConfirm}?')">
						<xsl:value-of select="$i18n.Resend" />
					</a>
				</xsl:if>
			</td>
			<td class="hidden"><xsl:value-of select="PrimaryContact/citizenIdentifier" /></td>
		</tr>
	
	</xsl:template>
	
	
	<xsl:template name="showBookingControlPanel">
	
		<xsl:param name="booking" select="Booking" />
		<xsl:param name="template" select="local-name()" />
		
	
		<div class="errand-menu buttons-in-desktop" data-menu="errand">
			<a class="btn btn-dark" data-toggle-menu="errand" href="#">
				<span data-icon-after="_">
				</span>
			</a>
			
			<ul>
				
				<li>
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{$booking/BookingSlot/bookingSlotID}" class="btn btn-light">
						<span data-icon-before="o"><xsl:value-of select="$i18n.ShowBookingSlot"/></span>
					</a>
				</li>
				
				<li>
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/show/{$booking/bookingID}" class="btn btn-light">
						<xsl:if test="$template = 'ShowBooking'">
							<xsl:attribute name="class">btn btn-light active</xsl:attribute>
						</xsl:if>
						
						<span data-icon-before="s"><xsl:value-of select="$i18n.ShowBooking"/></span>
					</a>
				</li>
				
				<xsl:if test="$booking/flowInstanceID">
						
					<li>
						<a target="_blank" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/preview/{$booking/bookingID}" class="btn btn-light">
							<span data-icon-before="s"><xsl:value-of select="$i18n.ShowFlowInstance"/></span>
						</a>
					</li>
					
					<li>
						<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/download/{$booking/bookingID}" class="btn btn-light">
							<span data-icon-before="d"><xsl:value-of select="$i18n.DownloadFlowInstancePDF"/></span>
						</a>
					</li>
						
				</xsl:if>
				
				<xsl:choose>
					<xsl:when test="$booking/BookingSlot/HasPassed">
						<xsl:if test="DeleteAccess">
							<li>
								<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/delete/{$booking/bookingID}" onclick="return confirmPost(this.href, '{$i18n.DeleteBookingConfirm}: {$booking/BookingSlot/start} ?');" title="{$i18n.DeleteBooking}: {$booking/BookingSlot/start}" class="btn btn-light">
									<span data-icon-before="t"><xsl:value-of select="$i18n.DeleteBooking"/></span>
								</a>
							</li>
						</xsl:if>
					</xsl:when>
					<xsl:when test="$booking/archived = 'true'">
					
						<li>
							<form id="unArchiveForm" action="{/Document/requestinfo/currentURI}/{/Document/module/alias}/unarchive/{$booking/bookingID}?show=t" method="post">
							
									<input type="hidden" name="comment" />
									
									<div style="display: none;">
								
										<div class="comment-modal contentitem">
											<div class="modal-content">
											
												<div class="modal-header bigmarginbottom">
													<h1>
														<xsl:value-of select="$i18n.UnArchiveBooking.Title"/>
														<xsl:text>: </xsl:text>
														<xsl:value-of select="$booking/BookingSlot/startDate"/>
													</h1>
												</div>
												
												<div class="modal-body">
												
													<xsl:if test="$booking/BookingSlot/Calendar/hideExternalMessages = 'false' or $booking/Analog">
												
														<div class="floatleft full bigmarginbottom">
														
															<p class="tiny floatleft full">
																<xsl:choose>
																	<xsl:when test="$booking/Analog">
																		<xsl:value-of select="$i18n.UnArchiveBooking.Description.Analog" />
																	</xsl:when>
																	<xsl:otherwise>
																		<xsl:value-of select="$i18n.UnArchiveBooking.Description" />
																	</xsl:otherwise>
																</xsl:choose>
															</p>
															
															<label for="save-email" class="floatleft clearboth">
																<xsl:value-of select="$i18n.Comment" />
															</label>
															
															<div class="floatleft full">
																<xsl:call-template name="createTextArea">
																	<xsl:with-param name="name" select="'message'"/>
																	<xsl:with-param name="maxlength" select="'1024'"/>
																</xsl:call-template>
															</div>
														</div>
														
													</xsl:if>
													
													<input class="btn btn-red close bigmargintop floatright" type="button" value="{$i18n.UnArchiveBooking}"/>
													
												</div>
												
											</div>
										</div>
									
									</div>
									
								<a href="#" onclick="commentModal(event, this, '#unArchiveForm')" title="{$i18n.UnArchiveBooking}: {$booking/BookingSlot/startDate}" class="btn btn-light">
									<span data-icon-before="+"><xsl:value-of select="$i18n.UnArchiveBooking"/></span>
								</a>
								
							</form>
						</li>
						
						<xsl:if test="DeleteAccess">
							<li>
								<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/delete/{$booking/bookingID}" onclick="return confirmPost(this.href, '{$i18n.DeleteBookingConfirm}: {$booking/BookingSlot/start} ?');" title="{$i18n.DeleteBooking}: {$booking/BookingSlot/start}" class="btn btn-light">
									<span data-icon-before="t"><xsl:value-of select="$i18n.DeleteBooking"/></span>
								</a>
							</li>
						</xsl:if>
					
					</xsl:when>
					<xsl:otherwise>
						
						<li>
							<form id="archiveForm" action="{/Document/requestinfo/currentURI}/{/Document/module/alias}/archive/{$booking/bookingID}?show=t" method="post">
						
								<input type="hidden" name="comment" value="{DefaultArchiveText}" />
								
								<div style="display: none;">
							
									<div class="comment-modal contentitem">
										<div class="modal-content">
										
											<div class="modal-header bigmarginbottom">
												<h1>
													<xsl:value-of select="$i18n.ArchiveBooking"/>
													<xsl:text>: </xsl:text>
													<xsl:value-of select="$booking/BookingSlot/startDate"/>
												</h1>
											</div>
											
											<div class="modal-body">
											
												<xsl:if test="$booking/BookingSlot/Calendar/hideExternalMessages = 'false' or $booking/Analog">
												
													<div class="floatleft full bigmarginbottom">
													
														<p class="tiny floatleft full">
															<xsl:choose>
																<xsl:when test="$booking/Analog">
																	<xsl:value-of select="$i18n.ArchiveBooking.Description.Analog" />
																</xsl:when>
																<xsl:otherwise>
																	<xsl:value-of select="$i18n.ArchiveBooking.Description" />
																</xsl:otherwise>
															</xsl:choose>
														</p>
													
														<label for="save-email" class="floatleft clearboth">
															<xsl:value-of select="$i18n.Comment" />
														</label>
														
														<div class="floatleft full">
															<xsl:call-template name="createTextArea">
																<xsl:with-param name="name" select="'message'"/>
																<xsl:with-param name="maxlength" select="'1024'"/>
															</xsl:call-template>
													  </div>
													  
												</div>
													
												</xsl:if>
												<input class="btn btn-red close bigmargintop floatright" type="button" value="{$i18n.ArchiveBooking}"/>
												
											</div>
											
										</div>
									</div>
								
								</div>
								
								<a href="#" onclick="commentModal(event, this, '#archiveForm')" title="{$i18n.ArchiveBooking}: {$booking/BookingSlot/startDate}" class="btn btn-light">
									<span data-icon-before="l"><xsl:value-of select="$i18n.ArchiveBooking"/></span>
								</a>
								
							</form>
						</li>
						
					</xsl:otherwise>
				</xsl:choose>
				
			</ul>
		</div>
	
	</xsl:template>
	
	<xsl:template match="ShowBooking">
	
		<div class="panel-wrapper official">
			<xsl:call-template name="showBookingControlPanel"/>
		</div>
	
		<section class="child">
			<div class="section-inside step full">
				<div class="heading-wrapper">
					<div class="inner inner-less-padding">
												
						<xsl:if test="validationError">
							<div class="bigmarginbottom">
								<xsl:apply-templates select="validationError"/>
							</div>
						</xsl:if>
						
						<div class="heading">
						
							<h1 class="xl">
							
								<xsl:choose>
									<xsl:when test="Booking/archived = 'true'">
										
										<xsl:value-of select="$i18n.ShowBooking.Archived.title"/>
										
									</xsl:when>
									<xsl:otherwise>
										
										<xsl:value-of select="$i18n.ShowBooking.title"/>
										
									</xsl:otherwise>
								</xsl:choose>
								
								<xsl:text>&#160;</xsl:text>
								<xsl:value-of select="Booking/BookingSlot/startDate" />
								<xsl:text> </xsl:text>
								<xsl:call-template name="printBookingSlotTime">
									<xsl:with-param name="bookingSlot" select="Booking/BookingSlot"/>
									<xsl:with-param name="calendar" select="Booking/BookingSlot/Calendar"/>
								</xsl:call-template>
								
								<xsl:if test="Booking/BookingSlot/title">
									<xsl:text> (</xsl:text>
									<xsl:value-of select="Booking/BookingSlot/title" />
									<xsl:text>)</xsl:text>
								</xsl:if>
								
							</h1>
							
							<div>
							
								<span class="errandno">
								
									<div>
										<xsl:value-of select="$i18n.Calendar.Name" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:value-of select="Booking/BookingSlot/Calendar/name" />
									</div>
									
									<div>
										<xsl:value-of select="$i18n.Booking.Added" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:value-of select="Booking/BookingSlot/added" />
									</div>
									
									<div>
										<xsl:value-of select="$i18n.Booking.Size" />
										<xsl:text>:&#160;</xsl:text>
										<xsl:value-of select="Booking/size" />
									</div>
									
								</span>
							
							</div>
							
							<xsl:apply-templates select="ExtensionFragments/ViewFragment"/>
							
						</div>
					</div>
 				</div>
 			</div>
 			
 			<div class="floatleft full border-box" style="padding: 0 3.9283784%">
 			
 				<div class="fifty floatleft paddingright border-box" style="min-width: 300px;">
					<fieldset class="floatleft border-box full border-radius-medium border bigpadding" style="min-width: 300px;">
						<legend class="">
							<xsl:value-of select="$i18n.PrimaryContact"/>
						</legend>
						
						<xsl:call-template name="Contact">
							<xsl:with-param name="contact" select="Booking/PrimaryContact"/>
						</xsl:call-template>
					</fieldset>
				</div>
				
				<div class="fifty floatleft paddingleft border-box" style="min-width: 300px;">
					<fieldset class="floatleft border-box full border-radius-medium border bigpadding" style="min-width: 300px;">
			
						<xsl:choose>
							<xsl:when test="Booking/Poster">
							
								<legend>
									<xsl:value-of select="$i18n.UserContact"/>
								</legend>
								
								<xsl:call-template name="Contact-User">
									<xsl:with-param name="user" select="Booking/Poster/user"/>
								</xsl:call-template>
							
							</xsl:when>
							<xsl:when test="Booking/ManualContact">
								
								<legend>
									<xsl:value-of select="$i18n.ManualContact"/>
								</legend>
								
								<a class="marginright floatright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/updatecontact/{Booking/bookingID}">
									<span data-icon-before="w">ndra</span>
								</a>
								
								<xsl:call-template name="Contact">
									<xsl:with-param name="contact" select="Booking/ManualContact"/>
								</xsl:call-template>
								
							</xsl:when>
							<xsl:otherwise>
							
								<legend>
									<xsl:value-of select="$i18n.ManualContact"/>
								</legend>
								
								<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/updatecontact/{Booking/bookingID}">
									<span data-icon-before="w">Lgg till</span>
								</a>
							
							</xsl:otherwise>
						</xsl:choose>
				
					</fieldset>
				</div>
				
 			</div>
  			
			<div id="tabs">
 				<ul class="tabs">
 					<li class="active">
 						<a data-icon-before="o" href="#history"><xsl:value-of select="$i18n.BookingEvents" /></a>
 					</li>
 					
						<xsl:if test="Booking/BookingSlot/Calendar/hideExternalMessages = 'false' and (Booking/Digital or Booking/Poster or Booking/ExternalMessages/ExternalMessage)">
	  					<li data-tabid="#messages">
	  						<a data-icon-before="m" href="#messages">
	  							<xsl:value-of select="$i18n.ExternalMessages" />
	  							<!-- TODO count how many unread messages since last login -->
	  							<xsl:if test="false()">
	  								<span class="count">0</span>
	  							</xsl:if>
	  						</a>
	  					</li>
 					</xsl:if>
 					
 					<li data-tabid="#notes" class="notes">
 						<a data-icon-before="i" href="#notes"><xsl:value-of select="$i18n.InternalMessages" /></a>
 					</li>
 				</ul>
 				
 				<xsl:if test="Booking/BookingSlot/Calendar/hideExternalMessages = 'false' and (Booking/Digital or Booking/Poster or Booking/ExternalMessages/ExternalMessage)">
	  				<div id="messages">
	  					
	  					<xsl:if test="Booking/Digital or Booking/Poster">
		  					<div id="new-message" class="tabs-content">
		  						
		  						<div class="heading-wrapper">
		  							<h2><xsl:value-of select="$i18n.NewMessage" /></h2>
		  							<a href="#" class="btn btn-light btn-right close_message"><xsl:value-of select="$i18n.Close" /><i data-icon-after="x"></i></a>
		  						</div>
		  						
									<xsl:if test="not(Booking/Digital)">
		 								<p class="error">
		 									<xsl:value-of select="$i18n.NewMessage.NoNotificationWay"/>
		 								</p>
		 							</xsl:if>
		 							
		  						<form action="{/Document/requestinfo/uri}?externalmessage#messages" method="post" enctype="multipart/form-data">
		  						
			  						<label class="required" for="message"><xsl:value-of select="$i18n.Message" /></label>
			  						<xsl:apply-templates select="validationError[fieldName = 'externalmessage']" />
			  						<textarea id="message" name="externalmessage" class="full"></textarea>
			  						<div class="heading-wrapper">
			  							<label><xsl:value-of select="$i18n.AttachFiles" /></label>
			  						</div>
			  						
			  						<script>
										imagePath = '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics';
										deleteFile = '<xsl:value-of select="$i18n.DeleteFile" />';
									</script>
									
									<xsl:apply-templates select="validationError[messageKey = 'FileSizeLimitExceeded' or messageKey = 'UnableToParseRequest']" />
									
									<div class="full">
										
										<div class="upload clearboth">
											<span class="btn btn-upload btn-blue">
												<xsl:value-of select="$i18n.ChooseFiles" />
												<input id="external-message" type="file" name="attachments" multiple="multiple" size="55" class="qloader externalmessages bigmarginbottom" />
											</span>
											<span><xsl:value-of select="$i18n.MaximumFileSize" />: <xsl:value-of select="FormatedMaxFileSize" /></span>
										</div>
										
										<ul id="external-message-qloader-filelist" class="files" />
										
									</div>
									
			  						<input type="submit" value="{$i18n.SubmitMessage}" name="externalmessage" class="btn btn-green btn-inline" />
			  						<a href="#" class="btn btn-light btn-inline close_message"><xsl:value-of select="$i18n.Cancel" /></a>
			  						
		  						</form>
		  						
		  					</div>
	  					</xsl:if>
	  					
	  					<div class="tabs-content">
		  					
		  					<div class="heading-wrapper">
		  						<h2><xsl:value-of select="$i18n.ExternalMessages" /></h2>
		  						
		  						<xsl:if test="IsNewExternalMessagesAllowed = 'true' and (Booking/Digital or Booking/Poster)">
		  							<a href="#" class="btn btn-blue btn-right open_message"><i data-icon-before="+"></i><xsl:value-of select="$i18n.NewMessage" /></a>
		  						</xsl:if>
		  					</div>
		  					
		  					<xsl:choose>
		  						<xsl:when test="Booking/ExternalMessages/ExternalMessage">
									
									<xsl:call-template name="sortMessagesButton">
										<xsl:with-param name="defaultOrder" select="DefaultMessageOrder" />
									</xsl:call-template>
									
		  							<ul class="messages">
		  								<xsl:apply-templates select="Booking/ExternalMessages/ExternalMessage" mode="admin" />
		  							</ul>
		  						</xsl:when>
		  						<xsl:otherwise>
		  							<xsl:value-of select="$i18n.NoExternalMessages" />
		  						</xsl:otherwise>	  					
		  					</xsl:choose>
		  					
		  				</div>
		  				
	  				</div>
 				</xsl:if>
 				
 				<div id="history" class="tabs-content nopadding" >
 					
 					<div class="errands-wrapper">
  					
	  					<div class="heading-wrapper">
		  					<h2><xsl:value-of select="$i18n.BookingEvents" /></h2>
	  					</div>
	  					
	  					<table class="oep-table">
	  						<thead class="errand">
	  							<tr>
	  								<th class="service active"><span><xsl:value-of select="$i18n.Action" /></span></th>
		  							<th class="details"><span><xsl:value-of select="$i18n.Details" /></span></th>
	  								<th class="date"><span><xsl:value-of select="$i18n.Date" /></span></th>
	  								<th class="person"><span><xsl:value-of select="$i18n.Person" /></span></th>
	  							</tr>
	  						</thead>
	  						<tbody>
	  							<xsl:choose>
	  								<xsl:when test="Booking/Events/BookingEvent">
	  									<xsl:apply-templates select="Booking/Events/BookingEvent" />
	  								</xsl:when>
	  								<xsl:otherwise>
	  									<tr><td class="icon" /><td colspan="5"><xsl:value-of select="$i18n.NoEvents" /></td></tr>
	  								</xsl:otherwise>
	  							</xsl:choose>
	  						</tbody>
	  					</table>
  					
  					</div>
  				
  			</div>
  			
	 			<div id="notes">
		  			
  				<div id="new-note" class="tabs-content notes">
  				
 						<div class="heading-wrapper">
 							<h2><xsl:value-of select="$i18n.NewInternalMessage" /></h2>
 							<a href="#" class="btn btn-light btn-right close_message"><xsl:value-of select="$i18n.Close" /><i data-icon-after="x"></i></a>
 						</div>
 						
 						<form action="{/Document/requestinfo/uri}?internalmessage#notes" method="post" enctype="multipart/form-data">
 						
  						<label class="required" for="message"><xsl:value-of select="$i18n.InternalMessage" /></label>
  						<xsl:apply-templates select="validationError[fieldName = 'internalmessage']" />
  						<textarea id="message" name="internalmessage" class="full"></textarea>
  						<div class="heading-wrapper">
  							<label><xsl:value-of select="$i18n.AttachFiles" /></label>
  						</div>
  						
  						<script>
							imagePath = '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics';
							deleteFile = '<xsl:value-of select="$i18n.DeleteFile" />';
						</script>				
						
						<xsl:apply-templates select="validationError[messageKey = 'FileSizeLimitExceeded' or messageKey = 'UnableToParseRequest']" />
						
						<div class="full">
							
							<div class="upload clearboth">
								<span class="btn btn-upload btn-blue">
									<xsl:value-of select="$i18n.ChooseFiles" />
									<input id="internal-message" type="file" name="attachments" multiple="multiple" size="55" class="qloader internalmessages bigmarginbottom" />
								</span>
								<span><xsl:value-of select="$i18n.MaximumFileSize" />: <xsl:value-of select="FormatedMaxFileSize" /></span>
							</div>
							
							<ul id="internal-message-qloader-filelist" class="files" />
							
						</div>
						
  						<input type="submit" value="{$i18n.SubmitInternalMessage}" name="internalmessage" class="btn btn-green btn-inline" />
  						<a href="#" class="btn btn-light btn-inline close_message"><xsl:value-of select="$i18n.Cancel" /></a>
  						
 						</form>
 						
 					</div>
 					
 					<div class="tabs-content notes">
  					
  					<div class="heading-wrapper">
  						<h2><xsl:value-of select="$i18n.InternalMessagesTitle" /></h2>
  						<a href="#" class="btn btn-blue btn-right open_message"><i data-icon-before="+"></i><xsl:value-of select="$i18n.NewInternalMessage" /></a>
  					</div>
  					
  					<xsl:choose>
  						<xsl:when test="Booking/InternalMessages/InternalMessage">
								
							<xsl:call-template name="sortMessagesButton">
								<xsl:with-param name="defaultOrder" select="DefaultMessageOrder" />
								<xsl:with-param name="type" select="'internal'"/>
							</xsl:call-template>	
														
  							<ul class="messages">
  								<xsl:apply-templates select="Booking/InternalMessages/InternalMessage" mode="admin" />
  							</ul>
  						</xsl:when>
  						<xsl:otherwise>
  							<xsl:value-of select="$i18n.NoInternalMessages" />
  						</xsl:otherwise>	  					
  					</xsl:choose>
  					
  				</div>
  				
  			</div>
  			
 			</div>
 			
 			<script type="text/javascript">
					
				$(function(){
						
					$("#tabs").tabs();
					
				});
					
			</script>
 			
		</section>
		
	</xsl:template>
	
	<xsl:template name="Contact">
		<xsl:param name="contact" select="null"/>
		
		<div class="floatleft">
			<label class="floatleft"><xsl:value-of select="$i18n.Contact.Name" /></label>
			
			<div class="floatleft clearboth">
				<xsl:value-of select="$contact/firstname" />
					<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="$contact/lastname" />
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.CitizenIdentifier" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/citizenIdentifier" />
				</div>
			</div>
			
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.Email" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/email" />
				</div>
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.Phone" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/phone" />
				</div>
			</div>
			
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.MobilePhone" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/mobilePhone" />
				</div>
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.Address" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/address" />
				</div>
			</div>
			
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.PostalCode" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/zipCode" />
				</div>
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.PostalAddress" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$contact/postalAddress" />
				</div>
			</div>
		
		</div>
	
	</xsl:template>
	
	<xsl:template name="Contact-User">
		<xsl:param name="user" select="null"/>
		
		<div class="floatleft">
			<label class="floatleft"><xsl:value-of select="$i18n.Contact.Name" /></label>
			
			<div class="floatleft clearboth">
				<xsl:value-of select="$user/firstname" />
					<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="$user/lastname" />
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.CitizenIdentifier" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/Attributes/Attribute[Name = 'citizenIdentifier']/Value" />
				</div>
			</div>
			
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.Email" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/email" />
				</div>
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.Phone" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/Attributes/Attribute[Name = 'phone']/Value" />
				</div>
			</div>
			
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.MobilePhone" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/Attributes/Attribute[Name = 'mobilePhone']/Value" />
				</div>
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.Address" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/Attributes/Attribute[Name = 'address']/Value" />
				</div>
			</div>
			
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.PostalCode" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/Attributes/Attribute[Name = 'zipCode']/Value" />
				</div>
			</div>
		</div>
		
		<div class="floatleft full">
			<div class="floatleft fifty">
				<label class="floatleft"><xsl:value-of select="$i18n.Contact.PostalAddress" /></label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="$user/Attributes/Attribute[Name = 'postalAddress']/Value" />
				</div>
			</div>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="AddBookingSlot">
	
		<section class="settings">
		
			<div class="heading-wrapper">
				<h1>
					<xsl:value-of select="$i18n.AddBookingSlot" />
				</h1>
			</div>
			
			<form method="POST" action="{/Document/requestinfo/uri}" name="bookingSlotForm" id="bookingSlotForm">
			
				<article class="marginleft">
					
					<xsl:call-template name="bookingSlotForm"/>
					
					<div class="full">
		
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'addBookings'" />
							<xsl:with-param name="name" select="'addBookings'" />
							<xsl:with-param name="value" select="'true'" />
						</xsl:call-template>
						
						<label for="addBookings">
							<xsl:value-of select="$i18n.BookingSlot.AddBookings" />
						</label>
					</div>
					
					<div class="full bigmarginbottom"  id="addBookingsContainer">
						<div class="floatleft full bigmarginbottom">
							<label for="client" class="floatleft full">
								<xsl:value-of select="$i18n.BookingSlot.Clients" />
							</label>
							
							<div id="bookingClients">
								<xsl:if test="requestparameters">
<!-- 									<xsl:apply-templates select="requestparameters/parameter[name='citizenID']/value" mode="booking"/> -->
								</xsl:if>
							</div>
							
							<div class="floatleft full" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/testssn/">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'client'" />
									<xsl:with-param name="name" select="'client'"/>
									<xsl:with-param name="placeholder" select="$i18n.Booking.TypeSSN"/>
								</xsl:call-template>
							</div>
							
							<p class="error" id="clientError" style="display: none;"><xsl:value-of select="$i18n.InvalidSSN"/></p>
							<p class="error" id="duplicateError" style="display: none;"><xsl:value-of select="$i18n.BookingDuplicate"/></p>
						</div>
					</div>
				
					<div class="full">
		
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'repeating'" />
							<xsl:with-param name="name" select="'repeating'" />
							<xsl:with-param name="value" select="'true'" />
						</xsl:call-template>
						
						<label for="repeating">
							<xsl:value-of select="$i18n.BookingSlot.Repeating" />
						</label>
					</div>
					
					<div class="full bigmarginbottom"  id="repetitionIntervalContainer">
						<label for="repetitionInterval" class="required full">
							<xsl:value-of select="$i18n.Repeating.RepetitionInterval" />
						</label>
						
						<div class="alternative floatleft clearboth">
							
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'repetitionInterval7'" />
								<xsl:with-param name="name" select="'repetitionInterval'" />
								<xsl:with-param name="value" select="'7'" />
							</xsl:call-template>
							
							<xsl:text>&#x20;</xsl:text>
							<label for="repetitionInterval7"><xsl:value-of select="$i18n.Repeating.RepetitionInterval.Weekly" /></label>
							
						</div>
						
						<div class="alternative clearboth">
							
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'repetitionInterval14'" />
								<xsl:with-param name="name" select="'repetitionInterval'" />
								<xsl:with-param name="value" select="'14'" />
							</xsl:call-template>
							
							<xsl:text>&#x20;</xsl:text>
							<label for="repetitionInterval14"><xsl:value-of select="$i18n.Repeating.RepetitionInterval.BiWeekly" /></label>
							
						</div>
						
						<div class="alternative clearboth">
							
							<xsl:call-template name="createRadio">
								<xsl:with-param name="id" select="'repetitionIntervalUseCustom'" />
								<xsl:with-param name="name" select="'repetitionInterval'" />
								<xsl:with-param name="value" select="'custom'" />
							</xsl:call-template>
							
							<xsl:text>&#x20;</xsl:text>
							<label for="repetitionIntervalUseCustom"><xsl:value-of select="$i18n.Repeating.RepetitionInterval.UseCustom" /></label>
							
						</div>
						
						<div class="full bigmarginbottom">
							<label for="repetitionIntervalCustom" class="required full">
								<xsl:value-of select="$i18n.Repeating.RepetitionInterval.Custom" />
							</label>
							
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'repetitionIntervalCustom'" />
								<xsl:with-param name="name" select="'repetitionIntervalCustom'" />
								<xsl:with-param name="size" select="10" />
							</xsl:call-template>
						</div>
					</div>
					
					<div class="full bigmarginbottom"  id="repetitionToDateContainer">
						<label for="repetitionToDate" class="required full">
							<xsl:value-of select="$i18n.Repeating.ToDate" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="id" select="'repetitionToDate'" />
							<xsl:with-param name="name" select="'repetitionToDate'" />
							<xsl:with-param name="type" select="'date'" />
							<xsl:with-param name="size" select="10" />
							<xsl:with-param name="element" select="BookingSlot"/>
						</xsl:call-template>
					</div>
					
					<xsl:apply-templates select="ExtensionFragments/ViewFragment"/>
					
				</article>
				
				<script type="text/javascript">
					$(function() {
						$("#repetitionToDate").datepicker({
							showOn: "button",
							buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
							buttonImageOnly: true,
							buttonText: '<xsl:value-of select="$i18n.OpenDatePicker"/>',
							changeMonth: true,
					        changeYear: true,
					        showWeek: true
						});
					});
				</script>
				
				<article class="buttons text-align-right">
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{Calendar/calendarID}" class="btn btn-light btn-inline" onclick="return confirmPost(this.href, '{$i18n.CancelConfirm}?');"><xsl:value-of select="$i18n.Cancel" /></a>
					<input type="submit" value="{$i18n.Add}" class="btn btn-green btn-inline next" />
				</article>
				
				<div style="display: none;">
								
					<div id="confirmBookingsModal" class="contentitem">
						<div class="modal-content">
						
							<div class="modal-header bigmarginbottom">
								<h1>
									<xsl:value-of select="$i18n.AddBooking.Confirm.Title"/>
									<xsl:text> </xsl:text>
									<span id="confirmBookingsModalDate"></span>
								</h1>
							</div>
							
							<div class="modal-body">
							
								<xsl:if test="Calendar/sendEnteredUserEmail = 'true' or Calendar/sendEnteredUserSMS = 'true'">
								
									<p id="confirmBookingsModalNotificationText" class="tiny floatleft full">
									
										<xsl:value-of select="$i18n.AddBooking.Confirm.Description" />
										
										<xsl:text> </xsl:text>
										
										<xsl:choose>
											<xsl:when test="Calendar/sendEnteredUserEmail = 'true' and Calendar/sendEnteredUserSMS = 'true'">
												<xsl:value-of select="$i18n.AddBooking.Confirm.Email"></xsl:value-of>
												<xsl:text> </xsl:text>
												<xsl:value-of select="$i18n.AddBooking.Confirm.And"></xsl:value-of>
												<xsl:text> </xsl:text>
												<xsl:value-of select="$i18n.AddBooking.Confirm.SMS"></xsl:value-of>
											</xsl:when>
											<xsl:when test="Calendar/sendEnteredUserEmail = 'true'">
												<xsl:value-of select="$i18n.AddBooking.Confirm.Email"></xsl:value-of>
											</xsl:when>
											<xsl:when test="Calendar/sendEnteredUserSMS = 'true'">
												<xsl:value-of select="$i18n.AddBooking.Confirm.SMS"></xsl:value-of>
											</xsl:when>
										</xsl:choose>
	
										<xsl:text>.</xsl:text>
									
									</p>

								</xsl:if>
							
								<div class="floatleft full bigmarginbottom">
								  
									<p id="confirmBookingsModalList" class="floatleft full"></p>
								  
								</div>
								
								<input class="btn btn-green close bigmargintop floatright" type="button" value="{$i18n.AddBooking.Confirm.Confirm}" onclick="$('#bookingSlotForm').trigger('submit')"/>
								<input class="btn btn-red close bigmargintop bigmarginright floatright" type="button" value="{$i18n.AddBooking.Confirm.Cancel}" onclick="$.featherlight.close()"/>
								
							</div>
							
						</div>
					</div>
				
				</div>
			
			</form>
			
			<div class="hidden" id="clientTemplate">
				<div class="clearfix">
					<img class="vertical-align-middle floatleft marginright" src="{$imagePath}/user.png"/>
					<input type="hidden" name="citizenID" value="$ssn"/>
					<input type="hidden" name="citizenName-$ssn" value="$name"/>
					<span class="citizen floatleft min-width-twenty">$ssn - $name</span>
					<input type="text" class="floatleft" name="phone-$ssn" placeholder="{$i18n.MobilePhone}" value="$phone"/>
						
					<xsl:if test="Calendar/bookingSizeSelectorEnabled = 'true'">
					
						<xsl:call-template name="BookingSizeSelector">
							<xsl:with-param name="name" select="'size-$ssn'" />
							<xsl:with-param name="value" select="1" />
							<xsl:with-param name="bookingSlot" select="BookingSlot" />
							<xsl:with-param name="hideText" select="true()" />
							<xsl:with-param name="requestparameters" select="null" />
						</xsl:call-template>
						
					</xsl:if>
						
					<a class="floatright delete" href="#" title="{$i18n.RemoveClient}"><img class="vertical-align-middle" src="{$imagePath}/user_delete.png" alt="{$i18n.RemoveClient}"/></a>
				</div>
			</div>
		
		</section>
		
		<script src="{$scriptPath}/bookingslotaddform.js?v=2"></script>
		<link rel="stylesheet" href="{$linkPath}/bookingslotaddform.css"></link>

		
		<script type="text/javascript">
			$(function(){
			
				AddFormi18n = {
					UnknownBooking: "<xsl:value-of select="$i18n.AddBooking.Confirm.UnknownBooking" />"
				}
			});
		</script>
		
	</xsl:template>
	
	<xsl:template match="value" mode="booking">
	
		<xsl:variable name="phoneParam">
			<xsl:text>phone-</xsl:text>
			<xsl:value-of select="."/>
		</xsl:variable>
		
		<xsl:variable name="readonlyParam">
			<xsl:text>readonly-</xsl:text>
			<xsl:value-of select="."/>
		</xsl:variable>

		<xsl:variable name="nameParam">
			<xsl:text>citizenName-</xsl:text>
			<xsl:value-of select="."/>
		</xsl:variable>
		
		<div class="clearfix">
			<img class="vertical-align-middle floatleft marginright" src="{$imagePath}/user.png"/>
			<input type="hidden" name="citizenID" value="{.}"/>
			<input type="hidden" name="citizenName-{.}" value="{../../parameter[name = $nameParam]/value}"/>
			<span class="citizen floatleft min-width-twenty"><xsl:value-of select="."/><xsl:text> - </xsl:text><xsl:value-of select="../../parameter[name = $nameParam]/value" /></span>
			<input type="text" class="floatleft" name="phone-{.}" placeholder="{$i18n.MobilePhone}" value="{../../parameter[name = $phoneParam]/value}">
				<xsl:if test="../../parameter[name = $readonlyParam]">
					<xsl:attribute name="readonly">readonly</xsl:attribute>
				</xsl:if>
			</input>
			<a class="floatright delete" href="#" title="{$i18n.RemoveClient}"><img class="vertical-align-middle" src="{$imagePath}/user_delete.png" alt="{$i18n.RemoveClient}"/></a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="UpdateBookingSlot">
	
		<div class="panel-wrapper official">
			<xsl:call-template name="showBookingSlotControlPanel"/>
		</div>
		
		<section class="settings">
			<div class="heading-wrapper">
				<h1>
					<xsl:value-of select="$i18n.UpdateBookingSlot" />
				</h1>
			</div>
			
			<form method="POST" action="{/Document/requestinfo/uri}" name="bookingSlotForm">
			
				<article class="marginleft">
					
					<xsl:call-template name="bookingSlotForm"/>

					<xsl:apply-templates select="ExtensionFragments/ViewFragment"/>
					
				</article>
			
				<article class="buttons floatright">
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{BookingSlot/bookingSlotID}" class="btn btn-light btn-inline" onclick="return confirmPost(this.href, '{$i18n.CancelConfirm}?');"><xsl:value-of select="$i18n.Cancel" /></a>
					<input type="submit" value="{$i18n.SaveChanges}" class="btn btn-green btn-inline next" />
				</article>
			
			</form>
			
		</section>
		
	</xsl:template>
	
	<xsl:template name="bookingSlotForm">
	
		<xsl:if test="validationException/validationError">
			<div class="bigmarginbottom">
				<xsl:apply-templates select="validationException/validationError"/>
			</div>
		</xsl:if>
		
		<input type="hidden" name="title" value="{BookingSlot/title}"/>
		
		<div class="full bigmarginbottom">
			<label for="startDate" class="full required">
				<xsl:value-of select="$i18n.BookingSlot.Date" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="name" select="'startDate'" />
				<xsl:with-param name="id" select="'startDate'" />
				<xsl:with-param name="type" select="'date'" />
				<xsl:with-param name="size" select="10" />
				<xsl:with-param name="value">
					<xsl:choose>
						<xsl:when test="StartDate">
							<xsl:value-of select="StartDate"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="BookingSlot/startDate"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:with-param>
			</xsl:call-template>
		</div>
		
		<div class="full bigmarginbottom" data-slotlength="{Calendar/defaultSlotLength}">
			<label for="startTime" class="full required">
				<xsl:value-of select="$i18n.BookingSlot.StartTime" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="'startTime'" />
				<xsl:with-param name="name" select="'startTime'" />
				<xsl:with-param name="type" select="'time'" />
				<xsl:with-param name="size" select="10" />
				<xsl:with-param name="value" select="Calendar/defaultStartTime"/>
				<xsl:with-param name="element" select="BookingSlot"/>
			</xsl:call-template>
		</div>
		
		<xsl:choose>
			<xsl:when test="Calendar/showDuration = 'true' or BookingSlot/Calendar/showDuration = 'true'">
		
				<div class="full bigmarginbottom">
					<label for="duration" class="full required">
						<xsl:value-of select="$i18n.BookingSlot.Duration" />
					</label>
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'duration'" />
						<xsl:with-param name="name" select="'duration'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="value" >
							<xsl:choose>
								<xsl:when test="BookingSlot/duration">
									<xsl:value-of select="BookingSlot/duration"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="Calendar/defaultSlotLength"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</div>	
			
			</xsl:when>
			<xsl:otherwise>
			
				<div class="full bigmarginbottom">
					<label for="endTime" class="full required">
						<xsl:value-of select="$i18n.BookingSlot.EndTime" />
					</label>
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'endTime'" />
						<xsl:with-param name="name" select="'endTime'" />
						<xsl:with-param name="type" select="'time'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="value" select="DefaultEndTime"/>
						<xsl:with-param name="element" select="BookingSlot"/>
					</xsl:call-template>
				</div>
			
			</xsl:otherwise>
		</xsl:choose>
		
		<script type="text/javascript">
			$(function(){
			
				$("#startDate, #bookableStartDate, #bookableEndDate").datepicker({
					showOn: "button",
					buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
					buttonImageOnly: true,
					buttonText: '<xsl:value-of select="$i18n.OpenDatePicker"/>',
					changeMonth: true,
					changeYear: true,
					showWeek: true
				});
				
				$("#startTime, #endTime, #bookableStartTime, #bookableEndTime").timePicker({
					startTime: "00:00",
					endTime: "23:59",
	    			step: 15
	    		});
			});
		</script>
		
		<div class="full bigmarginbottom">
			<label for="size" class="full required">
				<xsl:value-of select="$i18n.BookingSlot.Size" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="'size'" />
				<xsl:with-param name="name" select="'size'" />
				<xsl:with-param name="size" select="10" />
				<xsl:with-param name="element" select="BookingSlot"/>
			</xsl:call-template>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="location" class="floatleft full">
				<xsl:value-of select="$i18n.BookingSlot.Location" />
			</label>
			
			<div class="floatleft full">
				
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'location'" />
					<xsl:with-param name="name" select="'location'"/>
					<xsl:with-param name="value" select="Calendar/bookingSlotDefaultLocation"/>
					<xsl:with-param name="element" select="BookingSlot" />
				</xsl:call-template>
				
			</div>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="description" class="floatleft full">
				<xsl:value-of select="$i18n.BookingSlot.Description" />
			</label>
			
			<div class="floatleft full">
				
				<xsl:call-template name="createTextArea">
					<xsl:with-param name="id" select="'description'" />
					<xsl:with-param name="name" select="'description'"/>
					<xsl:with-param name="value" select="Calendar/bookingSlotDefaultDescription"/>
					<xsl:with-param name="rows" select="5"/>
					<xsl:with-param name="element" select="BookingSlot" />
				</xsl:call-template>
				
			</div>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="manager-search" class="floatleft full">
				<xsl:value-of select="$i18n.BookingSlot.Managers" />
			</label>
			
			<div class="floatleft full">
			
				<xsl:variable name="managers">
					<xsl:choose>
						<xsl:when test="BookingSlot">
							<xsl:copy-of select="BookingSlot/Managers/user"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:copy-of select="DefaultManagers/user"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				
				<xsl:call-template name="UserList">
					<xsl:with-param name="connectorURL">
						<xsl:value-of select="/Document/requestinfo/currentURI"/>
						<xsl:text>/</xsl:text>
						<xsl:value-of select="/Document/module/alias"/>
						<xsl:text>/searchmanager/</xsl:text>
						<xsl:choose>
							<xsl:when test="Calendar">
								<xsl:value-of select="Calendar/calendarID"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="BookingSlot/Calendar/calendarID"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:with-param>
					<xsl:with-param name="name">
						<xsl:text>manager</xsl:text>
					</xsl:with-param>
					<xsl:with-param name="users" select="exsl:node-set($managers)"/>
					<xsl:with-param name="showEmail" select="true()"/>
					<xsl:with-param name="showUsername" select="true()"/>
				</xsl:call-template>
				
				<script type="text/javascript">
					$(function(){
						initUserGroupList($("form[name='bookingSlotForm'] .usergroup-list"));
					});
				</script>
			</div>
		</div>
		
		<div class="full">
			<xsl:call-template name="createCheckbox">
				<xsl:with-param name="id" select="'bookableRestricted'" />
				<xsl:with-param name="name" select="'bookableRestricted'" />
				<xsl:with-param name="element" select="BookingSlot"/>
			</xsl:call-template>

			<label for="bookableRestricted">
				<xsl:value-of select="$i18n.BookingSlot.BookableRestricted" />
			</label>
		</div>
		
		<div id="bookableContainer">
		
			<div class="full bigmarginbottom">
				<label for="bookableStartDate" class="full">
					<xsl:value-of select="$i18n.BookingSlot.BookableStartDate" />
				</label>
				
				<xsl:call-template name="createTextField">
					<xsl:with-param name="name" select="'bookableStartDate'" />
					<xsl:with-param name="id" select="'bookableStartDate'" />
					<xsl:with-param name="type" select="'date'" />
					<xsl:with-param name="size" select="10" />
					<xsl:with-param name="element" select="BookingSlot"/>
				</xsl:call-template>
			</div>
			
			<div class="full bigmarginbottom">
				<label for="bookableStartTime" class="full">
					<xsl:value-of select="$i18n.BookingSlot.BookableStartTime" />
				</label>
				
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'bookableStartTime'" />
					<xsl:with-param name="name" select="'bookableStartTime'" />
					<xsl:with-param name="type" select="'time'" />
					<xsl:with-param name="size" select="10" />
					<xsl:with-param name="element" select="BookingSlot"/>
				</xsl:call-template>
			</div>
			
			<div class="full bigmarginbottom">
				<label for="bookableEndDate" class="full">
					<xsl:value-of select="$i18n.BookingSlot.BookableEndDate" />
				</label>
				
				<xsl:call-template name="createTextField">
					<xsl:with-param name="name" select="'bookableEndDate'" />
					<xsl:with-param name="id" select="'bookableEndDate'" />
					<xsl:with-param name="type" select="'date'" />
					<xsl:with-param name="size" select="10" />
					<xsl:with-param name="element" select="BookingSlot"/>
				</xsl:call-template>
			</div>
			
			<div class="full bigmarginbottom">
				<label for="bookableEndTime" class="full">
					<xsl:value-of select="$i18n.BookingSlot.BookableEndTime" />
				</label>
				
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'bookableEndTime'" />
					<xsl:with-param name="name" select="'bookableEndTime'" />
					<xsl:with-param name="type" select="'time'" />
					<xsl:with-param name="size" select="10" />
					<xsl:with-param name="element" select="BookingSlot"/>
				</xsl:call-template>
			</div>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="AddBooking">
	
		<section class="settings">
		
			<div class="heading-wrapper">
				<h1>
					<xsl:value-of select="$i18n.AddBooking" />
					<xsl:text> </xsl:text>
					<xsl:value-of select="BookingSlot/start" />
				</h1>
			</div>
			
			<form method="POST" action="{/Document/requestinfo/uri}" name="bookingForm" id="bookingForm">
			
				<article>
				
					<xsl:choose>
						<xsl:when test="NoPersonProvider">
						
							<p class="error">
							<span data-icon-before="!">
								<xsl:value-of select="$i18n.Error.NoPersonProvider"/>
							</span>
						</p>
						
						</xsl:when>
						<xsl:otherwise>
						
							<xsl:if test="validationException/validationError">
								<div class="bigmarginbottom">
									<xsl:apply-templates select="validationException/validationError"/>
								</div>
							</xsl:if>
							
							<div class="floatleft full bigmarginbottom" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/testssn/">
								<label for="citizenIdentifier" class="required full">
									<xsl:value-of select="$i18n.Contact.CitizenIdentifier" />
								</label>
								
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'citizenIdentifier'" />
									<xsl:with-param name="id" select="'citizenIdentifier'" />
									<xsl:with-param name="width" select="'400px'" />
									<xsl:with-param name="placeholder" select="$i18n.Contact.CitizenIdentifier.placeholder" />
								</xsl:call-template>
								
								<input type="button" value="{$i18n.VerifySSN}" class="btn btn-blue btn-inline next" id="verifySSN" />
								
								<input type="hidden" name="readonly" id="readonly" value="true"/>
								
								<p class="error" id="clientError" style="display: none;"><xsl:value-of select="$i18n.InvalidSSN"/></p>
							</div>

							<div style="display: none;" id="infoWrapper">
							
								<div class="floatleft full bigmarginbottom" >
									<label for="phone" class="full">
										<xsl:value-of select="$i18n.MobilePhone" />
									</label>
									
									<xsl:call-template name="createTextField">
										<xsl:with-param name="name" select="'phone'" />
										<xsl:with-param name="id" select="'phone'" />
										<xsl:with-param name="width" select="'400px'" />
										<xsl:with-param name="placeholder" select="$i18n.MobilePhone" />
										<xsl:with-param name="readonly">
											<xsl:if test="requestparameters/parameter[name='readonly']/value = 'true'">
												readonly
											</xsl:if>
										</xsl:with-param>
									</xsl:call-template>
								</div>
								
								<xsl:if test="BookingSlot/Calendar/bookingSizeSelectorEnabled = 'true'">
								
									<xsl:call-template name="BookingSizeSelector">
										<xsl:with-param name="name" select="'size'" />
										<xsl:with-param name="value" select="1" />
										<xsl:with-param name="bookingSlot" select="BookingSlot" />
									</xsl:call-template>
									
								</xsl:if>
								
							</div>							
							
						</xsl:otherwise>
					</xsl:choose>
					
				</article>
				
				<article class="buttons">
				
					<xsl:if test="not(NoPersonProvider)">
						<input type="submit" value="{$i18n.Add}" class="btn btn-green btn-inline nomargin" disabled="disabled" id="addBookingBtn" />
					</xsl:if>
					
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{BookingSlot/bookingSlotID}" class="btn btn-light btn-inline"><xsl:value-of select="$i18n.Cancel" /></a>
				</article>
			
			</form>
		
		</section>
		
		<script src="{$scriptPath}/bookingaddform.js"></script>
		
	</xsl:template>
	
	<xsl:template match="UpdateContact">
	
		<div class="panel-wrapper official">
			<xsl:call-template name="showBookingControlPanel"/>
		</div>
		
		<section class="settings">
			<div class="heading-wrapper">
				<h1>
					<xsl:value-of select="$i18n.UpdateContact" />
				</h1>
			</div>
			
			<form method="POST" action="{/Document/requestinfo/uri}" name="contactForm">
			
				<article>
				
					<xsl:if test="validationError">
						<div class="bigmarginbottom">
							<xsl:apply-templates select="validationError"/>
						</div>
					</xsl:if>
					
					<div class="floatleft full bigmarginbottom">
						<label for="firstname" class="full">
							<xsl:value-of select="$i18n.Contact.FirstName" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'firstname'" />
							<xsl:with-param name="id" select="'firstname'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/firstname"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/firstname"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="lastname" class="full">
							<xsl:value-of select="$i18n.Contact.LastName" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'lastname'" />
							<xsl:with-param name="id" select="'lastname'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/lastname"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/lastname"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="email" class="full">
							<xsl:value-of select="$i18n.Contact.Email" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'email'" />
							<xsl:with-param name="id" select="'email'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/email"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/email"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="phone" class="full">
							<xsl:value-of select="$i18n.Contact.Phone" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'phone'" />
							<xsl:with-param name="id" select="'phone'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/phone"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/phone"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="mobilePhone" class="full">
							<xsl:value-of select="$i18n.Contact.MobilePhone" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'mobilePhone'" />
							<xsl:with-param name="id" select="'mobilePhone'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/mobilePhone"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/mobilePhone"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="address" class="full">
							<xsl:value-of select="$i18n.Contact.Address" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'address'" />
							<xsl:with-param name="id" select="'address'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/address"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/address"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="zipCode" class="full">
							<xsl:value-of select="$i18n.Contact.PostalCode" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'zipCode'" />
							<xsl:with-param name="id" select="'zipCode'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/zipCode"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/zipCode"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<label for="postalAddress" class="full">
							<xsl:value-of select="$i18n.Contact.PostalAddress" />
						</label>
						
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'postalAddress'" />
							<xsl:with-param name="id" select="'postalAddress'" />
							<xsl:with-param name="value">
								<xsl:choose>
									<xsl:when test="Booking/ManualContact">
										<xsl:value-of select="Booking/ManualContact/postalAddress"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="Booking/PrimaryContact/postalAddress"/>
									</xsl:otherwise>
								</xsl:choose>
							</xsl:with-param>
						</xsl:call-template>
					</div>
				
				</article>
			
				<article class="buttons floatright">
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/show/{Booking/bookingID}" class="btn btn-light btn-inline" onclick="return confirmPost(this.href ,'{$i18n.CancelConfirm}?');"><xsl:value-of select="$i18n.Cancel" /></a>
					<input type="submit" value="{$i18n.SaveChanges}" class="btn btn-green btn-inline next" />
				</article>
			
			</form>
			
		</section>
		
	</xsl:template>
	
	<xsl:template match="SendMessageForm">
	
		<div class="contentitem">
		
			<h1>
				<xsl:choose>
					<xsl:when test="Target = 'calendar'">
						<xsl:value-of select="$i18n.SendMessageTitle.Calendar"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.SendMessageTitle.BookingSlot"/>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="Booking/name"/>
			</h1>
			
			<br/>
			
			<xsl:if test="SentEmails">
				
				<div class="border-radius-small lightbackground padding bigmarginbottom">
					<strong>
						<xsl:value-of select="$i18n.SendMessage.EmailsSent"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="SentEmails"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessage.Recipients"/>
					</strong>
				</div>
				
			</xsl:if>
			
			<xsl:apply-templates select="ValidationErrors/validationError" />
			
			<form id="sendMessageForm" method="post" action="{/Document/requestinfo/uri}">
				
				<div class="floatleft full bigmargintop bigmarginbottom">
				
					<h2><xsl:value-of select="$i18n.SendMessage.recipientType.title"/></h2>
			
					<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.recipientType.description"/></p>
					
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'toDigital'"/>
								<xsl:with-param name="name" select="'toDigital'"/>
							</xsl:call-template>
							
							<label for="toDigital">
								<xsl:value-of select="$i18n.SendMessage.toDigital" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="BookingSlotCounts/Digital" />
								<xsl:text>)</xsl:text>
							</label>					
						</div>
					</div>	
				
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'toAnalogWithEmail'"/>
								<xsl:with-param name="name" select="'toAnalogWithEmail'"/>
							</xsl:call-template>
							
							<label for="toAnalogWithEmail">
								<xsl:value-of select="$i18n.SendMessage.toAnalogWithEmail" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="BookingSlotCounts/AnalogWithEmail" />
								<xsl:text>)</xsl:text>
							</label>
						</div>
					</div>
					
					<p class="floatleft bigpaddingtop nomargin"><xsl:value-of select="$i18n.SendMessage.recipientType.description2"/></p>
					
					<xsl:choose>
						<xsl:when test="Target = 'calendar'">
						
							<div class="floatleft full">
											
								<div class="floatleft full">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'pending'"/>
										<xsl:with-param name="name" select="'pending'"/>
									</xsl:call-template>
									
									<label for="pending">
										<xsl:value-of select="$i18n.SendMessage.pending" />
										<xsl:text>&#160;(</xsl:text>
										<xsl:value-of select="BookingSlotCounts/Pending" />
										<xsl:text>)</xsl:text>
									</label>					
								</div>
							</div>	
						
							<div class="floatleft full">
											
								<div class="floatleft full">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'archived'"/>
										<xsl:with-param name="name" select="'archived'"/>
									</xsl:call-template>
									
									<label for="archived">
										<xsl:value-of select="$i18n.SendMessage.archived" />
										<xsl:text>&#160;(</xsl:text>
										<xsl:value-of select="BookingSlotCounts/Archived" />
										<xsl:text>)</xsl:text>
									</label>					
								</div>
							</div>
							
						</xsl:when>
						<xsl:otherwise>
						
							<input type="hidden" name="pending" value="true" />
							<input type="hidden" name="archived" value="true" />
							
						</xsl:otherwise>
					</xsl:choose>
					
				</div>
				
				<div class="floatleft full" id="email-text-box">
					<fieldset class="border-radius-small lightbackground">
						<legend><xsl:value-of select="$i18n.SendMessage.Email"/></legend>
							
						<div class="floatleft full bigmarginbottom">
							<label class="floatleft twenty" for="emailSubject"><xsl:value-of select="$i18n.SendMessage.Subject"/>:</label>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSubject'"/>
									<xsl:with-param name="id" select="'emailSubject'"/>
								</xsl:call-template>
							</div>
						</div>
						
						<label class="floatleft full" for="emailMessage"><xsl:value-of select="$i18n.SendMessage.Message"/>:</label>
							
						<div class="floatleft full bigmarginbottom">
						
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="name" select="'emailMessage'"/>
								<xsl:with-param name="id" select="'emailMessage'"/>
								<xsl:with-param name="rows" select="'8'"/>
								<xsl:with-param name="class" select="'flow-ckeditor'"/>
							</xsl:call-template>
							
							<xsl:call-template name="initializeFCKEditor">
								<xsl:with-param name="basePath"><xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/ckeditor/</xsl:with-param>
								<xsl:with-param name="customConfig">config.js</xsl:with-param>
								<xsl:with-param name="editorContainerClass">flow-ckeditor</xsl:with-param>
								<xsl:with-param name="editorHeight">150</xsl:with-param>
								
								<xsl:with-param name="contentsCss">
									<xsl:if test="cssPath">
										<xsl:value-of select="cssPath"/>
									</xsl:if>
								</xsl:with-param>
								
								<xsl:with-param name="filebrowserBrowseUri">
									
									<xsl:choose>
										<xsl:when test="ckConnectorModuleAlias">
											<xsl:text>filemanager/index.html?Connector=</xsl:text>
											<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
											<xsl:text>/connector</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>				
									</xsl:choose>
					
								</xsl:with-param>
								
								<xsl:with-param name="filebrowserImageBrowseUri">
								
									<xsl:choose>
										<xsl:when test="ckConnectorModuleAlias">
											<xsl:text>filemanager/index.html?Connector=</xsl:text>
											<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
											<xsl:text>/connector</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>
									</xsl:choose>
								
								</xsl:with-param>
								
							</xsl:call-template>
						
						</div>
							
					</fieldset>
				</div>
				
				<xsl:call-template name="addUserTagsTable"/>
				
				<div class="floatright bigmargintop">
				
					<xsl:choose>
						<xsl:when test="Target = 'calendar'">
							<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{Calendar/calendarID}">
								<xsl:value-of select="$i18n.Back" />
							</a>
						</xsl:when>
						<xsl:otherwise>
							<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showslot/{BookingSlot/bookingSlotID}">
								<xsl:value-of select="$i18n.Back" />
							</a>
						</xsl:otherwise>
					</xsl:choose>
				
				
					<div class="spinner-wrapper">
						<input class="btn btn-green btn-inline" type="submit" value="{$i18n.SendMessage.SubmitMessage}"/>
					</div>
				</div>
			
			</form>
		</div>
		
		<script type="text/javascript">
			$(function(){
			
				SendMessageFormi18n = {
					SubmittingMessage: "<xsl:value-of select="$i18n.SendMessage.SubmittingMessage" />",
				}
			});
		</script>
		
	</xsl:template>
	
	<xsl:template name="showRepeatingControlPanel">
	
		<xsl:param name="repeating" select="Repeating" />
		<xsl:param name="template" select="local-name()" />
	
		<div class="errand-menu buttons-in-desktop" data-menu="errand">
	  	<a class="btn btn-dark" data-toggle-menu="errand" href="#">
	  		<span data-icon-after="_">
	  		</span>
	  	</a>
	  	<ul>
	 		
		  	<li>
  				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{$repeating/Calendar/calendarID}" class="btn btn-light">
					<span data-icon-before="o"><xsl:value-of select="$i18n.ShowCalendar"/></span>
				</a>
	  		</li>
	  		
	  		<li>
	  			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/updaterepeating/{$repeating/repeatID}" class="btn btn-light">
					<xsl:if test="$template = 'UpdateRepeating'"><xsl:attribute name="class">btn btn-light active</xsl:attribute></xsl:if>
					<span data-icon-before="w"><xsl:value-of select="$i18n.UpdateRepeating"/></span>
				</a>
	  		</li>		  		
	 		
	  		<li>
	  			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/deleterepeating/{$repeating/repeatID}" onclick="return confirmPost(this.href, '{$i18n.DeleteRepeatingConfirm}: {$repeating/fromDate} till {$repeating/toDate}?');" title="{$i18n.DeleteRepeating}: {$repeating/fromDate}" class="btn btn-light">
					<span data-icon-before="t"><xsl:value-of select="$i18n.DeleteRepeating"/></span>
				</a>
	  		</li>
	  			
	  	</ul>
		</div>
	
	</xsl:template>	
	
	<xsl:template match="UpdateRepeating">
	
		<div class="panel-wrapper official">
			<xsl:call-template name="showRepeatingControlPanel"/>
		</div>
		
		<section class="settings">
			<div class="heading-wrapper">
				<h1>
					<xsl:value-of select="$i18n.UpdateRepeating" />
				</h1>
			</div>
			
			<form method="POST" action="{/Document/requestinfo/uri}" name="repeatingForm">
			
				<article class="marginleft">
					
					<xsl:call-template name="repeatingForm"/>
					
					<xsl:apply-templates select="ExtensionFragments/ViewFragment"/>
					
				</article>
			
				<article class="buttons floatright">
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/list/{Repeating/Calendar/calendarID}" class="btn btn-light btn-inline" onclick="return confirmPost(this.href, '{$i18n.CancelConfirm}?');"><xsl:value-of select="$i18n.Cancel" /></a>
					<input type="submit" value="{$i18n.SaveChanges}" class="btn btn-green btn-inline next" />
				</article>
			
			</form>
			
		</section>
		
	</xsl:template>
	
	<xsl:template name="repeatingForm">
	
		<xsl:variable name="bookingSlot" select="Repeating/BookingSlots/BookingSlot[1]" />
	
		<xsl:if test="validationException/validationError">
			<div class="bigmarginbottom">
				<xsl:apply-templates select="validationException/validationError"/>
			</div>
		</xsl:if>
		
		<div class="full bigmarginbottom" data-slotlength="{Calendar/defaultSlotLength}">
			<label for="startTime" class="full required">
				<xsl:value-of select="$i18n.BookingSlot.StartTime" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="'startTime'" />
				<xsl:with-param name="name" select="'startTime'" />
				<xsl:with-param name="type" select="'time'" />
				<xsl:with-param name="size" select="10" />
				<xsl:with-param name="element" select="$bookingSlot"/>
				<xsl:with-param name="disabled" select="'true'"/>
			</xsl:call-template>
		</div>
		
		<xsl:choose>
			<xsl:when test="Repeating/Calendar/showDuration = 'true'">
		
				<div class="full bigmarginbottom">
					<label for="duration" class="full required">
						<xsl:value-of select="$i18n.BookingSlot.Duration" />
					</label>
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'duration'" />
						<xsl:with-param name="name" select="'duration'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="value" select="$bookingSlot/duration" />
						<xsl:with-param name="disabled" select="'true'" />
					</xsl:call-template>
				</div>	
			
			</xsl:when>
			<xsl:otherwise>
			
				<div class="full bigmarginbottom">
					<label for="endTime" class="full required">
						<xsl:value-of select="$i18n.BookingSlot.EndTime" />
					</label>
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'endTime'" />
						<xsl:with-param name="name" select="'endTime'" />
						<xsl:with-param name="type" select="'time'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="element" select="$bookingSlot"/>
						<xsl:with-param name="disabled" select="'true'" />
					</xsl:call-template>
				</div>
			
			</xsl:otherwise>
		</xsl:choose>
		
		<script type="text/javascript">
			$(function(){
			
				$("#startDate").datepicker({
					showOn: "button",
					buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
					buttonImageOnly: true,
					buttonText: '<xsl:value-of select="$i18n.OpenDatePicker"/>',
					changeMonth: true,
					changeYear: true,
					showWeek: true
				});
				
				$("#startTime, #endTime").timePicker({
					startTime: "00:00",
					endTime: "23:59",
	    			step: 15
	    		});
			});
		</script>
		
		<div class="full bigmarginbottom">
			<label for="size" class="full required">
				<xsl:value-of select="$i18n.BookingSlot.Size" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="'size'" />
				<xsl:with-param name="name" select="'size'" />
				<xsl:with-param name="size" select="10" />
				<xsl:with-param name="element" select="$bookingSlot"/>
				<xsl:with-param name="disabled" select="'true'" />
			</xsl:call-template>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="location" class="floatleft full">
				<xsl:value-of select="$i18n.BookingSlot.Location" />
			</label>
			
			<div class="floatleft full">
				
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'location'" />
					<xsl:with-param name="name" select="'location'"/>
					<xsl:with-param name="element" select="$bookingSlot" />
				</xsl:call-template>
				
			</div>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="description" class="floatleft full">
				<xsl:value-of select="$i18n.BookingSlot.Description" />
			</label>
			
			<div class="floatleft full">
				
				<xsl:call-template name="createTextArea">
					<xsl:with-param name="id" select="'description'" />
					<xsl:with-param name="name" select="'description'"/>
					<xsl:with-param name="rows" select="5"/>
					<xsl:with-param name="element" select="$bookingSlot" />
				</xsl:call-template>
				
			</div>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="manager-search" class="floatleft full">
				<xsl:value-of select="$i18n.BookingSlot.Managers" />
			</label>
			
			<div class="floatleft full">
			
				<xsl:call-template name="UserList">
					<xsl:with-param name="connectorURL">
						<xsl:value-of select="/Document/requestinfo/currentURI"/>
						<xsl:text>/</xsl:text>
						<xsl:value-of select="/Document/module/alias"/>
						<xsl:text>/searchmanager/</xsl:text>
						<xsl:value-of select="Repeating/Calendar/calendarID"/>
					</xsl:with-param>
					<xsl:with-param name="name">
						<xsl:text>manager</xsl:text>
					</xsl:with-param>
					<xsl:with-param name="users" select="$bookingSlot/Managers"/>
					<xsl:with-param name="showEmail" select="true()"/>
					<xsl:with-param name="showUsername" select="true()"/>
				</xsl:call-template>
				
				<script type="text/javascript">
					$(function(){
						initUserGroupList($("form[name='repeatingForm'] .usergroup-list"));
					});
				</script>
			</div>
		</div>
		
		<div class="full bigmarginbottom"  id="toDateContainer">
			<label for="toDate" class="required full">
				<xsl:value-of select="$i18n.Repeating.ToDate" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="'toDate'" />
				<xsl:with-param name="name" select="'toDate'" />
				<xsl:with-param name="type" select="'date'" />
				<xsl:with-param name="size" select="10" />
				<xsl:with-param name="element" select="Repeating"/>
			</xsl:call-template>
		</div>
	
	</xsl:template>
	
	<xsl:template name="addUserTagsTable">
	
		<div class="floatleft full bigmarginbottom" id="user-tags">

			<p><xsl:value-of select="$i18n.UserTagsTable.description"/></p>
		
			<table class="full border">
				<tr>
					<th>
						<xsl:value-of select="$i18n.Tag"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.Description"/>
					</th>
				</tr>
				<tr>
					<td>
						<xsl:text>$calendar.name</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.CalendarNameTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$bookingSlot.start</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.BookingSlotStartTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$bookingSlot.end</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.BookingSlotEndTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$booking.url</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.BookingURLTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$contact.firstname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.PosterFirstnameTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$contact.lastname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.PosterLastnameTag"/>
					</td>
				</tr>
			</table>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='UnableToParseFile']">
	
		<p class="error">
			<xsl:value-of select="$i18n.UnableToParseFile.part1"/>
			<xsl:value-of select="filename"/>
			<xsl:value-of select="$i18n.UnableToParseFile.part2"/>
		</p>
			
	</xsl:template>

	<xsl:template match="validationError[messageKey='InvalidFileExtension']">
	
		<p class="error">
			<xsl:value-of select="$i18n.InvalidFileExtension.Part1" />
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="filename" />
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="$i18n.InvalidFileExtension.Part2" />

			<xsl:if test="AllowedExtensions">
			
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="$i18n.InvalidFileExtension.Part3" />
				<xsl:text>&#160;</xsl:text>
				
				<xsl:apply-templates select="AllowedExtensions/Extension" mode="AllowedExtensions"/>
			</xsl:if>			
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoRecipientTypesSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoRecipientTypesSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoRecipientStateSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoRecipientStateSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='EmailSenderNotSet']">
		<p class="error">
			<xsl:value-of select="$i18n.EmailSenderNotSet"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='InvalidRecipientEmail']">
		<p class="error">
			<xsl:value-of select="$i18n.InvalidRecipientEmail.1"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="../BookingSlot/start"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="$i18n.InvalidRecipientEmail.2"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="email"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='InvalidRecipientPhoneNumber']">
		<p class="error">
			<xsl:value-of select="$i18n.InvalidRecipientPhoneNumber.1"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="../BookingSlot/start"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="$i18n.InvalidRecipientPhoneNumber.2"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="phoneNumber"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='ErrorSendingToRecipientViaEmail']">
		<p class="error">
			<xsl:value-of select="$i18n.ErrorSendingToRecipientViaEmail.1"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="../BookingSlot/start"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="$i18n.ErrorSendingToRecipientViaEmail.2"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="email"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='ErrorSendingToRecipientViaSMS']">
		<p class="error">
			<xsl:value-of select="$i18n.ErrorSendingToRecipientViaSMS.1"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="../Booking/BookingSlot/start"/>
			<xsl:text>&#160;(</xsl:text>
			<xsl:value-of select="../Booking/bookingID"/>
			<xsl:text>)&#160;</xsl:text>
			<xsl:value-of select="$i18n.ErrorSendingToRecipientViaSMS.2"/>
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="phoneNumber"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='ExtensionErrors']">
		<p class="error">
			<xsl:value-of select="$i18n.ExtensionErrors"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError">
		
		<xsl:if test="fieldName and validationErrorType">
			<p class="error">
				<span data-icon-before="!">
					<xsl:choose>
						<xsl:when test="validationErrorType='RequiredField'">
							<xsl:value-of select="$i18n.validationError.RequiredField" />
						</xsl:when>
						<xsl:when test="validationErrorType='InvalidFormat'">
							<xsl:value-of select="$i18n.validationError.InvalidFormat" />
						</xsl:when>
						<xsl:when test="validationErrorType='TooShort'">
							<xsl:value-of select="$i18n.validationError.TooShort" />
						</xsl:when>
						<xsl:when test="validationErrorType='TooLong'">
							<xsl:value-of select="$i18n.validationError.TooLong" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.validationError.Other" />
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>:&#x20;</xsl:text>
					<xsl:choose>
						<xsl:when test="fieldName = 'citizenIdentifier'">
							<xsl:value-of select="$i18n.Contact.CitizenIdentifier" />
						</xsl:when>
						<xsl:when test="fieldName = 'firstname'">
							<xsl:value-of select="$i18n.Contact.FirstName" />
						</xsl:when>
						<xsl:when test="fieldName = 'lastname'">
							<xsl:value-of select="$i18n.Contact.LastName" />
						</xsl:when>
						<xsl:when test="fieldName = 'email'">
							<xsl:value-of select="$i18n.Contact.Email" />
						</xsl:when>
						<xsl:when test="fieldName = 'phone'">
							<xsl:value-of select="$i18n.Contact.Phone" />
						</xsl:when>
						<xsl:when test="fieldName = 'mobilePhone'">
							<xsl:value-of select="$i18n.Contact.MobilePhone" />
						</xsl:when>
						<xsl:when test="fieldName = 'address'">
							<xsl:value-of select="$i18n.Contact.Address" />
						</xsl:when>
						<xsl:when test="fieldName = 'zipCode'">
							<xsl:value-of select="$i18n.Contact.PostalCode" />
						</xsl:when>
						<xsl:when test="fieldName = 'postalAddress'">
							<xsl:value-of select="$i18n.Contact.PostalAddress" />
						</xsl:when>
						<xsl:when test="fieldName = 'postalAddress'">
							<xsl:value-of select="$i18n.Contact.PostalAddress" />
						</xsl:when>
						<xsl:when test="fieldName = 'externalmessage'">
							<xsl:value-of select="$i18n.SendMessage.Message" />
						</xsl:when>
						<xsl:when test="fieldName = 'internalmessage'">
							<xsl:value-of select="$i18n.SendMessage.Message" />
						</xsl:when>
						<xsl:when test="fieldName = 'emailSubject'">
							<xsl:value-of select="$i18n.SendMessage.Email" />
							<xsl:text>&#x20;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.Subject" />
						</xsl:when>
						<xsl:when test="fieldName = 'emailMessage'">
							<xsl:value-of select="$i18n.SendMessage.Email" />
							<xsl:text>&#x20;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.Message" />
						</xsl:when>
						<xsl:when test="fieldName = 'startDate'">
							<xsl:value-of select="$i18n.BookingSlot.Date" />
						</xsl:when>
						<xsl:when test="fieldName = 'startTime'">
							<xsl:value-of select="$i18n.BookingSlot.StartTime" />
						</xsl:when>
						<xsl:when test="fieldName = 'endTime'">
							<xsl:value-of select="$i18n.BookingSlot.EndTime" />
						</xsl:when>
						<xsl:when test="fieldName = 'duration'">
							<xsl:value-of select="$i18n.BookingSlot.Duration" />
						</xsl:when>
						<xsl:when test="fieldName = 'bookableStartDate'">
							<xsl:value-of select="$i18n.BookingSlot.BookableStartDate" />
						</xsl:when>
						<xsl:when test="fieldName = 'bookableStartTime'">
							<xsl:value-of select="$i18n.BookingSlot.BookableStartTime" />
						</xsl:when>
						<xsl:when test="fieldName = 'bookableEndDate'">
							<xsl:value-of select="$i18n.BookingSlot.BookableEndDate" />
						</xsl:when>
						<xsl:when test="fieldName = 'bookableEndTime'">
							<xsl:value-of select="$i18n.BookingSlot.BookableEndTime" />
						</xsl:when>
						<xsl:when test="fieldName = 'size'">
							<xsl:value-of select="$i18n.BookingSlot.Size" />
						</xsl:when>
						<xsl:when test="fieldName = 'repetitionInterval'">
							<xsl:value-of select="$i18n.Repeating.RepetitionInterval" />
						</xsl:when>
						<xsl:when test="fieldName = 'repetitionIntervalCustom'">
							<xsl:value-of select="$i18n.Repeating.RepetitionInterval.Custom" />
						</xsl:when>
						<xsl:when test="fieldName = 'repetitionToDate'">
							<xsl:value-of select="$i18n.Repeating.ToDate" />
						</xsl:when>
						<xsl:when test="fieldName = 'toDate'">
							<xsl:value-of select="$i18n.Repeating.ToDate" />
						</xsl:when>
						<xsl:when test="fieldName = 'description'">
							<xsl:value-of select="$i18n.BookingSlot.Description"/>
						</xsl:when>
						<xsl:when test="fieldName = 'location'">
							<xsl:value-of select="$i18n.BookingSlot.Location"/>
						</xsl:when>
						<xsl:when test="fieldName = 'fromDate'">
							<xsl:value-of select="$i18n.Export.fromDate"/>
						</xsl:when>
						<xsl:when test="fieldName = 'toDate'">
							<xsl:value-of select="$i18n.Export.toDate"/>
						</xsl:when>
						<xsl:when test="starts-with(fieldName, 'phone')">
							<xsl:value-of select="$i18n.MobilePhone"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="fieldName" />
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>!</xsl:text>
				</span>
			</p>
		</xsl:if>
		<xsl:if test="messageKey">
			<p class="error">
				<span data-icon-before="!">
					<xsl:choose>
						<xsl:when test="messageKey = 'PersonAlreadyInCalendar'">
							<xsl:value-of select="$i18n.validationError.PersonAlreadyInCalendar" />
						</xsl:when>
						<xsl:when test="messageKey = 'PersonAlreadyInBookingSlot'">
							<xsl:value-of select="$i18n.validationError.PersonAlreadyInBookingSlot" />
						</xsl:when>
						<xsl:when test="messageKey = 'TooManyBookings'">
							<xsl:value-of select="$i18n.validationError.TooManyBooking" />
						</xsl:when>
						<xsl:when test="messageKey = 'RepetitionToDateBeforeFromDate'">
							<xsl:value-of select="$i18n.validationError.RepetitionToDateBeforeFromDate" />
						</xsl:when>
						<xsl:when test="messageKey = 'RepetitionPeriodLessThanOneWeek'">
							<xsl:value-of select="$i18n.validationError.RepetitionPeriodLessThanOneWeek" />
						</xsl:when>
						<xsl:when test="messageKey = 'RepetitionToDateBeforeOldToDate'">
							<xsl:value-of select="$i18n.validationError.RepetitionToDateBeforeOldToDate" />
						</xsl:when>
						<xsl:when test="messageKey = 'DateInPast'">
							<xsl:value-of select="$i18n.validationError.DateInPast" />
						</xsl:when>
						<xsl:when test="messageKey = 'BookableStartOrEndRequired'">
							<xsl:value-of select="$i18n.validationError.BookableStartOrEndRequired" />
						</xsl:when>
						<xsl:when test="messageKey = 'BookableDateAfterDate'">
							<xsl:value-of select="$i18n.validationError.BookableDateAfterDate" />
						</xsl:when>
						<xsl:when test="messageKey = 'BookableStartAfterBookableEnd'">
							<xsl:value-of select="$i18n.validationError.BookableStartAfterBookableEnd" />
						</xsl:when>
						<xsl:when test="messageKey = 'BookingSlotHasPassed'">
							<xsl:value-of select="$i18n.validationError.BookingSlotHasPassed" />
						</xsl:when>
						<xsl:when test="messageKey = 'ShowFailedBookingSlotNotFound' or messageKey = 'UpdateFailedBookingSlotNotFound' or messageKey = 'DeleteFailedBookingSlotNotFound'">
							<xsl:value-of select="$i18n.validationError.BookingSlotNotFound" />
						</xsl:when>
						<xsl:when test="messageKey = 'ShowFailedBookingNotFound' or messageKey = 'UpdateFailedBookingNotFound' or messageKey = 'DeleteFailedBookingNotFound'">
							<xsl:value-of select="$i18n.validationError.BookingNotFound" />
						</xsl:when>
						<xsl:when test="messageKey = 'ErrorImportingCitizen'">
							<xsl:value-of select="$i18n.validationError.ErrorImportingCitizen" />
						</xsl:when>
						<xsl:when test="messageKey = 'HasPassed'">
							<xsl:value-of select="$i18n.validationError.HasPassed" />
						</xsl:when>
						<xsl:when test="messageKey = 'NoFreeSlots'">
							<xsl:value-of select="$i18n.validationError.NoFreeSlots" />
						</xsl:when>
						<xsl:when test="messageKey = 'NotEnoughFreeSlots'">
							<xsl:value-of select="$i18n.validationError.NotEnoughFreeSlots" />
						</xsl:when>
						<xsl:when test="messageKey = 'NotAllowedToSelectSize'">
							<xsl:value-of select="$i18n.validationError.NotAllowedToSelectSize" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.validationError.unknownMessageKey" />
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</p>
		</xsl:if>
		<xsl:apply-templates select="message" />
		
	</xsl:template>
	
	<xsl:template name="SearchResults">
	
		<div class="section-full search-results" id="booking-search-results" style="display: none;" data-nohits="{$i18n.NoHits}" data-show="{$i18n.Show}" data-showurl="{/Document/requestinfo/currentURI}/{/Document/module/alias}/show/">
			<div class="info">
				<span class="message">
					<i>c</i>
					<xsl:value-of select="$i18n.SearchComplete"/>
				</span>
				
				<span class="close">
					<a href="#">
						<xsl:value-of select="$i18n.Close"/>
						<xsl:text> </xsl:text>
						<i>x</i>
					</a>
				</span>
			</div>
			
			<h2 class="h1 search-results-title">
				<span class="title"></span>
				<xsl:text> </xsl:text>
				<xsl:value-of select="$i18n.Gave"/>
				<xsl:text> </xsl:text>
				<span class="hits"></span>
				<xsl:text> </xsl:text>
				<xsl:value-of select="$i18n.Hits"/>
			</h2>
			
			<div class="errands-wrapper">
				<table class="oep-table flowinstance-table">
					<thead>
						<tr>
							<th></th>
							<th><xsl:value-of select="$i18n.Name"/></th>
							<th><xsl:value-of select="$i18n.Added"/></th>
							<th><xsl:value-of select="$i18n.SlotDate"/></th>
							<th><xsl:value-of select="$i18n.BookedVia"/></th>
							<th><xsl:value-of select="$i18n.Archived"/></th>
							<th></th>
						</tr>
					</thead>
					<tbody>
					</tbody>
				</table>
			</div>
		</div>
		
		<script type="text/javascript">
			$(function(){
				SearchResultsi18n = {
						Yes: "<xsl:value-of select="$i18n.Yes" />",
						No: "<xsl:value-of select="$i18n.No" />",
						Flow: "<xsl:value-of select="$i18n.Flow" />",
						Manager: "<xsl:value-of select="$i18n.Manager" />",
				}
			});
		</script>
		
	</xsl:template>
	
</xsl:stylesheet>