package com.nordicpeak.flowengine.booking;

import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Field;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.concurrent.CopyOnWriteArrayList;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactoryConfigurationError;

import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileUploadBase.FileSizeLimitExceededException;
import org.apache.commons.fileupload.FileUploadBase.SizeLimitExceededException;
import org.apache.commons.io.FilenameUtils;
import org.apache.log4j.Level;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.cron4jutils.CronStringValidator;
import se.unlogic.fileuploadutils.MultipartRequest;
import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.EventListener;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextAreaSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.Group;
import se.unlogic.hierarchy.core.beans.LinkTag;
import se.unlogic.hierarchy.core.beans.ScriptTag;
import se.unlogic.hierarchy.core.beans.SimpleAccessInterface;
import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.CRUDAction;
import se.unlogic.hierarchy.core.enums.EventSource;
import se.unlogic.hierarchy.core.enums.EventTarget;
import se.unlogic.hierarchy.core.events.CRUDEvent;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.handlers.GroupHandler;
import se.unlogic.hierarchy.core.handlers.UserHandler;
import se.unlogic.hierarchy.core.interfaces.AccessInterface;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.HTMLContentFilter;
import se.unlogic.hierarchy.core.interfaces.SectionDescriptor;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.SystemInterface;
import se.unlogic.hierarchy.core.interfaces.ViewFragment;
import se.unlogic.hierarchy.core.interfaces.events.EventHandler;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.CRUDCallback;
import se.unlogic.hierarchy.core.utils.GenericCRUD;
import se.unlogic.hierarchy.core.utils.HierarchyAnnotatedDAOFactory;
import se.unlogic.hierarchy.core.utils.ModuleUtils;
import se.unlogic.hierarchy.core.utils.ModuleViewFragmentTransformer;
import se.unlogic.hierarchy.core.utils.ViewFragmentModule;
import se.unlogic.hierarchy.core.utils.crud.FragmentLinkScriptFilter;
import se.unlogic.hierarchy.core.utils.usergroupadminextensions.GroupAdminExtensionProvider;
import se.unlogic.hierarchy.core.utils.usergroupadminextensions.UserAdminExtensionProvider;
import se.unlogic.hierarchy.core.utils.usergroupadminextensions.UserGroupAdminExtensionHandler;
import se.unlogic.hierarchy.core.utils.usergrouplist.UserGroupListConnector;
import se.unlogic.hierarchy.core.validationerrors.FileSizeLimitExceededValidationError;
import se.unlogic.hierarchy.core.validationerrors.InvalidFileExtensionValidationError;
import se.unlogic.hierarchy.core.validationerrors.RequestSizeLimitExceededValidationError;
import se.unlogic.hierarchy.core.validationerrors.UnableToParseFileValidationError;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfile;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfileHandler;
import se.unlogic.standardutils.annotations.SplitOnLineBreak;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.LowLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.RelationQuery;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.dao.querys.ArrayListQuery;
import se.unlogic.standardutils.date.DateUtils;
import se.unlogic.standardutils.db.DBUtils;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.io.BinarySizes;
import se.unlogic.standardutils.io.FileUtils;
import se.unlogic.standardutils.json.JsonArray;
import se.unlogic.standardutils.json.JsonObject;
import se.unlogic.standardutils.json.JsonUtils;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.time.TimeUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLGeneratorDocument;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.HTTPUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.FlowAdminModule;
import com.nordicpeak.flowengine.FlowBrowserModule;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.beans.FlowInstanceEvent;
import com.nordicpeak.flowengine.booking.beans.Booking;
import com.nordicpeak.flowengine.booking.beans.BookingCalendar;
import com.nordicpeak.flowengine.booking.beans.BookingEvent;
import com.nordicpeak.flowengine.booking.beans.BookingSlot;
import com.nordicpeak.flowengine.booking.beans.ExternalMessage;
import com.nordicpeak.flowengine.booking.beans.InternalMessage;
import com.nordicpeak.flowengine.booking.beans.PrimaryContact;
import com.nordicpeak.flowengine.booking.cruds.BookingCRUD;
import com.nordicpeak.flowengine.booking.cruds.CalendarCRUD;
import com.nordicpeak.flowengine.booking.enums.BookingEventType;
import com.nordicpeak.flowengine.booking.enums.ExternalMessageType;
import com.nordicpeak.flowengine.booking.exceptions.PersonAlreadyInBookingSlotValidationException;
import com.nordicpeak.flowengine.booking.exceptions.PersonAlreadyInCalendarValidationException;
import com.nordicpeak.flowengine.booking.interfaces.CalendarFormExtensionProvider;
import com.nordicpeak.flowengine.booking.notificationhandler.BookingNotificationHandler;
import com.nordicpeak.flowengine.booking.queries.BookingQuery;
import com.nordicpeak.flowengine.booking.queries.BookingQueryInstance;
import com.nordicpeak.flowengine.booking.schedule.BookingPassedEventHandler;
import com.nordicpeak.flowengine.dao.FlowEngineDAOFactory;
import com.nordicpeak.flowengine.enums.ContentType;
import com.nordicpeak.flowengine.enums.EventType;
import com.nordicpeak.flowengine.events.ManagersChangedEvent;
import com.nordicpeak.flowengine.events.MultiSigningCanceledEvent;
import com.nordicpeak.flowengine.events.MultiSigningInitiatedEvent;
import com.nordicpeak.flowengine.events.SubmitEvent;
import com.nordicpeak.flowengine.exceptions.flowinstance.InvalidFlowInstanceStepException;
import com.nordicpeak.flowengine.exceptions.flowinstance.MissingQueryInstanceDescriptor;
import com.nordicpeak.flowengine.exceptions.queryprovider.QueryInstanceNotFoundInQueryProviderException;
import com.nordicpeak.flowengine.exceptions.queryprovider.QueryProviderErrorException;
import com.nordicpeak.flowengine.exceptions.queryprovider.QueryProviderNotFoundException;
import com.nordicpeak.flowengine.managers.FlowInstanceManager;
import com.nordicpeak.flowengine.queries.contactdetailquery.ContactDetailQueryInstance;
import com.nordicpeak.flowengine.utils.CitizenIdentifierUtils;
import com.nordicpeak.flowengine.utils.FlowInstanceUtils;

import it.sauronsoftware.cron4j.Scheduler;

public class CalendarAdminModule extends AnnotatedForegroundModule implements CRUDCallback<User>, Runnable, UserAdminExtensionProvider, GroupAdminExtensionProvider, ViewFragmentModule<ForegroundModuleDescriptor> {

	@XSLVariable(prefix = "java.")
	private String secondaryContactInternalMessagePrefix = "Secondary contact";

	@ModuleSetting(allowsNull = true)
	@SplitOnLineBreak
	@TextAreaSettingDescriptor(name = "Supported actionID's", description = "The action ID's which will trigger this module when a submit event is detected", required = true)
	private List<String> supportedActionIDs = CollectionUtils.getList("com.nordicpeak.flowengine.FlowBrowserModule.submit");

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Hide submitted event", description = "Hide submitted event in user bookings")
	private boolean hideSubmittedEvent = false;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Secondary contact firstname attribute", description = "The name of the attribute containing the firstname of the secondary contact")
	private String secondaryContactFirstnameAttribute = null;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Secondary contact lastname attribute", description = "The name of the attribute containing the lastname of the secondary contact")
	private String secondaryContactLastnameAttribute = null;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Secondary contact citizen identifier attribute", description = "The name of the attribute containing the citizen identifier attribute")
	private String secondaryContactCitizenIdentifierAttribute = null;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Check for expiring preliminary bookings", description = "How often this module should check for expiring preliminary bookings (specified in crontab format)", required = true, formatValidator = CronStringValidator.class)
	private String releaseOldPreliminaryBookingsInterval = "0 * * * *";

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Override contactBySMS", description = "Overrides the contactBySMS field in Contacts to true when sending SMS")
	private boolean overrideContactBySMS = true;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable setting in calendar admin to be able to choose to only send re-booking notifications if booking slot has managers", description = "When this is enabled calendar admin can choose to send re-booking notifications only to managers in the current booking slot")
	private boolean enableRebookingNotificationsOnlyToSlotManagers = false;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable fragment XML debug", description = "Enables debugging of fragment XML")
	private boolean debugFragmentXML;

	private UserGroupListConnector userGroupListConnector;

	private AnnotatedDAO<BookingCalendar> calendarDAO;
	private AnnotatedDAO<Booking> bookingDAO;
	private AnnotatedDAO<BookingSlot> bookingSlotDAO;
	private AnnotatedDAO<FlowInstance> flowInstanceDAO;
	private AnnotatedDAO<FlowInstanceEvent> flowInstanceEventDAO;

	private AnnotatedDAOWrapper<Booking, Integer> bookingDAOWrapper;

	private QueryParameterFactory<FlowInstanceEvent, FlowInstance> flowInstanceEventFlowInstanceParamFactory;
	private QueryParameterFactory<Booking, Integer> bookingFlowInstanceIDParameterFactory;
	private QueryParameterFactory<Booking, BookingSlot> bookingBookingSlotParameterFactory;
	private QueryParameterFactory<BookingCalendar, Integer> bookingCalendarIDParameterFactory;

	private CalendarCRUD calendarCRUD;

	private HierarchyAnnotatedDAOFactory daoFactory;

	@InstanceManagerDependency
	private FlowAdminModule flowAdminModule;

	@InstanceManagerDependency
	private HTMLContentFilter htmlContentFilter;

	@InstanceManagerDependency(required = true)
	private BookingNotificationHandler notificationHandler;

	private Scheduler scheduler;
	private Scheduler bookingPassedScheduler;

	private static final String SCHEDULER_EVERY_MINUTE_CRON_TAB = "* * * * *";

	private String releseOldPreliminaryBookingsScheduleID;

	private String oldBookingPassedScheduleID;

	private CopyOnWriteArrayList<CalendarFormExtensionProvider> extensionProviders = new CopyOnWriteArrayList<>();

	private ModuleViewFragmentTransformer<ForegroundModuleDescriptor> viewFragmentTransformer;

	private UserGroupAdminExtensionHandler userGroupAdminExtensionHandler;

	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {

		viewFragmentTransformer = new ModuleViewFragmentTransformer<>(sectionInterface.getForegroundModuleXSLTCache(), this, sectionInterface.getSystemInterface().getEncoding());

		super.init(moduleDescriptor, sectionInterface, dataSource);

		if (!systemInterface.getInstanceHandler().addInstance(CalendarAdminModule.class, this)) {

			throw new RuntimeException("Unable to register module in global instance handler using key " + CalendarAdminModule.class.getSimpleName() + ", another instance is already registered using this key.");
		}
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		super.createDAOs(dataSource);

		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, CalendarAdminModule.class.getName(), new XMLDBScriptProvider(CalendarAdminModule.class.getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		userGroupListConnector = new UserGroupListConnector(systemInterface);

		daoFactory = new HierarchyAnnotatedDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler(), false, true, false);

		calendarDAO = daoFactory.getDAO(BookingCalendar.class);
		bookingDAO = daoFactory.getDAO(Booking.class);
		bookingSlotDAO = daoFactory.getDAO(BookingSlot.class);

		bookingFlowInstanceIDParameterFactory = bookingDAO.getParamFactory("flowInstanceID", Integer.class);
		bookingBookingSlotParameterFactory = bookingDAO.getParamFactory("bookingSlot", BookingSlot.class);
		bookingCalendarIDParameterFactory = calendarDAO.getParamFactory("calendarID", Integer.class);

		bookingDAOWrapper = bookingDAO.getWrapper(Integer.class);
		bookingDAOWrapper.addRelations(Booking.BOOKING_SLOT_RELATION, BookingSlot.CALENDAR_RELATION);
		bookingDAOWrapper.setUseRelationsOnGet(true);

		AnnotatedDAOWrapper<BookingCalendar, Integer> calendarDAOWrapper = calendarDAO.getWrapper(Integer.class);
		calendarDAOWrapper.addRelations(BookingCalendar.MANAGER_USERS_RELATION, BookingCalendar.MANAGER_GROUPS_RELATION, BookingCalendar.ADMIN_GROUPS_RELATION);
		calendarDAOWrapper.setUseRelationsOnAdd(true);
		calendarDAOWrapper.setUseRelationsOnGet(true);
		calendarDAOWrapper.setUseRelationsOnUpdate(true);

		calendarCRUD = new CalendarCRUD(calendarDAOWrapper, this);
		calendarCRUD.addModuleResponseFilter(new FragmentLinkScriptFilter<>());

		FlowEngineDAOFactory flowEngineDAOFactory = new FlowEngineDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler());

		flowInstanceDAO = flowEngineDAOFactory.getFlowInstanceDAO();
		flowInstanceEventDAO = flowEngineDAOFactory.getFlowInstanceEventDAO();

		flowInstanceEventFlowInstanceParamFactory = flowInstanceEventDAO.getParamFactory("flowInstance", FlowInstance.class);

		initScheduler();
	}

	@Override
	protected void moduleConfigured() throws Exception {

		super.moduleConfigured();

		ModuleUtils.checkRequiredModuleSettings(moduleDescriptor, this, systemInterface, Level.WARN);

		viewFragmentTransformer.setDebugXML(debugFragmentXML);
	}

	@Override
	public void update(ForegroundModuleDescriptor descriptor, DataSource dataSource) throws Exception {

		super.update(descriptor, dataSource);

		resceduleScheduler();
	}

	private void resceduleScheduler() {

		scheduler.reschedule(releseOldPreliminaryBookingsScheduleID, releaseOldPreliminaryBookingsInterval);
		bookingPassedScheduler.reschedule(oldBookingPassedScheduleID, SCHEDULER_EVERY_MINUTE_CRON_TAB);
	}

	@Override
	public void unload() throws Exception {

		stopScheduler();

		systemInterface.getInstanceHandler().removeInstance(CalendarAdminModule.class, this);

		if (userGroupAdminExtensionHandler != null) {

			setUserGroupAdminExtensionHandler(null);
		}

		super.unload();
	}

	protected synchronized void initScheduler() {

		initStandardScheduler();
		initBookingPassedScheduler();
	}

	private void initStandardScheduler() {

		if (scheduler != null) {

			log.warn("Invalid state, scheduler already running!");
			stopScheduler();
		}

		scheduler = new Scheduler(systemInterface.getApplicationName() + " - " + moduleDescriptor.toString());
		scheduler.setDaemon(true);
		releseOldPreliminaryBookingsScheduleID = scheduler.schedule(releaseOldPreliminaryBookingsInterval, this);

		scheduler.start();
	}

	private void initBookingPassedScheduler() {

		if (bookingPassedScheduler != null) {

			log.warn("Invalid state, bookingPassedScheduler already running!");
			stopBookingsPassedScheduler();
		}

		bookingPassedScheduler = new Scheduler("BookingPassedScheduler");
		bookingPassedScheduler.setDaemon(true);
		oldBookingPassedScheduleID = bookingPassedScheduler.schedule(SCHEDULER_EVERY_MINUTE_CRON_TAB, new BookingPassedEventHandler(daoFactory, systemInterface));

		bookingPassedScheduler.start();
	}

	protected synchronized void stopScheduler() {

		stopStandardScheduler();
		stopBookingsPassedScheduler();
	}

	private synchronized void stopStandardScheduler() {

		try {

			if (scheduler != null) {

				scheduler.stop();
				scheduler = null;
			}

		} catch (IllegalStateException e) {

			log.error("Error stopping scheduler", e);
		}
	}

	private synchronized void stopBookingsPassedScheduler() {

		try {

			if (bookingPassedScheduler != null) {

				bookingPassedScheduler.stop();
				bookingPassedScheduler = null;
			}

		} catch (IllegalStateException e) {

			log.error("Error stopping bookingPassedScheduler", e);
		}
	}

	@Override
	public ForegroundModuleResponse defaultMethod(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return calendarCRUD.list(req, res, user, uriParser, null);
	}

	@WebPublic(alias = "add")
	public ForegroundModuleResponse addCalendar(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return calendarCRUD.add(req, res, user, uriParser);
	}

	@WebPublic(alias = "update")
	public ForegroundModuleResponse updateCalendar(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return calendarCRUD.update(req, res, user, uriParser);
	}

	@WebPublic(alias = "delete")
	public ForegroundModuleResponse deleteCalendar(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return calendarCRUD.delete(req, res, user, uriParser);
	}

	@WebPublic(alias = "export")
	public ForegroundModuleResponse exportCalendar(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		BookingCalendar cal = calendarCRUD.getRequestedBean(req, res, user, uriParser, GenericCRUD.SHOW);

		if (cal == null) {

			return calendarCRUD.list(req, res, user, uriParser, Arrays.asList(new ValidationError("CalendarNotFound")));
		}

		log.info("User " + user + " exporting calendar " + cal);

		Document doc = getExportCalendarDocument(cal);

		res.setHeader("Content-Disposition", "attachment; filename=\"" + FileUtils.toValidHttpFilename(cal.getName()) + ".oecal\"");
		res.setHeader("Cache-Control", "no-store, no-cache, must-revalidate, proxy-revalidate");
		res.setContentType("text/oecal");

		try {

			XMLUtils.writeXML(doc, res.getOutputStream(), true, systemInterface.getEncoding());

		} catch (TransformerException e) {

			log.info("Error sending exported calendar " + cal + " to user " + user + ", " + e);
		}

		return null;
	}

	@WebPublic(toLowerCase = true, alias = "import")
	public ForegroundModuleResponse showCalenderImport(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		ValidationException validationException = null;
		log.info("User " + user + " listing calendar import targets");

		if (req.getMethod().equalsIgnoreCase("POST") && MultipartRequest.isMultipartRequest(req)) {

			log.info("User " + user + " importing calendar...");

			MultipartRequest multipartRequest = null;

			try {

				multipartRequest = MultipartRequest.getMultipartRequest(flowAdminModule.getRamThreshold() * BinarySizes.KiloByte, flowAdminModule.getMaxRequestSize() * BinarySizes.MegaByte, flowAdminModule.getTempDir(), req);
				req = multipartRequest;

				if (multipartRequest.getFileCount() == 0 || multipartRequest.getFileCount() == 1 && multipartRequest.getFile(0).getName().equals("")) {

					throw new ValidationException(new ValidationError("NoAttachedFile"));
				}

				FileItem fileItem = multipartRequest.getFile(0);

				if (!fileItem.getName().endsWith(".oecal")) {

					throw new ValidationException(new InvalidFileExtensionValidationError(FilenameUtils.getName(fileItem.getName()), "oecal"));
				}

				try (InputStream inputStream = fileItem.getInputStream()) {

					importCalendar(inputStream, FilenameUtils.getName(fileItem.getName()), multipartRequest, res, user);
				}

			} catch (ValidationException e) {

				validationException = e;

			} catch (SizeLimitExceededException e) {

				validationException = new ValidationException(new RequestSizeLimitExceededValidationError(e.getActualSize(), e.getPermittedSize()));

			} catch (FileSizeLimitExceededException e) {

				validationException = new ValidationException(new FileSizeLimitExceededValidationError(e.getFileName(), e.getActualSize(), e.getPermittedSize()));

			} catch (Exception e) {

				validationException = new ValidationException(new ValidationError("UnableToParseRequest"));

			} finally {

				if (validationException != null) {

					log.warn("Import of calendar by user " + user + " failed due to validation error(s) " + validationException);
				}

				if (multipartRequest != null) {

					multipartRequest.deleteFiles();
				}
			}
		}

		Document doc = createDocument(req, uriParser, user);
		Element selectImport = doc.createElement("SelectImport");
		doc.getDocumentElement().appendChild(selectImport);

		if (validationException != null) {

			selectImport.appendChild(validationException.toXML(doc));
		}

		return new SimpleForegroundModuleResponse(doc, moduleDescriptor.getName(), this.getDefaultBreadcrumb());

	}

	@WebPublic(alias = "cullbookings")
	public ForegroundModuleResponse cullBookings(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return cullBookings(req, user, uriParser);
	}

	private ForegroundModuleResponse cullBookings(HttpServletRequest req, User user, URIParser uriParser) throws TransformerFactoryConfigurationError, URINotFoundException, SQLException {

		Document doc = createDocument(req, uriParser, user);
		Element cullBookingElement = doc.createElement("CullBookings");
		doc.getFirstChild().appendChild(cullBookingElement);

		addSearchDates(cullBookingElement, req, doc, uriParser);

		log.info("User " + user + " listing all cullings");

		return new SimpleForegroundModuleResponse(doc);
	}

	private void addSearchDates(Element cullBookingElement, HttpServletRequest req, Document doc, URIParser uriParser) throws URINotFoundException, SQLException {

		String fromDate = req.getParameter("fromDate");
		String toDate = req.getParameter("toDate");

		String calendarID = uriParser.get(2);

		BookingCalendar bookingCalendar = getCalendar(calendarID);

		if (!StringUtils.isEmpty(fromDate)) {
			XMLUtils.appendNewElement(doc, cullBookingElement, "fromDate", fromDate);
		}
		if (!StringUtils.isEmpty(toDate)) {
			XMLUtils.appendNewElement(doc, cullBookingElement, "toDate", toDate);
		}
		if (bookingCalendar != null) {
			XMLUtils.appendNewElement(doc, cullBookingElement, "calendarID", calendarID);
			XMLUtils.appendNewElement(doc, cullBookingElement, "calendarName", bookingCalendar.getName());
		} else {
			throw new URINotFoundException(uriParser);
		}

	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse getAllPassedBookingSlots(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws SQLException, IOException {

		List<BookingSlot> allBookingSlots = getAllPassedBookingSlots(req, uriParser.get(2));

		JsonObject jsonObject = new JsonObject(1);

		if (!CollectionUtils.isEmpty(allBookingSlots)) {
			JsonArray instancesArray = new JsonArray(allBookingSlots.size());

			for (BookingSlot bookingSlot : allBookingSlots) {
				JsonArray instanceArray = new JsonArray(6);
				instanceArray.addNode("");
				instanceArray.addNode(DateUtils.DATE_TIME_FORMATTER.format(bookingSlot.getStart()));
				instanceArray.addNode(DateUtils.DATE_TIME_FORMATTER.format(bookingSlot.getEnd()));
				instanceArray.addNode(bookingSlot.getBookings() == null ? 0 : bookingSlot.getBookings().size());
				instanceArray.addNode(bookingSlot.getDescription());
				instanceArray.addNode(bookingSlot.getBookingSlotID());
				instancesArray.addNode(instanceArray);
			}

			jsonObject.putField("data", instancesArray);

		} else {
			jsonObject.putField("data", new JsonArray());
		}
		HTTPUtils.sendReponse(jsonObject.toJson(), JsonUtils.getContentType(), res);

		return null;
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse removeSelectedBookingSlots(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		if (req.getMethod().equalsIgnoreCase("POST")) {

			List<Integer> bookingSlotIDs = NumberUtils.toInt(req.getParameterValues("bookingSlotID"));

			if (!CollectionUtils.isEmpty(bookingSlotIDs)) {
				List<BookingSlot> bookingSlots = getBookingSlots(bookingSlotIDs);
				log.info("User " + user + " deleting following bookingSlots " + bookingSlots);
				bookingSlotDAO.delete(bookingSlots);
			}

			redirectToDefaultMethod(req, res);

			return null;
		}

		throw new URINotFoundException(uriParser);

	}

	private List<BookingSlot> getAllPassedBookingSlots(HttpServletRequest req, String calendarID) throws SQLException {

		String fromDateText = req.getParameter("fromDate");
		String toDateText = req.getParameter("toDate");

		Date fromDate = DateUtils.getDate(DateUtils.DATE_FORMATTER, fromDateText);
		Date toDate = DateUtils.getDate(DateUtils.DATE_FORMATTER, toDateText);

		if (toDate != null) {
			toDate = DateUtils.setTimeToMaximum(toDate);
		}

		Date currentDate = new Date(System.currentTimeMillis());

		if (toDate == null || toDate.after(currentDate)) {
			toDate = currentDate;
		}

		LowLevelQuery<BookingSlot> query = new LowLevelQuery<>();

		if (fromDate != null) {

			query.setSql("SELECT * FROM " + bookingSlotDAO.getTableName() + " s INNER JOIN booking_calendars c ON (c.calendarID = s.calendarID) LEFT JOIN bookings b ON (b.bookingSlotID=s.bookingSlotID) WHERE c.calendarID=? AND start >= ? AND end <=?");
			query.addParameter(calendarID);
			query.addParameter(DateUtils.DATE_TIME_SECONDS_FORMATTER.format(fromDate));
			query.addParameter(DateUtils.DATE_TIME_SECONDS_FORMATTER.format(toDate));

		} else {
			query.addParameter(calendarID);
			query.setSql("SELECT * FROM " + bookingSlotDAO.getTableName() + " s INNER JOIN booking_calendars c ON (c.calendarID = s.calendarID) LEFT JOIN bookings b ON (b.bookingSlotID=s.bookingSlotID) WHERE c.calendarID=? AND end <=?");
			query.addParameter(DateUtils.DATE_TIME_SECONDS_FORMATTER.format(toDate));
		}

		query.addRelation(BookingSlot.CALENDAR_RELATION);
		query.addRelation(BookingSlot.BOOKINGS_RELATION);

		return bookingSlotDAO.getAll(query);
	}

	private List<BookingSlot> getBookingSlots(List<Integer> bookingSlotIDs) throws SQLException {

		LowLevelQuery<BookingSlot> query = new LowLevelQuery<>("SELECT * FROM " + bookingSlotDAO.getTableName() + " WHERE bookingSlotID IN (" + DBUtils.getPreparedStatementQuestionMarks(bookingSlotIDs) + ")");
		query.addParameters(bookingSlotIDs);
		return bookingSlotDAO.getAll(query);
	}

	private BookingCalendar getCalendar(String calendarID) throws SQLException {

		if (calendarID == null || !NumberUtils.isInt(calendarID)) {
			return null;
		}
		HighLevelQuery<BookingCalendar> query = new HighLevelQuery<>();
		query.addParameter(bookingCalendarIDParameterFactory.getParameter(Integer.parseInt(calendarID)));

		return calendarDAO.get(query);
	}

	private synchronized void importCalendar(InputStream inputStream, String filename, HttpServletRequest req, HttpServletResponse res, User user) throws ValidationException {

		try {

			Document doc = parseXML(inputStream, filename);

			Element docElement = doc.getDocumentElement();

			if (!docElement.getTagName().equals("Calendar")) {

				log.info("Error parsing file " + filename + ", unable to find calendar element");

				throw new ValidationException(new UnableToParseFileValidationError(filename));
			}

			BookingCalendar calendar = BookingCalendar.class.newInstance();

			XMLParser xmlParser = new XMLParser(docElement);

			calendar.populate(xmlParser);

			this.filterHTML(calendar);

			Document newDoc = XMLUtils.createDomDocument();

			XMLGeneratorDocument xmlGeneratorDocument = new XMLGeneratorDocument(newDoc);

			xmlGeneratorDocument.addIgnoredField(Arrays.asList(BookingCalendar.MANAGER_GROUPS_RELATION, BookingCalendar.ADMIN_GROUPS_RELATION, BookingCalendar.MANAGER_USERS_RELATION));

			Element calendarElement = calendar.toXML(xmlGeneratorDocument);

			newDoc.appendChild(calendarElement);

			calendarDAO.add(calendar);

			log.info("User " + user + " succefully imported calendar " + calendar);

			res.sendRedirect(this.getModuleURI(req));

		} catch (SQLException | IllegalAccessException | InstantiationException | IOException e) {

			log.error(e);
			throw new ValidationException(Arrays.asList(new ValidationError("UnableToParseRequest")));
		}
	}

	private Document parseXML(InputStream inputStream, String filename) throws ValidationException {

		try {

			return XMLUtils.parseXML(inputStream, false, false);

		} catch (Exception e) {

			log.info("Unable to parse file " + filename, e);

			throw new ValidationException(new UnableToParseFileValidationError(filename));
		}
	}

	public void filterHTML(BookingCalendar calendar) {

		if (htmlContentFilter == null) {

			return;
		}

		calendar.setDescription(htmlContentFilter.filterHTML(calendar.getDescription()));
	}

	public Document getExportCalendarDocument(BookingCalendar calendar) {

		Document doc = XMLUtils.createDomDocument();

		XMLGeneratorDocument xmlGeneratorDocument = new XMLGeneratorDocument(doc);

		xmlGeneratorDocument.addIgnoredField(Arrays.asList(BookingCalendar.MANAGER_GROUPS_RELATION, BookingCalendar.ADMIN_GROUPS_RELATION, BookingCalendar.MANAGER_USERS_RELATION));

		Element calendarElement = calendar.toXML(xmlGeneratorDocument);

		doc.appendChild(calendarElement);

		return doc;
	}

	public boolean hasBookingAdminAccess(BookingCalendar calendar, User user) {

		return AccessUtils.checkAccess(user, calendar);
	}

	@Override
	public Document createDocument(HttpServletRequest req, URIParser uriParser, User user) {

		Document doc = XMLUtils.createDomDocument();
		Element document = doc.createElement("Document");

		document.appendChild(RequestUtils.getRequestInfoAsXML(doc, req, uriParser));
		document.appendChild(this.moduleDescriptor.toXML(doc));
		XMLUtils.appendNewElement(doc, document, "ModuleURI", req.getContextPath() + getFullAlias());

		XMLUtils.appendNewElement(doc, document, "EnableProfileSupport", notificationHandler.isEnableProfileSupport());
		XMLUtils.appendNewElement(doc, document, "EnableRebookingNotificationsOnlyToSlotManagers", enableRebookingNotificationsOnlyToSlotManagers);

		doc.appendChild(document);
		return doc;
	}

	@Override
	public String getTitlePrefix() {

		return moduleDescriptor.getName();
	}

	public SectionDescriptor getSectionDescriptor() {

		return sectionInterface.getSectionDescriptor();
	}

	@WebPublic(alias = "users")
	public ForegroundModuleResponse getUsers(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return userGroupListConnector.getUsers(req, res, user, uriParser);
	}

	@WebPublic(alias = "groups")
	public ForegroundModuleResponse getGroups(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return userGroupListConnector.getGroups(req, res, user, uriParser);
	}

	public UserHandler getUserHandler() {

		return systemInterface.getUserHandler();
	}

	public GroupHandler getGroupHandler() {

		return systemInterface.getGroupHandler();
	}

	@EventListener(channel = FlowInstanceManager.class)
	public void processEvent(SubmitEvent event, EventSource source) {

		if (!source.isLocal() || event.getEvent() == null || event.getEvent().getEventType() != EventType.SUBMITTED || event.getActionID() == null || !supportedActionIDs.contains(event.getActionID())) {

			return;
		}

		try {

			FlowInstanceManager flowInstanceManager = event.getFlowInstanceManager();
			FlowInstance flowInstance = (FlowInstance) flowInstanceManager.getFlowInstance();

			List<BookingQueryInstance> bookingQueryInstances = flowInstanceManager.getQueries(BookingQueryInstance.class);

			if (CollectionUtils.isEmpty(bookingQueryInstances)) {

				return;
			}

			List<User> bookingSlotManagers = null;

			for (BookingQueryInstance queryInstance : bookingQueryInstances) {

				if (queryInstance.getQueryInstanceDescriptor().isPopulated() && queryInstance.isAccepted()) {

					Booking booking = createBookingFromSubmitEvent(queryInstance, event);

					if (booking != null) {

						BookingQuery query = queryInstance.getQuery();

						if (query.shouldAddBookingSlotManagersToFlowInstance()) {

							bookingSlotManagers = CollectionUtils.addAndInstantiateIfNeeded(bookingSlotManagers, booking.getBookingSlot().getManagers());
						}

						if (query.isSetAsAttribute()) {

							flowInstance.getAttributeHandler().setAttribute(query.getAttributeName() + ".url", notificationHandler.getUserBookingOverviewURL(booking));
							
							flowInstance.getAttributeHandler().setAttribute(query.getAttributeName() + ".bookingID", booking.getBookingID());
							
							updateFlowInstance(flowInstance, FlowInstance.ATTRIBUTES_RELATION);
						}
					}
				}
			}

			addManagersToFlowInstance(flowInstance, bookingSlotManagers);

		} catch (Exception e) {

			log.error("Error ", e);
		}
	}
	
	private void updateFlowInstance(FlowInstance flowInstance, Field... field) throws SQLException {
		
		RelationQuery updateQuery = new RelationQuery(field);

		flowInstanceDAO.update(flowInstance, updateQuery);
	}

	private Booking createBookingFromSubmitEvent(BookingQueryInstance queryInstance, SubmitEvent event) throws SQLException {

		FlowInstanceManager flowInstanceManager = event.getFlowInstanceManager();
		FlowInstance flowInstance = (FlowInstance) flowInstanceManager.getFlowInstance();

		if (!queryInstance.getQuery().getCalendar().isAllowPreliminaryBookings()) {

			return createBooking(queryInstance, flowInstanceManager, event.getEvent(), false);
		}

		Booking booking = getBooking(flowInstance, queryInstance, Booking.BOOKING_SLOT_RELATION, BookingSlot.CALENDAR_RELATION, BookingSlot.MANAGERS_RELATION);

		if (booking == null) {

			return createBooking(queryInstance, flowInstanceManager, event.getEvent(), false);
		}

		if (!booking.isPreliminary()) {

			log.warn("Attempt to either create multiple bookings for the same booking slot in the same flow instance, or attempt to complete preliminary booking that is already completed.");
			return null;
		}

		booking.setPreliminary(false);

		RelationQuery updateQuery = new RelationQuery();
		updateQuery.addExcludedFields(Booking.BOOKING_SLOT_RELATION);

		bookingDAO.update(booking, updateQuery);

		log.info("Completed booking " + booking + " of calendar " + queryInstance.getQuery().getCalendar() + " for " + event.getFlowInstanceManager().getFlowInstance());

		return booking;
	}

	private void addManagersToFlowInstance(FlowInstance flowInstance, List<User> newManagers) throws SQLException {

		if (CollectionUtils.isEmpty(newManagers)) {
			return;
		}

		List<User> previousManagers = flowInstance.getManagers();

		List<User> flowInstanceManagers = CollectionUtils.instantiateIfNeeded(flowInstance.getManagers());

		boolean addedAnyNewManagers = false;

		for (User newManager : newManagers) {

			if (flowInstanceManagers.contains(newManager)) {

				continue;
			}

			User newManagerWithGroups = getUserHandler().getUser(newManager.getUserID(), true, false);

			if (flowInstance.getFlow().getFlowFamily().getManagerAccess(newManagerWithGroups) != null) {

				flowInstanceManagers.add(newManager);
				addedAnyNewManagers = true;

			} else {

				log.warn("Tried to add booking slot managers to flowInstance " + flowInstance + " but the managers did not have the required access");
			}
		}

		if (addedAnyNewManagers) {

			flowInstance.setManagers(flowInstanceManagers);

			RelationQuery updateQuery = new RelationQuery(FlowInstance.MANAGERS_RELATION);

			flowInstanceDAO.update(flowInstance, updateQuery);

			String detailString = FlowInstanceUtils.getManagersString(flowInstance.getManagers(), flowInstance.getManagerGroups());

			SiteProfile profile = flowAdminModule.getSiteProfile(flowInstance);

			FlowInstanceEvent flowInstanceEvent = flowAdminModule.getFlowInstanceEventGenerator().addFlowInstanceEvent(flowInstance, EventType.MANAGERS_UPDATED, detailString, null);

			systemInterface.getEventHandler().sendEvent(FlowInstance.class, new CRUDEvent<>(CRUDAction.UPDATE, flowInstance), EventTarget.ALL);

			systemInterface.getEventHandler().sendEvent(FlowInstance.class, new ManagersChangedEvent(flowInstance, flowInstanceEvent, profile, previousManagers, flowInstance.getManagerGroups(), null), EventTarget.ALL);

		}
	}

	//TODO processEvent PaymentStarted, PaymentCanceled

	@EventListener(channel = FlowInstance.class, priority = 1)
	public void processEvent(MultiSigningInitiatedEvent event, EventSource source) throws SQLException {

		FlowInstanceManager flowInstanceManager = event.getFlowInstanceManager();

		List<BookingQueryInstance> queryInstances = flowInstanceManager.getQueries(BookingQueryInstance.class);

		if (queryInstances == null) {

			return;
		}

		for (BookingQueryInstance queryInstance : queryInstances) {

			if (queryInstance.getQueryInstanceDescriptor().isPopulated() && queryInstance.isAccepted() && queryInstance.getQuery().getCalendar().isAllowPreliminaryBookings()) {

				createBooking(queryInstance, flowInstanceManager, event.getEvent(), true);
			}
		}
	}

	@EventListener(channel = FlowInstance.class, priority = 1)
	public void processEvent(MultiSigningCanceledEvent event, EventSource source) throws SQLException, MissingQueryInstanceDescriptor, QueryProviderNotFoundException, InvalidFlowInstanceStepException, QueryProviderErrorException, QueryInstanceNotFoundInQueryProviderException {

		FlowInstanceManager flowInstanceManager = flowAdminModule.getImmutableFlowInstanceManager(event.getFlowInstance().getFlowInstanceID());

		List<BookingQueryInstance> queryInstances = flowInstanceManager.getQueries(BookingQueryInstance.class);

		if (queryInstances == null) {

			return;
		}

		FlowInstance flowInstance = (FlowInstance) flowInstanceManager.getFlowInstance();

		for (BookingQueryInstance queryInstance : queryInstances) {

			if (queryInstance.getQueryInstanceDescriptor().isPopulated() && queryInstance.isAccepted()) {

				Booking booking = getBooking(flowInstance, queryInstance);

				if (booking != null && booking.isPreliminary()) {

					log.info("Deleting preliminary booking due to multi signing aborted: " + booking);
					bookingDAO.delete(booking);
				}
			}
		}
	}

	private Booking createBooking(BookingQueryInstance queryInstance, FlowInstanceManager flowInstanceManager, FlowInstanceEvent event, boolean preliminary) throws SQLException {

		FlowInstance flowInstance = (FlowInstance) flowInstanceManager.getFlowInstance();

		Timestamp now = new Timestamp(System.currentTimeMillis());
		User poster = flowInstanceManager.getFlowInstance().getPoster();

		BookingSlot bookingSlot = queryInstance.getBookingSlot();

		if (bookingSlot == null) {

			log.error("Got event " + event + " for flow instance " + flowInstance + " new booking but booking slot in query instance " + queryInstance + " has been removed, can not create booking");
			return null;
		}

		BookingUtils.setBookingSlotTransientData(bookingSlot, bookingSlotDAO);

		if (bookingSlot.getFreeSlots() < 1) {

			log.error("Got event " + event + " for from flow instance " + flowInstance + " new booking but booking slot " + bookingSlot + " is already full!");
		}

		Booking booking = new Booking();
		booking.setBookingSlot(bookingSlot);
		booking.setAdded(now);
		booking.setFlowInstanceID(flowInstance.getFlowInstanceID());
		booking.setPreliminary(preliminary);
		booking.setSize(queryInstance.getSize());

		if (!StringUtils.isEmpty(queryInstance.getComment())) {

			ExternalMessage externalMessage = new ExternalMessage(queryInstance.getComment(), poster, event.getAdded(), ExternalMessageType.ENTRANCE);

			booking.addExternalMessage(externalMessage);
		}

		PrimaryContact primaryContact = getPrimaryContact(flowInstanceManager, poster);

		if (primaryContact != null) {

			String citizenIdentifier = primaryContact.getCitizenIdentifier();

			if (!StringUtils.isEmpty(citizenIdentifier)) {

				BookingCalendar calendar = queryInstance.getQuery().getCalendar();

				try {

					BookingCRUD.validateCitizenIdentifier(citizenIdentifier, calendar, bookingSlot, false, dataSource);

				} catch (PersonAlreadyInCalendarValidationException e) {

					log.warn("Contact " + primaryContact + " already has an active booking in " + calendar);
					return null;

				} catch (PersonAlreadyInBookingSlotValidationException e) {

					log.warn("Contact " + primaryContact + " has already booked " + bookingSlot);
					return null;
				}
			}

			booking.setPrimaryContact(primaryContact);
		}

		List<FlowInstanceEvent> flowInstanceEvents = getFlowInstanceEvents(flowInstance);
		List<BookingEvent> events = CollectionUtils.map(flowInstanceEvents, e -> e.getEventType() == EventType.PAYED ? new BookingEvent(e) : null);

		if (events == null) {

			events = new ArrayList<>();
		}

		events.add(new BookingEvent(now, poster, BookingEventType.SUBMITTED, null, null));

		booking.setEvents(events);

		//Secondary contact
		if (secondaryContactFirstnameAttribute != null && secondaryContactLastnameAttribute != null && secondaryContactCitizenIdentifierAttribute != null) {

			String secondaryContactFirstname = flowInstance.getAttributeHandler().getString(secondaryContactFirstnameAttribute);
			String secondaryContactLastname = flowInstance.getAttributeHandler().getString(secondaryContactLastnameAttribute);
			String secondaryContactCitizenIdentifier = flowInstance.getAttributeHandler().getString(secondaryContactCitizenIdentifierAttribute);

			if (secondaryContactFirstname != null && secondaryContactLastname != null && secondaryContactCitizenIdentifier != null) {

				String secondaryContactMessage = secondaryContactInternalMessagePrefix + " " + secondaryContactFirstname + " " + secondaryContactLastname + " " + secondaryContactCitizenIdentifier;

				InternalMessage internalMessage = new InternalMessage(secondaryContactMessage, poster, event.getAdded());

				booking.addInternalMessage(internalMessage);
			}
		}

		HighLevelQuery<Booking> highLevelQuery = new HighLevelQuery<>(Booking.EVENTS_RELATION, Booking.CONTACT_RELATION, Booking.INTERNAL_MESSAGES_RELATION, Booking.EXTERNAL_MESSAGES_RELATION);

		bookingDAO.add(booking, highLevelQuery);

		log.info("Added user " + poster + " to booking slot " + bookingSlot + " as  " + (preliminary ? "preliminary " : "") + booking);

		return booking;
	}

	private PrimaryContact getPrimaryContact(FlowInstanceManager flowInstanceManager, User poster) {

		FlowInstance flowInstance = (FlowInstance) flowInstanceManager.getFlowInstance();

		List<ContactDetailQueryInstance> contactDetailQueryInstances = flowInstanceManager.getQueries(ContactDetailQueryInstance.class);

		PrimaryContact primaryContact = null;

		if (!CollectionUtils.isEmpty(contactDetailQueryInstances)) {

			for (ContactDetailQueryInstance contactDetailQueryInstance : contactDetailQueryInstances) {

				if (contactDetailQueryInstance.getQueryInstanceDescriptor().isPopulated()) {

					if (primaryContact != null) {

						log.warn("Flow instance " + flowInstance + " contains multiple populated " + ContactDetailQueryInstance.class + " queries.");
					}

					primaryContact = new PrimaryContact(contactDetailQueryInstance);
				}
			}
		}

		if (poster != null) {

			if (primaryContact == null) {

				primaryContact = new PrimaryContact(poster);
			}

			if (StringUtils.isEmpty(primaryContact.getCitizenIdentifier())) {

				primaryContact.setCitizenIdentifier(CitizenIdentifierUtils.getUserOrManagerCitizenIdentifier(poster));
			}

			if (StringUtils.isEmpty(primaryContact.getFirstname())) {

				primaryContact.setFirstname(poster.getFirstname());
			}

			if (StringUtils.isEmpty(primaryContact.getLastname())) {

				primaryContact.setLastname(poster.getLastname());
			}
		}

		return primaryContact;
	}

	public Booking getBooking(FlowInstance flowInstance, BookingQueryInstance queryInstance, Field... relations) throws SQLException {

		HighLevelQuery<Booking> query = new HighLevelQuery<>();

		query.addParameter(bookingFlowInstanceIDParameterFactory.getParameter(flowInstance.getFlowInstanceID()));
		query.addParameter(bookingBookingSlotParameterFactory.getParameter(queryInstance.getBookingSlot()));

		if (relations != null) {

			query.addRelations(relations);
		}

		return bookingDAO.get(query);
	}

	protected List<FlowInstanceEvent> getFlowInstanceEvents(FlowInstance flowInstance) throws SQLException {

		HighLevelQuery<FlowInstanceEvent> query = new HighLevelQuery<>(FlowInstanceEvent.ATTRIBUTES_RELATION);

		query.addParameter(flowInstanceEventFlowInstanceParamFactory.getParameter(flowInstance));

		return flowInstanceEventDAO.getAll(query);
	}

	public Integer getModuleID() {

		return moduleDescriptor.getModuleID();
	}

	@Override
	public void run() {

		try {

			log.info("Checking for old preliminary bookings");

			ArrayListQuery<Integer> idQuery = new ArrayListQuery<>(dataSource,
			//@formatter:off
				"SELECT bookingID FROM " + bookingDAO.getTableName() + " b " +
				"INNER JOIN booking_slots s ON s.bookingSlotID = b.bookingSlotID " +
				"INNER JOIN booking_calendars c ON c.calendarID = s.calendarID AND c.hoursPreliminaryBookingsAreValidFor IS NOT NULL " +
				"WHERE b.preliminary = 1 AND b.added < SUBDATE(NOW(), INTERVAL c.hoursPreliminaryBookingsAreValidFor HOUR)", IntegerPopulator.getPopulator());
			//@formatter:on

			List<Integer> bookingIDs = idQuery.executeQuery();

			if (bookingIDs == null) {

				return;
			}

			for (Integer bookingID : bookingIDs) {

				Booking booking = bookingDAOWrapper.get(bookingID);
				FlowInstance flowInstance = flowAdminModule.getFlowInstance(booking.getFlowInstanceID());

				log.info("Removing preliminary booking " + booking + " of calendar " + booking.getBookingSlot().getCalendar() + " from " + flowInstance);

				try (TransactionHandler transactionHandler = bookingDAO.createTransaction()) {

					bookingDAO.delete(booking, transactionHandler);

					ContentType statusType = flowInstance.getStatus().getContentType();

					if (statusType == ContentType.WAITING_FOR_PAYMENT) {

						flowInstance.setStatus(flowInstance.getFlow().getDefaultState(FlowBrowserModule.SAVE_ACTION_ID));
						flowInstance.setLastStatusChange(TimeUtils.getCurrentTimestamp());

						flowInstanceDAO.update(flowInstance, transactionHandler, null);
					}

					transactionHandler.commit();

					systemInterface.getEventHandler().sendEvent(Booking.class, new CRUDEvent<>(CRUDAction.UPDATE, booking), EventTarget.ALL);

					if (statusType == ContentType.WAITING_FOR_MULTISIGN) {

						flowAdminModule.getMultiSigningHandler().cancelSigning(flowInstance);

					} else if (statusType == ContentType.WAITING_FOR_PAYMENT) {

						systemInterface.getEventHandler().sendEvent(FlowInstance.class, new CRUDEvent<>(CRUDAction.UPDATE, flowInstance), EventTarget.ALL);

						//TODO send notification to owners
					}
				}
			}

		} catch (Throwable t) {

			log.error("Error removing expiring preliminary bookings", t);
		}
	}

	@WebPublic(requireLogin = true)
	public ForegroundModuleResponse checkForExpiredPreliminaryBookings(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws URINotFoundException {

		if (user.isAdmin()) {

			run();
			return new SimpleForegroundModuleResponse("See log", getDefaultBreadcrumb());
		}

		throw new URINotFoundException(uriParser);
	}

	public boolean isHideSubmittedEvent() {

		return hideSubmittedEvent;
	}

	public SiteProfileHandler getSiteProfileHandler() {

		return notificationHandler.getSiteProfileHandler();
	}

	public boolean addExtensionProvider(CalendarFormExtensionProvider provider) {

		return extensionProviders.add(provider);
	}

	public boolean removeExtensionProvider(CalendarFormExtensionProvider provider) {

		return extensionProviders.remove(provider);
	}

	public List<CalendarFormExtensionProvider> getExtensionProviders() {

		return extensionProviders;
	}

	public FlowAdminModule getFlowAdminModule() {

		return flowAdminModule;
	}

	public List<String> getSupportedActionIDs() {

		return supportedActionIDs;
	}

	public EventHandler getEventHandler() {

		return systemInterface.getEventHandler();
	}

	public boolean isOverrideContactBySMS() {

		return overrideContactBySMS;
	}

	public boolean isEnableRebookingNotificationsOnlyToSlotManagers() {

		return enableRebookingNotificationsOnlyToSlotManagers;
	}

	public void setCalendarTemplatedFields(BookingCalendar calendar) {

		notificationHandler.setCalendarTemplatedFields(calendar);
	}

	public void clearUnchangedTemplatedFields(BookingCalendar calendar) {

		notificationHandler.clearUnchangedTemplatedFields(calendar);
	}

	public List<BookingCalendar> getCalendars(User user, Field... relations) throws SQLException {

		return getCalendars(user, user.getGroups(), relations);
	}

	public List<BookingCalendar> getCalendars(User user, Collection<Group> groups, Field... relations) throws SQLException {

		if (user == null && CollectionUtils.isEmpty(groups)) {

			throw new NullPointerException("user and groups may not both be null");
		}

		StringBuilder sql = new StringBuilder();
		LowLevelQuery<BookingCalendar> query = new LowLevelQuery<>();

		sql.append("SELECT c.* FROM " + calendarDAO.getTableName() + " c");

		if (user != null) {

			sql.append(" LEFT JOIN booking_calendar_manager_users u ON u.calendarID = c.calendarID");
		}

		if (!CollectionUtils.isEmpty(groups)) {

			sql.append(" LEFT JOIN booking_calendar_manager_groups g ON g.calendarID = c.calendarID");
			sql.append(" LEFT JOIN booking_calendar_admin_groups ag ON ag.calendarID = c.calendarID");
		}

		sql.append(" WHERE c.enabled = 1 AND (");

		if (user != null) {

			sql.append("u.userID = ?");
			query.addParameter(user.getUserID());
		}

		if (!CollectionUtils.isEmpty(groups)) {

			if (user != null) {

				sql.append(" OR ");
			}

			addCalendarGroupClause(groups, sql, query, "g");
			sql.append(" OR ");
			addCalendarGroupClause(groups, sql, query, "ag");
		}

		sql.append(") GROUP by c.calendarID");

		query.setSql(sql.toString());

		if (relations != null) {

			query.addRelations(relations);
		}

		return calendarDAO.getAll(query);
	}

	private void addCalendarGroupClause(Collection<Group> groups, StringBuilder sql, LowLevelQuery<BookingCalendar> query, String alias) {

		sql.append(alias + ".groupID IN (" + DBUtils.getPreparedStatementQuestionMarks(groups) + ")");

		for (Group group : groups) {

			query.addParameter(group.getGroupID());
		}
	}

	@InstanceManagerDependency
	public void setUserGroupAdminExtensionHandler(UserGroupAdminExtensionHandler userGroupAdminExtensionHandler) {

		if (this.userGroupAdminExtensionHandler != null) {

			this.userGroupAdminExtensionHandler.removeUserAdminExtensionProvider(this);
			this.userGroupAdminExtensionHandler.removeGroupAdminExtensionProvider(this);
		}

		this.userGroupAdminExtensionHandler = userGroupAdminExtensionHandler;

		if (userGroupAdminExtensionHandler != null) {

			userGroupAdminExtensionHandler.addUserAdminExtensionProvider(this);
			userGroupAdminExtensionHandler.addGroupAdminExtensionProvider(this);
		}
	}

	@Override
	public ViewFragment getUserAdminExtensionViewFragment(User requestedUser, HttpServletRequest req, URIParser uriParser, User user) throws Exception {

		Document doc = createDocument(req, uriParser, user);

		Element extensionElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "CalendarUserAdminExtension");

		List<BookingCalendar> calendars = getCalendars(requestedUser, BookingCalendar.MANAGER_GROUPS_RELATION, BookingCalendar.MANAGER_USERS_RELATION);

		if (calendars == null) {

			return null;
		}

		Element calendarsElement = XMLUtils.appendNewElement(doc, extensionElement, "Calendars");

		for (BookingCalendar calendar : calendars) {

			Element calendarElement = XMLUtils.appendNewElement(doc, calendarsElement, "Calendar");

			XMLUtils.appendNewElement(doc, calendarElement, "calendarID", calendar.getCalendarID());
			XMLUtils.appendNewElement(doc, calendarElement, "name", calendar.getName());

			AccessInterface managerAccess = new SimpleAccessInterface(calendar.getManagerGroupIDs(), calendar.getManagerUserIDs());
			String access = AccessUtils.checkAccess(requestedUser, managerAccess) ? "MANAGER" : "ADMIN";

			XMLUtils.appendNewElement(doc, calendarElement, "access", access);
		}

		XMLUtils.appendNewElement(doc, extensionElement, "CalendarAdminURL", req.getContextPath() + getSectionDescriptor().getFullAlias() + "/" + this.moduleDescriptor.getAlias());

		return viewFragmentTransformer.createViewFragment(doc);
	}

	@Override
	public ViewFragment getGroupAdminExtensionViewFragment(Group requestedGroup, HttpServletRequest req, URIParser uriParser, User user) throws Exception {

		Document doc = createDocument(req, uriParser, user);

		Element extensionElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "CalendarUserAdminExtension");

		List<BookingCalendar> calendars = getCalendars(null, Collections.singletonList(requestedGroup), BookingCalendar.MANAGER_GROUPS_RELATION);

		if (calendars == null) {

			return null;
		}

		Element calendarsElement = XMLUtils.appendNewElement(doc, extensionElement, "Calendars");

		for (BookingCalendar calendar : calendars) {

			Element calendarElement = XMLUtils.appendNewElement(doc, calendarsElement, "Calendar");

			XMLUtils.appendNewElement(doc, calendarElement, "calendarID", calendar.getCalendarID());
			XMLUtils.appendNewElement(doc, calendarElement, "name", calendar.getName());

			String access = CollectionUtils.contains(calendar.getManagerGroupIDs(), requestedGroup.getGroupID()) ? "MANAGER" : "ADMIN";

			XMLUtils.appendNewElement(doc, calendarElement, "access", access);
		}

		XMLUtils.appendNewElement(doc, extensionElement, "CalendarAdminURL", req.getContextPath() + getSectionDescriptor().getFullAlias() + "/" + this.moduleDescriptor.getAlias());

		return viewFragmentTransformer.createViewFragment(doc);
	}

	@Override
	public int getPriority() {

		return 2;
	}

	@Override
	public ForegroundModuleDescriptor getModuleDescriptor() {

		return moduleDescriptor;
	}

	@Override
	public List<LinkTag> getLinkTags() {

		return null;
	}

	@Override
	public List<ScriptTag> getScriptTags() {

		return null;
	}

	SystemInterface getSystemInterface() {

		return systemInterface;
	}

	public String getEmailSenderAddress() {

		return notificationHandler.getEmailSenderAddress();
	}

	public String getEmailSenderName() {

		return notificationHandler.getEmailSenderName();
	}

	public boolean isEnableProfileSupport() {

		return notificationHandler.isEnableProfileSupport();
	}

}
