package com.nordicpeak.flowengine.booking;

import java.util.Collection;

import org.apache.poi.common.usermodel.HyperlinkType;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.CreationHelper;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.xssf.usermodel.XSSFHyperlink;

import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.csv.CSVRow;
import se.unlogic.standardutils.date.DateUtils;
import se.unlogic.webutils.http.HTTPUtils;

import com.nordicpeak.flowengine.beans.Contact;
import com.nordicpeak.flowengine.booking.beans.BookingCalendar;
import com.nordicpeak.flowengine.booking.beans.BookingSlot;

public class SpreadSheetUtils {

	private SpreadSheetUtils() {}

	public static void addCell(CSVRow row, int columnIndex, Object value) {

		if (value != null) {

			row.setCellValue(columnIndex, value.toString());
		}
	}

	public static int addCells(Row row, int columnIndex, Collection<? extends Object> values) {

		if (!CollectionUtils.isEmpty(values)) {

			for (Object attributeColumn : values) {

				SpreadSheetUtils.addCell(row, columnIndex++, attributeColumn.toString());
			}
		}

		return columnIndex;
	}

	public static void addCell(Row row, int columnIndex, Object value) {

		if (value == null) {

			return;
		}

		Cell cell = row.createCell(columnIndex);

		cell.setCellValue(value.toString());
	}

	public static void addCell(Row row, int columnIndex, Object value, CellStyle style) {

		if (value == null) {

			return;
		}

		Cell cell = row.createCell(columnIndex);

		cell.setCellValue(value.toString());
		cell.setCellStyle(style);
	}

	public static void addNumericCell(Row row, int columnIndex, Number value) {

		if (value == null) {

			return;
		}

		Cell cell = row.createCell(columnIndex);

		cell.setCellValue(value.doubleValue());
	}

	public static void addHyperlinkCell(Row row, int columnIndex, CreationHelper creationhelper, String url) {

		if (url == null || !HTTPUtils.isValidURL(url)) {

			return;
		}

		XSSFHyperlink link = (XSSFHyperlink) creationhelper.createHyperlink(HyperlinkType.URL);
		link.setAddress(url);

		Cell cell = row.createCell(columnIndex);

		cell.setHyperlink(link);
		cell.setCellValue(url);
	}

	public static int addContactTitleCells(Row row, int startIndex) {

		addCell(row, startIndex++, "Personnummer");
		addCell(row, startIndex++, "Frnamn");
		addCell(row, startIndex++, "Efternamn");
		addCell(row, startIndex++, "E-post");
		addCell(row, startIndex++, "Telefon");
		addCell(row, startIndex++, "Mobiltelefon");
		addCell(row, startIndex++, "Address");
		addCell(row, startIndex++, "Postnummer");
		addCell(row, startIndex++, "Ort");

		return startIndex;
	}

	public static int addContactCells(Contact contact, Row row, int startIndex) {

		addCell(row, startIndex++, contact != null ? contact.getCitizenIdentifier() : "");
		addCell(row, startIndex++, contact != null ? contact.getFirstname() : "");
		addCell(row, startIndex++, contact != null ? contact.getLastname() : "");
		addCell(row, startIndex++, contact != null ? contact.getEmail() : "");
		addCell(row, startIndex++, contact != null ? contact.getPhone() : "");
		addCell(row, startIndex++, contact != null ? contact.getMobilePhone() : "");
		addCell(row, startIndex++, contact != null ? contact.getAddress() : "");
		addCell(row, startIndex++, contact != null ? contact.getZipCode() : "");
		addCell(row, startIndex++, contact != null ? contact.getPostalAddress() : "");

		return startIndex;
	}

	public static int addBookingSlotCells(BookingCalendar calendar, BookingSlot bookingSlot, Row row, int columnIndex) {

		SpreadSheetUtils.addCell(row, columnIndex++, DateUtils.DATE_FORMATTER.format(bookingSlot.getStart()));
		SpreadSheetUtils.addCell(row, columnIndex++, bookingSlot.getTimeFormatted(calendar));
		SpreadSheetUtils.addCell(row, columnIndex++, bookingSlot.getBookingsCount() + " / " + bookingSlot.getSize());
		SpreadSheetUtils.addCell(row, columnIndex++, bookingSlot.getLocation());
		SpreadSheetUtils.addCell(row, columnIndex++, bookingSlot.getDescription());

		return columnIndex;
	}

}
