package com.nordicpeak.flowengine.booking.beans;

import java.lang.reflect.Field;
import java.sql.Timestamp;
import java.util.List;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.booking.enums.ExternalMessageType;

@Table(name = "bookings_external_messages")
@XMLElement
public class ExternalMessage extends BaseMessage {

	private static final long serialVersionUID = -5166683291745202612L;

	public static final Field ATTACHMENTS_RELATION = ReflectionUtils.getField(ExternalMessage.class, "attachments");
	public static final Field BOOKING_RELATION = ReflectionUtils.getField(ExternalMessage.class, "booking");

	@DAOManaged(columnName = "bookingID")
	@ManyToOne
	@XMLElement
	private Booking booking;

	@DAOManaged
	@XMLElement
	private boolean postedByManager;

	@DAOManaged
	@XMLElement
	private ExternalMessageType type;

	@DAOManaged
	@OneToMany(autoAdd = true)
	@XMLElement
	private List<ExternalMessageAttachment> attachments;

	public ExternalMessage() {}

	public ExternalMessage(String message, User poster, Timestamp added, ExternalMessageType type) {

		super(message, poster, added);
		this.type = type;
	}

	public ExternalMessage(String message, User poster, Timestamp added, Booking booking, List<ExternalMessageAttachment> attachments, boolean postedByManager) {

		this(message, poster, added, booking, attachments, postedByManager, null);
	}

	public ExternalMessage(String message, User poster, Timestamp added, Booking booking, List<ExternalMessageAttachment> attachments, boolean postedByManager, ExternalMessageType type) {

		super(message, poster, added);
		this.booking = booking;
		this.attachments = attachments;
		this.postedByManager = postedByManager;
		this.type = type;
	}

	@Override
	public List<ExternalMessageAttachment> getAttachments() {

		return attachments;
	}

	public void setAttachments(List<ExternalMessageAttachment> attachments) {

		this.attachments = attachments;
	}

	@Override
	public Booking getBooking() {

		return booking;
	}

	public void setBooking(Booking booking) {

		this.booking = booking;
	}

	public boolean isPostedByManager() {

		return postedByManager;
	}

	public void setPostedByManager(boolean postedByManager) {

		this.postedByManager = postedByManager;
	}

	public ExternalMessageType getType() {

		return type;
	}

	public void setType(ExternalMessageType eventType) {

		this.type = eventType;
	}

}
