<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	
	<xsl:template match="Document">	
		
		<xsl:apply-templates select="ShowQueryValues"/>
		
	</xsl:template>
	
	<xsl:template match="ShowQueryValues">
		
		<div class="query">
			<xsl:attribute name="class">
				<xsl:text>query</xsl:text>
				<xsl:if test="BookingQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
			</xsl:attribute>
			
			<a name="query{BookingQueryInstance/QueryInstanceDescriptor/QueryDescriptor/queryID}"/>
			
			<h2>
				<xsl:value-of select="BookingQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
			</h2>
			
			<xsl:if test="Description">
				
				<div class="query-description">
					<xsl:choose>
						<xsl:when test="isHTMLDescription = 'true'">
							<xsl:value-of select="Description" disable-output-escaping="yes"/>
						</xsl:when>
						<xsl:otherwise>
							<p>
								<xsl:value-of select="Description" disable-output-escaping="yes"/>
							</p>
						</xsl:otherwise>
					</xsl:choose>
				</div>
								
			</xsl:if>
			
			<xsl:apply-templates select="BookingQueryInstance/BookingQuery/Calendar"/>
				
			<p>
				<strong><xsl:value-of select="$i18n.BookingSlot" /></strong>
				<br/>
				
				<xsl:if test="BookingQueryInstance/BookingSlot/location and BookingQueryInstance/BookingQuery/showLocationInList = 'true' and BookingQueryInstance/BookingQuery/Calendar/viewMode = 'LIST'">
					<xsl:value-of select="BookingQueryInstance/BookingSlot/location"/>
					<xsl:text> </xsl:text>
				</xsl:if>
				
				<xsl:value-of select="BookingQueryInstance/BookingSlot/startDate" />
				<xsl:text> </xsl:text>
				<xsl:call-template name="printBookingSlotTime">
					<xsl:with-param name="bookingSlot" select="BookingQueryInstance/BookingSlot"/>
					<xsl:with-param name="calendar" select="BookingQueryInstance/BookingQuery/Calendar"/>
				</xsl:call-template>
			</p>
			
			<xsl:if test="BookingQueryInstance/BookingSlot/location and not(BookingQueryInstance/BookingQuery/showLocationInList = 'true' and BookingQueryInstance/BookingQuery/Calendar/viewMode = 'LIST')">
				<p>
					<strong><xsl:value-of select="$i18n.BookingSlot.Location" />: </strong>
					<xsl:value-of select="BookingQueryInstance/BookingSlot/location"/>
				</p>
			</xsl:if>
			
			<xsl:if test="BookingQueryInstance/BookingQuery/Calendar/showManagers = 'true' and BookingQueryInstance/BookingSlot/Managers">
				<p>
					<strong><xsl:value-of select="$i18n.BookingSlot.Managers" /></strong>
					<br/>
					<xsl:apply-templates select="BookingQueryInstance/BookingSlot/Managers/user" mode="manager"/>
				</p>
			</xsl:if>
			
			<xsl:if test="BookingQueryInstance/BookingSlot/description">
				<p>
					<strong><xsl:value-of select="$i18n.BookingSlot.Description" /></strong>
					<br/>
					<xsl:call-template name="replaceLineBreak">
						<xsl:with-param name="string" select="BookingQueryInstance/BookingSlot/description"/>
					</xsl:call-template>
				</p>
			</xsl:if>
				
			<p>
				<xsl:if test="BookingQueryInstance/BookingQuery/Calendar/requireConfirmation = 'true' and BookingQueryInstance/accepted = 'true'">
					<xsl:value-of select="BookingQueryInstance/BookingQuery/acceptText" />
				</xsl:if>
			
				<xsl:if test="BookingQueryInstance/comment">
					<div class="bigmargintop">
						<strong>
							<xsl:choose>
								<xsl:when test="BookingQueryInstance/BookingQuery/commentName != ''">
									<xsl:value-of select="BookingQueryInstance/BookingQuery/commentName"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$i18n.Comment"/>
								</xsl:otherwise>
							</xsl:choose>
						</strong>
						<br/>
						<xsl:call-template name="replaceLineBreak">
							<xsl:with-param name="string" select="BookingQueryInstance/comment"/>
						</xsl:call-template>
					</div>
				</xsl:if>
			</p>
			
		</div>
		
	</xsl:template>		

	<xsl:template match="Calendar">

		<xsl:if test="price > 0">
			<p class="tiny">
				<xsl:value-of select="$i18n.PaymentRequired.1"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="price"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="$i18n.PaymentRequired.2"/>
			</p>
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template name="printBookingSlotTime">
		<xsl:param name="bookingSlot" select="BookingSlot"/>
		<xsl:param name="calendar" select="BookingSlot/Calendar"/>
		
		<xsl:value-of select="$bookingSlot/startTime" />
				
		<xsl:choose>
			<xsl:when test="$calendar/showDuration = 'true'">
				<xsl:text> </xsl:text>
				<xsl:value-of select="$bookingSlot/duration" />
				<xsl:text>min</xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text> - </xsl:text>
				<xsl:value-of select="$bookingSlot/endTime" />
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="user" mode="manager">
		
		<xsl:choose>
			<xsl:when test="Attributes/Attribute[Name = 'bookingManagerName']">
				<xsl:value-of select="Attributes/Attribute[Name = 'bookingManagerName']/Value" />
			</xsl:when>
			<xsl:otherwise>
		<xsl:value-of select="firstname" /><xsl:text>&#160;</xsl:text><xsl:value-of select="lastname" />
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:if test="position() != last()">
			<xsl:text>, </xsl:text>
		</xsl:if>
		
	</xsl:template>

</xsl:stylesheet>