var i18nCullingModule = {
	"EMPTY_TABLE": "There are no bookingslots to be shown",
	"NEXT": "Next",
	"PREVIOUS": "Previous",
	"YES": "Yes",
	"NO": "No",
	"CONFIRM_DELETE": "Do you really want to delete the selected",
	"SEARCH": "Search",
	"ZERO_RECORDS": "No matching records found"
};
$(function() {
	$("#CullingDiv").on("click", ".status-button", function(e) {
		e.preventDefault();
		
		var $button = $(this);
		
		$button.toggleClass("active");
		
		$button.find("input").prop("checked", $button.hasClass("active"));
	});
	
	var datatable = $("#bookings-table").DataTable({
		"deferRender": true,
		"info": false,
		"searching": false,
		"order": [[ 1, 'asc' ]],
		"lengthMenu": [ 15, 50, 100, 200, 500 ],
		"select": {
            "style": 'multi',
            "selector": 'td:first-child'
        },
		"initComplete": function(settings, json) {
			
			$(window).trigger("resize");
        },
        "columns": [
        	{
        		"name": "select",
        		"className": 'select-checkbox',
        		"orderable": false,
        		"searchable": false
        	},
			{
    			"name": "fromDate",
    			"render": function(data, type, row, meta) {
    				return data;
    			}
    		},
			{
    			"name": "toDate",
    			"render": function(data, type, row, meta) {
    				return data;
    			}
    		},
			{
    			"name": "nrOfBookings",
    			"render": function(data, type, row, meta) {
    				return data;
    			}
    		},
			{
    			"name": "description",
    			"render": function(data, type, row, meta) {
    				return data;
    			}
    		},
    		{
    			"name": "bookingSlotID",
    			"render": function(data, type, row, meta) {
    				return data;
    			},
				"visible": false,
                "searchable": false

    		}

    	],
    	"dom": 'frtipl',
		"language": {
			"emptyTable": i18nCullingModule.EMPTY_TABLE,
			"lengthMenu": i18nCullingModule.LENGTH_MENU,
			"paginate": {
				"next": i18nCullingModule.NEXT,
				"previous": i18nCullingModule.PREVIOUS
			}
		},
		preDrawCallback: function(settings) {
			
			// Remove callback
			settings.aoPreDrawCallback.splice(0, 1);
			
			settings.oClasses.sPageButton = "btn btn-inline btn-light";
		},
    });
	
	$("#bookings-wrapper").hide();
	
	datatable.on('change', '#select-all', function() {
		
		var checkbox = $(this);
		
		var visibleRows = datatable.rows();
		
		
		if (checkbox.prop("checked")) {
		
			visibleRows.select();
			
		} else {
		
			visibleRows.deselect();
		}
	});
	
	var $showInstanceBtn = $("#showBookings");
	var $validationErrors = $("#validationerrors");
	
	$showInstanceBtn.on("click", function(e) {
		e.preventDefault();
		
		$validationErrors.html("");
		$("#bookings-wrapper").hide();
		
		$showInstanceBtn.prop("disabled", true);
		
		var fromDate = $("#fromDate").val();
		var toDate = $("#toDate").val();
		
		if (fromDate && toDate) {
			if (new Date(fromDate) > new Date(toDate)) {
				$validationErrors.append('<p class="error">' + $showInstanceBtn.data("dateerror") + '</p>');
				
				$showInstanceBtn.prop("disabled", false);
				
				return;
			}
		}
		
		$.ajax({
			url : $showInstanceBtn.data("fetchurl"),
			beforeSend: function(jqXHR, settings) {
				jqXHR.setRequestHeader('NoLoginRedirect', 'true');
			},
			type: "post",
			dataType : "json",
			contentType: "application/x-www-form-urlencoded;charset=UTF-8",
			data: $("#CullingDiv input").serialize(),
			success : function(data) {
				
				if (data.error) {
					if (data.error === "dateinterval") {
						$validationErrors.append('<p class="error">' + $showInstanceBtn.data("dateerror") + '</p>');
					}
					else if (data.error === "dateformat") {
						$validationErrors.append('<p class="error">' + $showInstanceBtn.data("dateformaterror") + '</p>');
					}
					else {
						$validationErrors.append('<p class="error">' + $showInstanceBtn.data("unknownerror") + '</p>');
					}
					
					$showInstanceBtn.prop("disabled", false);
				}
				else {
					$("#bookings-wrapper").show();
					
					$("#bookings-count").html(data.data.length);
					
					datatable.clear();
					datatable.rows.add(data.data);
					datatable.draw();
					
					
					$showInstanceBtn.prop("disabled", false);
				}
			},
			error : function() {
				$showInstanceBtn.prop("disabled", false);
				
				$validationErrors.append('<p class="error">' + $showInstanceBtn.data("unknownerror") + '</p>');
			}
		});
	});
	
	var $deleteInstancesBtn = $("#deleteBookings");
	
	datatable.on( 'select.dt', function() {
		updateDeleteButton();
	});
	
	datatable.on( 'deselect.dt', function() {
		updateDeleteButton();
	});
	
	var updateDeleteButton = function() {
		
		var selectedRows = datatable.rows({selected: true});
		
		if (selectedRows[0].length === 0) {
			$deleteInstancesBtn.prop("disabled", true).addClass("btn-light").removeClass("btn-red");
		}
		else {
			$deleteInstancesBtn.prop("disabled", false).removeClass("btn-light").addClass("btn-red");;
		}
	}
	
	$deleteInstancesBtn.on("click", function(e) {
		
		if ($deleteInstancesBtn.prop("disabled")) {
			return false;
		}
		
		var selectedRows = datatable.rows({selected: true});
		
		$deleteInstancesBtn.prop("disabled", true);
		
		if (!confirm(i18nCullingModule.CONFIRM_DELETE_PART1 + " " + selectedRows[0].length + " " + i18nCullingModule.CONFIRM_DELETE_PART2 + "?")) {
			e.preventDefault();
			
			$deleteInstancesBtn.prop("disabled", false);
			
			return false;
		}
		
		var cells = datatable.cells(selectedRows.toArray()[0], "bookingSlotID:name");
		var selectedIDs = cells.data().toArray();
		
		var form = $('<form />', {
			action: $deleteInstancesBtn.prop("href"),
			method: 'post',
			style: 'display: none;'
		});
		
		for (let selectedID of selectedIDs) {
		  var field = $('<input/>');

		    field.attr("type", "hidden");
		    field.attr("name", "bookingSlotID");
		    field.attr("value", selectedID);
		
		    form.append(field);
		}
		
		form.appendTo("body").trigger("submit");
	});
});