<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/js/confirmpost.js
	</xsl:variable>	

	<xsl:variable name="scripts">
		/js/castorintegration.js?v=2
	</xsl:variable>

	<xsl:variable name="links">
		/css/castorintegration.css
	</xsl:variable>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:template match="Document">
	
		<xsl:apply-templates select="ShowIntegrationSettings" />
		<xsl:apply-templates select="UpdateIntegrationSettings" />
			
	</xsl:template>
	
	<xsl:template match="ShowIntegrationSettings">
	
		<a name="castorintegrationsettings" />
		
		<xsl:choose>
			<xsl:when test="IntegrationSettings">
					
				<xsl:value-of select="$i18n.IntegrationEnabled"/>
				<xsl:text>:&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="IntegrationSettings/enabled = 'true'">
						<xsl:value-of select="$i18n.Yes"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.No"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$i18n.NoIntegrationSettings" />
			</xsl:otherwise>
		</xsl:choose>
		
		<a href="{/Document/ModuleURI}/update/{Flow/flowID}" class="floatright">
			<xsl:value-of select="$i18n.UpdateIntegrationSettings" />
			<img class="alignbottom" src="{/Document/StaticContentURL}/pics/pen.png" alt="" />
		</a>
		
		<xsl:if test="IntegrationSettings">
			<a href="{/Document/ModuleURI}/delete/{Flow/flowID}" class="floatright clearboth" onclick="return confirmPost(this.href, '{$i18n.DeleteIntegrationSettings.Confirm}');">
				<xsl:value-of select="$i18n.DeleteIntegrationSettings" />
				<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
			</a>		
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="UpdateIntegrationSettings">
		
		<div id="CastorIntegrationProvider" class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.UpdateIntegrationSettingsTitle"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
				<xsl:text>&#x20;(</xsl:text>
				<xsl:value-of select="$i18n.flowVersion"/>
				<xsl:text>&#x20;</xsl:text>
				<xsl:value-of select="Flow/version"/>
				<xsl:text>)</xsl:text>
			</h1>
	
			<xsl:apply-templates select="validationException/validationError"/>
	
			<form method="post" action="{/Document/ModuleURI}/update/{Flow/flowID}">
			
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'enabled'" />
						<xsl:with-param name="id" select="'enabled'" />
						<xsl:with-param name="element" select="IntegrationSettings" />       
					</xsl:call-template>
					
					<label for="enabled">
						<xsl:value-of select="$i18n.Enabled" />
					</label>
				</div>
			
				<label for="endpointID" class="floatleft full">
					<xsl:value-of select="$i18n.Endpoint" />
				</label>
				
				<div class="floatleft full">
					<xsl:call-template name="createDropdown">
						<xsl:with-param name="id" select="'endpointID'"/>
						<xsl:with-param name="name" select="'endpointID'"/>
						<xsl:with-param name="element" select="Endpoints/Endpoint" /> 
						<xsl:with-param name="labelElementName" select="'name'" />        
						<xsl:with-param name="valueElementName" select="'endpointID'" />
						<xsl:with-param name="selectedValue" select="IntegrationSettings/Endpoint/endpointID"/>
					</xsl:call-template>
				</div>
				
				<xsl:call-template name="createTextFieldSetting">
					<xsl:with-param name="name" select="'templateID'" />
					<xsl:with-param name="label" select="$i18n.templateID"/>
				</xsl:call-template>
				
									
				<xsl:call-template name="createTextFieldSetting">
					<xsl:with-param name="name" select="'partnerID'" />
					<xsl:with-param name="label" select="$i18n.partnerID"/>
				</xsl:call-template>
				
				<div class="floatleft full bigmargintop">
		
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'createCaseOnSpecificStatus'" />
						<xsl:with-param name="id" select="'createCaseOnSpecificStatus'" />
						<xsl:with-param name="element" select="IntegrationSettings" />
					</xsl:call-template>
					
					<label class="marginright" for="createCaseOnSpecificStatus">
						<xsl:value-of select="$i18n.createCaseOnSpecificStatus" />
					</label>
					
				</div>
				
				<div class="floatleft full bigmarginbottom" data-connector-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/statuses/{Flow/flowID}">
		
					<p>
						<xsl:value-of select="$i18n.createCaseOnSpecificStatus.Description" />
					</p>
		
					<label class="nomargin" for="caseStatusName">
						<xsl:value-of select="$i18n.caseStatusName" />
					</label>
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'caseStatusName'"/>
						<xsl:with-param name="name" select="'caseStatusName'"/>
						<xsl:with-param name="element" select="IntegrationSettings" />          
					</xsl:call-template>
				</div>
				
				<div class="clearboth marginbottom">
					<br/>
				</div>
				
				<div class="floatleft full bigmargintop bigmarginbottom">
				
					<h2><xsl:value-of select="$i18n.SupportedTags.Title"/></h2>
					
					<p><xsl:value-of select="$i18n.SupportedTags.Description"/></p>
					
					<p><xsl:value-of select="SupportedTags"/></p>
				
				</div>				
				
				<div class="floatleft full bigmargintop bigmarginbottom">
				
					<h2><xsl:value-of select="$i18n.Applicant"/></h2>
					
					<xsl:call-template name="createContactFields">
						<xsl:with-param name="namePrefix" select="'case'" />
					</xsl:call-template>
				
				</div>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'realEstateOwner'" />
					<xsl:with-param name="label" select="$i18n.RealEstateOwner" />
					<xsl:with-param name="copiedFromApplicant" select="true()" />
				</xsl:call-template>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'invoiceRecipient'" />
					<xsl:with-param name="label" select="$i18n.InvoiceRecipient" />
					<xsl:with-param name="copiedFromApplicant" select="true()" />
				</xsl:call-template>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'inspectionManager'" />
					<xsl:with-param name="label" select="$i18n.InspectionManager" />
				</xsl:call-template>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'contactPerson'" />
					<xsl:with-param name="label" select="$i18n.ContactPerson" />
					<xsl:with-param name="copiedFromApplicant" select="true()" />
				</xsl:call-template>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'appellant'" />
					<xsl:with-param name="label" select="$i18n.Appellant" />
				</xsl:call-template>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'coApplicant'" />
					<xsl:with-param name="label" select="$i18n.CoApplicant" />
				</xsl:call-template>
				
				<xsl:call-template name="createOptionalContactFields">
					<xsl:with-param name="namePrefix" select="'constructionDeveloper'" />
					<xsl:with-param name="label" select="$i18n.ConstructionDeveloper" />
					<xsl:with-param name="copiedFromApplicant" select="true()" />
				</xsl:call-template>
				
				<div class="clearboth marginbottom">
					<br/>
				</div>
				
				<div class="floatleft full bigmargintop bigmarginbottom">
		
					<h2><xsl:value-of select="$i18n.Attachments"/></h2>
				
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'addAttachmentsSeparately'" />
						<xsl:with-param name="id" select="'addAttachmentsSeparately'" />
						<xsl:with-param name="element" select="IntegrationSettings" />
					</xsl:call-template>
					
					<label class="marginright" for="addAttachmentsSeparately">
						<xsl:value-of select="$i18n.addAttachmentsSeparately" />
					</label>
					
				</div>
				
				<div id="attachmentTypeMappingContainer" class="floatleft full bigmarginbottom">
				
					<div class="full floatleft bigmargintop">
						<h2><xsl:value-of select="$i18n.AttachmentTypeMappings" /></h2>
					</div>
				
					<table id="attachmentTypeMappingTable" class="full coloredtable ">
						<thead>
							<tr>
								<th><xsl:value-of select="$i18n.QueryName" /></th>
								<th><xsl:value-of select="$i18n.AttachmentTypeID" /></th>
								<th width="16px"></th>
							</tr>
						</thead>
						<tbody>
						
							<xsl:choose>
								<xsl:when test="requestparameters">
								
									<xsl:apply-templates select="requestparameters/parameter[name = 'attachmentTypeMappingID']/value" mode="attachmentTypeMapping"/>
								
								</xsl:when>
								<xsl:otherwise>
								
									<xsl:apply-templates select="IntegrationSettings/AttachmentTypeMappings/AttachmentTypeMapping"/>
								
								</xsl:otherwise>
							</xsl:choose>					
						
						</tbody>
					</table>
					
					<div class="floatright">
						<a onclick="addAttachmentTypeMapping();">
							<xsl:value-of select="$i18n.AddAttachmentTypeMapping" />
							<img class="marginleft alignbottom" src="{/Document/StaticContentURL}/pics/add.png" alt="" />
						</a>
					</div>							
					
					
					<xsl:call-template name="createTextFieldSetting">
						<xsl:with-param name="name" select="'defaultAttachmentTypeID'" />
						<xsl:with-param name="label" select="$i18n.defaultAttachmentTypeID"/>
					</xsl:call-template>					
					
				</div>
				
				<div class="clearboth marginbottom">
					<br/>
				</div>
				
				<div class="floatleft full bigmargintop bigmarginbottom">
		
					<h2><xsl:value-of select="$i18n.Notifications"/></h2>
				
					<xsl:call-template name="notificationEmail">
						<xsl:with-param name="toggleField" select="'sendErrorEmail'" />
						<xsl:with-param name="addressesField" select="'errorEmailAddresses'" />
						<xsl:with-param name="toggleLabel" select="$i18n.Notifications.ErrorEmail" />
						<xsl:with-param name="addressesLabel" select="$i18n.Notifications.ErrorEmail.EmailAddresses" />
						<xsl:with-param name="addresses" select="IntegrationSettings/ErrorEmailAddresses/Address" />
					</xsl:call-template>
				
					<xsl:call-template name="notificationEmail">
						<xsl:with-param name="toggleField" select="'sendConfigurationErrorEmail'" />
						<xsl:with-param name="addressesField" select="'configurationErrorEmailAddresses'" />
						<xsl:with-param name="toggleLabel" select="$i18n.Notifications.ConfigurationErrorEmail" />
						<xsl:with-param name="addressesLabel" select="$i18n.Notifications.ConfigurationErrorEmail.EmailAddresses" />
						<xsl:with-param name="addresses" select="IntegrationSettings/ConfigurationErrorEmailAddresses/Address" />
					</xsl:call-template>
					
					<xsl:call-template name="notificationEmail">
						<xsl:with-param name="toggleField" select="'sendInvalidCaseIDErrorEmail'" />
						<xsl:with-param name="addressesField" select="'invalidCaseIDErrorEmailAddresses'" />
						<xsl:with-param name="toggleLabel" select="$i18n.Notifications.InvalidCaseIDErrorEmail" />
						<xsl:with-param name="addressesLabel" select="$i18n.Notifications.InvalidCaseIDErrorEmail.EmailAddresses" />
						<xsl:with-param name="addresses" select="IntegrationSettings/InvalidCaseIDErrorEmailAddresses/Address" />
					</xsl:call-template>
					
				</div>
			
				<div class="floatright clearboth bigmargintop">
					<input type="submit" value="{$i18n.SaveChanges}" />
				</div>
			
			</form>
		
			<div style="display: none;">
		
				<table>
					<tr id="attachmentTypeMapping-template">
						<td>
							<input type="text" name="queryName" class="full"/>
						</td>
						<td>
							<input type="text" name="attachmentTypeID" class="full"/>
						</td>
						<td>
							<input type="hidden" name="attachmentTypeMappingID"/>
							
							<a onclick="deleteAttachmentTypeMapping(this)">
								<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
							</a>				
						</td>
					</tr>
				</table>
				
			</div>
				
		</div>

	</xsl:template>
	
	<xsl:template name="createOptionalContactFields">
		<xsl:param name="namePrefix" />
		<xsl:param name="label" />
		<xsl:param name="copiedFromApplicant" select="false()" />
		
		<div class="floatleft full bigmarginbottom">
		
			<xsl:variable name="enabled">
				<xsl:value-of select="$namePrefix" />
				<xsl:text>Enabled</xsl:text>
			</xsl:variable>
		
			<xsl:call-template name="createCheckbox">
				<xsl:with-param name="name" select="$enabled" />
				<xsl:with-param name="id" select="$enabled" />
				<xsl:with-param name="element" select="IntegrationSettings" />
			</xsl:call-template>
								
			<label class="marginright" for="{$enabled}">
				<xsl:value-of select="concat($i18n.Enable, ' ', $label)" />
			</label>
			
			<a class="tiny toggle-fields"><xsl:value-of select="$i18n.ToggleFields" /></a>
			
			<div class="fields hidden">
			
				<xsl:if test="$copiedFromApplicant">
					<p><xsl:value-of select="$i18n.CopiedFromApplicant"/></p>
				</xsl:if>
				
				<xsl:call-template name="createContactFields">
					<xsl:with-param name="namePrefix" select="$namePrefix" />
				</xsl:call-template>
				
			</div>
		
		</div>
		
	</xsl:template>
	
	<xsl:template name="createContactFields">
		<xsl:param name="namePrefix" />
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'Number')" />
			<xsl:with-param name="label" select="$i18n.Number"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'Name')" />
			<xsl:with-param name="label" select="$i18n.Name"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'CareOf')" />
			<xsl:with-param name="label" select="$i18n.CareOf"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'Address')" />
			<xsl:with-param name="label" select="$i18n.Address"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'ZIPCode')" />
			<xsl:with-param name="label" select="$i18n.ZIPCode"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'PostalAddress')" />
			<xsl:with-param name="label" select="$i18n.PostalAddress"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'Phone')" />
			<xsl:with-param name="label" select="$i18n.Phone"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'MobilePhone')" />
			<xsl:with-param name="label" select="$i18n.MobilePhone"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'Email')" />
			<xsl:with-param name="label" select="$i18n.Email"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'RealEstateName')" />
			<xsl:with-param name="label" select="$i18n.RealEstateName"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'RealEstateNumber')" />
			<xsl:with-param name="label" select="$i18n.RealEstateNumber"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'RealEstateAddress')" />
			<xsl:with-param name="label" select="$i18n.RealEstateAddress"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'RealEstatePostalAddress')" />
			<xsl:with-param name="label" select="$i18n.RealEstatePostalAddress"/>
		</xsl:call-template>
		
		<xsl:call-template name="createTextFieldSetting">
			<xsl:with-param name="name" select="concat($namePrefix, 'RealEstateZIPCode')" />
			<xsl:with-param name="label" select="$i18n.RealEstateZIPCode"/>
		</xsl:call-template>
		
	</xsl:template>
	
	<xsl:template name="createTextFieldSetting">
		<xsl:param name="name" />
		<xsl:param name="label" />
		
		<div class="floatleft full">
		
			<label for="{$name}">
				<xsl:value-of select="$label" />
			</label>
			
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="$name"/>
				<xsl:with-param name="name" select="$name"/>
				<xsl:with-param name="element" select="IntegrationSettings" />          
			</xsl:call-template>
		</div>
	
	</xsl:template>
		
	<xsl:template match="AttachmentTypeMapping">
		
		<tr id="attachmentTypeMapping-{attachmentTypeMappingID}">
			<td>
				<input type="text" name="queryName-{attachmentTypeMappingID}" value="{queryName}" class="full"/>
			</td>
			<td>
				<input type="text" name="attachmentTypeID-{attachmentTypeMappingID}" value="{attachmentTypeID}" class="full"/>
			</td>
			<td>
				<input type="hidden" name="attachmentTypeMappingID" value="{attachmentTypeMappingID}"/>
				
				<a onclick="deleteAttachmentTypeMapping(this)">
					<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
				</a>				
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="value" mode="attachmentTypeMapping">
		
 		<xsl:variable name="attachmentTypeMappingID" select="."/>
		
		<xsl:variable name="queryNameParam" select="concat('queryName-', $attachmentTypeMappingID)"/>
		
		<xsl:variable name="attachmentTypeIDParam" select="concat('attachmentTypeID-', $attachmentTypeMappingID)"/>
		
		<tr id="attachmentTypeMapping-{$attachmentTypeMappingID}">
 			<td>
				<input type="text" name="queryName-{$attachmentTypeMappingID}" value="{../../parameter[name = $queryNameParam]/value}" class="full"/>
			</td>
			<td>
				<input type="text" name="attachmentTypeID-{$attachmentTypeMappingID}" value="{../../parameter[name = $attachmentTypeIDParam]/value}" class="full"/>
			</td>
			<td>
				<input type="hidden" name="attachmentTypeMappingID" value="{$attachmentTypeMappingID}"/>
				
				<a onclick="deleteAttachmentTypeMapping(this)">
					<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
				</a>				
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template name="notificationEmail">
		<xsl:param name="toggleField" />
		<xsl:param name="addressesField" />
		<xsl:param name="toggleLabel" />
		<xsl:param name="addressesLabel" />
		<xsl:param name="addresses" />
	
		<div class="notification-email">
		
			<div>
			
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="name" select="$toggleField" />
					<xsl:with-param name="id" select="$toggleField" />
					<xsl:with-param name="element" select="IntegrationSettings" />
					<xsl:with-param name="class" select="'notification-email-toggle'" />
				</xsl:call-template>
				
				<label class="marginright" for="{$toggleField}">
					<xsl:value-of select="$toggleLabel" />
				</label>
			</div>
			
			<div class="notification-email-text">
			
				<xsl:if test="not(validationException/validationError/fieldName = $addressesField)">
					<xsl:attribute name="class">notification-email-text hidden</xsl:attribute>
				</xsl:if>
			
				<div>
				
					<label for="{$addressesField}">
						<xsl:value-of select="$addressesLabel" />
					</label>
					
					<xsl:call-template name="createTextArea">
						<xsl:with-param name="id" select="$addressesField"/>
						<xsl:with-param name="name" select="$addressesField"/>
						<xsl:with-param name="rows" select="5"/>
						<xsl:with-param name="separateListValues" select="'true'"/>
						<xsl:with-param name="element" select="$addresses" />
					</xsl:call-template>
				</div>
			</div>
		</div>
			
	</xsl:template>
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>														
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="displayName">
						<xsl:value-of select="displayName"/>
					</xsl:when>
					<xsl:when test="fieldName = 'endpointID'">
						<xsl:value-of select="$i18n.Endpoint"/>
					</xsl:when>
					<xsl:when test="fieldName = 'templateID'">
						<xsl:value-of select="$i18n.templateID"/>
					</xsl:when>
					<xsl:when test="fieldName = 'partnerID'">
						<xsl:value-of select="$i18n.partnerID"/>
					</xsl:when>
					<xsl:when test="fieldName = 'defaultAttachmentTypeID'">
						<xsl:value-of select="$i18n.defaultAttachmentTypeID"/>
					</xsl:when>													
					<xsl:when test="fieldName = 'errorEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.ErrorEmail.EmailAddresses"/>
					</xsl:when>													
					<xsl:when test="fieldName = 'configurationErrorEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.ConfigurationErrorEmail.EmailAddresses"/>
					</xsl:when>													
					<xsl:when test="fieldName = 'invalidCaseIDErrorEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.InvalidCaseIDErrorEmail.EmailAddresses"/>
					</xsl:when>													
					<xsl:when test="fieldName = 'caseStatusName'">
						<xsl:value-of select="$i18n.caseStatusName"/>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 5) = 'case'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 5)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.Applicant"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 16) = 'realEstateOwner'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 16)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.RealEstateOwner"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 17) = 'invoiceRecipient'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 17)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.InvoiceRecipient"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 18) = 'inspectionManager'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 18)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.InspectionManager"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 14) = 'contactPerson'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 14)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.ContactPerson"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 10) = 'appellant'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 10)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.Appellant"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 12) = 'coApplicant'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 12)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.CoApplicant"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:when test="substring(fieldName, 0, 22) = 'constructionDeveloper'">
						<xsl:call-template name="personData">
							<xsl:with-param name="field" select="substring(fieldName, 22)"/>
						</xsl:call-template>
						<xsl:text> (</xsl:text>
						<xsl:value-of select="$i18n.ConstructionDeveloper"/>
						<xsl:text>)</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>			
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template name="personData">
		<xsl:param name="field" />
	
		<xsl:choose>
			<xsl:when test="$field = 'Number'">
				<xsl:value-of select="$i18n.Number"/>
			</xsl:when>
			<xsl:when test="$field = 'Name'">
				<xsl:value-of select="$i18n.Name"/>
			</xsl:when>
			<xsl:when test="$field = 'CareOf'">
				<xsl:value-of select="$i18n.CareOf"/>
			</xsl:when>
			<xsl:when test="$field = 'Address'">
				<xsl:value-of select="$i18n.Address"/>
			</xsl:when>
			<xsl:when test="$field = 'ZIPCode'">
				<xsl:value-of select="$i18n.ZIPCode"/>
			</xsl:when>
			<xsl:when test="$field = 'PostalAddress'">
				<xsl:value-of select="$i18n.PostalAddress"/>
			</xsl:when>
			<xsl:when test="$field = 'Phone'">
				<xsl:value-of select="$i18n.Phone"/>
			</xsl:when>
			<xsl:when test="$field = 'MobilePhone'">
				<xsl:value-of select="$i18n.MobilePhone"/>
			</xsl:when>
			<xsl:when test="$field = 'Email'">
				<xsl:value-of select="$i18n.Email"/>
			</xsl:when>
			<xsl:when test="$field = 'RealEstateName'">
				<xsl:value-of select="$i18n.RealEstateName"/>
			</xsl:when>
			<xsl:when test="$field = 'RealEstateNumber'">
				<xsl:value-of select="$i18n.RealEstateNumber"/>
			</xsl:when>
			<xsl:when test="$field = 'RealEstateAddress'">
				<xsl:value-of select="$i18n.RealEstateAddress"/>
			</xsl:when>
			<xsl:when test="$field = 'RealEstatePostalAddress'">
				<xsl:value-of select="$i18n.RealEstatePostalAddress"/>
			</xsl:when>
			<xsl:when test="$field = 'RealEstateZIPCode'">
				<xsl:value-of select="$i18n.RealEstateZIPCode"/>
			</xsl:when>
		</xsl:choose>
	
	</xsl:template>
	
</xsl:stylesheet>