<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
	</xsl:variable>
	
	<xsl:variable name="scripts">
		/js/childinfoquery.js
	</xsl:variable>
	
	<xsl:template match="Document">

		<div id="ChildInfoQueryProvider" class="contentitem">

			<xsl:apply-templates select="validationError" />
			<xsl:apply-templates select="UpdateChildInfoQuery" />

		</div>

	</xsl:template>

	<xsl:template match="UpdateChildInfoQuery">

		<h1>
			<xsl:value-of select="$i18n.UpdateQuery" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="ChildInfoQuery/QueryDescriptor/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form id="updateChildInfoQueryForm" name="queryAdminForm" method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="ChildInfoQuery" />
			</xsl:call-template>
			
			<div class="floatleft full bigmarginbottom">

				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'showAddress'" />
					<xsl:with-param name="name" select="'showAddress'" />
					<xsl:with-param name="element" select="ChildInfoQuery" />
				</xsl:call-template>
				
				<label for="showAddress">
					<xsl:value-of select="$i18n.ShowAddress" />
				</label>
			</div>
			
			<div class="floatleft full bigmarginbottom">

				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'dontSetPopulated'" />
						<xsl:with-param name="name" select="'dontSetPopulated'" />
						<xsl:with-param name="value" select="'true'" />
						<xsl:with-param name="element" select="ChildInfoQuery" />
					</xsl:call-template>
					
					<label for="dontSetPopulated">
						<xsl:value-of select="$i18n.DontSetPopulated" />
					</label>
				</div>

			</div>
			
			<label class="floatleft full">
				<xsl:value-of select="$i18n.LookupMode" />
			</label>				
		
			<div class="floatleft full marginbottom">

				<div class="floatleft full">
					<xsl:call-template name="createRadio">
						<xsl:with-param name="id" select="'POSTER'" />
						<xsl:with-param name="name" select="'lookupMode'" />
						<xsl:with-param name="value" select="'POSTER'" />
						<xsl:with-param name="element" select="ChildInfoQuery" />
						<xsl:with-param name="onclick" select="'showHideSettings();'" />
						<xsl:with-param name="checked" select="'true'"/>
					</xsl:call-template>

					<label for="POSTER">
						<xsl:value-of select="$i18n.LookupMode.Poster" />
					</label>
				</div>
			</div>

			<div class="floatleft full marginbottom">

				<div class="floatleft full">
					<xsl:call-template name="createRadio">
						<xsl:with-param name="id" select="'ATTRIBUTE'" />
						<xsl:with-param name="name" select="'lookupMode'" />
						<xsl:with-param name="value" select="'ATTRIBUTE'" />
						<xsl:with-param name="element" select="ChildInfoQuery" />
						<xsl:with-param name="onclick" select="'showHideSettings();'" />
					</xsl:call-template>

					<label for="ATTRIBUTE">
						<xsl:value-of select="$i18n.LookupMode.Attribute" />
					</label>
				</div>
			</div>			
			
			<div class="clearboth floatleft marginbottom twenty" id="attribute-form">
				<xsl:value-of select="$i18n.Lookup.Attribute.Name" />
				<span class="required">*</span>
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'lookupAttributeName'" />
					<xsl:with-param name="name" select="'lookupAttributeName'" />
					<xsl:with-param name="element" select="ChildInfoQuery" />
				</xsl:call-template>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<h2><xsl:value-of select="$i18n.AdvancedSettings" /></h2>
			</div>
						
			<div class="floatleft full bigmarginbottom">
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'setAsAttribute'" />
						<xsl:with-param name="name" select="'setAsAttribute'" />
						<xsl:with-param name="element" select="ChildInfoQuery" /> 
						<xsl:with-param name="class" select="'vertical-align-middle'" />
					</xsl:call-template>
						
					<label for="setAsAttribute">
						<xsl:value-of select="$i18n.setAsAttribute" />
					</label>
			    </div>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<label for="attributeName" class="floatleft clearboth"><xsl:value-of select="$i18n.attributeName" /></label>
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'attributeName'"/>
						<xsl:with-param name="name" select="'attributeName'"/>
						<xsl:with-param name="title" select="$i18n.attributeName"/>
						<xsl:with-param name="element" select="ChildInfoQuery" />
						<xsl:with-param name="maxlength" select="'255'"/>
					</xsl:call-template>
			    </div>
			</div>			
			
			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>

		</form>
		
		<script>
			showHideSettings();
		</script>

	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'UpdateFailedChildInfoQueryNotFound']">

		<p class="error">
			<xsl:value-of select="$i18n.ChildInfoQueryNotFound" />
		</p>

	</xsl:template>
	
	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
			<xsl:when test="$fieldName = 'lookupAttributeName'">
				<xsl:value-of select="$i18n.Lookup.Attribute.Name" />
			</xsl:when>		
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>