package com.nordicpeak.flowengine.queries.colorpickerquery;

import java.lang.reflect.Field;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLUtils;

import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.StringValueQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;

@Table(name = "color_picker_instances")
@XMLElement
public class ColorPickerQueryInstance extends BaseQueryInstance implements StringValueQueryInstance {
	
	private static final long serialVersionUID = -7761759005604863873L;
	
	public static final Field QUERY_RELATION = ReflectionUtils.getField(ColorPickerQueryInstance.class, "query");
	
	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;
	
	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private ColorPickerQuery query;
	
	@DAOManaged
	@XMLElement
	private String color;
	
	public Integer getQueryInstanceID() {
		
		return queryInstanceID;
	}
	
	public void setQueryInstanceID(Integer queryInstanceID) {
		
		this.queryInstanceID = queryInstanceID;
	}
	
	public String getColor() {
		return color;
	}
	
	public void setColor(String color) {
		this.color = color;
	}
	
	@Override
	public ColorPickerQuery getQuery() {
		
		return query;
	}
	
	public void setQuery(ColorPickerQuery query) {
		
		this.query = query;
	}
	
	@Override
	public void reset(MutableAttributeHandler attributeHandler) {
		
		this.color = null;
		this.resetAttribute(attributeHandler);
		super.reset(attributeHandler);
	}
	
	public void setAttribute(MutableAttributeHandler attributeHandler) {
		
		if (query.getAttributeName() != null) {
			
			attributeHandler.setAttribute(query.getAttributeName(), getStringValue());
		}
	}
	
	public void resetAttribute(MutableAttributeHandler attributeHandler) {
		
		attributeHandler.removeAttribute(query.getAttributeName());
	}
	
	public void copyQueryValues() {
		
	}
	
	@Override
	public String toString() {
		
		return this.getClass().getSimpleName() + " (queryInstanceID=" + queryInstanceID + ")";
	}
	
	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {
		
		Element element = getBaseExportXML(doc);
		
		if (color != null) {
			
			XMLUtils.appendNewElement(doc, element, "Value", color);
		}
		return element;
	}
	
	@Override
	public String getStringValue() {
		
		StringBuilder builder = new StringBuilder();
		
		if (color != null) {
			
			builder.append(color);
		}
		
		return builder.toString();
	}
	
}
