<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js
	</xsl:variable>

	<xsl:variable name="scripts">
		/js/spectrum.js
		/js/colorpickerquery.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/colorpickerquery.css
		/css/spectrum.css
	</xsl:variable>

	<xsl:template match="Document">
		
		<xsl:apply-templates select="ShowQueryValues"/>
		<xsl:apply-templates select="ShowQueryForm"/>
		
	</xsl:template>
	
	<xsl:template match="ShowQueryValues">
		
		<div class="query">
			
			<article class="colorpickerquery show-mode">
				
				<div class="heading-wrapper">
					<h2>
						<xsl:attribute name="class">
							<xsl:if test="ColorPickerQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
								<xsl:text>required</xsl:text>
							</xsl:if>
						</xsl:attribute>
						<xsl:value-of select="ColorPickerQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
					</h2>
					
					<xsl:call-template name="createUpdateButton">
						<xsl:with-param name="queryID" select="ColorPickerQueryInstance/ColorPickerQuery/queryID" />
					</xsl:call-template>
					
				</div>

				<xsl:if test="ColorPickerQueryInstance/ColorPickerQuery/description">
					<span class="italic">
						<xsl:value-of select="ColorPickerQueryInstance/ColorPickerQuery/description" disable-output-escaping="yes" />
					</span>
				</xsl:if>
				
				<div class="clearboth"/>
				
				<div class="floatleft full">
					
					<label>
						<xsl:value-of select="$i18n.Color" />
					</label>
					
					<div>
						<xsl:value-of select="ColorPickerQueryInstance/color" />
						<div class="bigmarginleft colorpreview" style="background: {ColorPickerQueryInstance/color}"/>
					</div>
					
				</div>
				
			</article>
			
		</div>
		
	</xsl:template>	
		
	<xsl:template match="ShowQueryForm">
	
		<xsl:variable name="query" select="ColorPickerQueryInstance/ColorPickerQuery" />
		<xsl:variable name="shortQueryID" select="concat('q', $query/queryID)" />
		<xsl:variable name="queryID" select="concat('query_', $query/queryID)" />
	
		<div class="query colorpickerquery" id="{$queryID}" data-use-alpha="{$query/useAlpha}" data-use-palette="{$query/usePalette}" data-use-comparison="{$query/useComparison}" data-preferred-format="{$query/ColorPickerFormat/Value}">
			
			<xsl:if test="EnableAjaxPosting">
				<xsl:attribute name="class">query enableAjaxPosting</xsl:attribute>
			</xsl:if>
			
			<a name="{$queryID}" />
		
			<xsl:if test="ValidationErrors/validationError">
				<div id="{$queryID}-validationerrors" class="validationerrors">
					<div class="info-box error">
					
							<xsl:apply-templates select="ValidationErrors/validationError"/>
							
						<div class="marker"></div>
					</div>
				</div>
			</xsl:if>
	
			<article>
			
				<xsl:if test="ValidationErrors/validationError">
					<xsl:attribute name="class">colorpickerquery error</xsl:attribute>
				</xsl:if>
			
				<div class="heading-wrapper">
					
					<h2>
						<xsl:attribute name="class">
							<xsl:if test="ColorPickerQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
								<xsl:text>required</xsl:text>
							</xsl:if>
						</xsl:attribute>
						<xsl:value-of select="ColorPickerQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
					</h2>
					
					<xsl:if test="ColorPickerQueryInstance/ColorPickerQuery/helpText">		
						<xsl:apply-templates select="ColorPickerQueryInstance/ColorPickerQuery/helpText" />
					</xsl:if>
				
				</div>

				<xsl:if test="ColorPickerQueryInstance/ColorPickerQuery/description">
					<span class="italic">
						<xsl:if test="/Document/useCKEditorForDescription = 'true'"><xsl:attribute name="class">italic html-description</xsl:attribute></xsl:if>
						<xsl:value-of select="ColorPickerQueryInstance/ColorPickerQuery/description" disable-output-escaping="yes" />
					</span>		
				</xsl:if>
				
				<fieldset>
				
					<xsl:variable name="fieldName" select="concat($shortQueryID, '_color')" />
				
					<div class="split">
						
						<label for="{$fieldName}">
							<xsl:value-of select="$i18n.Color" />
						</label>
				
						<div class="inputdiv">
						
							<xsl:variable name="class">
								<xsl:if test="ValidationErrors/validationError[fieldName = $fieldName]">
									<xsl:text>sp-validation-error</xsl:text>
								</xsl:if>
							</xsl:variable>
						
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="$fieldName" />
								<xsl:with-param name="name" select="$fieldName" />
								<xsl:with-param name="type" select="'text'"/>
								<xsl:with-param name="width" select="'calc(100% - 60px)'"/>
								<xsl:with-param name="value" select="ColorPickerQueryInstance/color"/>
								<xsl:with-param name="class" select="concat($class, ' floatleft marginright')"/>
							</xsl:call-template>
						</div>
						
					</div>
				</fieldset>
							
				<script type="text/javascript">
					ColorPickerQueryi18n = {
						choose: "<xsl:value-of select="$i18n.js.Choose"/>",
						cancel: "<xsl:value-of select="$i18n.js.Cancel"/>",
					}
				
					initColorPickerQuery('<xsl:value-of select="ColorPickerQueryInstance/ColorPickerQuery/queryID" />');
				</script>
				
			</article>
			
		</div>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'RequiredQuery' or validationErrorType = 'RequiredField']">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.RequiredQuery"/>
			</strong>
		</span>
		
	</xsl:template>
	
	<xsl:template match="validationError[validationErrorType = 'InvalidFormat']">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.InvalidFormat"/>
			</strong>
		</span>
		
	</xsl:template>
	
	<xsl:template match="validationError">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.UnknownValidationError"/>
			</strong>
		</span>
		
	</xsl:template>	
		
</xsl:stylesheet>