package com.nordicpeak.flowengine.coloredtag.daos;

import java.lang.reflect.Field;
import java.sql.SQLException;
import java.util.List;

import javax.sql.DataSource;

import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOFactory;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.TransactionHandler;

import com.nordicpeak.flowengine.coloredtag.beans.ColoredTagMapping;

public class ColoredTagMappingDAO extends AnnotatedDAO<ColoredTagMapping> {

	private final QueryParameterFactory<ColoredTagMapping, Integer> flowInstanceIDParamFactory;

	public ColoredTagMappingDAO(DataSource dataSource, Class<ColoredTagMapping> beanClass, AnnotatedDAOFactory daoFactory) {

		super(dataSource, beanClass, daoFactory);

		flowInstanceIDParamFactory = this.getParamFactory(ColoredTagMapping.FIELD_FLOW_INSTANCE_ID, Integer.class);
	}

	public ColoredTagMapping getByFlowInstanceID(Integer flowInstanceID, Field... relations) throws SQLException {

		HighLevelQuery<ColoredTagMapping> query = new HighLevelQuery<>();

		query.addParameter(flowInstanceIDParamFactory.getParameter(flowInstanceID));

		if (relations != null) {

			query.addRelations(relations);
		}

		return this.get(query);
	}
	
	public List<ColoredTagMapping> getByFlowInstanceID(List<Integer> flowInstanceIDs, Field... relations) throws SQLException {

		HighLevelQuery<ColoredTagMapping> query = new HighLevelQuery<>();

		query.addParameter(flowInstanceIDParamFactory.getWhereInParameter(flowInstanceIDs));

		if (relations != null) {

			query.addRelations(relations);
		}

		return this.getAll(query);
	}

	public Integer deleteByFlowInstanceID(Integer flowInstanceID, Field... relations) throws SQLException {

		HighLevelQuery<ColoredTagMapping> query = new HighLevelQuery<>();

		query.addParameter(flowInstanceIDParamFactory.getParameter(flowInstanceID));

		if (relations != null) {

			query.addRelations(relations);
		}

		return this.delete(query);
	}
	
	public Integer deleteByFlowInstanceID(Integer flowInstanceID, TransactionHandler transactionHandler, Field... relations) throws SQLException {

		HighLevelQuery<ColoredTagMapping> query = new HighLevelQuery<>();

		query.addParameter(flowInstanceIDParamFactory.getParameter(flowInstanceID));

		if (relations != null) {

			query.addRelations(relations);
		}

		return this.delete(query, transactionHandler);
	}

}
