package com.nordicpeak.flowengine.queries.constructionpermit;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUD;
import com.nordicpeak.flowengine.queries.constructionpermit.beans.ConstructionPermitQuery;
import com.nordicpeak.flowengine.queries.constructionpermit.beans.Model;

public class ConstructionPermitQueryCRUD extends BaseQueryCRUD<ConstructionPermitQuery, ConstructionPermitQueryProviderModule> {

	protected AnnotatedDAOWrapper<ConstructionPermitQuery, Integer> queryDAO;

	public ConstructionPermitQueryCRUD(AnnotatedDAOWrapper<ConstructionPermitQuery, Integer> queryDAO, BeanRequestPopulator<ConstructionPermitQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, ConstructionPermitQueryProviderModule callback) {

		super(ConstructionPermitQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);

		this.queryDAO = queryDAO;
	}

	@Override
	protected ConstructionPermitQuery populateFromUpdateRequest(ConstructionPermitQuery bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		ConstructionPermitQuery query = super.populateFromUpdateRequest(bean, req, user, uriParser);

		List<ValidationError> validationErrors = new ArrayList<ValidationError>();

		this.populateQueryDescriptor((QueryDescriptor) query.getQueryDescriptor(), req, validationErrors);

		String modelID = req.getParameter("modelID");
		
		if(!StringUtils.isEmpty(modelID)){
			
			Model model = callback.getModel(modelID);
			
			if(model != null){
				
				query.setModel(model);
				
			}else{
				
				validationErrors.add(new ValidationError("SelectedModelNotFound"));
			}
			
		}else{
			
			validationErrors.add(new ValidationError("NoModelSelected"));
		}
		
		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}

		return query;
	}

	@Override
	protected void appendUpdateFormData(ConstructionPermitQuery bean, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {

		super.appendUpdateFormData(bean, doc, updateTypeElement, user, req, uriParser);
		
		XMLUtils.append(doc, updateTypeElement, "Models", callback.getModels());
	}

	@Override
	protected List<Field> getBeanRelations() {

		return Collections.singletonList(ConstructionPermitQuery.MODEL_RELATION);
	}
}
