package com.nordicpeak.flowengine.queries.constructionpermit.beans;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLUtils;

import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.StringValueQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesQueryInstance;

@Table(name = "construction_permit_query_instances")
@XMLElement
public class ConstructionPermitQueryInstance extends BaseQueryInstance implements StringValueQueryInstance, FixedAlternativesQueryInstance {

	private static final long serialVersionUID = -7761759005604863873L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(ConstructionPermitQueryInstance.class, "query");
	public static final Field VALUES_RELATION = ReflectionUtils.getField(ConstructionPermitQueryInstance.class, "values");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private ConstructionPermitQuery query;

	@DAOManaged
	@OneToMany
	@XMLElement(fixCase = true)
	private List<PermitNodeValue> values;

	public Integer getQueryInstanceID() {

		return queryInstanceID;
	}

	public void setQueryInstanceID(Integer queryInstanceID) {

		this.queryInstanceID = queryInstanceID;
	}

	@Override
	public ConstructionPermitQuery getQuery() {

		return query;
	}

	public void setQuery(ConstructionPermitQuery query) {

		this.query = query;
	}

	@Override
	public void reset(MutableAttributeHandler attributeHandler) {

		this.values = null;

		if (query.isSetAsAttribute()) {

			resetAttribute(attributeHandler);
		}

		super.reset(attributeHandler);
	}

	@Override
	public String toString() {

		return getClass().getSimpleName() + " (queryInstanceID=" + queryInstanceID + ")";
	}

	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {

		Element element = getBaseExportXML(doc);

		if (values != null) {

			for (PermitNodeValue nodeValue : values) {

				Element actionElement = doc.createElement("Action");

				XMLUtils.appendNewCDATAElement(doc, actionElement, "Name", nodeValue.getExportXMLValue());
				XMLUtils.appendNewCDATAElement(doc, actionElement, "Description", nodeValue.getDescription());
				XMLUtils.appendNewCDATAElement(doc, actionElement, "From", nodeValue.getFromDescription());
				XMLUtils.appendNewCDATAElement(doc, actionElement, "To", nodeValue.getToDescription());
				XMLUtils.appendNewElement(doc, actionElement, "Count", nodeValue.getCount());
				XMLUtils.appendNewElement(doc, actionElement, "RegisterTitle", nodeValue.getPermitNode().getRegisterTitle());
				XMLUtils.appendNewElement(doc, actionElement, "Weight", nodeValue.getPermitNode().getWeight());

				element.appendChild(actionElement);
			}
		}

		return element;
	}

	@Override
	public String getStringValue() {

		StringBuilder builder = new StringBuilder();

		if (values != null) {

			for (PermitNodeValue value : values) {

				if (builder.length() != 0) {

					builder.append(", ");
				}

				builder.append(value.getPermitNode().getExportXMLValue());
			}
		}

		return builder.toString();
	}

	@Override
	public List<? extends ImmutableAlternative> getAlternatives() {

		return values;
	}

	@Override
	public String getFreeTextAlternativeValue() {

		return null;
	}

	public List<PermitNodeValue> getValues() {

		return values;
	}

	public void setValues(List<PermitNodeValue> values) {

		this.values = values;
	}

	public void resetAttribute(MutableAttributeHandler attributeHandler) {

		attributeHandler.removeAttribute(query.getAttributeName());
	}

	public void setAttribute(MutableAttributeHandler attributeHandler) {

		
		if (query.isSetAsAttribute() && values != null) {

			List<String> attributeValues = new ArrayList<>(values.size());

			for (PermitNodeValue nodeValue : values) {
				attributeValues.add(nodeValue.getName());
			}
			if (!attributeValues.isEmpty()) {

				attributeHandler.setAttribute(query.getAttributeName(), StringUtils.toCommaSeparatedString(attributeValues));
			}
		}

		
	}
}
