<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
		/jquery/jquery-ui.js?v=1
		/timepicker/js/jquery.timepicker.js?v=1
	</xsl:variable>
	
	<xsl:variable name="globallinks">
		/css/openhierarchy-jquery-ui.css
		/timepicker/css/jquery.timepicker.css
	</xsl:variable>

	<xsl:variable name="scripts">
		/js/jquery.ui.datepicker-sv.js
		/js/datetimequeryadmin.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/datetimequery.css
	</xsl:variable>

	<xsl:variable name="rawTimeIntervalOptions">
		<option>
			<name>1 min</name>
			<value>1</value>
		</option>
		<option>
			<name>15 min</name>
			<value>15</value>
		</option>
		<option>
			<name>30 min</name>
			<value>30</value>
		</option>
		<option>
			<name>60 min</name>
			<value>60</value>
		</option>
	</xsl:variable>

	<xsl:variable name="timeIntervalOptions" select="exsl:node-set($rawTimeIntervalOptions)/option" />

	<xsl:template match="Document">

		<div id="DateTimeQueryProvider" class="contentitem">

			<xsl:apply-templates select="validationError" />
			<xsl:apply-templates select="UpdateDateTimeQuery" />

		</div>

	</xsl:template>

	<xsl:template match="UpdateDateTimeQuery">

		<h1>
			<xsl:value-of select="$i18n.UpdateQuery" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="DateTimeQuery/QueryDescriptor/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form id="updateDateTimeQueryForm" name="queryAdminForm" method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="DateTimeQuery" />
			</xsl:call-template>

			<fieldset>
				<legend><xsl:value-of select="$i18n.DateFieldsetLegend" /></legend>
				
				<div class="floatleft full bigmarginbottom">
	
					<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'useDateFields'" />
							<xsl:with-param name="name" select="'useDateFields'" />
							<xsl:with-param name="value" select="'true'" />
							<xsl:with-param name="element" select="DateTimeQuery" />
						</xsl:call-template>
						
						<label for="useDateFields">
							<xsl:value-of select="$i18n.UseDateFields" />
						</label>
					</div>
	
				</div>
	
				<div class="floatleft full bigmarginbottom hidden"  id="dateRestrictionContainer">
							
					<div class="floatleft full bigmarginbottom">
		
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'useMultiDate'" />
								<xsl:with-param name="name" select="'useMultiDate'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="DateTimeQuery" />
							</xsl:call-template>
							
							<label for="useMultiDate">
								<xsl:value-of select="$i18n.UseMultiDate" />
							</label>
						</div>
		
					</div>
					
					<fieldset id="start-date-fieldset" class="inner-fieldset fifty floatleft">
						<legend><xsl:value-of select="$i18n.StartDateLegend" /></legend>
					
						<div class="floatleft full bigmarginbottom date-field">
							
							<div class="floatleft full">
								<label>
									<xsl:value-of select="$i18n.MinStartDate" />
								</label>
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'minStartDate'" />
									<xsl:with-param name="name" select="'minStartDate'" />
									<xsl:with-param name="title" select="$i18n.MinStartDate"/>
									<xsl:with-param name="type" select="'date'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>
			
						<div class="floatleft full bigmarginbottom date-field">
							
							<div class="floatleft full">
								<label>
									<xsl:value-of select="$i18n.MaxStartDate" />
								</label>
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'maxStartDate'" />
									<xsl:with-param name="name" select="'maxStartDate'" />
									<xsl:with-param name="title" select="$i18n.MaxStartDate"/>
									<xsl:with-param name="type" select="'date'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>
					
					
						<div class="floatleft full">
							<label for="startDateRestriction" class="required full">
								<xsl:value-of select="$i18n.StartDateRestrictionHeading" />
							</label>
							
							<div class="alternative floatleft clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'startDateRestrictionNone'" />
									<xsl:with-param name="name" select="'startDateRestrictionType'" />
									<xsl:with-param name="value" select="'NONE'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="startDateRestrictionNone"><xsl:value-of select="$i18n.DateRestrictionNone" /></label>
								
							</div>
						</div>				
		
						<div class="floatleft full">
							<div class="alternative clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'restrictFutureStartDates'" />
									<xsl:with-param name="name" select="'startDateRestrictionType'" />
									<xsl:with-param name="value" select="'RESTRICT_FUTURE_DATES'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="restrictFutureStartDates"><xsl:value-of select="$i18n.RestrictFutureStartDates" /></label>
								
							</div>
						</div>
						
						<div class="floatleft full">
							<div class="alternative clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'restrictPastStartDates'" />
									<xsl:with-param name="name" select="'startDateRestrictionType'" />
									<xsl:with-param name="value" select="'RESTRICT_PAST_DATES'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="restrictPastStartDates"><xsl:value-of select="$i18n.RestrictPastStartDates" /></label>
								
							</div>
						</div>
		
					
						<div class="floatleft full bigmarginbottom hidden">
							<div class="floatleft full">
								<div id="minDaysInFutureStartDateInfoContainer" class="hidden">
									<label>
										<xsl:value-of select="$i18n.MinStartDaysInFuture" />
									</label>
									<div class="tiny"><xsl:value-of select="$i18n.MinDaysInFutureInfo"></xsl:value-of></div>
								</div>
								
								<div id="minDaysInPastStartDateInfoContainer" class="hidden">						
									<label>
										<xsl:value-of select="$i18n.MinStartDaysInPast" />
									</label>
									<div class="tiny"><xsl:value-of select="$i18n.MinDaysInPastInfo"></xsl:value-of></div>
								</div>
													
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'restrictedStartDays'" />
									<xsl:with-param name="name" select="'restrictedStartDays'" />
									<xsl:with-param name="width" select="'100px'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>
						
						<fieldset id="start-date-allowed-weekdays">
							<legend><xsl:value-of select="$i18n.StartDateAllowedWeekdaysLegend" /></legend>

							<div class="floatleft full bigmarginbottom">
				
								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdayMonday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'MONDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdayMonday">
										<xsl:value-of select="$i18n.WeekdayMonday" />
									</label>
								</div>

								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdayTuesday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'TUESDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdayTuesday">
										<xsl:value-of select="$i18n.WeekdayTuesday" />
									</label>
								</div>

								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdayWednesday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'WEDNESDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdayWednesday">
										<xsl:value-of select="$i18n.WeekdayWednesday" />
									</label>
								</div>

								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdayThursday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'THURSDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdayThursday">
										<xsl:value-of select="$i18n.WeekdayThursday" />
									</label>
								</div>

								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdayFriday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'FRIDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdayFriday">
										<xsl:value-of select="$i18n.WeekdayFriday" />
									</label>
								</div>

								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdaySaturday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'SATURDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdaySaturday">
										<xsl:value-of select="$i18n.WeekdaySaturday" />
									</label>
								</div>

								<div class="floatleft bigmarginleft bigmarginright">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'weekdaySunday'" />
										<xsl:with-param name="name" select="'allowedDayOfWeek'" />
										<xsl:with-param name="value" select="'SUNDAY'" />
										<xsl:with-param name="element" select="DateTimeQuery/allowedDaysOfWeek" />
									</xsl:call-template>
									
									<label for="weekdaySunday">
										<xsl:value-of select="$i18n.WeekdaySunday" />
									</label>
								</div>
							</div>
						</fieldset>


						<fieldset id="start-date-restrict-tomorrow-on-time">
							<legend><xsl:value-of select="$i18n.RestrictTomorrowOnTimeLegend" /></legend>
							
							<div class="floatleft full bigmarginbottom">
				
								<div class="floatleft">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'restrictTomorrowOnTime'" />
										<xsl:with-param name="name" select="'restrictTomorrowOnTime'" />
										<xsl:with-param name="value" select="'true'" />
										<xsl:with-param name="element" select="DateTimeQuery" />
									</xsl:call-template>
									
									<label for="restrictTomorrowOnTime">
										<xsl:value-of select="$i18n.RestrictTomorrowOnTimeCheckbox" />
									</label>
								</div>
							</div>

							<div id="tomorrowRestrictionModeContainer" class="floatleft full">
								
								<div class="alternative floatleft clearboth">
									
									<xsl:call-template name="createRadio">
										<xsl:with-param name="id" select="'tomorrowRestrictionModeToday'" />
										<xsl:with-param name="name" select="'tomorrowRestrictionMode'" />
										<xsl:with-param name="value" select="'RESTRICT_TODAY'" />
										<xsl:with-param name="element" select="DateTimeQuery"/>
									</xsl:call-template>
									
									<xsl:text>&#x20;</xsl:text>
									<label for="tomorrowRestrictionModeToday"><xsl:value-of select="$i18n.TomorrowRestrictionModeToday" /></label>
									
								</div>

								<div class="alternative clearboth">
									
									<xsl:call-template name="createRadio">
										<xsl:with-param name="id" select="'tomorrowRestrictionModeTomorrow'" />
										<xsl:with-param name="name" select="'tomorrowRestrictionMode'" />
										<xsl:with-param name="value" select="'RESTRICT_TOMORROW'" />
										<xsl:with-param name="element" select="DateTimeQuery"/>
									</xsl:call-template>
									
									<xsl:text>&#x20;</xsl:text>
									<label for="tomorrowRestrictionModeTomorrow"><xsl:value-of select="$i18n.TomorrowRestrictionModeTomorrow" /></label>
									
								</div>
							</div>

							<div class="floatleft full bigmarginbottom">
								<div class="floatleft full">
									<div id="tomorrowRestrictionModeTodayInfoContainer" class="hidden">
										<label>
											<xsl:value-of select="$i18n.TomorrowRestrictionModeTodayInfo1" />
										</label>
										<div class="tiny"><xsl:value-of select="$i18n.TomorrowRestrictionModeTodayInfo2"></xsl:value-of></div>
									</div>
									
									<div id="tomorrowRestrictionModeTomorrowInfoContainer" class="hidden">						
										<label>
											<xsl:value-of select="$i18n.TomorrowRestrictionModeTomorrowInfo1" />
										</label>
										<div class="tiny"><xsl:value-of select="$i18n.TomorrowRestrictionModeTomorrowInfo2"></xsl:value-of></div>
									</div>
														
								</div>
							</div>
							
							<div class="floatleft full">						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'restrictTomorrowTime'" />
									<xsl:with-param name="name" select="'restrictTomorrowTime'" />
									<xsl:with-param name="title" select="$i18n.RestrictTomorrowTime"/>
									<xsl:with-param name="width" select="'100px'"/>
									<xsl:with-param name="type" select="'time'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
							
						</fieldset>

						<fieldset id="start-date-restrict-upcoming-months" class="inner-fieldset">
							<legend><xsl:value-of select="$i18n.RestrictUpcomingMonthsLegend" /></legend>
	
							<div class="full">
				
								<div class="">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'restrictCurrentMonth'" />
										<xsl:with-param name="name" select="'restrictCurrentMonth'" />
										<xsl:with-param name="value" select="'true'" />
										<xsl:with-param name="element" select="DateTimeQuery" />
									</xsl:call-template>
									
									<label for="restrictCurrentMonth">
										<xsl:value-of select="$i18n.RestrictCurrentMonthCheckbox" />
									</label>
								</div>
							</div>
							
							<div id="upcoming-months-container" class="full bigmarginbottom hidden">

								<div class="tiny">
									<xsl:value-of select="$i18n.RestrictCurrentMonthInfo" />
								</div>
								<div class="">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'restrictUpcomingMonths'" />
										<xsl:with-param name="name" select="'restrictUpcomingMonths'" />
										<xsl:with-param name="value" select="'true'" />
										<xsl:with-param name="element" select="DateTimeQuery" />
									</xsl:call-template>
									
									<label for="restrictUpcomingMonths">
										<xsl:value-of select="$i18n.RestrictUpcomingMonthsCheckbox" />
									</label>
								</div>
	
								<div id="number-of-upcomming-months-container">
									<div class="tiny">
										<xsl:value-of select="$i18n.NumberOfUpcomingMonthsInfo" />
									</div>
									<div class="full">						
										<xsl:call-template name="createTextField">
											<xsl:with-param name="id" select="'numberOfUpcomingMonths'" />
											<xsl:with-param name="name" select="'numberOfUpcomingMonths'" />
											<xsl:with-param name="title" select="$i18n.NumberOfUpcomingMonths"/>
											<xsl:with-param name="width" select="'100px'"/>
											<xsl:with-param name="element" select="DateTimeQuery"/>
										</xsl:call-template>
									</div>
								</div>
							</div>
	
						</fieldset>
						
					</fieldset>

					<fieldset id="end-date-fieldset" class="inner-fieldset fifty floatleft">
						<legend><xsl:value-of select="$i18n.EndDateLegend" /></legend>
					
						<div class="floatleft full bigmarginbottom date-field">
							
							<div class="floatleft full">
								<label>
									<xsl:value-of select="$i18n.MinEndDate" />
								</label>
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'minEndDate'" />
									<xsl:with-param name="name" select="'minEndDate'" />
									<xsl:with-param name="title" select="$i18n.MinEndDate"/>
									<xsl:with-param name="type" select="'date'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>
			
						<div class="floatleft full bigmarginbottom date-field">
							
							<div class="floatleft full">
								<label>
									<xsl:value-of select="$i18n.MaxEndDate" />
								</label>
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'maxEndDate'" />
									<xsl:with-param name="name" select="'maxEndDate'" />
									<xsl:with-param name="title" select="$i18n.MaxEndDate"/>
									<xsl:with-param name="type" select="'date'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>
					
					
						<div class="floatleft full">
							<label for="endDateRestriction" class="required full">
								<xsl:value-of select="$i18n.EndDateRestrictionHeading" />
							</label>
							
							<div class="alternative floatleft clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'endDateRestrictionNone'" />
									<xsl:with-param name="name" select="'endDateRestrictionType'" />
									<xsl:with-param name="value" select="'NONE'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="endDateRestrictionNone"><xsl:value-of select="$i18n.DateRestrictionNone" /></label>
								
							</div>
						</div>				
		
						<div class="floatleft full">
							<div class="alternative clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'restrictFutureEndDates'" />
									<xsl:with-param name="name" select="'endDateRestrictionType'" />
									<xsl:with-param name="value" select="'RESTRICT_FUTURE_DATES'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="restrictFutureEndDates"><xsl:value-of select="$i18n.RestrictFutureEndDates" /></label>
								
							</div>
						</div>
						
						<div class="floatleft full">
							<div class="alternative clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'restrictPastEndDates'" />
									<xsl:with-param name="name" select="'endDateRestrictionType'" />
									<xsl:with-param name="value" select="'RESTRICT_PAST_DATES'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="restrictPastEndDates"><xsl:value-of select="$i18n.RestrictPastEndDates" /></label>
								
							</div>
						</div>
					
						<div class="floatleft full bigmarginbottom hidden">
							
							<div class="floatleft full">
								<div id="minDaysInFutureEndDateInfoContainer" class="hidden">
									<label>
										<xsl:value-of select="$i18n.MinEndDaysInFuture" />
									</label>
									<div class="tiny"><xsl:value-of select="$i18n.MinDaysInFutureInfo"></xsl:value-of></div>
								</div>
								
								<div id="minDaysInPastEndDateInfoContainer" class="hidden">						
									<label>
										<xsl:value-of select="$i18n.MinEndDaysInPast" />
									</label>
									<div class="tiny"><xsl:value-of select="$i18n.MinDaysInPastInfo"></xsl:value-of></div>
								</div>
													
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'restrictedEndDays'" />
									<xsl:with-param name="name" select="'restrictedEndDays'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>

						<fieldset id="end-date-restrict-upcoming-months" class="inner-fieldset">
							<legend><xsl:value-of select="$i18n.RestrictUpcomingMonthsLegend" /></legend>
	
							<div class="full">
				
								<div class="">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'endDateRestrictCurrentMonth'" />
										<xsl:with-param name="name" select="'endDateRestrictCurrentMonth'" />
										<xsl:with-param name="value" select="'true'" />
										<xsl:with-param name="element" select="DateTimeQuery" />
									</xsl:call-template>
									
									<label for="endDateRestrictCurrentMonth">
										<xsl:value-of select="$i18n.RestrictCurrentMonthCheckbox" />
									</label>
								</div>
							</div>
							
							<div id="upcoming-end-months-container" class="full bigmarginbottom hidden">

								<div class="tiny">
									<xsl:value-of select="$i18n.RestrictCurrentMonthInfo" />
								</div>
								<div class="">
									<xsl:call-template name="createCheckbox">
										<xsl:with-param name="id" select="'restrictUpcomingEndMonths'" />
										<xsl:with-param name="name" select="'restrictUpcomingEndMonths'" />
										<xsl:with-param name="value" select="'true'" />
										<xsl:with-param name="element" select="DateTimeQuery" />
									</xsl:call-template>
									
									<label for="restrictUpcomingEndMonths">
										<xsl:value-of select="$i18n.RestrictUpcomingMonthsCheckbox" />
									</label>
								</div>
	
								<div id="number-of-upcomming-end-months-container">
									<div class="tiny">
										<xsl:value-of select="$i18n.NumberOfUpcomingMonthsInfo" />
									</div>
									<div class="full">						
										<xsl:call-template name="createTextField">
											<xsl:with-param name="id" select="'numberOfUpcomingEndMonths'" />
											<xsl:with-param name="name" select="'numberOfUpcomingEndMonths'" />
											<xsl:with-param name="title" select="$i18n.NumberOfUpcomingMonths"/>
											<xsl:with-param name="width" select="'100px'"/>
											<xsl:with-param name="element" select="DateTimeQuery"/>
										</xsl:call-template>
									</div>
								</div>
							</div>
	
						</fieldset>

						
					</fieldset>

				</div>
				
				<fieldset id="interval-restriction-fieldset" class="inner-fieldset">
					<legend><xsl:value-of select="$i18n.DateIntervalRestrictionLegend" /></legend>
					
					<div class="floatleft full bigmarginbottom hidden">
		
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'restrictDateInterval'" />
								<xsl:with-param name="name" select="'restrictDateInterval'" />
								<xsl:with-param name="value" select="'true'" />
								<xsl:with-param name="element" select="DateTimeQuery" />
							</xsl:call-template>
							
							<label for="restrictDateInterval">
								<xsl:value-of select="$i18n.RestrictDateInterval" />
							</label>
						</div>
		
					</div>
					
					<div id="intervalRestrictionContainer" class="floatleft full hidden">
					
						<div class="floatleft full">
							<label for="dateIntervalRestrictionTypeHeading" class="required full">
								<xsl:value-of select="$i18n.DateRestrictionIntervalHeading" />
							</label>
							
							<div class="alternative floatleft clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'dateRestrictionIntervalMinimum'" />
									<xsl:with-param name="name" select="'dateIntervalRestrictionType'" />
									<xsl:with-param name="value" select="'INTERVAL_MINIMUM'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="dateRestrictionIntervalMinimum"><xsl:value-of select="$i18n.DateRestrictionIntervalMinimum" /></label>
								
							</div>
						</div>				
		
						<div class="floatleft full">
							<div class="alternative clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'dateRestrictionIntervalMaximum'" />
									<xsl:with-param name="name" select="'dateIntervalRestrictionType'" />
									<xsl:with-param name="value" select="'INTERVAL_MAXIMUM'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="dateRestrictionIntervalMaximum"><xsl:value-of select="$i18n.DateRestrictionIntervalMaximum" /></label>
								
							</div>
						</div>
									
						<div class="floatleft full">
							<label for="dateIntervalRestrictionUnitHeading" class="required full">
								<xsl:value-of select="$i18n.DateRestrictionIntervalUnitHeading" />
							</label>
							
							<div class="alternative floatleft clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'dateRestrictionIntervalUnitDays'" />
									<xsl:with-param name="name" select="'dateIntervalRestrictionUnit'" />
									<xsl:with-param name="value" select="'DAYS'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="dateRestrictionIntervalUnitDays"><xsl:value-of select="$i18n.DateRestrictionIntervalUnitDays" /></label>
								
							</div>
						</div>				
		
						<div class="floatleft full">
							<div class="alternative clearboth">
								
								<xsl:call-template name="createRadio">
									<xsl:with-param name="id" select="'dateRestrictionIntervalUnitMonths'" />
									<xsl:with-param name="name" select="'dateIntervalRestrictionUnit'" />
									<xsl:with-param name="value" select="'MONTHS'" />
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
								
								<xsl:text>&#x20;</xsl:text>
								<label for="dateRestrictionIntervalUnitMonths"><xsl:value-of select="$i18n.DateRestrictionIntervalUnitMonths" /></label>
								
							</div>
						</div>
	
						<div class="floatleft full bigmarginbottom">
							
							<div class="floatleft full">
								<label>
									<xsl:value-of select="$i18n.DateIntervalRestriction" />
								</label>
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'dateIntervalRestriction'" />
									<xsl:with-param name="name" select="'dateIntervalRestriction'" />
									<xsl:with-param name="title" select="$i18n.DateIntervalRestriction"/>
									<xsl:with-param name="type" select="'number'"/>
									<xsl:with-param name="element" select="DateTimeQuery"/>
								</xsl:call-template>
							</div>
						</div>
									
					</div>
			
				</fieldset>
				
				
			</fieldset>

				

			<fieldset>
				<legend><xsl:value-of select="$i18n.TimeFieldsetLegend"></xsl:value-of></legend>
				<div class="floatleft full bigmarginbottom">
	
					<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'useTimeFields'" />
							<xsl:with-param name="name" select="'useTimeFields'" />
							<xsl:with-param name="value" select="'true'" />
							<xsl:with-param name="element" select="DateTimeQuery" />
						</xsl:call-template>
						
						<label for="useTimeFields">
							<xsl:value-of select="$i18n.UseTimeFields" />
						</label>
					</div>
	
				</div>
	
				<div class="floatleft full bigmarginbottom hidden">
	
					<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'useMultiTime'" />
							<xsl:with-param name="name" select="'useMultiTime'" />
							<xsl:with-param name="value" select="'true'" />
							<xsl:with-param name="element" select="DateTimeQuery" />
						</xsl:call-template>
						
						<label for="useMultiTime">
							<xsl:value-of select="$i18n.UseMultiTime" />
						</label>
					</div>
	
				</div>
				
				<div class="floatleft full bigmarginbottom hidden">
	
					<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'allowStartTimeAfterEndTime'" />
							<xsl:with-param name="name" select="'allowStartTimeAfterEndTime'" />
							<xsl:with-param name="value" select="'true'" />
							<xsl:with-param name="element" select="DateTimeQuery" />
						</xsl:call-template>
						
						<label for="allowStartTimeAfterEndTime">
							<xsl:value-of select="$i18n.AllowStartTimeAfterEndTime" />
						</label>
					</div>
	
				</div>			
	
				<div class="floatleft full bigmarginbottom hidden">
					
					<label class="floatleft clearboth" for="timeInterval">
						<xsl:value-of select="$i18n.TimeInterval" />
					</label>
					
					<div class="clearboth floatleft marginbottom"><xsl:value-of select="$i18n.TimeIntervalDescription" /></div>
					
					<div class="floatleft full">
						<xsl:call-template name="createDropdown">
							<xsl:with-param name="id" select="'timeInterval'" />
							<xsl:with-param name="name" select="'timeInterval'" />
							<xsl:with-param name="element" select="$timeIntervalOptions" />
							<xsl:with-param name="labelElementName" select="'name'" />
							<xsl:with-param name="valueElementName" select="'value'" />
							<xsl:with-param name="selectedValue" select="DateTimeQuery/timeInterval" />
						</xsl:call-template>
					</div>
				</div>
				
				<div class="floatleft full bigmarginbottom">
					
					<div class="floatleft bigpaddingright">
						<label class="floatleft clearboth" for="earliestTime">
							<xsl:value-of select="$i18n.EarliestTime" />
						</label>
								
						<xsl:call-template name="createTextField">
							<xsl:with-param name="id" select="'earliestTime'" />
							<xsl:with-param name="name" select="'earliestTime'" />
							<xsl:with-param name="value" select="DateTimeQuery/earliestTime"/>
							<xsl:with-param name="class">floatleft clearboth</xsl:with-param>
							<xsl:with-param name="width">100%</xsl:with-param>
						</xsl:call-template>
					</div>
					
					<div class="floatleft">
						<label class="floatleft clearboth" for="latestTime">
							<xsl:value-of select="$i18n.LatestTime" />
						</label>
								
						<xsl:call-template name="createTextField">
							<xsl:with-param name="id" select="'latestTime'" />
							<xsl:with-param name="name" select="'latestTime'" />
							<xsl:with-param name="value" select="DateTimeQuery/latestTime"/>
							<xsl:with-param name="class">floatleft clearboth</xsl:with-param>
							<xsl:with-param name="width">100%</xsl:with-param>
						</xsl:call-template>
					</div>
				</div>
			</fieldset>
						
			<div class="floatleft full bigmarginbottom">
				<h2><xsl:value-of select="$i18n.AdvancedSettings" /></h2>
			</div>

			<div class="floatleft full bigmarginbottom">

				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'hideTitle'" />
						<xsl:with-param name="name" select="'hideTitle'" />
						<xsl:with-param name="value" select="'true'" />
						<xsl:with-param name="element" select="DateTimeQuery" />
					</xsl:call-template>
					
					<label for="hideTitle">
						<xsl:value-of select="$i18n.HideTitle" />
					</label>
				</div>

			</div>
			
			<div class="floatleft full bigmarginbottom">
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'lockOnOwnershipTransfer'" />
						<xsl:with-param name="name" select="'lockOnOwnershipTransfer'" />
						<xsl:with-param name="element" select="DateTimeQuery" /> 
					</xsl:call-template>
					
					<label for="lockOnOwnershipTransfer">
						<xsl:value-of select="$i18n.lockOnOwnershipTransfer" />
					</label>
				</div>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'setAsAttribute'" />
						<xsl:with-param name="name" select="'setAsAttribute'" />
						<xsl:with-param name="element" select="DateTimeQuery" /> 
						<xsl:with-param name="class" select="'vertical-align-middle'" />
					</xsl:call-template>
						
					<label for="setAsAttribute">
						<xsl:value-of select="$i18n.setAsAttribute" />
					</label>
			    </div>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<label for="attributeName" class="floatleft clearboth"><xsl:value-of select="$i18n.attributeName" /></label>
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'attributeName'"/>
						<xsl:with-param name="name" select="'attributeName'"/>
						<xsl:with-param name="title" select="$i18n.attributeName"/>
						<xsl:with-param name="element" select="DateTimeQuery" />
						<xsl:with-param name="maxlength" select="'255'"/>
					</xsl:call-template>
			    </div>
			</div>	

			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>

		</form>

	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'UpdateFailedDateTimeQueryNotFound']">

		<p class="error">
			<xsl:value-of select="$i18n.DateTimeQueryNotFound" />
		</p>

	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'NoChoosenFields']">

		<p class="error">
			<xsl:value-of select="$i18n.NoChoosenFields" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'LatestTimeMustBeAfterEarliestTime']">

		<p class="error">
			<xsl:value-of select="$i18n.LatestTimeMustBeAfterEarliestTime" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'RestrictedStartDaysMustBeSet']">

		<p class="error">
			<xsl:value-of select="$i18n.RestrictedStartDaysMustBeSet" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'MinStartDateAfterMinEndDate']">

		<p class="error">
			<xsl:value-of select="$i18n.MinStartDateCannotBeAfterMinEndDate" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'RestrictedEndDaysMustBeSet']">

		<p class="error">
			<xsl:value-of select="$i18n.RestrictedEndDaysMustBeSet" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'EndDatePossiblyEarlierThanStartDate']">

		<p class="error">
			<xsl:value-of select="$i18n.EndDatePossiblyEarlierThanStartDate" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'MaxStartDateAfterMaxEndDate']">

		<p class="error">
			<xsl:value-of select="$i18n.MaxStartDateAfterMaxEndDate" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'MinStartDateAfterMaxStartDate']">

		<p class="error">
			<xsl:value-of select="$i18n.MinStartDateAfterMaxStartDate" />
		</p>

	</xsl:template>
	<xsl:template match="validationError[messageKey = 'MinEndDateAfterMaxEndDate']">

		<p class="error">
			<xsl:value-of select="$i18n.MinEndDateAfterMaxEndDate" />
		</p>

	</xsl:template>
	<xsl:template match="validationError[messageKey = 'NoDayOfWeekChosen']">

		<p class="error">
			<xsl:value-of select="$i18n.NoDayOfWeekChosen" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'NoTimeInRestrictTomorrowTime']">

		<p class="error">
			<xsl:value-of select="$i18n.NoTimeInRestrictTomorrowTime" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'NoTomorrowRestrictionMode']">

		<p class="error">
			<xsl:value-of select="$i18n.NoTomorrowRestrictionMode" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'NumberOfRestrictedMonthsMustBeSet']">

		<p class="error">
			<xsl:value-of select="$i18n.NumberOfRestrictedMonthsMustBeSet" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'NumberOfRestrictedEndMonthsMustBeSet']">

		<p class="error">
			<xsl:value-of select="$i18n.NumberOfRestrictedEndMonthsMustBeSet" />
		</p>

	</xsl:template>

	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
<!-- 			<xsl:when test="$fieldName = 'minDaysInFuture'"> -->
<!-- 				<xsl:value-of select="$i18n.MinDaysInFuture" /> -->
<!-- 			</xsl:when> -->
			<xsl:when test="$fieldName = 'timeInterval'">
				<xsl:value-of select="$i18n.TimeInterval" />
			</xsl:when>
			<xsl:when test="$fieldName = 'minStartDate'">
				<xsl:value-of select="$i18n.MinStartDate" />
			</xsl:when>
			<xsl:when test="$fieldName = 'earliestTime'">
				<xsl:value-of select="$i18n.EarliestTime" />
			</xsl:when>
			<xsl:when test="$fieldName = 'latestTime'">
				<xsl:value-of select="$i18n.LatestTime" />
			</xsl:when>
			<xsl:when test="$fieldName = 'attributeName'">
				<xsl:value-of select="$i18n.attributeName" />
			</xsl:when>
<!-- 			<xsl:when test="$fieldName = 'restrictedStartDays'"> -->
<!-- 				<xsl:value-of select="$i18n.restrictedStartDays" /> -->
<!-- 			</xsl:when> -->
<!-- 			<xsl:when test="$fieldName = 'minDaysInFuture'"> -->
<!-- 				<xsl:value-of select="$i18n.MinDaysInFuture" /> -->
<!-- 			</xsl:when> -->
			<xsl:when test="$fieldName = 'dateIntervalRestrictionType'">
				<xsl:value-of select="$i18n.DateIntervalRestrictionTypeField" />
			</xsl:when>
			<xsl:when test="$fieldName = 'dateIntervalRestrictionUnit'">
				<xsl:value-of select="$i18n.DateIntervalRestrictionUnitField" />
			</xsl:when>
			<xsl:when test="$fieldName = 'dateIntervalRestriction'">
				<xsl:value-of select="$i18n.DateIntervalRestrictionField" />
			</xsl:when>
			<xsl:when test="$fieldName = 'numberOfUpcomingMonths'">
				<xsl:value-of select="$i18n.NumberOfUpcomingMonthsField" />
			</xsl:when>
			<xsl:when test="$fieldName = 'numberOfUpcomingEndMonths'">
				<xsl:value-of select="$i18n.NumberOfUpcomingEndMonthsField" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>