package com.nordicpeak.flowengine.queries;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUD;
import com.nordicpeak.flowengine.queries.enums.DateRestrictionType;

public class DateTimeQueryCRUD extends BaseQueryCRUD<DateTimeQuery, DateTimeQueryProviderModule> {
	
	protected AnnotatedDAOWrapper<DateTimeQuery, Integer> queryDAO;
	
	public DateTimeQueryCRUD(AnnotatedDAOWrapper<DateTimeQuery, Integer> queryDAO, BeanRequestPopulator<DateTimeQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, DateTimeQueryProviderModule callback) {
		
		super(DateTimeQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);
		
		this.queryDAO = queryDAO;
	}
	
	@Override
	protected DateTimeQuery populateFromUpdateRequest(DateTimeQuery bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {
		
		DateTimeQuery query = super.populateFromUpdateRequest(bean, req, user, uriParser);
		
		List<ValidationError> validationErrors = new ArrayList<ValidationError>();
		
		this.populateQueryDescriptor((QueryDescriptor) query.getQueryDescriptor(), req, validationErrors);
		
		if (!bean.isUseDateFields() && !bean.isUseTimeFields()) {
			
			validationErrors.add(new ValidationError("NoChoosenFields"));
		}
		
		if (bean.isUseTimeFields() && !bean.isAllowStartTimeAfterEndTime() && bean.getEarliestTime() != null && bean.getLatestTime() != null && !bean.getLatestTime().after(bean.getEarliestTime())) {
		
			validationErrors.add(new ValidationError("LatestTimeMustBeAfterEarliestTime"));
		}

		if (DateRestrictionType.RESTRICT_FUTURE_DATES.equals(bean.getStartDateRestrictionType()) || DateRestrictionType.RESTRICT_PAST_DATES.equals(bean.getStartDateRestrictionType())) {
			
			if (bean.getRestrictedStartDays() == null) {
				
				validationErrors.add(new ValidationError("RestrictedStartDaysMustBeSet"));
			}
		}

		if (DateRestrictionType.RESTRICT_FUTURE_DATES.equals(bean.getEndDateRestrictionType()) || DateRestrictionType.RESTRICT_PAST_DATES.equals(bean.getEndDateRestrictionType())) {			
			if (bean.getRestrictedEndDays() == null) {
				
				validationErrors.add(new ValidationError("RestrictedEndDaysMustBeSet"));
			}
		}
		
		if(bean.getMinStartDate() != null && bean.getMinEndDate() != null && bean.getMinStartDate().after(bean.getMinEndDate())) {
			
			validationErrors.add(new ValidationError("MinStartDateAfterMinEndDate"));
		}
		
		if(bean.getRestrictedStartDays() != null && bean.getRestrictedEndDays() != null && DateRestrictionType.RESTRICT_FUTURE_DATES.equals(bean.getStartDateRestrictionType()) && DateRestrictionType.RESTRICT_FUTURE_DATES.equals(bean.getEndDateRestrictionType()) && bean.getRestrictedStartDays() > bean.getRestrictedEndDays()) {
			
			validationErrors.add(new ValidationError("EndDatePossiblyEarlierThanStartDate"));
		}

		if(bean.getRestrictedStartDays() != null && bean.getRestrictedEndDays() != null && DateRestrictionType.RESTRICT_PAST_DATES.equals(bean.getStartDateRestrictionType()) && DateRestrictionType.RESTRICT_PAST_DATES.equals(bean.getEndDateRestrictionType()) && bean.getRestrictedStartDays() < bean.getRestrictedEndDays()) {
			
			validationErrors.add(new ValidationError("EndDatePossiblyEarlierThanStartDate"));
		}
		
		if(bean.getMaxStartDate() != null && bean.getMaxEndDate() != null && bean.getMaxStartDate().after(bean.getMaxEndDate())) {
			
			validationErrors.add(new ValidationError("MaxStartDateAfterMaxEndDate"));
		}
		
		if(bean.getMinStartDate() != null && bean.getMaxStartDate() != null && bean.getMinStartDate().after(bean.getMaxStartDate())) {
			
			validationErrors.add(new ValidationError("MinStartDateAfterMaxStartDate"));
		}

		if(bean.getMinEndDate() != null && bean.getMaxEndDate() != null && bean.getMinEndDate().after(bean.getMaxEndDate())) {
			
			validationErrors.add(new ValidationError("MinEndDateAfterMaxEndDate"));
		}
		
		if(bean.getAllowedDaysOfWeek() == null) {
			
			validationErrors.add(new ValidationError("NoDayOfWeekChosen"));
		}
		
		if(bean.isRestrictTomorrowOnTime() && bean.getRestrictTomorrowTime() == null) {
			
			validationErrors.add(new ValidationError("NoTimeInRestrictTomorrowTime"));
		}

		if(bean.isRestrictTomorrowOnTime() && bean.getTomorrowRestrictionMode() == null) {
			
			validationErrors.add(new ValidationError("NoTomorrowRestrictionMode"));
		}
		
		if(bean.isRestrictCurrentMonth() && bean.isRestrictUpcomingMonths() && bean.getNumberOfUpcomingMonths() == null) {
			
			validationErrors.add(new ValidationError("NumberOfRestrictedMonthsMustBeSet"));
		}

		if(bean.isEndDateRestrictCurrentMonth() && bean.isRestrictUpcomingEndMonths() && bean.getNumberOfUpcomingEndMonths() == null) {
			
			validationErrors.add(new ValidationError("NumberOfRestrictedEndMonthsMustBeSet"));
		}
		
		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}
		
		return query;
	}
	
}
