package com.nordicpeak.flowengine.queries.dynamictablequery;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLParserPopulateable;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.queries.basetablequery.TableRow;

@Table(name = "dynamic_table_query_rows")
@XMLElement(name = "Row")
public class DynamicTableRow extends TableRow<DropDownAlternative, DynamicTableColumn, DynamicTableQuery> implements XMLParserPopulateable, Comparable<DynamicTableRow> {

	private static final long serialVersionUID = -2724650199031970214L;

	public static final Field QUERY_INSTANCE_RELATION = ReflectionUtils.getField(DynamicTableRow.class, "queryInstance");
	public static final Field VALUES_RELATION = ReflectionUtils.getField(DynamicTableRow.class, "values");

	@DAOManaged
	@OrderBy
	@XMLElement
	private Integer sortIndex;

	@DAOManaged
	@OneToMany
	@XMLElement(fixCase = true)
	private List<DynamicTableCellValue> values;

	@DAOManaged(columnName = "queryInstanceID")
	@ManyToOne
	private DynamicTableQueryInstance queryInstance;

	private String identifier;

	@Override
	public boolean isRequired() {

		return true;
	}

	public List<DynamicTableCellValue> getValues() {

		return values;
	}

	public void setValues(List<DynamicTableCellValue> values) {

		this.values = values;
	}

	@Override
	public Integer getSortIndex() {

		return sortIndex;
	}

	@Override
	public void setSortIndex(Integer sortIndex) {

		this.sortIndex = sortIndex;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<>();

		setSortIndex(XMLValidationUtils.validateParameter("sortIndex", xmlParser, true, PositiveStringIntegerPopulator.getPopulator(), errors));

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	@Override
	public String getRowIdentifier() {

		if (getRowID() != null) {
			return getRowID().toString();
		}

		return identifier;
	}

	public void setRowIdentifier(String identifier) {

		this.identifier = identifier;
	}

	@Override
	public int compareTo(DynamicTableRow o) {

		return sortIndex.compareTo(o.getSortIndex());
	}

	public DynamicTableQueryInstance getQueryInstance() {

		return queryInstance;
	}

	public void setQueryInstance(DynamicTableQueryInstance instance) {

		this.queryInstance = instance;
	}

	@Override
	public Element toXML(Document doc) {

		Element element = super.toXML(doc);

		if (getRowID() == null) {
			XMLUtils.appendNewElement(doc, element, "rowID", identifier);
		}

		return element;
	}

	@Override
	public String getName() {

		return null;
	}

}
