
function initDynamicTableQuery(queryID, queryRequestURL) {
	
	dynamicTableWaitUntilBaseTableQueryIsLoaded(queryID, queryRequestURL);
}

function dynamicTableWaitUntilBaseTableQueryIsLoaded(queryID, queryRequestURL) {
	
	if (typeof initTableQuery === "undefined") {

		setTimeout(function() { dynamicTableWaitUntilBaseTableQueryIsLoaded(queryID, queryRequestURL); }, 10);
		
	} else {
		
		initDynamicTableQuery2(queryID, queryRequestURL);
	} 
}

function initDynamicTableQuery2(queryID, queryRequestURL) {
	
	setQueryRequiredFunctions["DynamicTableQueryInstance"] = makeTableQueryRequired;
	setQueryValidationErrorFunctions["DynamicTableQueryInstance"] = setTableFieldValidationError;
	
	initTableQuery(queryID, queryRequestURL);
	
	var query = $("#query_" + queryID);
	
	query.find(".tableRowTemplate").each(function(){
		$(this).find("input, select").prop('disabled', true);
	});
	
	query.find(".newDynamicTableRow a").on("click", function(event){
		
		event.preventDefault();
		
		if($(this).hasClass("disabled")) {
			
			return;
		}
		
		var query = $(this).closest(".query");
		var queryID = query.prop("id").substring("query_".length);
		var tbody = $("tbody#query_" + queryID + "_maintable");
		
		var rowID = generateUUID();
		
		var template = $("#query_" + queryID + "-rowTemplate").children().first().clone();
		
		template.find("input[name='q" + queryID + "-row']").val(rowID).attr("value", rowID);
		
		var inputs = template.find("input, select, textarea");
		
		inputs.prop('disabled', false);
		
		inputs.each(function(){
			
			var input = $(this);
			
			input.prop("name", input.prop("name").replace("template", rowID));
			
			var inputID = input.prop("id");
			
			if (inputID != "") {
				input.prop("id", inputID.replace("template", rowID));
			}
		});
		
		template.find("label").each(function(){
			
			var label = $(this);
			
			label.prop("for", label.prop("for").replace("template", rowID));
		});
		
		template.find("td.rowsum span").each(function(){
			var span = $(this);
			span.prop("id", span.prop("id").replace("template", rowID));
			span.data("rowid", rowID);
		});
		
		tbody.append(template);
		
		tableEnableDisableAddButton(query);
		
		addSummationListeners(template);
		
		if(query.hasClass("enableAjaxPosting")) {
			bindTableQueryCellChangeEvent(template, query, queryID);
		}
		
		addListSearchListeners(template, queryRequestURL);
	});
	
	query.find(".newDynamicTableRow").each(function(){
		
		var query = $(this).closest(".query");
		
		tableEnableDisableAddButton(query);
	});
}

function generateUUID() {
	var chars = '0123456789abcdef'.split('');
	var uuid = [], rnd = Math.random;
	var r;
	uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
	uuid[14] = '4';
	for (var i = 0; i < 36; i++) {
		if (!uuid[i]) {
			r = 0 | rnd()*16;
			uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r & 0xf];
		}
	}
	return uuid.join('');
}

function removeTableRow(self){
	
	var row = $(self).closest("tr");
	var query = row.closest(".query");
	var queryID = query.prop("id").substring("query_".length);
	
	if (query.hasClass("enableAjaxPosting")) {
		unBindTableQueryCellChangeEvent(row);
	}
	
	row.find("input").val("").prop('checked', false).trigger("change");
	
	if (query.hasClass("enableAjaxPosting")) {
		runTableQueryEvaluators(query, queryID);	
	}
	
	row.remove();
	
	tableEnableDisableAddButton(query);
}

function tableEnableDisableAddButton(query){
	
	var tbody = query.find("tbody").not(".tableRowTemplate");
	var addButton = query.find(".newDynamicTableRow a");
	var maxRows = tbody.data("maxrows");
	
	if(maxRows != undefined && maxRows != "" && tbody.find("tr").length >= maxRows){
		
		addButton.addClass("disabled");
		addButton.text(DynamicTableQuery.i18nMaxRowsReached);
		
	} else {
		
		addButton.removeClass("disabled");
		addButton.text(DynamicTableQuery.i18nAddRow);
	}
}

function addSummationListeners(row){
	
	row.find("td.rowsum").each(function () {
		
		var td = $(this);
		var tr = td.parent();
		var span = td.find("span");
		var columnID = span.data("columnid");
		var rowSumInput = span.siblings("input");
		
		tr.children("td").each(function(loopIndex, cell){
			var inputs = $(cell).find("input").not(rowSumInput);
			
			addTableQueryRowListener(inputs, span, tr, columnID);
		});
	});
	
	row.closest("table.tablequery").find("td[data-summarise='true']").each(function () {
		
		var td = $(this);
		var columnIndex = td.data("columnindex");
		
		row.children("td").each(function(loopIndex, cell){
			
			if (loopIndex == columnIndex){
				
				var inputs = $(cell).find("input");
				
				addTableQueryColumnListener(inputs, td, columnIndex);
			}
		})
	});
	
	if (!Modernizr.inputtypes.date) {
		
		row.find("input[type='date']").datepicker({
	        changeMonth: true,
	        changeYear: true,
	        showWeek: true,
	        dayNamesShort: true,
	        onSelect: function() {
	            $(this).trigger("blur");
	        }
	    });
	}
}
