package com.nordicpeak.flowengine.integration.easit.beans;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.utils.AttributeTagUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;

import com.easit.bpsservice.proxy.Item.Property;
import com.nordicpeak.flowengine.integration.easit.utils.ParameterFormatter;

@Table(name = "easit_integration_parametergroup_parameters")
@XMLElement
public class IntegrationParameter extends GeneratedElementable {

	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	private Integer parameterID;

	@DAOManaged
	@OrderBy
	@XMLElement
	private String name;

	@DAOManaged
	@XMLElement
	private String value;

	@DAOManaged
	@XMLElement
	private boolean splitValue;

	@DAOManaged(columnName = "parameterGroupID")
	@ManyToOne
	private IntegrationParameterGroup integrationGroup;

	public Integer getParameterID() {

		return parameterID;
	}

	public void setParameterID(Integer parameterID) {

		this.parameterID = parameterID;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public String getValue() {

		return value;
	}

	public void setValue(String value) {

		this.value = value;
	}

	public boolean isSplitValue() {

		return splitValue;
	}

	public void setSplitValue(boolean splitValue) {

		this.splitValue = splitValue;
	}

	public IntegrationParameterGroup getIntegrationGroup() {

		return integrationGroup;
	}

	public void setIntegrationGroup(IntegrationParameterGroup integrationGroup) {

		this.integrationGroup = integrationGroup;
	}

	public List<Property> getEasitProperties(AttributeHandler attributeHandler, Map<String, ParameterFormatter> parameterFormatters) {

		List<Property> properties = null;

		String replacedValue = null;

		if (attributeHandler != null) {

			replacedValue = AttributeTagUtils.replaceTags(value, attributeHandler, false);

		} else {

			replacedValue = value;
		}

		if (parameterFormatters.containsKey(name)) {

			replacedValue = parameterFormatters.get(name).formatParameter(replacedValue);
		}
		
		if (splitValue) {

			properties = new ArrayList<Property>();

			String[] values = replacedValue.split(",");

			for (String val : values) {

				properties.add(getProperty(name, val.trim()));

			}

		} else {

			properties = CollectionUtils.getGenericSingletonList(getProperty(name, replacedValue));

		}

		return properties;
	}

	private Property getProperty(String name, String value) {

		Property property = new Property();
		property.setName(name);
		property.setContent(value);

		return property;
	}

}
