package com.nordicpeak.flowengine.integration.efecte;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactoryConfigurationError;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.emailutils.framework.ByteArrayAttachment;
import se.unlogic.emailutils.framework.SimpleEmail;
import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.EventListener;
import se.unlogic.hierarchy.core.annotations.HTMLEditorSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.EventSource;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.hierarchy.core.utils.AttributeTagUtils;
import se.unlogic.standardutils.bool.BooleanUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.fileattachments.FileAttachment;
import se.unlogic.standardutils.fileattachments.FileAttachmentHandler;
import se.unlogic.standardutils.mime.MimeUtils;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.streams.StreamUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.time.MillisecondTimeUnits;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.ByteArrayPart;
import se.unlogic.webutils.http.FilePart;
import se.unlogic.webutils.http.FormPart;
import se.unlogic.webutils.http.HTTPUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.SimpleMultipartRequest;
import se.unlogic.webutils.http.SimpleRequest;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.validation.ValidationUtils;

import com.nordicpeak.flowengine.Constants;
import com.nordicpeak.flowengine.beans.ExternalMessageAttachment;
import com.nordicpeak.flowengine.beans.Flow;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.beans.FlowInstanceAttribute;
import com.nordicpeak.flowengine.beans.FlowInstanceEvent;
import com.nordicpeak.flowengine.events.ExternalMessageAddedEvent;
import com.nordicpeak.flowengine.events.StatusChangedByManagerEvent;
import com.nordicpeak.flowengine.events.SubmitEvent;
import com.nordicpeak.flowengine.integration.base.BaseIntegrationProviderModule;
import com.nordicpeak.flowengine.integration.base.exceptions.IntegrationRequestException;
import com.nordicpeak.flowengine.integration.base.exceptions.IntegrationSettingsException;
import com.nordicpeak.flowengine.integration.efecte.beans.AttachmentMode;
import com.nordicpeak.flowengine.integration.efecte.beans.IntegrationEndpoint;
import com.nordicpeak.flowengine.integration.efecte.beans.IntegrationParameter;
import com.nordicpeak.flowengine.integration.efecte.beans.IntegrationSettings;
import com.nordicpeak.flowengine.integration.efecte.beans.QueuedIntegrationRequest;
import com.nordicpeak.flowengine.integration.efecte.exceptions.IncompleteRequestException;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowInstance;
import com.nordicpeak.flowengine.interfaces.PDFProvider;
import com.nordicpeak.flowengine.managers.FlowInstanceManager;
import com.nordicpeak.flowengine.utils.FlowEngineFileAttachmentUtils;
import com.nordicpeak.flowengine.utils.PDFByteAttachment;

public class EfecteIntegrationProviderModule extends BaseIntegrationProviderModule<QueuedIntegrationRequest, IntegrationSettings, IntegrationEndpoint> {

	private static final AnnotatedRequestPopulator<IntegrationSettings> POPULATOR = new AnnotatedRequestPopulator<>(IntegrationSettings.class);

	private static final Charset UTF8 = Charset.forName("UTF-8");

	@XSLVariable(name = "i18n.Name")
	protected String paramNameDisplayName;

	@XSLVariable(name = "i18n.Value")
	protected String paramValueDisplayName;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Error email subject", description = "The subject of emails sent when requests fail")
	@XSLVariable(prefix = "java.")
	private String errorEmailSubject = "Not set";

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Error email message", description = "The message of emails sent when errors are received", required = true)
	@XSLVariable(prefix = "java.")
	private String errorEmailMessage = "Not set";

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "External ID prefix", description = "External ID prefix")
	private String externalIDPrefix = "FlowInstance-";

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Log generated XML", description = "Toggles logging of the generated XML")
	protected boolean logXML;

	@InstanceManagerDependency(required = true)
	private PDFProvider pdfProvider;

	@InstanceManagerDependency
	private FileAttachmentHandler fileAttachmentHandler;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		super.createDAOs(dataSource);

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, "com.nordicpeak.flowengine.integration.efecte.EfecteIntegrationProvider", new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		SimpleAnnotatedDAOFactory daoFactory = new SimpleAnnotatedDAOFactory(dataSource);

		settingsDAO = daoFactory.getDAO(IntegrationSettings.class);
		endpointDAO = daoFactory.getDAO(IntegrationEndpoint.class);
		queuedRequestDAO = daoFactory.getDAO(QueuedIntegrationRequest.class);

		flowFamilyIDParamFactory = settingsDAO.getParamFactory("flowFamilyID", Integer.class);
		endpointIDParamFactory = endpointDAO.getParamFactory("endpointID", Integer.class);
		lastRetryParamFactory = queuedRequestDAO.getParamFactory("lastRetry", Timestamp.class);
		eventIDParamFactory = queuedRequestDAO.getParamFactory("eventID", Integer.class);
		flowInstanceIDParamFactory = queuedRequestDAO.getParamFactory("flowInstanceID", Integer.class);
	}

	@EventListener(channel = FlowInstance.class)
	public void processEvent(StatusChangedByManagerEvent event, EventSource eventSource) throws SQLException {

		//Check to avoid event recursion
		if (StringUtils.compare("Efecte", event.getEvent().getAttributeHandler().getString("integrationSource"))) {

			return;
		}

		IntegrationSettings integrationSettings = getIntegrationSettings(event.getFlowInstance().getFlow());

		if (integrationSettings == null || !integrationSettings.isManagerStatusChangedSupportEnabled()) {

			return;
		}

		String externalID = event.getFlowInstance().getAttributeHandler().getString(Constants.FLOW_INSTANCE_EXTERNAL_ID_ATTRIBUTE);

		if (externalID == null) {

			log.error("Unable to send status change " + event.getFlowInstance().getStatus() + " from flow instance " + event.getFlowInstance() + " to Efecte since the flow instance has no external ID attribute set.");

			return;
		}

		MutableAttributeHandler attributeHandler = event.getFlowInstance().getAttributeHandler();

		Document doc = XMLUtils.createDomDocument();

		doc.appendChild(doc.createElement("entityset"));

		Element entityElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "entity");

		appendCodeElement(doc, entityElement, "template", integrationSettings.getTemplateCode(), attributeHandler);

		Element efecteIDElement = appendCodeElement(doc, entityElement, "attribute", "efecte_id", attributeHandler);
		XMLUtils.appendNewElement(doc, efecteIDElement, "value", externalID);

		Element statusElement = appendCodeElement(doc, entityElement, "attribute", "status", attributeHandler);
		XMLUtils.appendNewElement(doc, statusElement, "value", event.getFlowInstance().getStatus().getName());

		String xml;

		try {
			xml = XMLUtils.toString(doc, "UTF-8", true);

		} catch (TransformerFactoryConfigurationError | TransformerException e) {

			log.error("Error generating XML file for event " + event.getEvent() + " belonging to flow instance " + event.getFlowInstance(), e);
			return;
		}

		if (logXML && log.isInfoEnabled()) {

			log.info("Generated XML of event " + event.getEvent() + " from flow instance " + event.getFlowInstance() + ":\n" + xml);
		}

		try {
			log.info("Sending generated XML of event " + event.getEvent() + " from flow instance " + event.getFlowInstance() + " to " + integrationSettings.getEndpoint().getImportAddress());

			SimpleRequest request = new SimpleRequest(integrationSettings.getEndpoint().getImportAddress());

			request.setUsername(integrationSettings.getUsername());
			request.setPassword(integrationSettings.getPassword());
			request.setConnectionTimeout(connectionTimeout * MillisecondTimeUnits.SECOND);
			request.setReadTimeout(requestTimeout * MillisecondTimeUnits.SECOND);

			request.addParameter("folderId", integrationSettings.getFolderID().toString());

			String response = HTTPUtils.sendHTTPPostRequest(request, new ByteArrayInputStream(xml.getBytes(UTF8)), UTF8);

			log.info("XML successfully sent with response: " + response);

		} catch (Exception e) {

			log.error("Error sending XML for event " + event.getEvent() + " belonging to flow instance " + event.getFlowInstance() + " to URL " + integrationSettings.getEndpoint().getImportAddress(), e);
		}
	}

	@EventListener(channel = FlowInstance.class, priority = 200)
	public void processEvent(ExternalMessageAddedEvent event, EventSource eventSource) throws SQLException {

		if (event.getExternalMessage().isPostedByManager()) {

			return;
		}

		IntegrationSettings integrationSettings = getIntegrationSettings(event.getFlowInstance().getFlow());

		if (integrationSettings != null && integrationSettings.isEnabled() && integrationSettings.isExternalMessageSupportEnabled()) {

			String externalID = event.getFlowInstance().getAttributeHandler().getString(Constants.FLOW_INSTANCE_EXTERNAL_ID_ATTRIBUTE);

			if (externalID == null) {

				log.error("Unable to send external messeage " + event.getExternalMessage() + " from flow instance " + event.getFlowInstance() + " to Efecte since the flow instance has no external ID attribute set.");

				return;
			}

			if (!integrationSettings.getEndpoint().hasEmailConfiguration()) {

				log.error("Unable to send external messeage " + event.getExternalMessage() + " from flow instance " + event.getFlowInstance() + " to Efecte since the endpoint " + integrationSettings.getEndpoint() + " does not have a complete email configuration.");

				return;
			}

			log.info("Sending external message " + event.getExternalMessage() + " to endpoint " + integrationSettings.getEndpoint());

			try {
				SimpleEmail email = new SimpleEmail(systemInterface.getEncoding());

				email.setSubject("[#ID:" + externalID + "#]");
				email.setMessageContentType(SimpleEmail.TEXT);
				email.setMessage(event.getExternalMessage().getMessage());
				email.addRecipient(integrationSettings.getEndpoint().getEmailAddress());
				email.setSenderAddress(integrationSettings.getEndpoint().getEmailSenderAddress());
				email.setSenderName(integrationSettings.getEndpoint().getEmailSenderName());

				if (event.getExternalMessage().getAttachments() != null) {

					for (ExternalMessageAttachment attachment : event.getExternalMessage().getAttachments()) {

						if (attachment.getData() != null) {

							email.add(new ByteArrayAttachment(attachment.getData().getBytes(1L, (int) attachment.getData().length()), MimeUtils.getMimeType(attachment.getFilename()), attachment.getFilename()));

						} else {

							if (fileAttachmentHandler == null) {

								throw new IOException("Unable to find attachment data for external message attachment " + attachment + " for flow instance " + event.getFlowInstance() + ", no file attachment handler available.");
							}

							FileAttachment fileAttachment = fileAttachmentHandler.getFileAttachment(FlowEngineFileAttachmentUtils.getAttachmentPath(attachment.getMessage(), attachment));

							if (fileAttachment == null) {

								throw new IOException("Unable to find attachment data for external message attachment " + attachment + " for flow instance " + event.getFlowInstance() + ", no file found in file attachment handler.");
							}

							byte[] attachmentData = StreamUtils.toByteArray(fileAttachment.getInputStream());

							email.add(new ByteArrayAttachment(attachmentData, MimeUtils.getMimeType(attachment.getFilename()), attachment.getFilename()));
						}
					}
				}

				systemInterface.getEmailHandler().send(email);

			} catch (Exception e) {

				log.error("Unable to send external messeage " + event.getExternalMessage() + " from flow instance " + event.getFlowInstance() + " to Efecte", e);
			}
		}
	}

	@EventListener(channel = FlowInstanceManager.class, priority = 49)
	public void processEvent(SubmitEvent event, EventSource eventSource) throws Exception {

		FlowInstance flowInstance = (FlowInstance) event.getFlowInstanceManager().getFlowInstance();
		IntegrationSettings settings = getIntegrationSettings(flowInstance.getFlow().getFlowFamily().getFlowFamilyID());

		if (settings == null || !settings.isEnabled() || !shouldProcessEvent(event)) {

			return;
		}

		FlowInstanceEvent flowInstanceEvent = event.getEvent();

		try {

			processIntegrationEvent(flowInstance, flowInstanceEvent);

		} catch (IncompleteRequestException e) {

			if (settings.isSendErrorEmail()) {

				log.info("Sending error emails");

				sendEmails(settings.getErrorEmailAddresses(), errorEmailSubject, errorEmailMessage, flowInstance, getTagReplacer(flowInstance));
			}

		} catch (IntegrationRequestException e) {

			if (maxRetryCount > 0) {

				log.info("Adding request to retry queue");

				addQueuedEvent(flowInstanceEvent, flowInstance);

			} else if (settings.isSendErrorEmail()) {

				log.info("Sending error emails");

				sendEmails(settings.getErrorEmailAddresses(), errorEmailSubject, errorEmailMessage, flowInstance, getTagReplacer(flowInstance));
			}

		} catch (IntegrationSettingsException e) {

			log.error("Settings error while processing event " + event, e);
		}
	}

	@Override
	public void retryEvent(FlowInstance flowInstance, FlowInstanceEvent event, QueuedIntegrationRequest queuedRequest, TransactionHandler transactionHandler) throws Exception {

		try {

			super.retryEvent(flowInstance, event, queuedRequest, transactionHandler);

		} catch (IncompleteRequestException e) {

			log.info("Deleting " + queuedRequest + " due to previous error");

			queuedRequestDAO.delete(queuedRequest, transactionHandler);

			IntegrationSettings settings;

			if (flowInstance != null && (settings = getIntegrationSettings(flowInstance.getFlow())) != null && settings.isSendErrorEmail()) {

				log.info("Sending error emails");

				sendEmails(settings.getErrorEmailAddresses(), errorEmailSubject, errorEmailMessage, flowInstance, getTagReplacer(flowInstance));
			}
		}
	}

	@Override
	public void processIntegrationEvent(FlowInstance flowInstance, FlowInstanceEvent event) throws SQLException, IntegrationSettingsException, IntegrationRequestException {

		IntegrationSettings integrationSettings = getIntegrationSettings(flowInstance.getFlow());

		if (integrationSettings == null) {

			throw new IntegrationSettingsException("Settings are null");
		}

		if (!integrationSettings.isEnabled()) {

			throw new IntegrationSettingsException("Settings are disabled");
		}

		MutableAttributeHandler attributeHandler = flowInstance.getAttributeHandler();

		Document doc = XMLUtils.createDomDocument();

		doc.appendChild(doc.createElement("entityset"));

		Element entityElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "entity");

		appendCodeElement(doc, entityElement, "template", integrationSettings.getTemplateCode(), attributeHandler);
		appendCodeElement(doc, entityElement, "group", integrationSettings.getGroupCode(), attributeHandler);

		if (flowInstance.getPoster() != null && flowInstance.getPoster().getUsername() != null) {

			appendAttribute(doc, entityElement, "OrderedBy", flowInstance.getPoster().getUsername(), attributeHandler, false, false);
		}

		appendAttribute(doc, entityElement, "subject", integrationSettings.getSubject(), attributeHandler, false, false);
		appendAttribute(doc, entityElement, "description", integrationSettings.getDescription(), attributeHandler, false, false);

		appendAttribute(doc, entityElement, "externalId", this.externalIDPrefix + flowInstance.getFlowInstanceID());

		if (integrationSettings.getParameters() != null) {

			for (IntegrationParameter parameter : integrationSettings.getParameters()) {

				appendAttribute(doc, entityElement, parameter.getName(), parameter.getValue(), attributeHandler, parameter.isSplitValue(), integrationSettings.isSkipEmptyParameters());
			}
		}

		String xml;

		try {
			xml = XMLUtils.toString(doc, "UTF-8", true);

		} catch (TransformerFactoryConfigurationError | TransformerException e) {

			log.error("Error generating XML file for event " + event + " belonging to flow instance " + flowInstance, e);
			return;
		}

		if (logXML && log.isInfoEnabled()) {

			log.info("Generated XML of event " + event + " from flow instance " + flowInstance + ":\n" + xml);
		}

		try {
			log.info("Sending generated XML of event " + event + " from flow instance " + flowInstance + " to " + integrationSettings.getEndpoint().getImportAddress());

			SimpleRequest request = new SimpleRequest(integrationSettings.getEndpoint().getImportAddress());

			request.setUsername(integrationSettings.getUsername());
			request.setPassword(integrationSettings.getPassword());
			request.setConnectionTimeout(connectionTimeout * MillisecondTimeUnits.SECOND);
			request.setReadTimeout(requestTimeout * MillisecondTimeUnits.SECOND);

			request.addParameter("folderId", integrationSettings.getFolderID().toString());

			String response = HTTPUtils.sendHTTPPostRequest(request, new ByteArrayInputStream(xml.getBytes(UTF8)), UTF8);

			log.info("XML successfully sent with response: " + response);

		} catch (IOException e) {

			boolean shouldLogAsError = maxRetryCount == 0 && (!integrationSettings.isSendErrorEmail() || CollectionUtils.isEmpty(integrationSettings.getErrorEmailAddresses()));

			logResponse("Error sending XML for event " + event + " belonging to flow instance " + flowInstance + " to URL " + integrationSettings.getEndpoint().getImportAddress(), e, shouldLogAsError);

			throw new IntegrationRequestException();
		}

		String externalID;
		Integer entityID;

		try {
			log.info("Getting external ID and entity ID for event " + event + " from flow instance " + flowInstance);

			SimpleRequest request = new SimpleRequest(integrationSettings.getEndpoint().getSearchAddress());

			request.setUsername(integrationSettings.getUsername());
			request.setPassword(integrationSettings.getPassword());
			request.setConnectionTimeout(connectionTimeout * MillisecondTimeUnits.SECOND);
			request.setReadTimeout(requestTimeout * MillisecondTimeUnits.SECOND);

			request.addParameter("query", "select entity from entity where stringData.value ='FlowInstance-" + flowInstance.getFlowInstanceID() + "'", "UTF-8");

			String response = HTTPUtils.sendHTTPGetRequest(request, UTF8).getValue();

			Document responseDoc = XMLUtils.parseXML(response, "UTF-8", false, false);

			XMLParser responseParser = new XMLParser(responseDoc);

			externalID = responseParser.getString("/entityset/entity/attribute[@name='Efecte-ID']/value");

			entityID = responseParser.getInteger("/entityset/entity/@id");

			if (StringUtils.isEmpty(externalID)) {

				log.error("Got empty external ID for event " + event + " belonging to flow instance " + flowInstance + ", response:\n" + response);
				externalID = null;
			}

			if (entityID == null) {

				log.error("Got empty entity ID for event " + event + " belonging to flow instance " + flowInstance + ", response:\n" + response);
			}

		} catch (Exception e) {

			boolean shouldLogAsError = !integrationSettings.isSendErrorEmail() || CollectionUtils.isEmpty(integrationSettings.getErrorEmailAddresses());

			logResponse("Error getting external ID and entity ID for event " + event + " belonging to flow instance " + flowInstance, e, shouldLogAsError);

			throw new IncompleteRequestException();
		}

		if (externalID != null) {

			log.info("Got external ID: " + externalID);

			FlowInstanceAttribute attribute = new FlowInstanceAttribute(Constants.FLOW_INSTANCE_EXTERNAL_ID_ATTRIBUTE, externalID);
			attribute.setFlowInstance(flowInstance);

			flowAdminModule.getDAOFactory().getFlowInstanceAttributeDAO().add(attribute);

			attributeHandler.setAttribute(Constants.FLOW_INSTANCE_EXTERNAL_ID_ATTRIBUTE, externalID);
		}

		if (entityID != null && integrationSettings.getAttachmentMode() != null) {

			SimpleMultipartRequest request = new SimpleMultipartRequest(integrationSettings.getEndpoint().getFileUploadAddress());

			request.setUsername(integrationSettings.getUsername());
			request.setPassword(integrationSettings.getPassword());

			request.addPart(new FormPart("attributeId", integrationSettings.getAttachmentAttributeID().toString()));
			request.addPart(new FormPart("entityId", entityID.toString()));
			request.addPart(new FormPart("operationType", "add"));

			File pdf = pdfProvider.getPDF(flowInstance.getFlowInstanceID(), event.getEventID());

			if (pdf == null) {

				log.error("No PDF found for event " + event + " belonging to flow instance " + flowInstance);
				return;
			}

			request.addPart(new FilePart(pdf, flowInstance.getFlowInstanceID() + ".pdf", "pdf"));

			if (integrationSettings.getAttachmentMode() == AttachmentMode.PDF_AND_ATTACHMENTS) {

				try {
					List<PDFByteAttachment> pdfAttachments = pdfProvider.getPDFAttachments(pdf, true);

					int index = 0;

					for (PDFByteAttachment attachment : pdfAttachments) {

						request.addPart(new ByteArrayPart(flowInstance.getFlowInstanceID() + "-" + attachment.getFilename(), attachment.getData(), "file-" + index++));
					}

				} catch (Exception e) {

					log.error("Error getting attachments from PDF for event " + event + " belonging to flow instance " + flowInstance, e);
				}
			}

			try {
				String response = HTTPUtils.sendHTTPPostRequest(request, UTF8);

				log.info("Attachments successfully sent with response: " + response);

			} catch (Exception e) {

				boolean shouldLogAsError = !integrationSettings.isSendErrorEmail() || CollectionUtils.isEmpty(integrationSettings.getErrorEmailAddresses());

				logResponse("Error sending attachments for event " + event + " belonging to flow instance " + flowInstance + " to URL " + integrationSettings.getEndpoint().getFileUploadAddress(), e, shouldLogAsError);

				throw new IncompleteRequestException();
			}
		}
	}

	protected Element appendCodeElement(Document doc, Element entityElement, String elementName, String code, AttributeHandler attributeHandler) {

		Element codeElement = XMLUtils.appendNewElement(doc, entityElement, elementName);

		codeElement.setAttribute("code", AttributeTagUtils.replaceTags(code, attributeHandler, false));

		return codeElement;
	}

	protected void appendAttribute(Document doc, Element entityElement, String code, String value, AttributeHandler attributeHandler, boolean split, boolean skipEmpty) {

		value = AttributeTagUtils.replaceTags(value, attributeHandler, false);

		if (skipEmpty && StringUtils.isEmpty(value)) {

			return;
		}

		Element attributeElement = XMLUtils.appendNewElement(doc, entityElement, "attribute");

		attributeElement.setAttribute("code", code);

		if (split && value.contains(",")) {

			String[] values = value.split(",");

			for (String splitValue : values) {

				XMLUtils.appendNewElement(doc, attributeElement, "value", splitValue.trim());
			}

		} else {

			XMLUtils.appendNewElement(doc, attributeElement, "value", value);
		}
	}

	protected void appendAttribute(Document doc, Element entityElement, String code, Object value) {

		Element attributeElement = XMLUtils.appendNewElement(doc, entityElement, "attribute");

		attributeElement.setAttribute("code", code);

		XMLUtils.appendNewElement(doc, attributeElement, "value", value);
	}

	@WebPublic(alias = "update")
	public ForegroundModuleResponse updateFlowIntegrationSettings(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		Flow flow = flowAdminModule.getRequestedFlow(req, user, uriParser);

		if (flow == null) {

			return flowAdminModule.list(req, res, user, uriParser, new ValidationError("FlowNotFound"));
		}
		
		if (!flowAdminModule.hasFlowAccess(user, flow)) {

			throw new AccessDeniedException("User does not have access to flow type " + flow.getFlowType());
		}

		IntegrationSettings integrationSettings = getIntegrationSettings(flow);

		ValidationException validationException = null;

		if (req.getMethod().equalsIgnoreCase("POST")) {

			if (integrationSettings == null) {

				integrationSettings = new IntegrationSettings();
				integrationSettings.setFlowFamilyID(flow.getFlowFamily().getFlowFamilyID());
			}

			try {
				POPULATOR.populate(integrationSettings, req);

				List<ValidationError> validationErrors = new ArrayList<>();

				IntegrationEndpoint endpoint = getEndpoint(req);

				if (endpoint == null) {

					validationErrors.add(new ValidationError("NoEndpointSelected"));

				} else {

					integrationSettings.setEndpoint(endpoint);
				}

				String[] parameterIDs = req.getParameterValues("parameterID");

				if (parameterIDs != null) {

					List<IntegrationParameter> parameters = new ArrayList<>(parameterIDs.length);

					for (String parameterID : parameterIDs) {

						String name = ValidationUtils.validateParameter("name-" + parameterID, paramNameDisplayName, req, true, 1, 255, StringPopulator.getPopulator(), validationErrors);
						String value = ValidationUtils.validateParameter("value-" + parameterID, paramValueDisplayName, req, true, 1, 255, StringPopulator.getPopulator(), validationErrors);

						if (validationErrors.isEmpty()) {

							IntegrationParameter parameter = new IntegrationParameter();
							parameter.setName(name);
							parameter.setValue(value);
							parameter.setSplitValue(BooleanUtils.toBoolean(req.getParameter("split-" + parameterID)));
							parameters.add(parameter);
						}
					}

					integrationSettings.setParameters(parameters);

				} else {

					integrationSettings.setParameters(null);
				}

				if (!validationErrors.isEmpty()) {

					throw new ValidationException(validationErrors);
				}

				log.info("User " + user + " updating integration settings for flow " + flow);

				if (integrationSettings.isPopulated()) {

					settingsDAO.addOrUpdate(integrationSettings, null);

				} else {

					settingsDAO.delete(integrationSettings);
				}

				flowAdminModule.redirectToMethod(req, res, "/showflow/" + flow.getFlowID() + getShowFlowModuleAnchorLink());

				return null;

			} catch (ValidationException e) {

				validationException = e;
			}
		}

		log.info("User " + user + " requesting update integration settings form for flow " + flow);

		Document doc = createDocument(req, uriParser, user);

		Element integrationSettingsElement = doc.createElement("UpdateIntegrationSettings");
		doc.getDocumentElement().appendChild(integrationSettingsElement);

		integrationSettingsElement.appendChild(flow.toXML(doc));

		XMLUtils.append(doc, integrationSettingsElement, integrationSettings);
		XMLUtils.append(doc, integrationSettingsElement, "Endpoints", endpointDAO.getAll());

		if (validationException != null) {

			integrationSettingsElement.appendChild(validationException.toXML(doc));
			integrationSettingsElement.appendChild(RequestUtils.getRequestParameters(req, doc));
		}

		return new SimpleForegroundModuleResponse(doc, this.getDefaultBreadcrumb());
	}

	@Override
	protected QueuedIntegrationRequest getNewQueuedIntegrationRequest() {

		return new QueuedIntegrationRequest();
	}

	@Override
	protected void handleMaxRetryCountExceeded(ImmutableFlowInstance flowInstance, FlowInstanceEvent event, QueuedIntegrationRequest queuedRequest, TransactionHandler transactionHandler, IntegrationRequestException lastRequestException) throws SQLException {

		super.handleMaxRetryCountExceeded(flowInstance, event, queuedRequest, transactionHandler, lastRequestException);

		IntegrationSettings settings;

		if (flowInstance != null && (settings = getIntegrationSettings(flowInstance.getFlow())) != null) {

			if (settings.isSendErrorEmail() && !CollectionUtils.isEmpty(settings.getErrorEmailAddresses())) {

				log.info("Sending error emails due to max retries exceeded");

				sendEmails(settings.getErrorEmailAddresses(), errorEmailSubject, errorEmailMessage, flowInstance, getTagReplacer(flowInstance));

			} else {

				log.error(queuedRequest + " hit its max retry count and error email is disabled");
			}
		}
	}

	@Override
	protected String getShowFlowModuleAnchorLink() {

		return "#efecteintegrationsettings";
	}
}
