package com.nordicpeak.flowengine.integration.efecte.beans;

import java.util.List;

import se.unlogic.emailutils.populators.EmailPopulator;
import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.SplitOnLineBreak;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.integration.base.beans.BaseIntegrationSettings;

@Table(name = "efecte_integration_settings")
@XMLElement
public class IntegrationSettings extends BaseIntegrationSettings {

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "password")
	@XMLElement
	private String username;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "username")
	@XMLElement
	private String password;

	@DAOManaged(columnName = "endpointID")
	@ManyToOne(autoGet = true)
	@XMLElement
	private IntegrationEndpoint integrationEndpoint;

	@DAOManaged
	@WebPopulate(required = true, populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer folderID;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "enabled")
	@XMLElement
	private String templateCode;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "enabled")
	@XMLElement
	private String groupCode;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "enabled")
	@XMLElement
	private String subject;

	@DAOManaged
	@WebPopulate(maxLength = 65536)
	@RequiredIfSet(paramNames = "enabled")
	@XMLElement
	private String description;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private AttachmentMode attachmentMode;

	@DAOManaged
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@RequiredIfSet(paramNames = "attachmentMode")
	@XMLElement
	private Integer attachmentAttributeID;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean externalMessageSupportEnabled;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean managerStatusChangedSupportEnabled;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean solutionSupportEnabled;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean skipEmptyParameters;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "solutionSupportEnabled")
	@XMLElement
	private String solutionStatusName;

	@DAOManaged
	@WebPopulate(maxLength = 65536)
	@RequiredIfSet(paramNames = "solutionSupportEnabled")
	@XMLElement
	private String solutionMessage;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<IntegrationParameter> parameters;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean sendErrorEmail;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "efecte_integration_email_recipients_error", remoteValueColumnName = "email")
	@WebPopulate(maxLength = 255, populator = EmailPopulator.class)
	@RequiredIfSet(paramNames = "sendErrorEmail")
	@SplitOnLineBreak
	@XMLElement(fixCase = true, childName = "Address")
	private List<String> errorEmailAddresses;

	public List<IntegrationParameter> getParameters() {

		return parameters;
	}

	public void setParameters(List<IntegrationParameter> parameters) {

		this.parameters = parameters;
	}

	public String getUsername() {

		return username;
	}

	public void setUsername(String username) {

		this.username = username;
	}

	public String getPassword() {

		return password;
	}

	public void setPassword(String password) {

		this.password = password;
	}

	@Override
	public boolean isPopulated() {

		if (isEnabled() || integrationEndpoint != null || username != null || password != null || parameters != null) {

			return true;
		}

		return false;
	}

	public String getSubject() {

		return subject;
	}

	public void setSubject(String subject) {

		this.subject = subject;
	}

	public String getDescription() {

		return description;
	}

	public void setDescription(String description) {

		this.description = description;
	}

	public String getTemplateCode() {

		return templateCode;
	}

	public void setTemplateCode(String templateCode) {

		this.templateCode = templateCode;
	}

	public String getGroupCode() {

		return groupCode;
	}

	public void setGroupCode(String groupCode) {

		this.groupCode = groupCode;
	}

	public Integer getFolderID() {

		return folderID;
	}

	public void setFolderID(Integer folderID) {

		this.folderID = folderID;
	}

	public IntegrationEndpoint getEndpoint() {

		return integrationEndpoint;
	}

	public void setEndpoint(IntegrationEndpoint integrationEndpoint) {

		this.integrationEndpoint = integrationEndpoint;
	}

	public IntegrationEndpoint getIntegrationEndpoint() {

		return integrationEndpoint;
	}

	public void setIntegrationEndpoint(IntegrationEndpoint integrationEndpoint) {

		this.integrationEndpoint = integrationEndpoint;
	}

	public Integer getAttachmentAttributeID() {

		return attachmentAttributeID;
	}

	public void setAttachmentAttributeID(Integer attachmentAttributeID) {

		this.attachmentAttributeID = attachmentAttributeID;
	}

	public AttachmentMode getAttachmentMode() {

		return attachmentMode;
	}

	public void setAttachmentMode(AttachmentMode attachmentMode) {

		this.attachmentMode = attachmentMode;
	}

	public boolean isExternalMessageSupportEnabled() {

		return externalMessageSupportEnabled;
	}

	public void setExternalMessageSupportEnabled(boolean externalMessageSupportEnabled) {

		this.externalMessageSupportEnabled = externalMessageSupportEnabled;
	}

	public boolean isSolutionSupportEnabled() {

		return solutionSupportEnabled;
	}

	public void setSolutionSupportEnabled(boolean solutionSupportEnabled) {

		this.solutionSupportEnabled = solutionSupportEnabled;
	}

	public String getSolutionStatusName() {

		return solutionStatusName;
	}

	public void setSolutionStatusName(String solutionStatusName) {

		this.solutionStatusName = solutionStatusName;
	}

	public String getSolutionMessage() {

		return solutionMessage;
	}

	public void setSolutionMessage(String solutionMessage) {

		this.solutionMessage = solutionMessage;
	}

	public boolean isSendErrorEmail() {

		return sendErrorEmail;
	}

	public void setSendErrorEmail(boolean sendErrorEmail) {

		this.sendErrorEmail = sendErrorEmail;
	}

	public List<String> getErrorEmailAddresses() {

		return errorEmailAddresses;
	}

	public void setErrorEmailAddresses(List<String> errorEmailAddresses) {

		this.errorEmailAddresses = errorEmailAddresses;
	}

	public boolean isSkipEmptyParameters() {

		return skipEmptyParameters;
	}

	public void setSkipEmptyParameters(boolean skipEmptyParameters) {

		this.skipEmptyParameters = skipEmptyParameters;
	}

	public boolean isManagerStatusChangedSupportEnabled() {

		return managerStatusChangedSupportEnabled;
	}

	public void setManagerStatusChangedSupportEnabled(boolean managerStatusChangedSupportEnabled) {

		this.managerStatusChangedSupportEnabled = managerStatusChangedSupportEnabled;
	}
}
