package com.nordicpeak.flowengine.externaladdflowinstance;

import java.io.Serializable;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

import se.unlogic.emailutils.populators.EmailPopulator;
import se.unlogic.hierarchy.core.handlers.SourceAttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeSource;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.webutils.populators.StringHTTPURLPopulator;

@Table(name = "add_flowinstance_externalrequests")
public class AddFlowInstanceRequest implements Serializable, AttributeSource {
	
	private static final long serialVersionUID = -6051192005917882966L;
	
	@DAOManaged
	@Key
	private String requestKey;
	
	@DAOManaged
	private Timestamp created;
	
	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	private String firstname;
	
	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	private String lastname;
	
	@DAOManaged
	@WebPopulate(populator = EmailPopulator.class, maxLength = 255)
	private String email;
	
	@DAOManaged
	@WebPopulate(populator = StringHTTPURLPopulator.class, maxLength = 255)
	private String returnURL;
	
	@DAOManaged
	@OneToMany(autoAdd = true, autoUpdate = true, autoGet = true)
	@XMLElement(fixCase=true)
	private List<AddFlowInstanceRequestAttribute> attributes;
	
	private SourceAttributeHandler attributeHandler;
	
	@Override
	public List<AddFlowInstanceRequestAttribute> getAttributes() {
		
		return attributes;
	}
	
	public void setAttributes(List<AddFlowInstanceRequestAttribute> attributes) {
		
		this.attributes = attributes;
	}
	
	@Override
	public void addAttribute(String name, String value) {
		
		if (this.attributes == null) {
			
			attributes = new ArrayList<AddFlowInstanceRequestAttribute>();
		}
		
		attributes.add(new AddFlowInstanceRequestAttribute(name, value));
	}
	
	public synchronized MutableAttributeHandler getAttributeHandler() {
		
		if (attributeHandler == null) {
			
			this.attributeHandler = new SourceAttributeHandler(this, 255, 65536);
		}
		
		return attributeHandler;
	}
	
	public void setRequestKey(String key) {
		this.requestKey = key;
	}
	
	public void setCreated(Timestamp created) {
		this.created = created;
	}
	
	public String getReturnURL() {
		return returnURL;
	}
	
	public String getEmail() {
		return email;
	}
	
	public String getFirstname() {
		return firstname;
	}
	
	public String getLastname() {
		return lastname;
	}
	
	public String getRequestKey() {
		return requestKey;
	}
	
	public Timestamp getCreated() {
		return created;
	}
	
	@Override
	public String toString(){
		
		return firstname + " " + lastname + " (key: " + requestKey + ")";
	}

	
	public void setFirstname(String firstname) {
	
		this.firstname = firstname;
	}

	
	public void setLastname(String lastname) {
	
		this.lastname = lastname;
	}

	
	public void setEmail(String email) {
	
		this.email = email;
	}

	
	public void setReturnURL(String returnURL) {
	
		this.returnURL = returnURL;
	}
}
