package com.nordicpeak.flowengine.externaladdflowinstance;

import java.io.Serializable;

import javax.servlet.http.HttpSession;

import org.apache.log4j.Logger;

import com.nordicpeak.flowengine.FlowBrowserModule;
import com.nordicpeak.flowengine.accesscontrollers.SessionAccessController;
import com.nordicpeak.flowengine.addflowinstance.AddFlowInstanceCallback;
import com.nordicpeak.flowengine.addflowinstance.AddFlowInstanceModule;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.beans.FlowInstanceEvent;
import com.nordicpeak.flowengine.enums.EventType;
import com.nordicpeak.flowengine.managers.FlowInstanceManager;
import com.nordicpeak.flowengine.managers.MutableFlowInstanceManager;

import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.string.StringUtils;

public class ExternalAddFlowInstanceCallback implements AddFlowInstanceCallback, Serializable {

	private static final long serialVersionUID = -1518909826970607855L;
	protected static Logger log = Logger.getLogger(ExternalAddFlowInstanceCallback.class);

	private final AddFlowInstanceRequest addRequest;
	private final String flowBrowserURI;

	public ExternalAddFlowInstanceCallback(AddFlowInstanceRequest addRequest, String flowBrowserURI) {

		super();

		this.addRequest = addRequest;
		this.flowBrowserURI = flowBrowserURI;
	}

	public AddFlowInstanceRequest getAddRequest() {

		return addRequest;
	}

	@Override
	public void beforeSave(MutableFlowInstanceManager instanceManager, EventType eventType) {

		FlowInstance flowInstance = (FlowInstance) instanceManager.getFlowInstance();
		MutableAttributeHandler flowInstanceAttributeHandler = flowInstance.getAttributeHandler();

		flowInstanceAttributeHandler.setAttribute("addFlowInstanceRequestKey", addRequest.getRequestKey());
		
		flowInstanceAttributeHandler.setAttribute("contactInfoAttributes", "true");
		flowInstanceAttributeHandler.setAttribute("firstname", addRequest.getFirstname());
		flowInstanceAttributeHandler.setAttribute("lastname", addRequest.getLastname());
		flowInstanceAttributeHandler.setAttribute("email", addRequest.getEmail());

		flowInstanceAttributeHandler.setAttribute("contactBySMS", "false");
		flowInstanceAttributeHandler.setAttribute("contactByEmail", Boolean.toString(!StringUtils.isEmpty(addRequest.getEmail())));
	}

	@Override
	public void afterSave(FlowInstanceManager instanceManager, EventType eventType, HttpSession session, FlowInstanceEvent saveEvent, AddFlowInstanceModule addFlowInstanceModule) {

		if (StringUtils.isEmpty(addRequest.getReturnURL())) {

			SessionAccessController.setSessionAttribute(instanceManager.getFlowInstanceID(), session, FlowBrowserModule.SESSION_ACCESS_CONTROLLER_TAG);
		}

	}

	@Override
	public String getCustomReturnURL(FlowInstanceManager instanceManager) {

		if (!StringUtils.isEmpty(addRequest.getReturnURL())) {

			return addRequest.getReturnURL();

		} else {

			return flowBrowserURI + "/submitted/" + instanceManager.getFlowInstanceID();
		}
	}

}
