package com.nordicpeak.flowengine.externalalternativelist;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.nio.charset.Charset;
import java.util.List;

import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathExpressionException;

import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.PooledXPathFactory;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.alternativelist.provider.BaseAlternativeList;
import com.nordicpeak.flowengine.interfaces.APISource;

@Table(name = "external_alternative_list_sources")
@XMLElement(name = "AlternativeList")
public class ListSource extends BaseAlternativeList<ListSource, ListSourceEvent> implements Serializable, APISource {

	public static final Field EVENTS_RELATION = ReflectionUtils.getField(ListSource.class, "events");

	private static final long serialVersionUID = 3296400205039536096L;

	@Key
	@DAOManaged(autoGenerated = true)
	@XMLElement(name = "listID")
	private Integer sourceID;

	@DAOManaged
	@OrderBy
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String name;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 1000)
	@XMLElement
	private String url;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean enableAttributeFiltering;

	@DAOManaged
	@WebPopulate(maxLength = 1000)
	@RequiredIfSet(paramNames = "enableAttributeFiltering", paramValues = "true")
	@XMLElement
	private String dynamicURL;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private Integer cacheRefreshTime;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean keepOldListOnRefreshFail;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useAuthentication;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "useAuthentication")
	@XMLElement
	private String username;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "useAuthentication")
	@XMLElement
	private String password;

	@DAOManaged
	@WebPopulate(required = true)
	@XMLElement
	private String encoding;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String alternativeXPath;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String keyXPath;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String valueXPath;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<ListSourceEvent> events;

	private transient XPathExpression alternativeXPathExpression;

	private transient XPathExpression keyXPathExpression;

	private transient XPathExpression valueXPathExpression;

	public Integer getSourceID() {

		return sourceID;
	}

	public void setSourceID(Integer sourceID) {

		this.sourceID = sourceID;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public String getUrl() {

		return url;
	}

	public void setUrl(String url) {

		this.url = url;
	}

	public boolean isEnableAttributeFiltering() {

		return enableAttributeFiltering;
	}

	public void setEnableAttributeFiltering(boolean enableAttributeFiltering) {

		this.enableAttributeFiltering = enableAttributeFiltering;
	}

	public String getDynamicURL() {

		return dynamicURL;
	}

	public void setDynamicURL(String dynamicURL) {

		this.dynamicURL = dynamicURL;
	}

	// In minutes
	public Integer getCacheRefreshTime() {

		return cacheRefreshTime;
	}

	public void setCacheRefreshTime(Integer cacheRefreshTime) {

		this.cacheRefreshTime = cacheRefreshTime;
	}

	@Override
	public String toString() {

		return StringUtils.toLogFormat(name, 30) + " (ID: " + sourceID + ")";
	}

	@Override
	public String getListName() {

		return name;
	}

	@Override
	public Integer getListID() {

		return sourceID;
	}

	@Override
	public List<ListSourceEvent> getEvents() {

		return events;
	}

	@Override
	public void setEvents(List<ListSourceEvent> events) {

		this.events = events;
	}

	public boolean getUseAuthentication() {

		return useAuthentication;
	}

	public void setUseAuthentication(boolean useAuthentication) {

		this.useAuthentication = useAuthentication;
	}

	public String getUsername() {

		return username;
	}

	public void setUsername(String username) {

		this.username = username;
	}

	public String getPassword() {

		return password;
	}

	public void setPassword(String password) {

		this.password = password;
	}

	public String getEncoding() {

		return encoding;
	}

	public void setEncoding(String encoding) {

		this.encoding = encoding;
	}

	public Charset getCharset() {

		return Charset.forName(encoding);
	}
	
	public String getAlternativeXPath() {

		return alternativeXPath;
	}

	public void setAlternativeXPath(String alternativeXPath) {

		this.alternativeXPath = alternativeXPath;
	}

	public String getKeyXPath() {

		return keyXPath;
	}

	public void setKeyXPath(String keyXPath) {

		this.keyXPath = keyXPath;
	}

	public String getValueXPath() {

		return valueXPath;
	}

	public void setValueXPath(String valueXPath) {

		this.valueXPath = valueXPath;
	}

	public XPathExpression getAlternativeXPathExpression() throws XPathExpressionException {

		if (alternativeXPathExpression == null) {

			alternativeXPathExpression = PooledXPathFactory.newXPath().compile(alternativeXPath);
		}

		return alternativeXPathExpression;
	}

	public XPathExpression getKeyXPathExpression() throws XPathExpressionException {

		if (keyXPathExpression == null) {

			keyXPathExpression = PooledXPathFactory.newXPath().compile(keyXPath);
		}

		return keyXPathExpression;
	}

	public XPathExpression getValueXPathExpression() throws XPathExpressionException {

		if (valueXPathExpression == null) {

			valueXPathExpression = PooledXPathFactory.newXPath().compile(valueXPath);
		}

		return valueXPathExpression;
	}

	public boolean isKeepOldListOnRefreshFail() {

		return keepOldListOnRefreshFail;
	}

	public void setKeepOldListOnRefreshFail(boolean keepOldListOnRefreshFail) {

		this.keepOldListOnRefreshFail = keepOldListOnRefreshFail;
	}

	@Override
	public Integer getEndpointID() {

		return sourceID;
	}

	@Override
	public String getAddress() {

		if(enableAttributeFiltering) {
			
			return this.dynamicURL;
			
		}else {
			
			return url;
		}
	}
}
