package com.nordicpeak.flowengine.queries.fixedtablequery;

import java.lang.reflect.Field;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;

import com.nordicpeak.flowengine.queries.basetablequery.BaseTableColumn;

@Table(name = "fixed_table_query_columns")
@XMLElement(name = "Column")
public class FixedTableColumn extends BaseTableColumn<DropDownAlternative, FixedTableColumn, FixedTableQuery> {

	private static final long serialVersionUID = -5669662208391544909L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(FixedTableColumn.class, "query");
	public static final Field ROWSUM_ADD_COLUMNS_RELATION = ReflectionUtils.getField(FixedTableColumn.class, "rowSumAddedColumns");
	public static final Field ROWSUM_SUBTRACT_COLUMNS_RELATION = ReflectionUtils.getField(FixedTableColumn.class, "rowSumSubtractedColumns");

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	private FixedTableQuery query;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<FixedTableCellValue> values;

	@DAOManaged
	@OneToMany(autoUpdate = true, autoAdd = true, autoGet = true)
	@XMLElement(fixCase = true)
	private List<DropDownAlternative> dropDownAlternatives;

	@DAOManaged
	@OneToMany
	@SimplifiedRelation(table = "fixed_table_query_columns_add", remoteKeyColumnName = "columnID", remoteValueColumnName = "targetColumnID")
	@WebPopulate(paramName = "rowsumadd")
	@XMLElement(fixCase = true)
	private List<Integer> rowSumAddedColumns;

	@DAOManaged
	@OneToMany
	@SimplifiedRelation(table = "fixed_table_query_columns_sub", remoteKeyColumnName = "columnID", remoteValueColumnName = "targetColumnID")
	@WebPopulate(paramName = "rowsumsubtract")
	@XMLElement(fixCase = true)
	private List<Integer> rowSumSubtractedColumns;

	@Override
	public FixedTableQuery getQuery() {

		return query;
	}

	@Override
	public void setQuery(FixedTableQuery query) {

		this.query = query;
	}

	public List<FixedTableCellValue> getValues() {

		return values;
	}

	public void setValues(List<FixedTableCellValue> values) {

		this.values = values;
	}

	@Override
	public List<DropDownAlternative> getDropDownAlternatives() {

		return dropDownAlternatives;
	}

	@Override
	public void setDropDownAlternatives(List<DropDownAlternative> dropdownAlternatives) {

		this.dropDownAlternatives = dropdownAlternatives;
	}

	@Override
	public List<Integer> getRowSumAddedColumns() {

		return rowSumAddedColumns;
	}

	@Override
	public void setRowSumAddedColumns(List<Integer> addedColumns) {

		this.rowSumAddedColumns = addedColumns;
	}

	@Override
	public List<Integer> getRowSumSubtractedColumns() {

		return rowSumSubtractedColumns;
	}

	@Override
	public void setRowSumSubtractedColumns(List<Integer> subtractedColumns) {

		this.rowSumSubtractedColumns = subtractedColumns;
	}

	@Override
	protected void populateDropdownAlternatives(XMLParser xmlParser, List<ValidationError> errors) throws ValidationException {

		dropDownAlternatives = FixedTableColumnCRUD.ALTERNATIVES_POPLATOR.populate(xmlParser, errors);

		if (!CollectionUtils.isEmpty(dropDownAlternatives)) {

			for (DropDownAlternative alternative : dropDownAlternatives) {
				alternative.setColumn(this);
			}
		}
	}

}
