package com.nordicpeak.flowengine.queries.fixedtablequery;

import java.lang.reflect.Field;
import java.util.Arrays;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.CRUDAction;
import se.unlogic.hierarchy.core.enums.EventTarget;
import se.unlogic.hierarchy.core.events.CRUDEvent;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.queries.basetablequery.TableQueryCRUD;

public class FixedTableQueryCRUD extends TableQueryCRUD<DropDownAlternative, FixedTableCellValue, FixedTableRow, FixedTableQueryInstance, FixedTableColumn, FixedTableQuery, FixedTableQueryProviderModule> {

	protected AnnotatedDAOWrapper<FixedTableQuery, Integer> queryDAO;

	public FixedTableQueryCRUD(AnnotatedDAOWrapper<FixedTableQuery, Integer> queryDAO, BeanRequestPopulator<FixedTableQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, FixedTableQueryProviderModule callback) {

		super(FixedTableQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);

		this.queryDAO = queryDAO;
	}

	@Override
	protected List<Field> getBeanRelations() {

		return Arrays.asList(FixedTableQuery.COLUMNS_RELATION, FixedTableQuery.ROWS_RELATION);
	}

	public ForegroundModuleResponse sortRows(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		FixedTableQuery query = this.getRequestedBean(req, res, user, uriParser, UPDATE);

		if (query != null) {

			this.checkUpdateAccess(query, user, req, uriParser);

			if (req.getMethod().equalsIgnoreCase("POST")) {

				List<FixedTableRow> tableRows = query.getRows();

				if (!CollectionUtils.isEmpty(tableRows)) {

					for (FixedTableRow tableRow : tableRows) {

						String sortIndex = req.getParameter("sortorder_" + tableRow.getRowID());

						if (NumberUtils.isInt(sortIndex)) {

							tableRow.setSortIndex(NumberUtils.toInt(sortIndex));
						}
					}

					queryDAO.update(query);

					callback.getEventHandler().sendEvent(QueryDescriptor.class, new CRUDEvent<>(CRUDAction.UPDATE, (QueryDescriptor) query.getQueryDescriptor()), EventTarget.ALL);

					callback.redirectToQueryConfig(query, req, res);

					return null;
				}
			}

			Document doc = this.callback.createDocument(req, uriParser, user);
			Element updateTypeElement = doc.createElement("SortRows");
			doc.getFirstChild().appendChild(updateTypeElement);

			updateTypeElement.appendChild(query.toXML(doc));

			return new SimpleForegroundModuleResponse(doc);

		}

		throw new URINotFoundException(uriParser);
	}
}
