<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:variable name="scripts">
		/common/js/query.js
		/js/jquery.ui.datepicker-sv.js
		/js/tablequery.js?v=1
		/js/fixedtablequery.js?v=1
	</xsl:variable>
	
	<xsl:variable name="links">
		/css/tablequery.css?v=2
	</xsl:variable>
	
	<xsl:template match="Document">	
		
		<xsl:apply-templates select="ShowQueryValues"/>
		<xsl:apply-templates select="ShowQueryForm"/>
		
	</xsl:template>
		
	<xsl:template match="ShowQueryValues">
		
		<xsl:variable name="queryID" select="concat('query_', FixedTableQueryInstance/FixedTableQuery/queryID)" />
		
		<div class="query">
			<xsl:attribute name="class">
				<xsl:text>query</xsl:text>
				<xsl:if test="FixedTableQueryInstance/FixedTableQuery/hideTitle = 'true'"> notitle</xsl:if>				
				<xsl:if test="FixedTableQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
			</xsl:attribute>
			
			<article>
				
				<div class="heading-wrapper tablequery-heading">
				
					<xsl:if test="not(FixedTableQueryInstance/FixedTableQuery/hideTitle = 'true')">
						<h2 id="{$queryID}-title">
							<xsl:attribute name="class">
								<xsl:if test="FixedTableQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
									<xsl:text>required</xsl:text>
								</xsl:if>
							</xsl:attribute>
							<xsl:value-of select="FixedTableQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
						</h2>
					</xsl:if>
				
					
					
					<xsl:call-template name="createUpdateButton">
						<xsl:with-param name="queryID" select="FixedTableQueryInstance/FixedTableQuery/queryID" />
					</xsl:call-template>
				</div>

				<xsl:if test="FixedTableQueryInstance/FixedTableQuery/description">
					<span class="italic">
						<xsl:if test="/Document/useCKEditorForDescription = 'true'"><xsl:attribute name="class">italic html-description</xsl:attribute></xsl:if>
						<xsl:value-of select="FixedTableQueryInstance/FixedTableQuery/description" disable-output-escaping="yes" />
					</span>
				</xsl:if>
				
				<div class="clearboth"/>
				
				<xsl:variable name="showRowLabels" select="not(FixedTableQueryInstance/FixedTableQuery/hideRowLabels = 'true')"/>
				
				<table class="fixedtable tablequery full" aria-describedby="{$queryID}-title">
				
					<thead>
					
						<tr>
							<xsl:if test="$showRowLabels">
								<th class="paddingright">
									<xsl:value-of select="FixedTableQueryInstance/FixedTableQuery/rowsLabel"/>
								</th>
							</xsl:if>
						
							<xsl:apply-templates select="FixedTableQueryInstance/FixedTableQuery/Columns/Column" mode="thead-show" />
						
						</tr>
						
					</thead>
					
					<tbody>
					
						<xsl:apply-templates select="FixedTableQueryInstance/FixedTableQuery/Rows/Row" mode="tbody-show" />
						
					</tbody>
					
					<tfoot>
					
						<xsl:if test="FixedTableQueryInstance/FixedTableQuery/Columns/Column[summarise = 'true']">
							<tr data-title="{$i18n.Summary}">
								
								<xsl:if test="$showRowLabels">
									<td class="paddingright">
										<strong><xsl:value-of select="$i18n.Summary"/></strong>
									</td>
								</xsl:if>
								
								<xsl:for-each select="FixedTableQueryInstance/FixedTableQuery/Columns/Column">
									
									<xsl:variable name="columnIndex"><xsl:number/></xsl:variable>
									
									<xsl:choose>
										<xsl:when test="$columnIndex = 1 and not($showRowLabels)">
										
											<td class="padding" data-summarise="{summarise}" data-title="{label}">
												<strong class="floatleft"><xsl:value-of select="$i18n.Summary"/></strong>
												
												<xsl:if test="summarise = 'true'">
													<span class="floatright">
														<xsl:value-of select="sum"/>
													</span>
												</xsl:if>
											</td>
										
										</xsl:when>
										<xsl:otherwise>
										
											<td class="padding text-align-right" data-summarise="{summarise}" data-title="{label}">
												<xsl:if test="summarise = 'true'">
													<span class="floatright">
														<xsl:value-of select="sum"/>
													</span>
												</xsl:if>
											</td>
											
										</xsl:otherwise>
									</xsl:choose>
									
								</xsl:for-each>
								
							</tr>
						</xsl:if>
					
					</tfoot>
					
				</table>
				
			</article>
			
		</div>
		
	</xsl:template>		
		
	<xsl:template match="ShowQueryForm">
	
		<xsl:variable name="queryID" select="concat('query_', FixedTableQueryInstance/FixedTableQuery/queryID)" />
	
		<div class="query tablequery fixedtablequery" id="{$queryID}">
			<xsl:attribute name="class">
				<xsl:text>query tablequery fixedtablequery</xsl:text>
				<xsl:if test="FixedTableQueryInstance/FixedTableQuery/hideTitle = 'true'"> notitle</xsl:if>
				<xsl:if test="EnableAjaxPosting"> enableAjaxPosting</xsl:if>
				<xsl:if test="FixedTableQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
			</xsl:attribute>
			
			<xsl:if test="EnableAjaxPosting">
				<xsl:call-template name="loadAjaxValidationErrors"/>
			</xsl:if>
		
			<a name="{$queryID}" />
			
			<input type="hidden" name="summaryURL" disabled="disabled" value="{../ModuleURL}/getcolumnsum"/>
			<input type="hidden" name="rowsumURL" disabled="disabled" value="{../ModuleURL}/getrowsum"/>
			
			<xsl:if test="ValidationErrors/validationError">
			
				<div id="{$queryID}-validationerrors" class="validationerrors">
					<div class="info-box error">
							
						<xsl:variable name="fieldValidationErrors" select="ValidationErrors/validationError[fieldName]"/>
						
						<xsl:choose>
							<xsl:when test="$fieldValidationErrors">
								
								<xsl:call-template name="fieldValidationErrorsMessage" />
								
							</xsl:when>
							<xsl:otherwise>
								
								<span />
								
							</xsl:otherwise>
						</xsl:choose>
						<div class="marker"></div>
					</div>
				</div>
			
			</xsl:if>
	
			<article>
			
				<xsl:if test="ValidationErrors/validationError">
					<xsl:attribute name="class">error</xsl:attribute>
				</xsl:if>
			
				<div class="heading-wrapper tablequery-heading">
					<xsl:if test="not(FixedTableQueryInstance/FixedTableQuery/hideTitle = 'true')">
						<h2>
							<xsl:attribute name="class">
								<xsl:if test="FixedTableQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
									<xsl:text>required</xsl:text>
								</xsl:if>
							</xsl:attribute>
							<xsl:value-of select="FixedTableQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
						</h2>
					</xsl:if>
					
					<xsl:if test="FixedTableQueryInstance/FixedTableQuery/helpText">
						<xsl:apply-templates select="FixedTableQueryInstance/FixedTableQuery/helpText" />
					</xsl:if>
					
				</div>

				<xsl:if test="FixedTableQueryInstance/FixedTableQuery/description">
					<span class="italic">
						<xsl:if test="/Document/useCKEditorForDescription = 'true'"><xsl:attribute name="class">italic html-description</xsl:attribute></xsl:if>
						<xsl:value-of select="FixedTableQueryInstance/FixedTableQuery/description" disable-output-escaping="yes" />
					</span>
				</xsl:if>
				
				<xsl:variable name="showRowLabels" select="not(FixedTableQueryInstance/FixedTableQuery/hideRowLabels = 'true')"/>
				<xsl:variable name="createRowLabelColumn" select="not(FixedTableQueryInstance/FixedTableQuery/hideRowLabels = 'true') or FixedTableQueryInstance/FixedTableQuery/Rows/Row[required = 'true']"/>
				
				<table>
				
					<xsl:attribute name="class">
						<xsl:text>fixedtable tablequery full</xsl:text>
						
						<xsl:if test="FixedTableQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
							<xsl:text> required</xsl:text>
						</xsl:if>
					</xsl:attribute>
				
					<thead>
					
						<tr>
						
							<xsl:if test="$createRowLabelColumn">
								<th class="paddingright">
									<xsl:if test="$showRowLabels">
										<xsl:value-of select="FixedTableQueryInstance/FixedTableQuery/rowsLabel"/>
									</xsl:if>
								</th>
							</xsl:if>
						
							<xsl:apply-templates select="FixedTableQueryInstance/FixedTableQuery/Columns/Column" mode="thead" />
							
							<!-- If all columns have specified width % and the sum of those is less than 100, push columns left with a filler column -->
							<xsl:if test="FixedTableQueryInstance/FixedTableQuery/hideRowLabels = 'true' and (count(FixedTableQueryInstance/FixedTableQuery/Columns/Column/width) = count(FixedTableQueryInstance/FixedTableQuery/Columns/Column)) and sum(FixedTableQueryInstance/FixedTableQuery/Columns/Column/width) &lt; 100">
								<th style="width: {100 - sum(FixedTableQueryInstance/FixedTableQuery/Columns/Column/width)}%;" />
							</xsl:if>
						
						</tr>
						
					</thead>
					
					<tbody>
					
						<xsl:apply-templates select="FixedTableQueryInstance/FixedTableQuery/Rows/Row" mode="tbody" />
						
					</tbody>
					
					<tfoot>
					
						<xsl:if test="FixedTableQueryInstance/FixedTableQuery/Columns/Column[summarise = 'true']">
							<tr data-title="{$i18n.Summary}">
								
								<xsl:if test="$createRowLabelColumn">
									<td class="paddingright">
										<xsl:if test="$showRowLabels">
											<strong><xsl:value-of select="$i18n.Summary"/></strong>
										</xsl:if>
									</td>
								</xsl:if>
								
								<xsl:for-each select="FixedTableQueryInstance/FixedTableQuery/Columns/Column">
									
									<xsl:variable name="columnIndex"><xsl:number/></xsl:variable>
									
									<xsl:variable name="columnIndex2">
										<xsl:choose>
											<xsl:when test="$createRowLabelColumn">
											
												<xsl:value-of select="$columnIndex"/>
											
											</xsl:when>
											<xsl:otherwise>
											
												<xsl:value-of select="$columnIndex - 1"/>
												
											</xsl:otherwise>
										</xsl:choose>
									</xsl:variable>
									
									<xsl:choose>
										<xsl:when test="$columnIndex = 1 and not($showRowLabels)">
										
											<td class="padding bigpaddingright text-align-right" id="summary-{columnID}" data-summarise="{summarise}" data-columnindex="{$columnIndex2}" data-title="{label}">
												<strong class="floatleft"><xsl:value-of select="$i18n.Summary"/></strong>
												
												<xsl:if test="summarise = 'true'">
													<span>0</span>
												</xsl:if>
											</td>
										
										</xsl:when>
										<xsl:otherwise>
										
											<td class="padding bigpaddingright text-align-right" id="summary-{columnID}" data-summarise="{summarise}" data-columnindex="{$columnIndex2}" data-title="{label}">
												<xsl:if test="summarise = 'true'">
													<span>
														<xsl:text>0</xsl:text>
													</span>
												</xsl:if>
											</td>
											
										</xsl:otherwise>
									</xsl:choose>
									
								</xsl:for-each>
								
							</tr>
						</xsl:if>
							
					</tfoot>
					
				</table>
		
			</article>
			
		</div>
		
		<script type="text/javascript">
			$(function(){
				initFixedTableQuery(
					'<xsl:value-of select="FixedTableQueryInstance/FixedTableQuery/queryID" />',
					'<xsl:value-of select="queryRequestURL" />'
				);
			});
		</script>
		
	</xsl:template>
	
	<xsl:template match="Row" mode="tbody">
	
		<xsl:variable name="class">
			<xsl:value-of select="'paddingright'"/>
			
			<xsl:if test="required = 'true'">
				<xsl:value-of select="' required'"/>
			</xsl:if>
		</xsl:variable>
	
		<tr>
		
			<xsl:if test="not(../../hideRowLabels = 'true') or ../../Rows/Row[required = 'true']">
				<td class="{$class}">
					<xsl:if test="not(../../hideRowLabels = 'true')">
						<strong>
							<xsl:value-of select="label"/>
						</strong>
					</xsl:if>
					<xsl:if test="helpText">
						<i data-icon-after="?" title="{helpText}"></i>
					</xsl:if>
				</td>
			</xsl:if>
			
			<xsl:apply-templates select="../../Columns/Column" mode="tbody" >
				<xsl:with-param name="rowID" select="rowID"/>
			</xsl:apply-templates>
			
		</tr>
	
	</xsl:template>
	
	<xsl:template match="Row" mode="tbody-show">
	
		<tr>
		
			<xsl:if test="not(../../hideRowLabels = 'true')">
				<td class="paddingright">
					<strong>
						<xsl:value-of select="label"/>
					</strong>
				</td>
			</xsl:if>
			
			<xsl:apply-templates select="../../Columns/Column" mode="tbody-show" >
				<xsl:with-param name="rowID" select="rowID"/>
			</xsl:apply-templates>
			
		</tr>
	
	</xsl:template>
	
</xsl:stylesheet>