<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl"/>
	
	<xsl:variable name="globalscripts">
		/jquery/jquery.js
		/jquery/jquery-migrate.js
		/jquery/jquery-ui.js
		/jquery/plugins/jquery.qloader.js
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
		/tablesorter/js/jquery.tablesorter.min.js
	</xsl:variable>
	
	<xsl:variable name="globallinks">
		/css/openhierarchy-jquery-ui.css
	</xsl:variable>
	
	<xsl:variable name="scripts">
		/js/flowengine.tablesorter.js
		/js/flowengine.tablefilter.js
		/js/jquery.ui.datepicker-sv.js
		/js/jquery.qloader-init.js
		/js/flowinstanceadminsendmessages.js?v=2
	</xsl:variable>
	
	<xsl:variable name="scripts-buttonextension">
		/js/flowinstanceadminsendmessages.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css
	</xsl:variable>

	<xsl:template match="Document">
	
		<div id="FlowBrowser" class="contentitem errands-wrapper">
			<xsl:apply-templates select="ListFamilies" />
			<xsl:apply-templates select="ListFlowVersions" />
			<xsl:apply-templates select="SendMessageForm" />
		</div>
		
	</xsl:template>

	<xsl:template match="ListFamilies">
	
		<div class="floatright marginbottom">
			<label for="name" class="marginright margintop"><xsl:value-of select="$i18n.Filter" />:</label>
			<input type="text" size="20" name="filter-input" class="filter-input" data-tableid="flowlist" /> 
		</div>
	
		<h1><xsl:value-of select="$i18n.Flowslist.title" /></h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<p>
			<xsl:value-of select="$i18n.Flowlist.description" />
		</p>
		
		<table id="flowlist" class="full coloredtable oep-table" cellspacing="0">
			<thead class="sortable">	
				<tr>
					<th width="25" class="no-sort"></th>
					<th class="default-sort"><xsl:value-of select="$i18n.flowName" /></th>
					<th><xsl:value-of select="$i18n.flowType" /></th>
					<th><xsl:value-of select="$i18n.versions" /></th>
					<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
					<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
				</tr>
			</thead>
			<tbody>
				<xsl:choose>
					<xsl:when test="not(Flow)">
						<tr>
							<td class="icon"></td>
							<td colspan="7">
								<xsl:value-of select="$i18n.noFlowsFound" />
							</td>
						</tr>
					</xsl:when>
					<xsl:otherwise>
						
						<xsl:apply-templates select="Flow[latestVersion = 'true']" mode="list"/>
						
					</xsl:otherwise>
				</xsl:choose>
			</tbody>
		</table>
		
		<div class="floatright bigmargintop">
			<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/contextpath}{FlowInstanceAdmin2ModuleFullAlias}">
				<span>
					<xsl:value-of select="$i18n.Back" />
				</span>
			</a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list">
		
		<tr>
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td data-title="{$i18n.flowName}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="name" /></a>
			</td>
			<td data-title="{$i18n.flowType}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="FlowType/name" /></a>
			</td>
			<td data-title="{$i18n.versions}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="VersionCount" /></a>
			</td>
			<td data-title="{$i18n.SubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="SubmittedInstanceCount" /></a>
			</td>
			<td data-title="{$i18n.NotSubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="InstanceCount - SubmittedInstanceCount" /></a>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ListFlowVersions">
	
		<script>
			$(function() {
				if (!Modernizr.inputtypes.date) {
					$( "#fromDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.fromDate"/>',
						changeMonth: true,
						changeYear: true,
						showWeek: true,
					});
					
					$( "#toDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.toDate"/>',
						changeMonth: true,
						changeYear: true,
						showWeek: true,
					});
				}
			});
		</script>
		
		<h1>
			<xsl:value-of select="Flow[position() = last()]/name"/>
		</h1>
		
		<xsl:apply-templates select="validationError"/>

		<p><xsl:value-of select="$i18n.versions.description"/></p>
		
		<form id="exportForm" method="get" action="{/Document/requestinfo/currentURI}/{/Document/module/alias}/sendmessages/{FlowFamily/flowFamilyID}">
		
			<table id="flowversionlist" class="full coloredtable sortabletable oep-table floatleft" cellspacing="0">
				<thead>	
					<tr>
						<th width="15"><input id="select-page" type="checkbox"/></th>
						<th width="25"></th>
						<th><xsl:value-of select="$i18n.name" /></th>
						<th width="50"><xsl:value-of select="$i18n.version.title" /></th>
						<th width="30"><xsl:value-of select="$i18n.steps" /></th>
						<th width="50"><xsl:value-of select="$i18n.queries" /></th>
						<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
						<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
						<th width="80"><xsl:value-of select="$i18n.status" /></th>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="Flow" mode="list-versions"/>
				</tbody>
			</table>
			
			<br/>
			
			<div class="marginleft floatleft">
				
				<label for="fromDate" class="marginright">
					<xsl:value-of select="$i18n.fromDate" />
				</label>
				
				<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'fromDate'" />
						<xsl:with-param name="id" select="'fromDate'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="type" select="'date'"/>
						<xsl:with-param name="class" select="'width-auto'"/>
				</xsl:call-template>
			</div>
			
			<div class="bigmarginleft floatleft">
				
				<label for="toDate" class="marginright">
					<xsl:value-of select="$i18n.toDate" />
				</label>
				
				<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'toDate'" />
						<xsl:with-param name="id" select="'toDate'" />
						<xsl:with-param name="size" select="10" />
						<xsl:with-param name="type" select="'date'"/>
						<xsl:with-param name="class" select="'width-auto'"/>
				</xsl:call-template>
			</div>
			
			<div class="floatright marginright bigmargintop">
				
				<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}" title="{$i18n.Back}">
					<xsl:value-of select="$i18n.Back"/>
				</a>
				
				<input class="btn btn-green btn-inline marginright" type="submit" value="{$i18n.SendMessages}" title="{$i18n.SendMessages}"/>
			</div>
			
		</form>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list-versions">
		
		<tr>
			<td>
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="name" select="'flowID'"/>
					<xsl:with-param name="value" select="flowID"/>
					<xsl:with-param name="requestparameters" select="../requestparameters"/>
					
					<xsl:with-param name="disabled">
					
						<xsl:if test="enabled = 'false'">
							<xsl:text>true</xsl:text>
						</xsl:if>
					
					</xsl:with-param>
					
				</xsl:call-template>
			</td>			
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td>
				<xsl:value-of select="name" />
			</td>
			<td>
				<xsl:value-of select="version" />
			</td>	
			<td>
				<xsl:value-of select="count(Steps/Step)" />
			</td>
			<td>
				<xsl:value-of select="count(Steps/Step/QueryDescriptors/QueryDescriptor)" />
			</td>
			<td>
				<xsl:value-of select="flowSubmittedInstanceCount" />
			</td>
			<td>
				<xsl:value-of select="flowInstanceCount - flowSubmittedInstanceCount" />
			</td>
			<td>
					<xsl:choose>
						<xsl:when test="enabled = 'false'">
							<xsl:value-of select="$i18n.disabled" />
						</xsl:when>
						<xsl:when test="published = 'true'">
							<xsl:value-of select="$i18n.published" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.notPublished" />
						</xsl:otherwise>
					</xsl:choose>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="SendMessageForm">
	
		<script type="text/javascript">
			$(function() {
			
				var sendEmail = $("#send-email");
				var sendSMS = $("#send-sms");
				var sendExternalMessage = $("#send-external-message");
				
				var userTags = $("#user-tags");
				userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				
				
				var sendEmailBox = $("#email-text-box");
				sendEmailBox.toggle(sendEmail.prop("checked"));
				
				sendEmail.click(function(){
					sendEmailBox.toggle(sendEmail.prop("checked"));
					userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				});
				
				
				var sendSMSBox = $("#sms-text-box");
				sendSMSBox.toggle(sendSMS.prop("checked"));
				
				sendSMS.click(function(){
					sendSMSBox.toggle(sendSMS.prop("checked"));
					userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				});
				
				
				var sendExternalMessageBox = $("#external-message-text-box, #warning-flows-with-disabled-external-messages");
				sendExternalMessageBox.toggle(sendExternalMessage.prop("checked"));
				
				sendExternalMessage.click(function(){
					sendExternalMessageBox.toggle(sendExternalMessage.prop("checked"));
					userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				});
			});
		</script>
		
		<div>
		
			<h1>
				<xsl:value-of select="$i18n.SendMessageTitle"/>
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="FlowFamilyName"/>
				
				<xsl:choose>
					<xsl:when test="FlowSelection/fromDate and FlowSelection/toDate">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleBetween"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/fromDate"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleBetween2"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/toDate"/>
					</xsl:when>
					<xsl:when test="FlowSelection/fromDate">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleAfter"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/fromDate"/>
					</xsl:when>
					<xsl:when test="FlowSelection/toDate">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleBefore"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/toDate"/>
					</xsl:when>
				</xsl:choose>
			</h1>
			
			<br/>
			
			<xsl:if test="SentEmails or SentSMSs or SentExternalMessages">
				
				<xsl:if test="SentEmails">
					<div class="border-radius-small lightbackground padding bigmarginbottom">
						<strong>
							<xsl:value-of select="$i18n.SendMessage.EmailsSent"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="SentEmails"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part1"/>
							
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="FlowInstanceCount"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part2"/>
						</strong>
					</div>
				</xsl:if>
				<xsl:if test="SentSMSs">
					<div class="border-radius-small lightbackground padding bigmarginbottom">
						<strong>
							<xsl:value-of select="$i18n.SendMessage.SMSsSent"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="SentSMSs"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part1"/>
							
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="FlowInstanceCount"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part2"/>
						</strong>
					</div>
				</xsl:if>
				<xsl:if test="SentExternalMessages">
					<div class="border-radius-small lightbackground padding bigmarginbottom">
						<strong>
							<xsl:value-of select="$i18n.SendMessage.SentExternalMessages"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="SentExternalMessages"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part1"/>
							
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="FlowInstanceCount"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part2"/>
						</strong>
						<br/>
					</div>
				</xsl:if>
				
			</xsl:if>
			
			<xsl:if test="ValidationErrors/validationError">
				<xsl:apply-templates select="ValidationErrors/validationError" />
				<br/>
			</xsl:if>
			
			<form method="post" action="{/Document/requestinfo/uri}"  enctype="multipart/form-data">
				
				<xsl:call-template name="createHiddenField">
					<xsl:with-param name="name">fromform</xsl:with-param>
					<xsl:with-param name="value">true</xsl:with-param>
				</xsl:call-template>
				
				<xsl:apply-templates select="FlowSelection"/>
				
				<xsl:if test="not(FlowSelection/DirectFlowInstances)">
					
					<div class="bigpaddingbottom">
						<h2><xsl:value-of select="$i18n.SendMessage.Status.title"/></h2>
				
						<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.Status.description"/></p>
						<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.Status.description2"/></p>
						
						<xsl:apply-templates select="Statuses/Status" mode="filter-list"/>
					</div>
					
				</xsl:if>
				
				<h2><xsl:value-of select="$i18n.SendMessage.Transport"/></h2>
				
				<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.Transport.description"/></p>
				<p><xsl:value-of select="$i18n.SendMessage.Info" /></p>
				
				<div>
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'send-email'" />
						<xsl:with-param name="name" select="'send-email'" />
					</xsl:call-template>
					
					<label for="send-email">
						<xsl:value-of select="$i18n.SendMessage.SendEmail" />
					</label>
				</div>
				
				<div>
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'send-sms'" />
						<xsl:with-param name="name" select="'send-sms'" />
					</xsl:call-template>
					
					<label for="send-sms">
						<xsl:value-of select="$i18n.SendMessage.SendSMS" />
					</label>
				</div>
				
				<div class="bigmarginbottom">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'send-external-message'" />
						<xsl:with-param name="name" select="'send-external-message'" />
					</xsl:call-template>
					
					<label for="send-external-message">
						<xsl:value-of select="$i18n.SendMessage.SendExternalMessage" />
					</label>
				</div>
				
				<xsl:if test="FlowsWithDisabledExternalMessages">
					<div id="warning-flows-with-disabled-external-messages">
						<p class="error">
							<xsl:value-of select="$i18n.SendMessage.SendExternalMessage.FlowsWithDisabledExternalMessages"/>
							
							<xsl:for-each select="FlowsWithDisabledExternalMessages/Flow">
								<br/>
								<xsl:value-of select="name" />
								<xsl:text> (v.</xsl:text>
								<xsl:value-of select="version" />
								<xsl:text>)</xsl:text>
							</xsl:for-each>
						</p>
					</div>
				</xsl:if>
				
				<div id="email-text-box">
				
					<fieldset class="border-radius-small lightbackground">
						<legend><xsl:value-of select="$i18n.SendMessage.Email"/></legend>
							
						<div class="bigmarginbottom">
							<label class="floatleft twenty" for="emailSenderName"><xsl:value-of select="$i18n.SendMessage.SenderName"/>:</label>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSenderName'"/>
									<xsl:with-param name="id" select="'emailSenderName'"/>
								</xsl:call-template>
							</div>
						</div>
						
						<div class="bigmarginbottom">
							<span class="floatleft twenty">
								<label for="emailSenderName"><xsl:value-of select="$i18n.SendMessage.SenderAddress"/>:</label>
								
								<xsl:if test="not(ForceAutomaticEmailSenderAddress) and DefaultEmailSenderAddress">
									<p class="tiny">
										<xsl:value-of select="$i18n.SendMessage.SenderAddress.description"/>
										<xsl:text> </xsl:text>
										<xsl:value-of select="DefaultEmailSenderAddress"/>
									</p>
								</xsl:if>
							</span>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSenderAddress'" />
									<xsl:with-param name="id" select="'emailSenderAddress'" />
									<xsl:with-param name="value" >
										<xsl:if test="ForceAutomaticEmailSenderAddress">
											<xsl:value-of select="DefaultEmailSenderAddress" />
										</xsl:if>
									</xsl:with-param>
									<xsl:with-param name="disabled" select="ForceAutomaticEmailSenderAddress" />
								</xsl:call-template>
							</div>
						</div>
						
						
						
						<div class="bigmarginbottom clearboth">
							<label class="floatleft twenty" for="emailSubject"><xsl:value-of select="$i18n.SendMessage.Subject"/>:</label>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSubject'"/>
									<xsl:with-param name="id" select="'emailSubject'"/>
								</xsl:call-template>
							</div>
						</div>
						
						<div class="bigmarginbottom bigpaddingtop clearboth">
							<xsl:apply-templates select="/Document/SendMessageForm/FlowSelection/FlowFamily" mode="messageTemplates">
								<xsl:with-param name="id" select="'emailMessageHandler'"/>
								<xsl:with-param name="type" select="'EXTERNAL'"/>
							</xsl:apply-templates>	
						</div>
						
						<label class="full nomargin" for="emailMessage"><xsl:value-of select="$i18n.SendMessage.Message"/>:</label>
							
						<div class="bigmarginbottom">
						
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="name" select="'emailMessage'"/>
								<xsl:with-param name="id" select="'emailMessage'"/>
								<xsl:with-param name="rows" select="'8'"/>
								<xsl:with-param name="class" select="'flow-ckeditor'"/>
							</xsl:call-template>
							
							<xsl:call-template name="initializeFCKEditor">
								<xsl:with-param name="basePath"><xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/ckeditor/</xsl:with-param>
								<xsl:with-param name="customConfig">config.js</xsl:with-param>
								<xsl:with-param name="editorContainerClass">flow-ckeditor</xsl:with-param>
								<xsl:with-param name="editorHeight">150</xsl:with-param>
								
								<xsl:with-param name="contentsCss">
									<xsl:if test="cssPath">
										<xsl:value-of select="cssPath"/>
									</xsl:if>
								</xsl:with-param>
								
								<xsl:with-param name="filebrowserBrowseUri">
									
									<xsl:choose>
										<xsl:when test="ckConnectorModuleAlias">
											<xsl:text>filemanager/index.html?Connector=</xsl:text>
											<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
											<xsl:text>/connector</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>
									</xsl:choose>
					
								</xsl:with-param>
								
								<xsl:with-param name="filebrowserImageBrowseUri">
								
									<xsl:choose>
										<xsl:when test="ckConnectorModuleAlias">
											<xsl:text>filemanager/index.html?Connector=</xsl:text>
											<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
											<xsl:text>/connector</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>
									</xsl:choose>
								
								</xsl:with-param>
								
							</xsl:call-template>

	  						<div class="heading-wrapper">
	  							<label><xsl:value-of select="$i18n.AttachFiles" /></label>
	  						</div>
	  						
	  						<script>
								imagePath = '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics';
								deleteFile = '<xsl:value-of select="$i18n.DeleteFile" />';
							</script>
							
							<xsl:apply-templates select="validationError[messageKey = 'FileSizeLimitExceeded' or messageKey = 'UnableToParseRequest']" />

							<div class="full">
								
								<div class="upload clearboth">
									<span class="btn btn-upload btn-blue">
										<xsl:value-of select="$i18n.ChooseFiles" />
										<input id="external-message" type="file" name="email-attachments" multiple="multiple" size="55" class="qloader externalmessages bigmarginbottom" />
									</span>
									<span><xsl:value-of select="$i18n.MaximumFileSize" />: <xsl:value-of select="FormatedMaxEmailFileSize" /></span>
								</div>
								
								<ul id="external-message-qloader-filelist" class="files" />
								
							</div>
						
						</div>
							
					</fieldset>
				</div>
				
				<div id="sms-text-box">
					<fieldset class="border-radius-small lightbackground">
						<legend><xsl:value-of select="$i18n.SendMessage.SMS"/></legend>
							<xsl:apply-templates select="/Document/SendMessageForm/FlowSelection/FlowFamily" mode="messageTemplates">
								<xsl:with-param name="type" select="'EXTERNAL'"/>
								<xsl:with-param name="id" select="'smsMessageHandler'"/>
							</xsl:apply-templates>	
					
						<div>
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="id" select="'smsMessage'" />
								<xsl:with-param name="name" select="'smsMessage'" />
								<xsl:with-param name="rows" select="5"/>
								<xsl:with-param name="class" select="'border-box'"/>
							</xsl:call-template>
						</div>
					</fieldset>
				</div>
				
				
				
				
				<div id="external-message-text-box">
					<fieldset class="border-radius-small lightbackground">
						
						<legend><xsl:value-of select="$i18n.SendMessage.ExternalMessage"/></legend>
						
						<xsl:apply-templates select="/Document/SendMessageForm/FlowSelection/FlowFamily" mode="messageTemplates">
							<xsl:with-param name="type" select="'EXTERNAL'"/>
							<xsl:with-param name="id" select="'externalMessageHandler'"/>
						</xsl:apply-templates>
						
						<div class="full">
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="id" select="'externalMessage'" />
								<xsl:with-param name="name" select="'externalMessage'" />
								<xsl:with-param name="rows" select="5"/>
								<xsl:with-param name="class" select="'border-box'"/>
							</xsl:call-template>
						</div>
						
  						<div class="heading-wrapper">
  							<label><xsl:value-of select="$i18n.AttachFiles" /></label>
  						</div>
	  						
  						<script>
							imagePath = '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics';
							deleteFile = '<xsl:value-of select="$i18n.DeleteFile" />';
						</script>
						
						<xsl:apply-templates select="validationError[messageKey = 'FileSizeLimitExceeded' or messageKey = 'UnableToParseRequest']" />

						<div class="full">
							
							<div class="upload clearboth">
								<span class="btn btn-upload btn-blue">
									<xsl:value-of select="$i18n.ChooseFiles" />
									<input id="external-message" type="file" name="external-message-attachments" multiple="multiple" size="55" class="qloader externalmessages bigmarginbottom" />
								</span>
								<span><xsl:value-of select="$i18n.MaximumFileSize" />: <xsl:value-of select="FormatedMaxExternalMessageFileSize" /></span>
							</div>
							
							<ul id="external-message-qloader-filelist" class="files" />
							
						</div>
						
					</fieldset>
				</div>
				
				<xsl:call-template name="addUserTagsTable"/>
				
				<div class="floatright bigmargintop">
					
					<xsl:choose>
						<xsl:when test="FlowSelection/FlowInstanceIDs">
							<input class="btn btn-light btn-inline marginright" type="button" value="{$i18n.Back}" onclick="window.location = '{/Document/requestinfo/contextpath}{FlowInstanceAdmin2ModuleFullAlias}'"/>
						</xsl:when>
						<xsl:otherwise>
							<input class="btn btn-light btn-inline marginright" type="button" value="{$i18n.Back}" onclick="window.location = '{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowSelection/FlowFamily/flowFamilyID}'"/>
						</xsl:otherwise>
					</xsl:choose>
					
					<input class="btn btn-green btn-inline" type="submit" value="{$i18n.SendMessage.SubmitMessage}"/>
				</div>
			
			</form>
		</div>
		
	</xsl:template>
	
	<xsl:template match="FlowFamily" mode="messageTemplates">
		<xsl:param name="id"/>
		<xsl:param name="type" />
		
		<xsl:if test="MessageTemplates/MessageTemplate[type=$type or type='ALL']">
			
			<select class="messageTemplates floatright">
				<xsl:attribute name="id">
					<xsl:value-of select="$id"/>
				</xsl:attribute>
	
				<option value="">
					<xsl:value-of select="$i18n.MessageTemplates.choose" />
				</option>
	
				<xsl:for-each select="MessageTemplates/MessageTemplate[type=$type or type='ALL']">
					
						<option value="{message}" data-template-id="{templateID}">
		
							<xsl:value-of select="name" />
		
						</option>
						
				</xsl:for-each>
				
			</select>
			
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="Status" mode="filter-list">
		
		<xsl:variable name="inputID">
			<xsl:text>status-</xsl:text>
			<xsl:value-of select="Name"/>
		</xsl:variable>
	
		<div>
			
			<div>
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="$inputID"/>
					<xsl:with-param name="name" select="'status'" />
					<xsl:with-param name="value" select="Name"/>
					<xsl:with-param name="requestparameters" select="../../requestparameters"/>
				</xsl:call-template>
				
				<label for="{$inputID}">
					<xsl:value-of select="Name" />
					<xsl:text>&#160;(</xsl:text>
					<xsl:value-of select="FlowInstanceCount" />
					<xsl:text>)</xsl:text>
				</label>
			</div>
		</div>
		
		<xsl:if test="Multisigning">
			
			<div class="bigmarginleft">
				
				<xsl:choose>
					<xsl:when test="../../MultiSigningHandler">
						
						<div>
							
							<xsl:variable name="inputIDNotSigned">
								<xsl:value-of select="$inputID"/>
								<xsl:text>-notsigned</xsl:text>
							</xsl:variable>
							
							<div>
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="$inputIDNotSigned"/>
									<xsl:with-param name="name" select="'status-multisign-notsigned'"/>
									<xsl:with-param name="value" select="Name"/>
									<xsl:with-param name="requestparameters" select="../../requestparameters"/>
								</xsl:call-template>
								
								<label for="{$inputIDNotSigned}">
									<xsl:value-of select="$i18n.SendMessage.Status.WAITING_FOR_MULTISIGN.notSigned" />
									<xsl:text>&#160;(</xsl:text>
									<xsl:value-of select="FlowInstanceCountMultiSignNotSigned" />
									<xsl:text>)</xsl:text>
								</label>
							</div>
						</div>
						
						<div>
							
							<xsl:variable name="inputIDSigned">
								<xsl:value-of select="$inputID"/>
								<xsl:text>-signed</xsl:text>
							</xsl:variable>
							
							<div>
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="$inputIDSigned"/>
									<xsl:with-param name="name" select="'status-multisign-signed'"/>
									<xsl:with-param name="value" select="Name"/>
									<xsl:with-param name="requestparameters" select="../../requestparameters"/>
								</xsl:call-template>
								
								<label for="{$inputIDSigned}">
									<xsl:value-of select="$i18n.SendMessage.Status.WAITING_FOR_MULTISIGN.signed" />
									<xsl:text>&#160;(</xsl:text>
									<xsl:value-of select="FlowInstanceCountMultiSignSigned" />
									<xsl:text>)</xsl:text>
								</label>
							</div>
						</div>
						
						<div>
							
							<xsl:variable name="inputIDOwner">
								<xsl:value-of select="$inputID"/>
								<xsl:text>-poster</xsl:text>
							</xsl:variable>
							
							<div>
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="$inputIDOwner"/>
									<xsl:with-param name="name" select="'status-multisign-owner'"/>
									<xsl:with-param name="value" select="Name"/>
									<xsl:with-param name="requestparameters" select="../../requestparameters"/>
								</xsl:call-template>
								
								<label for="{$inputIDOwner}">
									<xsl:value-of select="$i18n.SendMessage.Status.WAITING_FOR_MULTISIGN.owner" />
								</label>
							</div>
						</div>
						
					</xsl:when>
					<xsl:otherwise>
					
						<div>
							<label>
								<xsl:value-of select="$i18n.SendMessage.Status.WAITING_FOR_MULTISIGN.MultiSigningHandlerMissing" />
							</label>
						</div>
					
					</xsl:otherwise>
				</xsl:choose>
				
			</div>
			
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template name="addUserTagsTable">
	
		<div class="bigmarginbottom" id="user-tags">

			<p><xsl:value-of select="$i18n.UserTagsTable.description"/></p>
		
			<table class="full border">
				<tr>
					<th>
						<xsl:value-of select="$i18n.Tag"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.Description"/>
					</th>
				</tr>
				<tr>
					<td>
						<xsl:text>$flow.name</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.FlowNameTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$flowInstance.flowInstanceID</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.FlowInstanceIDTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$flowInstance.url</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.FlowInstanceURLTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$contact.firstname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.PosterFirstnameTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$contact.lastname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.PosterLastnameTag"/>
					</td>
				</tr>
			</table>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="FlowSelection">
		
		<xsl:choose>
			<xsl:when test="DirectFlowInstances">
			
				<xsl:for-each select="FlowInstanceIDs/FlowInstanceID">
					<xsl:call-template name="createHiddenField">
						<xsl:with-param name="name" select="'flowInstanceID'"/>
						<xsl:with-param name="value" select="."/>
					</xsl:call-template>
				</xsl:for-each>
				
			</xsl:when>
			<xsl:otherwise>
				
				<xsl:for-each select="Flows/Flow">
					<xsl:call-template name="createHiddenField">
						<xsl:with-param name="name" select="'flowID'"/>
						<xsl:with-param name="value" select="flowID"/>
					</xsl:call-template>
				</xsl:for-each>
				
				<xsl:call-template name="createHiddenField">
					<xsl:with-param name="name" select="'fromDate'"/>
					<xsl:with-param name="value" select="fromDate"/>
				</xsl:call-template>
				
				<xsl:call-template name="createHiddenField">
					<xsl:with-param name="name" select="'toDate'"/>
					<xsl:with-param name="value" select="toDate"/>
				</xsl:call-template>
				
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='MultipleFlowFamiliesSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.MultipleFlowFamiliesSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyNotFound']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.FlowFamilyNotFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyAccessDenied']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.FlowFamilyAccessDenied"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoFlowVersionsSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.NoFlowVersionsSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoStatusesSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.NoStatusesSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoMultiSignTypesSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.NoMultiSignTypesSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoMessagePathSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.NoMessagePathSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoRecipients']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.NoEmailNoRecipients"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FileSizeLimitExceeded']">
	
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.FileSizeLimitExceeded.part1"/>
			<xsl:value-of select="filename"/>
			<xsl:value-of select="$i18n.ValidationError.FileSizeLimitExceeded.part2"/>
			<xsl:value-of select="size"/>
			<xsl:value-of select="$i18n.ValidationError.FileSizeLimitExceeded.part3"/>
			<xsl:value-of select="maxFileSize"/>
			<xsl:value-of select="$i18n.ValidationError.FileSizeLimitExceeded.part4"/>
		</p>
			
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='UnableToParseRequest']">
		
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.UnableToParseRequest" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='ExternalMessagesDisabled']">
		
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.ExternalMessagesDisabled.1" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="skippedMessages" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="$i18n.ValidationError.ExternalMessagesDisabled.2" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="flowName" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="$i18n.ValidationError.ExternalMessagesDisabled.3" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="fieldName = 'fromDate'">
						<xsl:value-of select="$i18n.fromDate"/>
					</xsl:when>
					<xsl:when test="fieldName = 'toDate'">
						<xsl:value-of select="$i18n.toDate"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailSenderName'">
						<xsl:value-of select="$i18n.emailSenderName"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailSenderAddress'">
						<xsl:value-of select="$i18n.emailSenderAddress"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailSubject'">
						<xsl:value-of select="$i18n.emailSubject"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailMessage'">
						<xsl:value-of select="$i18n.emailMessage"/>
					</xsl:when>
					<xsl:when test="fieldName = 'smsMessage'">
						<xsl:value-of select="$i18n.smsMessage"/>
					</xsl:when>
					<xsl:when test="fieldName = 'externalMessage'">
						<xsl:value-of select="$i18n.externalMessage"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>
	
</xsl:stylesheet>