<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl"/>
	
	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-migrate.js?v=1
		/jquery/jquery-ui.js?v=1
		/jquery/plugins/jquery.qloader.js
		/featherlight/js/featherlight.min.js
		/js/confirmpost.js
		/tablesorter/js/jquery.tablesorter.min.js
	</xsl:variable>
	
	<xsl:variable name="globallinks">
		/css/openhierarchy-jquery-ui.css
		/featherlight/css/featherlight.min.css?v=1
	</xsl:variable>
	
	<xsl:variable name="scripts">
		/js/flowengine.tablesorter.js
		/js/flowengine.tablefilter.js
		/js/jquery.ui.datepicker-sv.js
		/js/flowinstanceexcelexporter.js?v=3
	</xsl:variable>
	
	<xsl:variable name="scripts-buttonextension">
		/js/flowinstanceexcelexporter.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css
		/css/flowinstanceexcelexporter.css
	</xsl:variable>

	<xsl:template match="Document">
	
		<xsl:choose>
			<xsl:when test="ShowExportSettings or UpdateExportSettings">
			
				<xsl:apply-templates select="ShowExportSettings"/>
				<xsl:apply-templates select="UpdateExportSettings"/>
				
			</xsl:when>
			<xsl:otherwise>
			
				<div id="FlowBrowser" class="contentitem errands-wrapper">
					<xsl:apply-templates select="ListFamilies" />
					<xsl:apply-templates select="ListFlowVersions" />
				</div>
			
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

	<xsl:template match="ListFamilies">
	
		<div class="floatright marginbottom">
			<label for="name" class="marginright margintop"><xsl:value-of select="$i18n.Filter" />:</label>
			<input type="text" size="20" name="filter-input" class="filter-input" data-tableid="flowlist" /> 
		</div>
	
		<h1><xsl:value-of select="$i18n.Flowslist.title" /></h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<p>
			<xsl:value-of select="$i18n.Flowlist.description" />
		</p>
		
		<table id="flowlist" class="full coloredtable oep-table" cellspacing="0">
			<thead class="sortable">	
				<tr>
					<th width="25" class="no-sort"></th>
					<th class="default-sort"><xsl:value-of select="$i18n.flowName" /></th>
					<th><xsl:value-of select="$i18n.flowType" /></th>
					<th><xsl:value-of select="$i18n.versions" /></th>
					<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
					<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
				</tr>
			</thead>
			<tbody>
				<xsl:choose>
					<xsl:when test="not(Flow)">
						<tr>
							<td class="icon"></td>
							<td colspan="7">
								<xsl:value-of select="$i18n.noFlowsFound" />
							</td>
						</tr>
					</xsl:when>
					<xsl:otherwise>
						
						<xsl:apply-templates select="Flow[latestVersion = 'true']" mode="list"/>
						
					</xsl:otherwise>
				</xsl:choose>
			</tbody>
		</table>
		
		<div class="floatright bigmargintop">
			<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/contextpath}{FlowInstanceAdmin2ModuleFullAlias}">
				<span>
					<xsl:value-of select="$i18n.Back" />
				</span>
			</a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list">
		
		<tr>
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td data-title="{$i18n.flowName}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="name" /></a>
			</td>
			<td data-title="{$i18n.flowType}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="FlowType/name" /></a>
			</td>
			<td data-title="{$i18n.versions}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="VersionCount" /></a>
			</td>
			<td data-title="{$i18n.SubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="SubmittedInstanceCount" /></a>
			</td>
			<td data-title="{$i18n.NotSubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="InstanceCount - SubmittedInstanceCount" /></a>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ListFlowVersions">
	
		<script>
			$(function() {
				if (!Modernizr.inputtypes.date) {
					$( "#fromDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.fromDate"/>',
						changeMonth: true,
						changeYear: true,
						showWeek: true,
					});
					
					$( "#toDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.toDate"/>',
						changeMonth: true,
						changeYear: true,
						showWeek: true,
					});
				}
			});
		</script>
		
		<h1>
			<xsl:value-of select="Flow[position() = last()]/name"/>
		</h1>
		
		<xsl:apply-templates select="validationError"/>

		<p><xsl:value-of select="$i18n.versions.description"/></p>
		
		<form id="exportForm" method="get">
		
			<xsl:call-template name="createHiddenField">
				<xsl:with-param name="name" select="'timestamp'"/>
			</xsl:call-template>
		
			<table id="flowversionlist" class="full coloredtable sortabletable oep-table floatleft" cellspacing="0">
				<thead>	
					<tr>
						<th width="15"><input id="select-page" type="checkbox"/></th>
						<th width="25"></th>
						<th><xsl:value-of select="$i18n.name" /></th>
						<th width="50"><xsl:value-of select="$i18n.version.title" /></th>
						<th width="30"><xsl:value-of select="$i18n.steps" /></th>
						<th width="50"><xsl:value-of select="$i18n.queries" /></th>
						<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
						<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
						<th width="80"><xsl:value-of select="$i18n.status" /></th>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="Flow" mode="list-versions"/>
				</tbody>
			</table>
			
			<br/>
			<div class="full">
				<div class="marginleft floatleft">
					
					<label for="fromDate" class="marginright">
						<xsl:value-of select="$i18n.fromDate" />
					</label>
					
					<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'fromDate'" />
							<xsl:with-param name="id" select="'fromDate'" />
							<xsl:with-param name="size" select="10" />
							<xsl:with-param name="type" select="'date'"/>
							<xsl:with-param name="class" select="'width-auto'"/>
					</xsl:call-template>
				</div>
				
				<div class="bigmarginleft floatleft">
					
					<label for="toDate" class="marginright">
						<xsl:value-of select="$i18n.toDate" />
					</label>
					
					<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'toDate'" />
							<xsl:with-param name="id" select="'toDate'" />
							<xsl:with-param name="size" select="10" />
							<xsl:with-param name="type" select="'date'"/>
							<xsl:with-param name="class" select="'width-auto'"/>
					</xsl:call-template>
				</div>
				
				<div class="floatright marginright bigmargintop">
					
					<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}" title="{$i18n.Back}">
						<xsl:value-of select="$i18n.Back"/>
					</a>
					
					<input class="btn btn-green btn-inline marginright" type="submit" value="{$i18n.ExportFlowInstancesAsExcel}" onclick="exportFlowInstances(this, event)" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/exportflowversionstoexcel/{FlowFamily/flowFamilyID}" title="{$i18n.ExportFlowInstancesAsExcel}"/>
				</div>
			</div>		
		</form>
		
		<div class="hidden">
			
			<div id="exportProgressModal" class="contentitem" data-url="{/Document/requestinfo/currentURI}/{/Document/module/alias}/exportprogress/">
				
				<div class="modal-content">
				
					<div class="modal-header">
						<h1 class="working"><xsl:value-of select="$i18n.ExportProgress.title.working" /></h1>
						<h1 class="done" style="display: none;"><xsl:value-of select="$i18n.ExportProgress.title.done" /></h1>
					</div>
					
					<div class="modal-body">
						
						<p class="progressTextTotal">
							<xsl:value-of select="$i18n.ExportProgress.total" />
							<xsl:text>: </xsl:text>
							<xsl:value-of select="$i18n.ExportProgress.flowInstance" />
							<xsl:text> </xsl:text>
							<span class="totalProgress">0</span>
							<xsl:text> </xsl:text>
							<xsl:value-of select="$i18n.ExportProgress.of" />
							<xsl:text> </xsl:text>
							<span class="total">?</span>
						</p>

						<div class="progressContainer totalBar margintop">
							<div class="progressBar" />
						</div>
						
						<p class="progressTextVersion">
							<xsl:value-of select="$i18n.version.title" />
							<xsl:text> </xsl:text>
							<span class="version">?</span>
							<xsl:text>: </xsl:text>
							<xsl:value-of select="$i18n.ExportProgress.flowInstance" />
							<xsl:text> </xsl:text>
							<span class="versionProgress">0</span>
							<xsl:text> </xsl:text>
							<xsl:value-of select="$i18n.ExportProgress.of" />
							<xsl:text> </xsl:text>
							<span class="versionTotal">?</span>
						</p>
						
						<div class="progressContainer versionBar">
							<div class="progressBar" />
						</div>
					
					</div>
					
					<div class="modal-buttons bigmargintop">
					
						<input type="button" class="btn btn-blue" value="{$i18n.ExportProgress.Close}" onclick="$.featherlight.close();"/>
						
					</div>
				
				</div>
				
			</div>
			
		</div>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list-versions">
		
		<tr>
			<td>
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="name" select="'flowID'"/>
					<xsl:with-param name="value" select="flowID"/>
					<xsl:with-param name="requestparameters" select="../requestparameters"/>
					
					<xsl:with-param name="disabled">
					
						<xsl:if test="enabled = 'false'">
							<xsl:text>true</xsl:text>
						</xsl:if>
					
					</xsl:with-param>
					
				</xsl:call-template>
			</td>			
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td>
				<xsl:value-of select="name" />
			</td>
			<td>
				<xsl:value-of select="version" />
			</td>	
			<td>
				<xsl:value-of select="count(Steps/Step)" />
			</td>
			<td>
				<xsl:value-of select="count(Steps/Step/QueryDescriptors/QueryDescriptor)" />
			</td>
			<td>
				<xsl:value-of select="flowSubmittedInstanceCount" />
			</td>
			<td>
				<xsl:value-of select="flowInstanceCount - flowSubmittedInstanceCount" />
			</td>
			<td>
					<xsl:choose>
						<xsl:when test="enabled = 'false'">
							<xsl:value-of select="$i18n.disabled" />
						</xsl:when>
						<xsl:when test="published = 'true'">
							<xsl:value-of select="$i18n.published" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.notPublished" />
						</xsl:otherwise>
					</xsl:choose>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ShowExportSettings">
	
		<a name="excelexportsettings" />
		
		<xsl:choose>
			<xsl:when test="(FlowFamilyExportSettings/enabled = 'true')">
			
				<xsl:if test="FlowFamilyExportSettings/exportExternalFlowID = 'true'">
					<xsl:value-of select="$i18n.ExportSettings.ExportExternalFlowIDActive"/><br/>
				</xsl:if>

				<xsl:if test="FlowFamilyExportSettings/exportLastStatusChange = 'true'">
					<xsl:value-of select="$i18n.ExportSettings.ExportLastStatusChangeActive"/><br/>
				</xsl:if>

				<xsl:if test="ColoredTagProvider and FlowFamilyExportSettings/exportColoredTags = 'true'">
					<xsl:value-of select="$i18n.ExportSettings.ExportColoredTagsActive"/><br/>
				</xsl:if>
				
				<xsl:if test="FlowFamilyExportSettings/hideQueryColumns = 'true'">
					<xsl:value-of select="$i18n.ExportSettings.HideQueryColumnsActive"/><br/>
				</xsl:if>
				
				<xsl:if test="FlowFamilyExportSettings/addDateToFileName = 'true'">
					<xsl:value-of select="$i18n.ExportSettings.AddDateToFileNameActive"/><br/>
				</xsl:if>
				
				<xsl:choose>
					<xsl:when test="count(FlowFamilyExportSettings/ExportAttributes/exportAttribute) > 0">
							<xsl:value-of select="$i18n.ExportSettings.NumberOfAttributes.Part1"/>
							<xsl:text>&#x20;</xsl:text>
							<xsl:value-of select="count(FlowFamilyExportSettings/ExportAttributes/exportAttribute)"/>
							<xsl:text>&#x20;</xsl:text>
							<xsl:choose>
								<xsl:when test="count(FlowFamilyExportSettings/ExportAttributes/exportAttribute) = 1">
									<xsl:value-of select="$i18n.ExportSettings.NumberOfAttributes.Part2.single"/>
								</xsl:when>
								<xsl:when test="count(FlowFamilyExportSettings/ExportAttributes/exportAttribute) > 1">
									<xsl:value-of select="$i18n.ExportSettings.NumberOfAttributes.Part2.several"/>
								</xsl:when>
							</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.ExportSettings.NoAttributes"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$i18n.ExportSettings.NoSettings" />
			</xsl:otherwise>
		</xsl:choose>
		
		
		<a href="{/Document/ModuleURI}/updateexportsettings/{Flow/flowID}" class="floatright">
			<xsl:value-of select="$i18n.ExportSettings.UpdateSettings" />
			<img class="marginleft vertical-align-bottom" src="{/Document/StaticContentURL}/pics/pen.png" alt="" />
		</a>
		
		<xsl:if test="(FlowFamilyExportSettings/enabled = 'true') and (count(FlowFamilyExportSettings/ExportAttributes/exportAttribute) > 0)">
			<a href="{/Document/ModuleURI}/deleteexportsettings/{Flow/flowID}" class="floatright clearboth" onclick="return confirmPost(this.href, '{$i18n.ExportSettings.DeleteSettings.Confirm}');">
				<xsl:value-of select="$i18n.ExportSettings.DeleteSettings" />
				<img class="marginleft vertical-align-bottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
			</a>
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="UpdateExportSettings">
		
		<div class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.ExportSettings.UpdateSettingsTitle"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
				<xsl:text>&#x20;(</xsl:text>
				<xsl:value-of select="$i18n.ExportSettings.AllVersions"/>
				<xsl:text>)</xsl:text>
			</h1>
	
			<xsl:apply-templates select="validationException/validationError"/>
	
			<form id="exportSettingsForm" method="post">
			
				<div class="floatleft full marginbottom">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'enabled'" />
						<xsl:with-param name="id" select="'enabled'" />
						<xsl:with-param name="element" select="FlowFamilyExportSettings" />       
					</xsl:call-template>
					
					<label for="enabled">
						<xsl:value-of select="$i18n.ExportSettings.Enabled" />
					</label>
				</div>


				<div id="settingsContainer">
					<xsl:if test="not(FlowFamilyExportSettings/enabled = 'true')">
						<xsl:attribute name="style">display: none</xsl:attribute>
					</xsl:if>
					
						<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'addDateToFileName'" />
							<xsl:with-param name="id" select="'addDateToFileName'" />
							<xsl:with-param name="element" select="FlowFamilyExportSettings" />       
						</xsl:call-template>
						
						<label for="addDateToFileName">
							<xsl:value-of select="$i18n.ExportSettings.AddDateToFileName" />
						</label>
					</div>
				
					<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'exportExternalFlowID'" />
							<xsl:with-param name="id" select="'exportExternalFlowID'" />
							<xsl:with-param name="element" select="FlowFamilyExportSettings" />       
						</xsl:call-template>
						
						<label for="exportExternalFlowID">
							<xsl:value-of select="$i18n.ExportSettings.ExportExternalFlowID" />
						</label>
					</div>
									
					<div class="floatleft full">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'exportLastStatusChange'" />
							<xsl:with-param name="id" select="'exportLastStatusChange'" />
							<xsl:with-param name="element" select="FlowFamilyExportSettings" />       
						</xsl:call-template>
						
						<label for="exportLastStatusChange">
							<xsl:value-of select="$i18n.ExportSettings.ExportLastStatusChange" />
						</label>
					</div>

					<xsl:if test="ColoredTagProvider">
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="name" select="'exportColoredTags'" />
								<xsl:with-param name="id" select="'exportColoredTags'" />
								<xsl:with-param name="element" select="FlowFamilyExportSettings" />       
							</xsl:call-template>
							
							<label for="exportColoredTags">
								<xsl:value-of select="$i18n.ExportSettings.ExportColoredTags" />
							</label>
						</div>
					</xsl:if>
					<div class="floatleft full bigmarginbottom">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'hideQueryColumns'" />
							<xsl:with-param name="id" select="'hideQueryColumns'" />
							<xsl:with-param name="element" select="FlowFamilyExportSettings" />       
						</xsl:call-template>
						
						<label for="hideQueryColumns">
							<xsl:value-of select="$i18n.ExportSettings.HideQueryColumns" />
						</label>
					</div>
	
					<div class="floatleft full bigmarginbottom">
					
						<label for="exportAttributes" class="floatleft full nomargin">
							<xsl:value-of select="$i18n.ExportSettings.Attributes" />
						</label>
	
						<div class="tiny">
							<xsl:value-of select="$i18n.ExportSettings.Attributes.Info.1" />
						</div>
						<div class="tiny">
							<xsl:value-of select="$i18n.ExportSettings.Attributes.Info.2" />
						</div>
						
						<div class="floatleft full">
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="id" select="'exportAttributes'"/>
								<xsl:with-param name="name" select="'exportAttributes'"/>
								<xsl:with-param name="rows" select="5"/>
								<xsl:with-param name="separateListValues" select="'true'"/>
								<xsl:with-param name="element" select="FlowFamilyExportSettings/ExportAttributes/exportAttribute" />          
							</xsl:call-template>
						</div>
					</div>
				</div>
							
				<div class="floatright clearboth bigmargintop">
					<input type="submit" value="{$i18n.ExportSettings.SaveChanges}" />
				</div>
			
			</form>
		
		</div>

	</xsl:template>
	
	<xsl:template match="validationError[messageKey='MultipleFlowsSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.MultipleFlowsSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyNotFound']">
		<p class="error">
			<xsl:value-of select="$i18n.FlowFamilyNotFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyAccessDenied']">
		<p class="error">
			<xsl:value-of select="$i18n.FlowFamilyAccessDenied"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoFlowVersionsSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoFlowVersionsSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="fieldName = 'fromDate'">
						<xsl:value-of select="$i18n.fromDate"/>
					</xsl:when>
					<xsl:when test="fieldName = 'toDate'">
						<xsl:value-of select="$i18n.toDate"/>
					</xsl:when>
					<xsl:when test="fieldName = 'exportAttributes'">
						<xsl:value-of select="$i18n.ExportSettings.Attributes"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>
	
</xsl:stylesheet>