package com.nordicpeak.flowengine.flowinstanceextraparameters;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;
import javax.xml.transform.TransformerException;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathException;

import org.apache.log4j.Level;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import com.nordicpeak.flowengine.FlowAdminModule;
import com.nordicpeak.flowengine.api.FlowInstanceAPIModule;
import com.nordicpeak.flowengine.api.XMLDocumentFilter;
import com.nordicpeak.flowengine.beans.Flow;
import com.nordicpeak.flowengine.beans.FlowAdminExtensionShowView;
import com.nordicpeak.flowengine.beans.FlowFamily;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.interfaces.FlowAdminExtensionViewProvider;
import com.nordicpeak.flowengine.interfaces.ImmutableFlow;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowFamily;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowInstance;
import com.nordicpeak.flowengine.interfaces.XSDExtensionProvider;
import com.nordicpeak.flowengine.notifications.StandardFlowNotificationHandler;

import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.EventListener;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.SystemStartupListener;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.LinkTag;
import se.unlogic.hierarchy.core.beans.ScriptTag;
import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.CRUDAction;
import se.unlogic.hierarchy.core.enums.EventSource;
import se.unlogic.hierarchy.core.events.CRUDEvent;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.AttributeTagUtils;
import se.unlogic.hierarchy.core.utils.ForegroundModuleTracker;
import se.unlogic.hierarchy.core.utils.ForegroundModuleTrackerListener;
import se.unlogic.hierarchy.core.utils.ModuleUtils;
import se.unlogic.hierarchy.core.utils.ModuleViewFragmentTransformer;
import se.unlogic.hierarchy.core.utils.ViewFragmentModule;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;
import se.unlogic.hierarchy.foregroundmodules.staticcontent.StaticContentModule;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.string.AnnotatedBeanTagSourceFactory;
import se.unlogic.standardutils.string.SingleTagSource;
import se.unlogic.standardutils.string.TagReplacer;
import se.unlogic.standardutils.validation.NonNegativeStringIntegerValidator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.PooledXPathFactory;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.HTTPUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.validation.ValidationUtils;

public class FlowInstanceExtraParametersProvider extends AnnotatedForegroundModule implements FlowAdminExtensionViewProvider, ViewFragmentModule<ForegroundModuleDescriptor>, XMLDocumentFilter, XSDExtensionProvider, ForegroundModuleTrackerListener<FlowInstanceAPIModule> {

	@XSLVariable(name = "i18n.Name")
	private String paramNameDisplayName;

	@XSLVariable(name = "i18n.Value")
	private String paramValueDisplayName;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Provider priority", description = "The priority of this provider", required = true)
	private Integer priority = 100;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable fragment XML debug", description = "Enables debugging of fragment XML")
	private boolean debugFragmententXML;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Containing element name", description = "The name of the element containing the parameters", required = true)
	private String containingElementName = "ExtraParameters";

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "FlowInstance API module ID", description = "The module ID of the flowInstance API module to register this filter", required = true, formatValidator = NonNegativeStringIntegerValidator.class)
	protected Integer flowInstanceAPIModuleID;

	@InstanceManagerDependency(required = true)
	private StaticContentModule staticContentModule;

	@InstanceManagerDependency(required = true)
	private StandardFlowNotificationHandler standardFlowNotificationHandler;

	private FlowAdminModule flowAdminModule;

	private ForegroundModuleTracker<FlowInstanceAPIModule> flowInstanceAPITracker;

	private AnnotatedDAO<FlowInstanceExtraParameter> parameterDAO;
	private QueryParameterFactory<FlowInstanceExtraParameter, Integer> flowFamilyIDParamFactory;

	private ModuleViewFragmentTransformer<ForegroundModuleDescriptor> viewFragmentTransformer;

	public static final AnnotatedBeanTagSourceFactory<Flow> FLOW_TAG_SOURCE_FACTORY = new AnnotatedBeanTagSourceFactory<>(Flow.class, "$flow.");
	public static final AnnotatedBeanTagSourceFactory<FlowInstance> FLOWINSTANCE_TAG_SOURCE_FACTORY = new AnnotatedBeanTagSourceFactory<>(FlowInstance.class, "$flowInstance.");

	protected boolean configured;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		super.createDAOs(dataSource);

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, FlowInstanceExtraParametersProvider.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		parameterDAO = new AnnotatedDAO<>(dataSource, FlowInstanceExtraParameter.class, new SimpleAnnotatedDAOFactory(dataSource));

		flowFamilyIDParamFactory = parameterDAO.getParamFactory("flowFamilyID", Integer.class);
	}

	@Override
	protected void moduleConfigured() throws Exception {

		this.configured = ModuleUtils.checkRequiredModuleSettings(moduleDescriptor, this, systemInterface, Level.WARN);

		this.viewFragmentTransformer = new ModuleViewFragmentTransformer<>(sectionInterface.getForegroundModuleXSLTCache(), this, systemInterface.getEncoding());

		this.viewFragmentTransformer.setDebugXML(debugFragmententXML);

		stopTracker();

		if (flowInstanceAPIModuleID == null) {

			log.warn("No FlowInstance API module ID specified, check module settings.");

			configured = false;
			return;
		}

		startTracker();
	}

	private void startTracker() {

		if (configured) {
			flowInstanceAPITracker = new ForegroundModuleTracker<>(FlowInstanceAPIModule.class, flowInstanceAPIModuleID, sectionInterface.getSystemInterface(), sectionInterface.getSystemInterface().getRootSection(), true, true, this);
		}
	}

	@SystemStartupListener(priority = 1000)
	public void systemStarted() {

		if (!configured) {

			log.warn("Module is not configured correctly, check module settings");
			return;
		}

		if (flowInstanceAPITracker == null || flowInstanceAPITracker.getInstance() == null) {

			log.error("Unable to find specified FlowInstanceAPIModule with foreground module ID " + this.flowInstanceAPIModuleID);
		}
	}

	@Override
	public void moduleCached(ForegroundModuleDescriptor descriptor, FlowInstanceAPIModule instance) {

		instance.addXMLDocumentFilter(this);
	}

	@Override
	public void moduleUnloaded(ForegroundModuleDescriptor descriptor, FlowInstanceAPIModule instance) {

		instance.removeXMLDocumentFilter(this);
	}

	private void stopTracker() {

		if (flowInstanceAPITracker != null) {

			if (flowInstanceAPITracker.getInstance() != null) {

				flowInstanceAPITracker.getInstance().removeXMLDocumentFilter(this);
			}

			flowInstanceAPITracker.shutdown();

			flowInstanceAPITracker = null;
		}
	}

	@Override
	public void unload() throws Exception {

		if (flowAdminModule != null) {

			setFlowAdminModule(null);
		}

		stopTracker();

		super.unload();
	}

	@Override
	public FlowAdminExtensionShowView getShowView(Flow flow, HttpServletRequest req, User user, URIParser uriParser) throws TransformerException, SQLException {

		if (!AccessUtils.checkAccess(user, this.moduleDescriptor)) {

			return null;
		}

		Document doc = createDocument(req);

		Element showViewElement = doc.createElement("ShowExtraParameters");
		doc.getDocumentElement().appendChild(showViewElement);

		List<FlowInstanceExtraParameter> parameters = getExtraParameters(flow.getFlowFamily());

		Element parametersElement = XMLUtils.appendNewElement(doc, showViewElement, "FlowInstanceExtraParameters");

		boolean enabled = false;

		if (parameters != null) {

			XMLUtils.append(doc, parametersElement, parameters);
			enabled = true;
		}

		showViewElement.appendChild(flow.toXML(doc));

		return new FlowAdminExtensionShowView(viewFragmentTransformer.createViewFragment(doc, true), enabled);
	}

	private boolean hasExtraParameters(ImmutableFlowFamily flowFamily) throws SQLException {

		HighLevelQuery<FlowInstanceExtraParameter> query = new HighLevelQuery<>();

		query.addParameter(flowFamilyIDParamFactory.getParameter(flowFamily.getFlowFamilyID()));

		return parameterDAO.getBoolean(query);
	}

	private List<FlowInstanceExtraParameter> getExtraParameters(ImmutableFlowFamily flowFamily) throws SQLException {

		HighLevelQuery<FlowInstanceExtraParameter> query = new HighLevelQuery<>();

		query.addParameter(flowFamilyIDParamFactory.getParameter(flowFamily.getFlowFamilyID()));

		return parameterDAO.getAll(query);
	}

	public Document createDocument(HttpServletRequest req) {

		Document doc = XMLUtils.createDomDocument();
		Element document = doc.createElement("Document");

		XMLUtils.appendNewElement(doc, document, "ModuleURI", req.getContextPath() + getFullAlias());
		XMLUtils.appendNewElement(doc, document, "StaticContentURL", staticContentModule.getModuleContentURL(moduleDescriptor));

		doc.appendChild(document);

		return doc;
	}

	@WebPublic(alias = "update")
	public ForegroundModuleResponse updateFlowExtraParameters(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		Flow flow = flowAdminModule.getRequestedFlow(req, user, uriParser);

		if (flow == null) {

			return flowAdminModule.list(req, res, user, uriParser, new ValidationError("FlowNotFound"));

		} else if (!flowAdminModule.hasFlowAccess(user, flow)) {

			throw new AccessDeniedException("User does not have access to flow type " + flow.getFlowType());
		}

		ValidationException validationException = null;

		if (req.getMethod().equalsIgnoreCase("POST")) {

			List<FlowInstanceExtraParameter> parameters = new ArrayList<>();

			try {

				String[] parameterIDs = req.getParameterValues("parameterID");

				if (parameterIDs != null) {

					List<ValidationError> validationErrors = new ArrayList<>();

					for (String parameterID : parameterIDs) {

						String name = ValidationUtils.validateParameter("name-" + parameterID, paramNameDisplayName, req, true, 1, 255, StringPopulator.getPopulator(), validationErrors);
						String value = ValidationUtils.validateParameter("value-" + parameterID, paramValueDisplayName, req, true, 1, 1024, StringPopulator.getPopulator(), validationErrors);

						if (validationErrors.isEmpty()) {

							FlowInstanceExtraParameter parameter = new FlowInstanceExtraParameter();
							parameter.setFlowFamilyID(flow.getFlowFamily().getFlowFamilyID());

							parameter.setName(name);
							parameter.setValue(value);
							parameters.add(parameter);
						}
					}

					if (!validationErrors.isEmpty()) {

						throw new ValidationException(validationErrors);
					}

				}

				log.info("User " + user + " updating extra parameters for flow " + flow);

				List<FlowInstanceExtraParameter> oldParameters = getExtraParameters(flow.getFlowFamily());

				if (!CollectionUtils.isEmpty(oldParameters)) {

					parameterDAO.delete(oldParameters);
				}

				if (!CollectionUtils.isEmpty(parameters)) {

					parameterDAO.addAll(parameters, null);
				}

				flowAdminModule.redirectToMethod(req, res, "/showflow/" + flow.getFlowID() + "#extraparameters");

				return null;

			} catch (ValidationException e) {

				validationException = e;
			}
		}

		log.info("User " + user + " requesting update extra parameters form for flow " + flow);

		List<FlowInstanceExtraParameter> parameters = getExtraParameters(flow.getFlowFamily());

		Document doc = createDocument(req);

		Element updateExtraParametersElement = doc.createElement("UpdateExtraParameters");
		doc.getDocumentElement().appendChild(updateExtraParametersElement);

		updateExtraParametersElement.appendChild(flow.toXML(doc));

		Element extraParametersElement = XMLUtils.appendNewElement(doc, updateExtraParametersElement, "FlowInstanceExtraParameters");

		XMLUtils.append(doc, extraParametersElement, parameters);

		if (validationException != null) {

			updateExtraParametersElement.appendChild(validationException.toXML(doc));
			updateExtraParametersElement.appendChild(RequestUtils.getRequestParameters(req, doc));
		}

		return new SimpleForegroundModuleResponse(doc, this.getDefaultBreadcrumb());
	}

	@WebPublic(alias = "delete")
	public ForegroundModuleResponse deleteFlowExtraParameters(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		if (!HTTPUtils.isPost(req)) {

			throw new AccessDeniedException("Delete requests using method " + req.getMethod() + " are not allowed.");
		}

		Flow flow = flowAdminModule.getRequestedFlow(req, user, uriParser);

		if (flow == null) {

			return flowAdminModule.list(req, res, user, uriParser, new ValidationError("FlowNotFound"));

		} else if (!flowAdminModule.hasFlowAccess(user, flow)) {

			throw new AccessDeniedException("User does not have access to flow type " + flow.getFlowType());
		}

		List<FlowInstanceExtraParameter> parameters = getExtraParameters(flow.getFlowFamily());

		if (parameters != null) {

			log.info("User " + user + " deleting extra parameters for flow " + flow);

			parameterDAO.delete(parameters);

			//TODO add event to flow family history

		} else {

			log.warn("User " + user + " trying to delete extra parameters for flow " + flow + " which has no extra parameters");
		}

		flowAdminModule.redirectToMethod(req, res, "/showflow/" + flow.getFlowID() + "#extraparameters");

		return null;
	}

	@Override
	public String getExtensionViewTitle() {

		return moduleDescriptor.getName();
	}

	@Override
	public int getPriority() {

		return priority;
	}

	@Override
	public ForegroundModuleDescriptor getModuleDescriptor() {

		return moduleDescriptor;
	}

	@Override
	public List<LinkTag> getLinkTags() {

		return links;
	}

	@Override
	public List<ScriptTag> getScriptTags() {

		return scripts;
	}

	@InstanceManagerDependency(required = true)
	public void setFlowAdminModule(FlowAdminModule flowAdminModule) {

		if (flowAdminModule == null && this.flowAdminModule != null) {

			this.flowAdminModule.removeExtensionViewProvider(this);
			this.flowAdminModule.removeXSDExtensionProvider(this);
		}

		this.flowAdminModule = flowAdminModule;

		if (this.flowAdminModule != null) {

			this.flowAdminModule.addExtensionViewProvider(this);
			this.flowAdminModule.addXSDExtensionProvider(this);
		}
	}

	@Override
	public boolean supportFlowInstance(ImmutableFlowInstance flowInstance) throws SQLException {

		return hasExtraParameters(flowInstance.getFlow().getFlowFamily());
	}

	@Override
	public void processXML(ImmutableFlowInstance flowInstance, Document doc) throws SQLException {

		List<FlowInstanceExtraParameter> parameters = getExtraParameters(flowInstance.getFlow().getFlowFamily());

		if (CollectionUtils.isEmpty(parameters)) {

			return;
		}

		TagReplacer tagReplacer = new TagReplacer();

		tagReplacer.addTagSource(FLOWINSTANCE_TAG_SOURCE_FACTORY.getTagSource((FlowInstance) flowInstance));
		tagReplacer.addTagSource(FLOW_TAG_SOURCE_FACTORY.getTagSource((Flow) flowInstance.getFlow()));

		tagReplacer.addTagSource(new SingleTagSource("$flowInstance.url", standardFlowNotificationHandler.getFlowInstanceAdminModuleAlias(flowInstance) + "/overview/" + flowInstance.getFlow().getFlowID() + "/" + flowInstance.getFlowInstanceID()));

		AttributeHandler attributeHandler = flowInstance.getAttributeHandler();

		Element element = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), containingElementName);

		Element parametersElement = XMLUtils.appendNewElement(doc, element, "Parameters");

		for (FlowInstanceExtraParameter parameter : parameters) {

			Element parameterElement = doc.createElement("Parameter");

			XMLUtils.appendNewElement(doc, parameterElement, "Name", parameter.getName());
			
			String value = AttributeTagUtils.replaceTags(parameter.getValue(), attributeHandler);
			
			XMLUtils.appendNewCDATAElement(doc, parameterElement, "Value", tagReplacer.replace(value));

			parametersElement.appendChild(parameterElement);
		}
	}

	@Override
	public void processXSD(ImmutableFlow flow, Document doc) throws SQLException {

		List<FlowInstanceExtraParameter> parameters = getExtraParameters(flow.getFlowFamily());

		if (CollectionUtils.isEmpty(parameters)) {
			return;
		}

		try {
			{
				Element flowInstanceTypeNode = (Element) PooledXPathFactory.newXPath().evaluate("/schema/complexType[@name='FlowInstance']/sequence", doc.getDocumentElement(), XPathConstants.NODE);

				Element containingElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
				containingElement.setAttribute("name", containingElementName);
				containingElement.setAttribute("type", containingElementName + "Type");
				containingElement.setAttribute("minOccurs", "1");
				containingElement.setAttribute("maxOccurs", "1");
				flowInstanceTypeNode.appendChild(containingElement);
			}

			Element containingTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
			containingTypeElement.setAttribute("name", containingElementName + "Type");
			doc.getDocumentElement().appendChild(containingTypeElement);

			Element containingTypeSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
			containingTypeElement.appendChild(containingTypeSequenceElement);

			Element parametersElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
			parametersElement.setAttribute("name", "Parameters");
			parametersElement.setAttribute("minOccurs", "1");
			parametersElement.setAttribute("maxOccurs", "1");
			containingTypeSequenceElement.appendChild(parametersElement);

			Element parametersTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
			parametersElement.appendChild(parametersTypeElement);

			Element parametersSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
			parametersTypeElement.appendChild(parametersSequenceElement);

			Element parameterElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
			parameterElement.setAttribute("name", "Parameter");
			parameterElement.setAttribute("minOccurs", "" + parameters.size());
			parameterElement.setAttribute("maxOccurs", "" + parameters.size());
			parametersSequenceElement.appendChild(parameterElement);

			Element parameterTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
			parameterElement.appendChild(parameterTypeElement);

			Element parameterSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
			parameterTypeElement.appendChild(parameterSequenceElement);

			Element nameElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
			nameElement.setAttribute("name", "Name");
			nameElement.setAttribute("minOccurs", "1");
			nameElement.setAttribute("maxOccurs", "1");
			parameterSequenceElement.appendChild(nameElement);

			Element nameTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:simpleType");
			nameElement.appendChild(nameTypeElement);

			Element nameRestrictionElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:restriction");
			nameRestrictionElement.setAttribute("base", "xs:string");
			nameTypeElement.appendChild(nameRestrictionElement);

			for (FlowInstanceExtraParameter parameter : parameters) {

				Element nameEnumerationElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:enumeration");
				nameEnumerationElement.setAttribute("value", parameter.getName());
				nameRestrictionElement.appendChild(nameEnumerationElement);
			}

			Element valueElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
			valueElement.setAttribute("name", "Value");
			valueElement.setAttribute("type", "xs:string");
			valueElement.setAttribute("minOccurs", "0");
			valueElement.setAttribute("maxOccurs", "1");
			parameterSequenceElement.appendChild(valueElement);

		} catch (XPathException e) {

			log.error("Error finding FlowInstance node", e);
		}
	}

	@EventListener(channel = FlowFamily.class)
	public void processEvent(CRUDEvent<FlowFamily> event, EventSource eventSource) {

		if (event.getAction() == CRUDAction.DELETE) {

			for (FlowFamily flowFamily : event.getBeans()) {

				log.info("Deleting extra XML parameters for flow family ID: " + flowFamily.getFlowFamilyID());

				try {
					HighLevelQuery<FlowInstanceExtraParameter> query = new HighLevelQuery<>();

					query.addParameter(flowFamilyIDParamFactory.getParameter(flowFamily.getFlowFamilyID()));

					parameterDAO.delete(query);

				} catch (SQLException e) {

					log.error("Error deleting extra XML parameters for flow family ID: " + flowFamily.getFlowFamilyID(), e);
				}
			}
		}
	}

	@Override
	public int getModuleID() {

		return moduleDescriptor.getModuleID();
	}

}
