<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl"/>
	
	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-migrate.js?v=1
		/jquery/jquery-ui.js?v=1
		/jquery/plugins/jquery.qloader.js
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
		/tablesorter/js/jquery.tablesorter.min.js
	</xsl:variable>
	
	<xsl:variable name="globallinks">
		/css/openhierarchy-jquery-ui.css
	</xsl:variable>
	
	<xsl:variable name="scripts">
		/js/flowengine.tablesorter.js
		/js/flowengine.tablefilter.js
		/js/jquery.ui.datepicker-sv.js
		/js/datatables.min.js
		/js/jquery.qloader-init.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css
		/css/datatables.css
		/css/overrides.css
	</xsl:variable>

	<xsl:template match="Document">
		
		<xsl:choose>
			<xsl:when test="UpdateFlowInstanceStatuses or AddFlowInstanceManagers">
			
				<div class="contentitem errands-wrapper">
					<xsl:apply-templates select="UpdateFlowInstanceStatuses" />
					<xsl:apply-templates select="AddFlowInstanceManagers" />
				</div>
			
			</xsl:when>
			<xsl:otherwise>
			
				<div id="FlowBrowser" class="contentitem errands-wrapper">
					<xsl:apply-templates select="ListFamilies" />
					<xsl:apply-templates select="ListFlowVersions" />
					<xsl:apply-templates select="ListFlowInstances" />
					<xsl:apply-templates select="SendMessageForm" />
				</div>
			
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

	<xsl:template match="ListFamilies">
	
		<div class="floatright marginbottom">
			<label for="name" class="marginright margintop"><xsl:value-of select="$i18n.Filter" />:</label>
			<input type="text" size="20" name="filter-input" class="filter-input" data-tableid="flowlist" /> 
		</div>
	
		<h1><xsl:value-of select="$i18n.Flowslist.title" /></h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<p>
			<xsl:value-of select="$i18n.Flowlist.description" />
		</p>
		
		<table id="flowlist" class="full coloredtable oep-table" cellspacing="0">
			<thead class="sortable">	
				<tr>
					<th width="25" class="no-sort"></th>
					<th class="default-sort"><xsl:value-of select="$i18n.flowName" /></th>
					<th><xsl:value-of select="$i18n.flowType" /></th>
					<th><xsl:value-of select="$i18n.versions" /></th>
					<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
					<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
				</tr>
			</thead>
			<tbody>
				<xsl:choose>
					<xsl:when test="not(Flow)">
						<tr>
							<td class="icon"></td>
							<td colspan="7">
								<xsl:value-of select="$i18n.noFlowsFound" />
							</td>
						</tr>
					</xsl:when>
					<xsl:otherwise>
						
						<xsl:apply-templates select="Flow[latestVersion = 'true']" mode="list"/>
						
					</xsl:otherwise>
				</xsl:choose>
			</tbody>
		</table>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list">
		
		<tr>
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td data-title="{$i18n.flowName}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="name" /></a>
			</td>
			<td data-title="{$i18n.flowType}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="FlowType/name" /></a>
			</td>
			<td data-title="{$i18n.versions}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="VersionCount" /></a>
			</td>
			<td data-title="{$i18n.SubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="SubmittedInstanceCount" /></a>
			</td>
			<td data-title="{$i18n.NotSubmittedInstances}">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}"><xsl:value-of select="InstanceCount - SubmittedInstanceCount" /></a>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ListFlowVersions">
	
		<script>
			$(function() {
				if (!Modernizr.inputtypes.date) {
					$( "#fromDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.fromDate"/>',
						changeMonth: true,
	            		changeYear: true,
	            		showWeek: true,
					});
					
					$( "#toDate" ).datepicker({
						showOn: "button",
						buttonImage: '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics/calendar_grid.png',
						buttonImageOnly: true,
						buttonText: '<xsl:value-of select="$i18n.toDate"/>',
						changeMonth: true,
	            		changeYear: true,
	            		showWeek: true,
					});
				}
			});	
		</script>
		
		<div class="floatright">
			
		</div>
		
		<h1>
			<xsl:value-of select="Flow[position() = last()]/name"/>
		</h1>
		
		<xsl:apply-templates select="validationError"/>

		<p><xsl:value-of select="$i18n.versions.description"/></p>
		
		<form method="get">
		
			<table id="flowversionlist" class="full coloredtable sortabletable oep-table floatleft" cellspacing="0">
				<thead>	
					<tr>
						<th width="15"></th>
						<th width="25"></th>
						<th><xsl:value-of select="$i18n.name" /></th>
						<th width="50"><xsl:value-of select="$i18n.version.title" /></th>
						<th width="30"><xsl:value-of select="$i18n.steps" /></th>
						<th width="50"><xsl:value-of select="$i18n.queries" /></th>
						<th width="100"><xsl:value-of select="$i18n.SubmittedInstances" /></th>
						<th width="115"><xsl:value-of select="$i18n.NotSubmittedInstances" /></th>
						<th width="80"><xsl:value-of select="$i18n.status" /></th>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="Flow" mode="list-versions"/>
				</tbody>
			</table>
			
			<br/>
			
			<div class="full">
				<div class="marginleft floatleft">
					
					<label for="fromDate" class="marginright">
						<xsl:value-of select="$i18n.fromDate" />
					</label>
					
					<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'fromDate'" />
							<xsl:with-param name="id" select="'fromDate'" />
							<xsl:with-param name="size" select="10" />
							<xsl:with-param name="type" select="'date'"/>
							<xsl:with-param name="class" select="'width-auto'"/>
					</xsl:call-template>
				</div>
				
				<div class="bigmarginleft floatleft">
					
					<label for="toDate" class="marginright">
						<xsl:value-of select="$i18n.toDate" />
					</label>
					
					<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'toDate'" />
							<xsl:with-param name="id" select="'toDate'" />
							<xsl:with-param name="size" select="10" />
							<xsl:with-param name="type" select="'date'"/>
							<xsl:with-param name="class" select="'width-auto'"/>
					</xsl:call-template>
				</div>
				
				<div class="floatright marginright bigmargintop">
					
					<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}" title="{$i18n.Back}">
						<xsl:value-of select="$i18n.Back"/>
					</a>
					
					<input class="btn btn-blue btn-inline marginright" type="submit" value="{$i18n.ShowSubmittedInstances}" onclick="this.form.action = '{/Document/requestinfo/currentURI}/{/Document/module/alias}/instances/{FlowFamily/flowFamilyID}'" title="{$i18n.ShowSubmittedInstancesTitle}"/>
					
					<input class="btn btn-blue btn-inline marginright" type="submit" value="{$i18n.SendMessages}" onclick="this.form.action = '{/Document/requestinfo/currentURI}/{/Document/module/alias}/sendMessages/{FlowFamily/flowFamilyID}'" title="{$i18n.SendMessages}"/>
					
					<input class="btn btn-green btn-inline marginright" type="submit" value="{$i18n.ExportFlowInstancesAsExcel}" onclick="alert('{$i18n.ExportFlowInstancesAsExcel.Deprecated}'); return false;" title="{$i18n.ExportFlowInstancesAsExcel.Deprecated}"/>
					
					<input class="btn btn-green btn-inline" type="submit" value="{$i18n.ExportFlowInstancesAsPDF}" onclick="this.form.action = '{/Document/requestinfo/currentURI}/{/Document/module/alias}/exportpdf/{FlowFamily/flowFamilyID}'" title="{$i18n.ExportFlowInstancesAsPDF}"/>
				</div>
			</div>		
		</form>
	
	</xsl:template>
	
	<xsl:template match="Flow" mode="list-versions">
		
		<tr>
			<td>
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="name" select="'flowID'"/>
					<xsl:with-param name="value" select="flowID"/>
					<xsl:with-param name="requestparameters" select="../requestparameters"/>
					
					<xsl:with-param name="disabled">
					
						<xsl:if test="enabled = 'false'">
							<xsl:text>true</xsl:text>
						</xsl:if>
					
					</xsl:with-param>
					
				</xsl:call-template>
			</td>			
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}" width="25" alt="" />
			</td>
			<td>
				<xsl:value-of select="name" />
			</td>
			<td>
				<xsl:value-of select="version" />
			</td>	
			<td>
				<xsl:value-of select="count(Steps/Step)" />
			</td>
			<td>
				<xsl:value-of select="count(Steps/Step/QueryDescriptors/QueryDescriptor)" />
			</td>
			<td>
				<xsl:value-of select="flowSubmittedInstanceCount" />
			</td>
			<td>
				<xsl:value-of select="flowInstanceCount - flowSubmittedInstanceCount" />
			</td>
			<td>
					<xsl:choose>
						<xsl:when test="enabled = 'false'">
							<xsl:value-of select="$i18n.disabled" />
						</xsl:when>
						<xsl:when test="published = 'true'">
							<xsl:value-of select="$i18n.published" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.notPublished" />
						</xsl:otherwise>
					</xsl:choose>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="ListFlowInstances">
	
		<h1>
			<xsl:value-of select="Flows/Flow[position() = last()]/name"/>
		</h1>
		
		<div id="table-description" class="floatleft" style="max-width: calc(100% - 220px);">
			<p><xsl:value-of select="$i18n.instances.description"/></p>
		</div>

		<table id="flowversionlist" class="stripe display">
			<thead>
				<tr>
					<th><input id="select-page" type="checkbox"/></th>
					<th><xsl:value-of select="$i18n.Column.InstanceID" /></th>
					<th><xsl:value-of select="$i18n.Column.Poster" /></th>
					<th><xsl:value-of select="$i18n.status" /></th>
					<th><xsl:value-of select="$i18n.Column.SubmittedDate" /></th>
					<th><xsl:value-of select="$i18n.Column.FlowName" /></th>
					<th><xsl:value-of select="$i18n.version.title" /></th>
					<th/>
				</tr>
			</thead>
			<tbody/>
		</table>
		
		<xsl:variable name="ajaxURL">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/instancedata/</xsl:text>
			<xsl:value-of select="FlowSelection/FlowFamily/flowFamilyID"/>
			
			<xsl:if test="FlowSelection/fromDate or FlowSelection/toDate or FlowSelection/flowIDs">
				<xsl:text>?</xsl:text>
			
				<xsl:if test="FlowSelection/fromDate">
					<xsl:text>fromDate=</xsl:text>
					<xsl:value-of select="FlowSelection/fromDate"/>
				</xsl:if>
				
				<xsl:if test="FlowSelection/toDate">
					<xsl:if test="FlowSelection/fromDate">&amp;</xsl:if>
					<xsl:text>toDate=</xsl:text>
					<xsl:value-of select="FlowSelection/toDate"/>
				</xsl:if>
				
				<xsl:if test="FlowSelection/flowIDs">
				
					<xsl:if test="FlowSelection/fromDate or FlowSelection/toDate">&amp;</xsl:if>
				
					<xsl:for-each select="FlowSelection/flowIDs/value">
					
						<xsl:if test="position() > 1">&amp;</xsl:if>
						
						<xsl:text>flowID=</xsl:text>
						<xsl:value-of select="."/>
					</xsl:for-each>
					
				</xsl:if>
			</xsl:if>
			
		</xsl:variable>
		
		<script type="text/javascript">
			$(function() {
			
				var table = $('#flowversionlist').DataTable({
					ajax: { url: '<xsl:value-of select="$ajaxURL"/>',
							dataSrc: 'rows',
							beforeSend: function(jqXHR, settings) {
								jqXHR.setRequestHeader('NoLoginRedirect', 'true');
							},
							error: function(jqXHR, textStatus, errorThrown) {
								
								if (jqXHR.status == 403) { // Access denied
									window.location.reload();
									
								} else {
									$('#flowversionlist').find("td.dataTables_empty").text('<xsl:value-of select="$i18n.DataTable.fetchError"/>');
									
									if (console != undefined) {
										console.error(errorThrown);
									}
								}
							}
					},
					deferRender: true,
					columns: [
						{ "name": "select", className: 'select-checkbox', orderable: false, searchable: false },
						{ "name": "instanceID" },
						{ "name": "poster", render: $.fn.dataTable.render.text() },
						{ "name": "status", render: $.fn.dataTable.render.text() },
						{ "name": "submitted" },
						{ "name": "flowName", render: $.fn.dataTable.render.text() },
						{ "name": "version" },
						{ "name": "searchExtra", "visible": false }
					],
					order: [[ 1, 'desc' ]],
					dom: 'frtipl',
					bAutoWidth: false,
					paging: true,
					pagingType: 'simple_numbers',
					pageLength: <xsl:value-of select="PageSize"/>,
					lengthMenu: [ 15, 50, 100, 200, 500 ],
					select: {
						style:    'multi',
						selector: 'td:first-child'
					},
					language: {
						"decimal":        "<xsl:value-of select="$i18n.DataTable.decimal"/>",
						"emptyTable":     "<xsl:value-of select="$i18n.DataTable.emptyTable"/>",
						"info":           "<xsl:value-of select="$i18n.DataTable.info"/>",
						"infoEmpty":      "<xsl:value-of select="$i18n.DataTable.infoEmpty"/>",
						"infoFiltered":   "<xsl:value-of select="$i18n.DataTable.infoFiltered"/>",
						"infoPostFix":    "<xsl:value-of select="$i18n.DataTable.infoPostFix"/>",
						"thousands":      "<xsl:value-of select="$i18n.DataTable.thousands"/>",
						"lengthMenu":     "<xsl:value-of select="$i18n.DataTable.lengthMenu"/>",
						"loadingRecords": "<xsl:value-of select="$i18n.DataTable.loadingRecords"/>",
						"processing":     "<xsl:value-of select="$i18n.DataTable.processing"/>",
						"search":         "<xsl:value-of select="$i18n.DataTable.search"/>",
						"zeroRecords":    "<xsl:value-of select="$i18n.DataTable.zeroRecords"/>",
						paginate: {
							"first":      "<xsl:value-of select="$i18n.DataTable.paginate.first"/>",
							"last":       "<xsl:value-of select="$i18n.DataTable.paginate.last"/>",
							"next":       "<xsl:value-of select="$i18n.DataTable.paginate.next"/>",
							"previous":   "<xsl:value-of select="$i18n.DataTable.paginate.previous"/>"
						},
						aria: {
							"sortAscending":  "<xsl:value-of select="$i18n.DataTable.aria.sortAscending"/>",
							"sortDescending": "<xsl:value-of select="$i18n.DataTable.aria.sortDescending"/>"
						},
						select: {
							rows: {
								_: "<xsl:value-of select="$i18n.DataTable.selection.many"/>",
								0: "<xsl:value-of select="$i18n.DataTable.selection.none"/>",
								1: "<xsl:value-of select="$i18n.DataTable.selection.one"/>"
							}
						},
					},
					stateSave: true,
					stateSaveParams: function (settings, data) {
						data.search.search = "";
					},
					preDrawCallback: function(settings) {
					
						// Remove callback
						settings.aoPreDrawCallback.splice(0, 1);
						
						settings.oClasses.sPageButton = "btn btn-inline btn-light";
					},
				});
				
				$("#flowversionlist_wrapper").prepend($("#table-description"));
				
				table.on( 'change', '#select-page', function() {
				
					var checkbox = $(this);
					
					var visibleRows = table.rows({ page: 'current', filter: 'applied' });
					
					if(checkbox.prop("checked")){
					
						visibleRows.select();
					
					} else {
					
						visibleRows.deselect();
					}
				});
				
				table.on( 'click', 'tbody td', function() {
				
					var td = $(this);
					var tr = td.parent();
					
					if(tr.children("td").first().hasClass("dataTables_empty")){
						return;
					}
					
					if(tr.closest("table").hasClass("collapsed") &amp;&amp; td.is(":first-child")){
						return;
					}
					
					if(td.is(":first-child")){
						return;
					}
					
					var flowID = table.cell(tr, "instanceID:name").data();
					window.open("<xsl:value-of select="ServerURL"/><xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="FlowInstanceAdminFullAlias"/>/overview/" + flowID);
				});
				
				var changeStatusButton = $("#changestatuses");
				
				var isValidStatusSelection = function(){
				
					var validSelection = true;
					
					var rows = table.rows({ selected: true });
					
					if (rows.any()) {
					
						var versionCells = table.cells(rows.toArray()[0], "version:name");
						var data = versionCells.data();
						var uniqueData = data.unique();
						
						if(uniqueData.count() > 1){
							validSelection = false;
						}
					}
					
					return validSelection;
				}
				
				var updateChangeStatusButton = function(){
					
					if (isValidStatusSelection()) {
					
						changeStatusButton.removeClass("btn-light").addClass("btn-green");
					
					} else {
					
						changeStatusButton.removeClass("btn-green").addClass("btn-light");
					}
				}
				
				table.on( 'select.dt', function() {
					updateChangeStatusButton();
				});
				
				table.on( 'deselect.dt', function() {
					updateChangeStatusButton();
				});
				
				var clearSelection = function(){
					var rows = table.rows({ selected: true }).deselect();
					changeStatusButton.removeClass("btn-light").addClass("btn-green");
					
					$("#select-page").attr("checked", false);
				}
				
				table.on( 'page.dt', function() {
					clearSelection();
				});
				
				table.on( 'length.dt', function() {
					clearSelection();
				});
				
				table.on( 'search.dt', function() {
					clearSelection();
				});
				
				changeStatusButton.on("click", function(){
				
					var rows = table.rows({ selected: true });
					
					if (!rows.any()) {

						alert("<xsl:value-of select="$i18n.NothingSelected"/>");
					
					} else if (!isValidStatusSelection()) {
					
						alert("<xsl:value-of select="$i18n.MultipleFlowsSelected"/>");
					
					} else {
					
						var cells = table.cells(rows.toArray()[0], "instanceID:name");
						var selectedIDs = cells.data().toArray();
						
						var form = $("#dummyForm");
						form.attr("action", "<xsl:value-of select="ServerURL"/><xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="/Document/fullAlias"/>/updatestatuses/<xsl:value-of select="FlowSelection/FlowFamily/flowFamilyID"/>");
						
						for (var i = 0, len = selectedIDs.length; len > i; i++) {
						
							var field = $('<input/>');

							field.attr("type", "hidden");
							field.attr("name", "flowInstanceID");
							field.attr("value", selectedIDs[i]);
			
							form.append(field);
						}
						
						form.trigger("submit");
					}
				});
				
				var addManagersButton = $("#addmanagers");
				addManagersButton.on("click", function(){
				
					var rows = table.rows({ selected: true });
					
					if (!rows.any()) {

						alert("<xsl:value-of select="$i18n.NothingSelected"/>");
					
					} else {
					
						var cells = table.cells(rows.toArray()[0], "instanceID:name");
						var selectedIDs = cells.data().toArray();
						
						var form = $("#dummyForm");
						form.attr("action", "<xsl:value-of select="ServerURL"/><xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="/Document/fullAlias"/>/addmanagers/<xsl:value-of select="FlowSelection/FlowFamily/flowFamilyID"/>");
						
						for (var i = 0, len = selectedIDs.length; len > i; i++) {
						
							var field = $('<input/>');

							field.attr("type", "hidden");
							field.attr("name", "flowInstanceID");
							field.attr("value", selectedIDs[i]);
			
							form.append(field);
						}
						
						form.trigger("submit");
					}
				});
			});
		</script>
		
		<div class="floatright marginleft bigmargintop">
			<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowSelection/FlowFamily/flowFamilyID}" title="{$i18n.Back}">
				<xsl:value-of select="$i18n.Back"/>
			</a>
			
			<a id="changestatuses" class="btn btn-green btn-inline marginright" href="#" onclick="return false;" title="{$i18n.UpdateFlowInstanceStatuses.Button}">
				<xsl:value-of select="$i18n.UpdateFlowInstanceStatuses.Button"/>
			</a>
			
			<a id="addmanagers" class="btn btn-green btn-inline marginright" href="#" onclick="return false;" title="{$i18n.AddFlowInstanceManagers.Button}">
				<xsl:value-of select="$i18n.AddFlowInstanceManagers.Button"/>
			</a>
			
			<div style="display: none;">
				<form id="dummyForm" method="POST">
				
					<xsl:call-template name="createHiddenField">
						<xsl:with-param name="name" select="'directFromInstanceList'"/>
						<xsl:with-param name="value" select="true"/>
					</xsl:call-template>
				
					<xsl:apply-templates select="FlowSelection" />
				</form>
			</div>
		</div>
	
	</xsl:template>
	
	<xsl:template match="SendMessageForm">
	
		<script type="text/javascript">
			$(function() {
			
				var sendEmail = $("#send-email");
				var sendSMS = $("#send-sms");
				var sendExternalMessage = $("#send-external-message");
				
				var userTags = $("#user-tags");
				userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				
				
				var sendEmailBox = $("#email-text-box");
				sendEmailBox.toggle(sendEmail.prop("checked"));
				
				sendEmail.on("click", function(){
					sendEmailBox.toggle(sendEmail.prop("checked"));
					userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				});
				
				
				var sendSMSBox = $("#sms-text-box");
				sendSMSBox.toggle(sendSMS.prop("checked"));
				
				sendSMS.on("click", function(){
					sendSMSBox.toggle(sendSMS.prop("checked"));
					userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				});
				
				
				var sendExternalMessageBox = $("#external-message-text-box");
				sendExternalMessageBox.toggle(sendExternalMessage.prop("checked"));
				
				sendExternalMessage.on("click", function(){
					sendExternalMessageBox.toggle(sendExternalMessage.prop("checked"));
					userTags.toggle(sendSMS.prop("checked") || sendEmail.prop("checked") || sendExternalMessage.prop("checked"));
				});				
			});
		</script>
		
		<div>
		
			<h1>
				<xsl:value-of select="$i18n.SendMessageTitle"/>
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="FlowFamilyName"/>
				
				<xsl:choose>
					<xsl:when test="FlowSelection/fromDate and FlowSelection/toDate">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleBetween"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/fromDate"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleBetween2"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/toDate"/>
					</xsl:when>
					<xsl:when test="FlowSelection/fromDate">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleAfter"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/fromDate"/>
					</xsl:when>
					<xsl:when test="FlowSelection/toDate">
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$i18n.SendMessageTitleBefore"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowSelection/toDate"/>
					</xsl:when>
				</xsl:choose>
			</h1>
			
			<br/>
			
			<xsl:if test="SentEmails or SentSMSs or SentExternalMessages">
				
				<xsl:if test="SentEmails">
					<div class="border-radius-small lightbackground padding bigmarginbottom">
						<strong>
							<xsl:value-of select="$i18n.SendMessage.EmailsSent"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="SentEmails"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part1"/>
							
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="FlowInstanceCount"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part2"/>
						</strong>
					</div>
				</xsl:if>
				<xsl:if test="SentSMSs">
					<div class="border-radius-small lightbackground padding bigmarginbottom">
						<strong>
							<xsl:value-of select="$i18n.SendMessage.SMSsSent"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="SentSMSs"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part1"/>
							
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="FlowInstanceCount"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part2"/>
						</strong>
					</div>
				</xsl:if>
				<xsl:if test="SentExternalMessages">
					<div class="border-radius-small lightbackground padding bigmarginbottom">
						<strong>
							<xsl:value-of select="$i18n.SendMessage.SentExternalMessages"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="SentExternalMessages"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part1"/>
							
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="FlowInstanceCount"/>
							<xsl:text>&#160;</xsl:text>
							<xsl:value-of select="$i18n.SendMessage.MessagesSent.part2"/>
						</strong>
						<br/>
					</div>
				</xsl:if>
				
			</xsl:if>
			
			<xsl:if test="ValidationErrors/validationError">
			
				<xsl:apply-templates select="ValidationErrors/validationError" />
				
				<br/>
			</xsl:if>
			
			
			<form method="post" action="{/Document/requestinfo/uri}"  enctype="multipart/form-data">
				
				<xsl:apply-templates select="FlowSelection"/>
				
				<h2><xsl:value-of select="$i18n.SendMessage.Transport"/></h2>
				
				<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.Transport.description"/></p>
				
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'send-email'" />
						<xsl:with-param name="name" select="'send-email'" />
					</xsl:call-template>
					
					<label for="send-email">
						<xsl:value-of select="$i18n.SendMessage.SendEmail" />
					</label>
				</div>
				
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'send-sms'" />
						<xsl:with-param name="name" select="'send-sms'" />
					</xsl:call-template>
					
					<label for="send-sms">
						<xsl:value-of select="$i18n.SendMessage.SendSMS" />
					</label>
				</div>
				
				<div class="floatleft full bigmarginbottom">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'send-external-message'" />
						<xsl:with-param name="name" select="'send-external-message'" />
					</xsl:call-template>
					
					<label for="send-external-message">
						<xsl:value-of select="$i18n.SendMessage.SendExternalMessage" />
					</label>
				</div>				
				
				<div class="floatleft full bigmargintop bigmarginbottom">
				
					<h2><xsl:value-of select="$i18n.SendMessage.statusContentType.title"/></h2>
			
					<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.statusContentType.description"/></p>
					<p class="nomargin"><xsl:value-of select="$i18n.SendMessage.statusContentType.description2"/></p>
					
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'new'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'NEW'"/>
							</xsl:call-template>
							
							<label for="new">
								<xsl:value-of select="$i18n.contentType.NEW" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/NEW" />
								<xsl:text>)</xsl:text>
							</label>					
						</div>
					</div>
					
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'waiting_for_multisign'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'WAITING_FOR_MULTISIGN'"/>
							</xsl:call-template>
							
							<label for="waiting_for_multisign">
								<xsl:value-of select="$i18n.contentType.WAITING_FOR_MULTISIGN" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/WAITING_FOR_MULTISIGN" />
								<xsl:text>)</xsl:text>
							</label>					
						</div>
					</div>
				
					<div class="floatleft full bigmarginleft">
				
						<xsl:choose>
							<xsl:when test="MultiSigningHandler">
							
								<div class="floatleft full">
												
									<div class="floatleft full">
										<xsl:call-template name="createCheckbox">
											<xsl:with-param name="id" select="'multisign_user_not_signed'"/>
											<xsl:with-param name="name" select="'multisign_user_not_signed'"/>
										</xsl:call-template>
										
										<label for="multisign_user_not_signed">
											<xsl:value-of select="$i18n.contentType.WAITING_FOR_MULTISIGN.userNotSigned" />
											<xsl:text>&#160;(</xsl:text>
											<xsl:value-of select="FlowInstanceCounts/WAITING_FOR_MULTISIGN_NotSigned" />
											<xsl:text>)</xsl:text>
										</label>					
									</div>
								</div>
								
								<div class="floatleft full">
												
									<div class="floatleft full">
										<xsl:call-template name="createCheckbox">
											<xsl:with-param name="id" select="'multisign_owner_signed'"/>
											<xsl:with-param name="name" select="'multisign_owner_signed'"/>
										</xsl:call-template>
										
										<label for="multisign_owner_signed">
											<xsl:value-of select="$i18n.contentType.WAITING_FOR_MULTISIGN.ownerSigned" />
											<xsl:text>&#160;(</xsl:text>
											<xsl:value-of select="FlowInstanceCounts/WAITING_FOR_MULTISIGN_OwnerSigned" />
											<xsl:text>)</xsl:text>
										</label>					
									</div>
								</div>
								
<!-- 								<div class="floatleft full"> -->
												
<!-- 									<div class="floatleft full"> -->
<!-- 										<xsl:call-template name="createCheckbox"> -->
<!-- 											<xsl:with-param name="id" select="'multisign_other_signed'"/> -->
<!-- 											<xsl:with-param name="name" select="'multisign_other_signed'"/> -->
<!-- 										</xsl:call-template> -->
										
<!-- 										<label for="multisign_other_signed"> -->
<!-- 											<xsl:value-of select="$i18n.contentType.WAITING_FOR_MULTISIGN.otherSigned" /> -->
<!-- 											<xsl:text>&#160;(</xsl:text> -->
<!-- 											<xsl:value-of select="FlowInstanceCounts/WAITING_FOR_MULTISIGN_OtherSigned" /> -->
<!-- 											<xsl:text>)</xsl:text> -->
<!-- 										</label>					 -->
<!-- 									</div> -->
<!-- 								</div> -->
					
							</xsl:when>
							<xsl:otherwise>
							
								<div class="floatleft full">
												
									<label>
										<xsl:value-of select="$i18n.MultiSigningHandler.missing" />
									</label>			
								</div>
							
							</xsl:otherwise>
						</xsl:choose>
						
					</div>
					
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'waiting_for_payment'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'WAITING_FOR_PAYMENT'"/>
							</xsl:call-template>
							
							<label for="waiting_for_payment">
								<xsl:value-of select="$i18n.contentType.WAITING_FOR_PAYMENT" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/WAITING_FOR_PAYMENT" />
								<xsl:text>)</xsl:text>
							</label>					
						</div>
					</div>
				
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'submitted'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'SUBMITTED'"/>
								<xsl:with-param name="checked" select="'true'"/>
							</xsl:call-template>
							
							<label for="submitted">
								<xsl:value-of select="$i18n.contentType.SUBMITTED" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/SUBMITTED" />
								<xsl:text>)</xsl:text>
							</label>
						</div>
					</div>	
				
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'in_progress'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'IN_PROGRESS'"/>
								<xsl:with-param name="checked" select="'true'"/>
							</xsl:call-template>
							
							<label for="in_progress">
								<xsl:value-of select="$i18n.contentType.IN_PROGRESS" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/IN_PROGRESS" />
								<xsl:text>)</xsl:text>
							</label>
						</div>
					</div>	
					
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'waiting_for_completion'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'WAITING_FOR_COMPLETION'"/>
								<xsl:with-param name="checked" select="'true'"/>
							</xsl:call-template>
							
							<label for="waiting_for_completion">
								<xsl:value-of select="$i18n.contentType.WAITING_FOR_COMPLETION" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/WAITING_FOR_COMPLETION" />
								<xsl:text>)</xsl:text>
							</label>
						</div>
					</div>
				
					<div class="floatleft full">
									
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'archived'"/>
								<xsl:with-param name="name" select="'contentType'"/>
								<xsl:with-param name="value" select="'ARCHIVED'"/>
							</xsl:call-template>
							
							<label for="archived">
								<xsl:value-of select="$i18n.contentType.ARCHIVED" />
								<xsl:text>&#160;(</xsl:text>
								<xsl:value-of select="FlowInstanceCounts/ARCHIVED" />
								<xsl:text>)</xsl:text>
							</label>
						</div>
					</div>
				
				</div>
				
				<div class="floatleft full" id="email-text-box">
					<fieldset class="border-radius-small lightbackground">
						<legend><xsl:value-of select="$i18n.SendMessage.Email"/></legend>
							
						<div class="floatleft full bigmarginbottom">
							<label class="floatleft twenty" for="emailSenderName"><xsl:value-of select="$i18n.SendMessage.SenderName"/>:</label>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSenderName'"/>
									<xsl:with-param name="id" select="'emailSenderName'"/>
								</xsl:call-template>
							</div>
						</div>
						
						<xsl:variable name="senderAddressDisabled">
							<xsl:choose>
								<xsl:when test="DefaultEmailSenderAddress">true</xsl:when>
							</xsl:choose>
						</xsl:variable>
						
						<div class="floatleft full bigmarginbottom">
							<label class="floatleft twenty" for="emailSenderName"><xsl:value-of select="$i18n.SendMessage.SenderAddress"/>:</label>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSenderAddress'" />
									<xsl:with-param name="id" select="'emailSenderAddress'" />
									<xsl:with-param name="value" select="DefaultEmailSenderAddress" />
									<xsl:with-param name="disabled" select="$senderAddressDisabled" />
								</xsl:call-template>
							</div>
						</div>
						
						<div class="floatleft full bigmarginbottom">
							<label class="floatleft twenty" for="emailSubject"><xsl:value-of select="$i18n.SendMessage.Subject"/>:</label>
							<div class="floatleft eighty">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="name" select="'emailSubject'"/>
									<xsl:with-param name="id" select="'emailSubject'"/>
								</xsl:call-template>
							</div>
						</div>
						
						<label class="floatleft full" for="emailMessage"><xsl:value-of select="$i18n.SendMessage.Message"/>:</label>
							
						<div class="floatleft full bigmarginbottom">
						
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="name" select="'emailMessage'"/>
								<xsl:with-param name="id" select="'emailMessage'"/>
								<xsl:with-param name="rows" select="'8'"/>
								<xsl:with-param name="class" select="'flow-ckeditor'"/>
							</xsl:call-template>
							
							<xsl:call-template name="initializeFCKEditor">
								<xsl:with-param name="basePath"><xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/ckeditor/</xsl:with-param>
								<xsl:with-param name="customConfig">config.js</xsl:with-param>
								<xsl:with-param name="editorContainerClass">flow-ckeditor</xsl:with-param>
								<xsl:with-param name="editorHeight">150</xsl:with-param>
								
								<xsl:with-param name="contentsCss">
									<xsl:if test="cssPath">
										<xsl:value-of select="cssPath"/>
									</xsl:if>
								</xsl:with-param>
								
								<xsl:with-param name="filebrowserBrowseUri">
									
									<xsl:choose>
										<xsl:when test="ckConnectorModuleAlias">
											<xsl:text>filemanager/index.html?Connector=</xsl:text>
											<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
											<xsl:text>/connector</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>
									</xsl:choose>
					
								</xsl:with-param>
								
								<xsl:with-param name="filebrowserImageBrowseUri">
								
									<xsl:choose>
										<xsl:when test="ckConnectorModuleAlias">
											<xsl:text>filemanager/index.html?Connector=</xsl:text>
											<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
											<xsl:text>/connector</xsl:text>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>
									</xsl:choose>
								
								</xsl:with-param>
								
							</xsl:call-template>

	  						<div class="heading-wrapper">
	  							<label><xsl:value-of select="$i18n.AttachFiles" /></label>
	  						</div>
	  						
	  						<script>
								imagePath = '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics';
								deleteFile = '<xsl:value-of select="$i18n.DeleteFile" />';
							</script>
							
							<xsl:apply-templates select="validationError[messageKey = 'FileSizeLimitExceeded' or messageKey = 'UnableToParseRequest']" />

							<div class="full">
								
								<div class="upload clearboth">
									<span class="btn btn-upload btn-blue">
										<xsl:value-of select="$i18n.ChooseFiles" />
										<input id="external-message" type="file" name="email-attachments" multiple="multiple" size="55" class="qloader externalmessages bigmarginbottom" />
									</span>
									<span><xsl:value-of select="$i18n.MaximumFileSize" />: <xsl:value-of select="FormatedMaxEmailFileSize" /></span>
								</div>
								
								<ul id="external-message-qloader-filelist" class="files" />
								
							</div>
						
						</div>
							
					</fieldset>
				</div>
				
				<div class="floatleft full" id="sms-text-box">
					<fieldset class="border-radius-small lightbackground">
						<legend><xsl:value-of select="$i18n.SendMessage.SMS"/></legend>
					
						<div class="floatleft full">
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="id" select="'smsMessage'" />
								<xsl:with-param name="name" select="'smsMessage'" />
								<xsl:with-param name="rows" select="5"/>
								<xsl:with-param name="class" select="'border-box'"/>
							</xsl:call-template>
						</div>
					</fieldset>
				</div>
				
				<div class="floatleft full" id="external-message-text-box">
					<fieldset class="border-radius-small lightbackground">
						<legend><xsl:value-of select="$i18n.SendMessage.ExternalMessage"/></legend>
					
						<div class="full">
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="id" select="'externalMessage'" />
								<xsl:with-param name="name" select="'externalMessage'" />
								<xsl:with-param name="rows" select="5"/>
								<xsl:with-param name="class" select="'border-box'"/>
							</xsl:call-template>
						</div>
						
  						<div class="heading-wrapper">
  							<label><xsl:value-of select="$i18n.AttachFiles" /></label>
  						</div>
	  						
  						<script>
							imagePath = '<xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics';
							deleteFile = '<xsl:value-of select="$i18n.DeleteFile" />';
						</script>				
						
						<xsl:apply-templates select="validationError[messageKey = 'FileSizeLimitExceeded' or messageKey = 'UnableToParseRequest']" />

						<div class="full">
							
							<div class="upload clearboth">
								<span class="btn btn-upload btn-blue">
									<xsl:value-of select="$i18n.ChooseFiles" />
									<input id="external-message" type="file" name="external-message-attachments" multiple="multiple" size="55" class="qloader externalmessages bigmarginbottom" />
								</span>
								<span><xsl:value-of select="$i18n.MaximumFileSize" />: <xsl:value-of select="FormatedMaxExternalMessageFileSize" /></span>
							</div>
							
							<ul id="external-message-qloader-filelist" class="files" />
							
						</div>
						
					</fieldset>
				</div>				
				
				<xsl:call-template name="addUserTagsTable"/>
				
				<div class="floatright bigmargintop">
				
<!-- 					<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowFamily/flowFamilyID}" title="{$i18n.Back}"> -->
<!-- 						<xsl:value-of select="$i18n.Back" /> -->
<!-- 					</a> -->
				
					<input class="btn btn-light btn-inline marginright" type="button" value="{$i18n.Back}" onclick="window.location = '{/Document/requestinfo/currentURI}/{/Document/module/alias}/family/{FlowSelection/FlowFamily/flowFamilyID}'"/>
					<input class="btn btn-green btn-inline" type="submit" value="{$i18n.SendMessage.SubmitMessage}"/>
				</div>
			
			</form>
		</div>
		
	</xsl:template>
	
	<xsl:template name="addUserTagsTable">
	
		<div class="floatleft full bigmarginbottom" id="user-tags">

			<p><xsl:value-of select="$i18n.UserTagsTable.description"/></p>
		
			<table class="full border">
				<tr>
					<th>
						<xsl:value-of select="$i18n.Tag"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.Description"/>
					</th>
				</tr>
				<tr>
					<td>
						<xsl:text>$flow.name</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.FlowNameTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$flowInstance.flowInstanceID</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.FlowInstanceIDTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$flowInstance.url</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.FlowInstanceURLTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$contact.firstname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.PosterFirstnameTag"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$contact.lastname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.PosterLastnameTag"/>
					</td>
				</tr>
			</table>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="FlowSelection">
	
		<xsl:if test="not(allFlows = 'true')">
			<xsl:for-each select="flowIDs/value">
				<xsl:call-template name="createHiddenField">
					<xsl:with-param name="name" select="'flowID'"/>
					<xsl:with-param name="value" select="."/>
				</xsl:call-template>
			</xsl:for-each>
		</xsl:if>
		
		<xsl:call-template name="createHiddenField">
			<xsl:with-param name="name" select="'fromDate'"/>
			<xsl:with-param name="value" select="fromDate"/>
		</xsl:call-template>
		
		<xsl:call-template name="createHiddenField">
			<xsl:with-param name="name" select="'toDate'"/>
			<xsl:with-param name="value" select="toDate"/>
		</xsl:call-template>
				
	</xsl:template>
	
	<xsl:template match="UpdateFlowInstanceStatuses">
	
		<div>
		
			<h1>
				<xsl:value-of select="$i18n.UpdateFlowInstanceStatuses.Title"/>
				<xsl:text>:&#160;</xsl:text>
				<xsl:value-of select="FlowName"/>
			</h1>
			
			<p class="nomargin">
				<xsl:value-of select="$i18n.UpdateFlowInstanceStatuses.description.1"/>
				<xsl:text> </xsl:text>
				<strong>
					<xsl:value-of select="count(FlowInstances/flowInstanceID)"/>
				</strong>
				<xsl:text> </xsl:text>
				<xsl:value-of select="$i18n.UpdateFlowInstanceStatuses.description.2"/>
			</p>
				
			<xsl:apply-templates select="ValidationErrors/validationError" />
			
			<form method="post" action="{/Document/requestinfo/uri}">
				
				<xsl:apply-templates select="FlowSelection"/>
				
				<xsl:for-each select="FlowInstances/flowInstanceID">
					<xsl:call-template name="createHiddenField">
						<xsl:with-param name="name" select="'flowInstanceID'"/>
						<xsl:with-param name="value" select="."/>
					</xsl:call-template>
				</xsl:for-each>
				
				<article class="bigmargintop">
				
					<h2>Ny status:</h2>
					
					<div class="clearfix"/>
					
					<xsl:apply-templates select="Statuses/Status[contentType != 'NEW' and contentType != 'WAITING_FOR_MULTISIGN' and contentType != 'WAITING_FOR_PAYMENT']" mode="radiobutton" />
					
				</article>
			
				<div class="floatright bigmargintop">
				
					<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/instances/{FlowSelection/FlowFamily/flowFamilyID}?{FlowSelection/URLParameters}" title="{$i18n.Back}">
						<xsl:value-of select="$i18n.Back"/>
					</a>
					<input class="btn btn-green btn-inline" type="submit" value="{$i18n.UpdateFlowInstanceStatuses.Submit}"/>
				</div>
			
			</form>
		</div>
		
	</xsl:template>
	
	<xsl:template match="Status" mode="radiobutton">
	
		<div class="bigmarginleft">
			<input type="radio" value="{statusID}" id="status_{statusID}" name="statusID" />
				
			<label for="status_{statusID}">
				<xsl:value-of select="name"/>
			</label>
		</div>
		
	</xsl:template>
	
	<xsl:template match="AddFlowInstanceManagers">
	
		<div>
		
			<h1>
				<xsl:value-of select="$i18n.AddFlowInstanceManagers.Title"/>
				<xsl:text>:&#160;</xsl:text>
				<xsl:value-of select="FlowName"/>
			</h1>
			
			<p class="nomargin">
				<xsl:value-of select="$i18n.AddFlowInstanceManagers.description.1"/>
				<xsl:text> </xsl:text>
				<strong>
					<xsl:value-of select="count(FlowInstances/flowInstanceID)"/>
				</strong>
				<xsl:text> </xsl:text>
				<xsl:value-of select="$i18n.AddFlowInstanceManagers.description.2"/>
			</p>
				
			<xsl:apply-templates select="ValidationErrors/validationError" />
			
			<form method="post" action="{/Document/requestinfo/uri}">
				
				<xsl:apply-templates select="FlowSelection"/>
				
				<xsl:for-each select="FlowInstances/flowInstanceID">
					<xsl:call-template name="createHiddenField">
						<xsl:with-param name="name" select="'flowInstanceID'"/>
						<xsl:with-param name="value" select="."/>
					</xsl:call-template>
				</xsl:for-each>
				
				<article class="bigmargintop">
				
					<h2>Nya handlggare:</h2>
					
					<div class="clearfix"/>
					
					<xsl:apply-templates select="Managers/user" mode="checkbox" />
					
				</article>
			
				<div class="floatright bigmargintop">
				
					<a class="btn btn-light btn-inline marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/instances/{FlowSelection/FlowFamily/flowFamilyID}?{FlowSelection/URLParameters}" title="{$i18n.Back}">
						<xsl:value-of select="$i18n.Back"/>
					</a>
					<input class="btn btn-green btn-inline" type="submit" value="{$i18n.AddFlowInstanceManagers.Submit}"/>
				</div>
			
			</form>
		</div>
		
	</xsl:template>
	
	<xsl:template match="user" mode="checkbox">
	
		<div class="bigmarginleft">
			<input type="checkbox" value="{userID}" id="manager_{userID}" name="managerID" />
				
			<label for="manager_{userID}">
				<xsl:value-of select="firstname"/>
				<xsl:text> </xsl:text>
				<xsl:value-of select="lastname"/>
				
				<xsl:if test="username">
					<xsl:text> (</xsl:text>
					<xsl:value-of select="username"/>
					<xsl:text>)</xsl:text>
				</xsl:if>
			</label>
		</div>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='MultipleFlowsSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.MultipleFlowsSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='StatusNotFoundValidationError']">
		<p class="error">
			<xsl:value-of select="$i18n.StatusNotFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='InvalidStatusValidationError']">
		<p class="error">
			<xsl:value-of select="$i18n.InvalidStatus"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='OneOrMoreSelectedManagerUsersNotFoundError']">
		<p class="error">
			<xsl:value-of select="$i18n.OneOrMoreSelectedManagerNotFoundError"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyNotFound']">
		<p class="error">
			<xsl:value-of select="$i18n.FlowFamilyNotFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyAccessDenied']">
		<p class="error">
			<xsl:value-of select="$i18n.FlowFamilyAccessDenied"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoFlowVersionsSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoFlowVersionsSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoRecipients']">
		<p class="error">
			<xsl:value-of select="$i18n.NoEmailNoRecipients"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoContentTypesSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoContentTypesSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoMultiSignTypesSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoMultiSignTypesSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='NoMessagePathSelected']">
		<p class="error">
			<xsl:value-of select="$i18n.NoMessagePathSelected"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[fieldName = 'managerID' and validationErrorType = 'RequiredField']">
		<p class="error">
			<xsl:value-of select="$i18n.NoManagerSelected"/>
		</p>
	</xsl:template>

	<xsl:template match="validationError[messageKey='FileSizeLimitExceeded']">
	
		<p class="error">
			<xsl:value-of select="$i18n.FileSizeLimitExceeded.part1"/>
			<xsl:value-of select="filename"/>
			<xsl:value-of select="$i18n.FileSizeLimitExceeded.part2"/>
			<xsl:value-of select="size"/>
			<xsl:value-of select="$i18n.FileSizeLimitExceeded.part3"/>
			<xsl:value-of select="maxFileSize"/>
			<xsl:value-of select="$i18n.FileSizeLimitExceeded.part4"/>
		</p>
			
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='UnableToParseRequest']">
	
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.UnableToParseRequest" />
		</p>
				
	</xsl:template>						
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="fieldName = 'fromDate'">
						<xsl:value-of select="$i18n.fromDate"/>
					</xsl:when>
					<xsl:when test="fieldName = 'toDate'">
						<xsl:value-of select="$i18n.toDate"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailSenderName'">
						<xsl:value-of select="$i18n.emailSenderName"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailSenderAddress'">
						<xsl:value-of select="$i18n.emailSenderAddress"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailSubject'">
						<xsl:value-of select="$i18n.emailSubject"/>
					</xsl:when>
					<xsl:when test="fieldName = 'emailMessage'">
						<xsl:value-of select="$i18n.emailMessage"/>
					</xsl:when>
					<xsl:when test="fieldName = 'smsMessage'">
						<xsl:value-of select="$i18n.smsMessage"/>
					</xsl:when>
					<xsl:when test="fieldName = 'externalMessage'">
						<xsl:value-of select="$i18n.externalMessage"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>
	
</xsl:stylesheet>