package com.nordicpeak.flowengine.queries.userlistquery;

import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;
import se.unlogic.standardutils.collections.CollectionUtils;

import com.nordicpeak.flowengine.FlowAdminModule;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowFamily;
import com.nordicpeak.listuserprovider.ListParameter;
import com.nordicpeak.listuserprovider.ListUser;
import com.nordicpeak.listuserprovider.ListUserHandler;
import com.nordicpeak.listuserprovider.ListUserProvider;
import com.nordicpeak.listuserprovider.SimpleListUser;

public class FlowManagersListUserProvider extends AnnotatedForegroundModule implements ListUserProvider {
	
	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Provider ID", description = "The unique identifier for this provider.", required = true)
	private String providerID = getClass().getName();
	
	protected ListUserHandler listUserHandler;
	
	@InstanceManagerDependency
	protected FlowAdminModule flowAdminModule;
	
	@Override
	public void update(ForegroundModuleDescriptor descriptor, DataSource dataSource) throws Exception {
		
		if (listUserHandler != null) {
			listUserHandler.removeUserListProvider(this);
		}
		
		super.update(descriptor, dataSource);
		
		if (listUserHandler != null) {
			listUserHandler.addUserListProvider(this);
		}
	}
	
	@Override
	public void unload() throws Exception {
		
		if (listUserHandler != null) {
			listUserHandler.removeUserListProvider(this);
		}
		
		super.unload();
	}
	
	@InstanceManagerDependency
	public void setListUserHandler(ListUserHandler listUserHandler) {
		
		if (listUserHandler != null) {
			
			listUserHandler.addUserListProvider(this);
			
		} else if (this.listUserHandler != null) {
			
			this.listUserHandler.removeUserListProvider(this);
		}
		
		this.listUserHandler = listUserHandler;
	}
	
	@Override
	public String getListName() {
		
		return moduleDescriptor.getDescription();
	}
	
	@Override
	public String getListID() {
		
		return providerID;
	}
	
	@Override
	public ListUser getListUser(String providerUserID) {
		
		User user = getUser(providerUserID);
		
		if (user == null) {
			return null;
		}
		
		return new SimpleListUser(user);
	}
	
	@Override
	public User getUser(String providerUserID) {
		
		return systemInterface.getUserHandler().getUser(Integer.parseInt(providerUserID), false, true);
	}
	
	protected List<User> getAllowedFlowManagers(ImmutableFlowFamily flowFamily) {
		
		List<User> managingUsers = new ArrayList<User>();
		
		Collection<Integer> managerIDs = flowFamily.getActiveManagerUserIDs();
		List<Integer> managerGroupIDs = flowFamily.getManagerGroupIDs();
		
		if (!CollectionUtils.isEmpty(managerIDs)) {
			
			List<User> users = systemInterface.getUserHandler().getUsers(managerIDs, false, true);
			
			if (users != null) {
				managingUsers.addAll(users);
			}
		}
		
		if (!CollectionUtils.isEmpty(managerGroupIDs)) {
			
			List<User> users = systemInterface.getUserHandler().getUsersByGroups(managerGroupIDs, true);
			
			if (users != null) {
				managingUsers.addAll(users);
			}
		}
		
		return managingUsers;
	}
	
	@Override
	public List<ListUser> searchUsers(Integer flowID, String searchString, List<? extends ListParameter> filterParameters, User user) throws Exception {
		
		ImmutableFlowFamily flowFamily = flowAdminModule.getFlow(flowID).getFlowFamily();
		
		List<User> managingUsers = getAllowedFlowManagers(flowFamily);
		
		if (CollectionUtils.isEmpty(managingUsers)) {
			return null;
		}
		
		String terms[] = searchString.toLowerCase().split("[ ]+");
		
		List<ListUser> matchingUsers = new ArrayList<ListUser>(managingUsers.size());
		
		for (User potentialUser : managingUsers) {
			
			List<String> fields = new ArrayList<String>();
			
			if (potentialUser.getFirstname() != null) {
				fields.add(potentialUser.getFirstname().toLowerCase());
			}
			
			if (potentialUser.getLastname() != null) {
				fields.add(potentialUser.getLastname().toLowerCase());
			}
			
			if (potentialUser.getUsername() != null) {
				fields.add(potentialUser.getUsername().toLowerCase());
			}
			
			int matches = 0;
			
			for (String term : terms) {
				for (String field : fields) {
					
					if (field.contains(term)) {
						
						matches++;
						break;
					}
				}
			}
			
			if (matches == terms.length) {
				matchingUsers.add(new SimpleListUser(potentialUser));
			}
		}
		
		return matchingUsers;
	}
	
	@Override
	public List<ListUser> getUsers(Integer flowID, List<? extends ListParameter> filterParameters) throws Exception {
		
		return null;
	}
	
}
