<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl"/>
	
	<xsl:variable name="imgPath"><xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/pics</xsl:variable>
	
	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/featherlight/js/featherlight.min.js
		/js/confirmpost.js
		/tablesorter/js/jquery.tablesorter.min.js
	</xsl:variable>
	
	<xsl:variable name="globallinks">
		/featherlight/css/featherlight.min.css?v=1
	</xsl:variable>	
	
	<xsl:variable name="scripts">
		/js/flowengine.tablesorter.js
		/js/flowengine.js?v=1
		/js/datatables.min.js
		/js/voting.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css
		/css/datatables.css
		/css/overrides.css?v1
	</xsl:variable>
	
	<xsl:variable name="updatescripts">
		/js/flowvoteupdate.js
	</xsl:variable>
	
	<xsl:variable name="updatelinks">
		/css/flowengine.css
		/css/flowvoteupdate.css?v=1
	</xsl:variable>

	<xsl:template match="Document">	
		
		<xsl:choose>
			<xsl:when test="ShowSettings or UpdateSettings">
				
				<xsl:apply-templates select="ShowSettings" />
				<xsl:apply-templates select="UpdateSettings" />
			
			</xsl:when>
			<xsl:otherwise>
			
				<xsl:if test="VoteForm and(VoteForm/Voted or VoteForm/VoteRemoved)">
				
					<div class="contentitem">
				
						<xsl:if test="Vote/Voted">
							<section class="modal success">
								<span data-icon-before="c">
									<xsl:value-of select="$i18n.Voting.Voted" />
								</span>
								<i class="icon close">x</i>
							</section>
						</xsl:if>
						
						<xsl:if test="Vote/VoteRemoved">
							<section class="modal success">
								<span data-icon-before="c">
									<xsl:value-of select="$i18n.Voting.VoteRemoved" />
								</span>
								<i class="icon close">x</i>
							</section>
						</xsl:if>
					
					</div>
				</xsl:if>
			
				<div id="flowvote" class="contentitem">
					<xsl:apply-templates select="ListVotings" />
					<xsl:apply-templates select="ListArchivedVotings" />
					<xsl:apply-templates select="ListPropositions" />
					<xsl:apply-templates select="ListArchivedPropositions" />
					<xsl:apply-templates select="VoteForm" />
				</div>
			
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="ShowSettings">
	
		<a name="flowvotesettings" />
		
		<xsl:choose>
			<xsl:when test="Settings">
			
				<xsl:choose>
					<xsl:when test="Settings/votingActivated = 'true'">
						<xsl:value-of select="$i18n.VotingEnabled" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.PropositionEnabledNoVoting" />
					</xsl:otherwise>
				</xsl:choose>
				
				<div class="floatleft full">
					<span class="floatleft marginright"><xsl:value-of select="$i18n.Settings.alias" />: </span>
					<xsl:value-of select="Settings/alias" />
				</div>
				
				<xsl:if test="Settings/municipalCode">
					<div class="floatleft full">
						<span class="floatleft marginright"><xsl:value-of select="$i18n.Settings.municipalCode" />: </span>
						<xsl:value-of select="Settings/municipalCode" />
					</div>
				</xsl:if>
								
				<xsl:if test="Profile">
					<div class="floatleft full">
						<span class="floatleft marginright"><xsl:value-of select="$i18n.Settings.siteProfileID" />: </span>
						<xsl:value-of select="Profile/name" />
					</div>
				</xsl:if>

				<div class="floatleft full">
				
					<xsl:variable name="link">
						<xsl:choose>
							<xsl:when test="Profile">
								<xsl:value-of select="Protocol" />
								<xsl:text>://</xsl:text>
								<xsl:value-of select="Profile/domains/domain" />
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="ServerURL" />
							</xsl:otherwise>
						</xsl:choose>
					
						<xsl:value-of select="/Document/ModuleURI" />
						<xsl:text>/</xsl:text>
						<xsl:value-of select="Settings/alias" />
					</xsl:variable>

					<span class="floatleft marginright"><xsl:value-of select="$i18n.Settings.publicpage" /></span>
					<a href="{$link}">
						<xsl:value-of select="$link" />
					</a>
				</div>
				
				<xsl:if test="Settings/rssFeedActive = 'true'"> 
					<div class="floatleft full">

						<xsl:variable name="rsslink">
							<xsl:choose>
								<xsl:when test="Profile">
									<xsl:value-of select="Protocol" />
									<xsl:text>://</xsl:text>
									<xsl:value-of select="Profile/domains/domain" />
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="ServerURL" />
								</xsl:otherwise>
							</xsl:choose>
						
							<xsl:value-of select="/Document/ModuleURI" />
							<xsl:text>/rss/</xsl:text>
							<xsl:value-of select="Settings/alias" />
						</xsl:variable>


						<span class="floatleft marginright"><xsl:value-of select="$i18n.Settings.rssFeedActive" /><xsl:text>&#160;</xsl:text></span>
						<a href="{$rsslink}">
							<xsl:value-of select="$rsslink" />
						</a>
					</div>
				</xsl:if>
				
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$i18n.NoSettings" />
			</xsl:otherwise>
		</xsl:choose>
		
		<a href="{/Document/ModuleURI}/updateflowsettings/{Flow/flowID}" class="floatright">
			<xsl:value-of select="$i18n.UpdateSettings" />
			<img class="marginleft" src="{$imgPath}/pen.png" alt="" />
		</a>
		
		<xsl:if test="Settings">
			<a href="{/Document/ModuleURI}/deleteflowsettings/{Flow/flowID}" class="floatright clearboth" onclick="return confirmPost(this.href, '{$i18n.DeleteSettings.Confirm}');">
				<xsl:value-of select="$i18n.DeleteSettings" />
				<img class="marginleft" src="{$imgPath}/delete.png" alt="" />
			</a>		
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="UpdateSettings">
		
		<div id="AddFlowInstanceAsManager" class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.UpdateSettings.Title"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
			</h1>
	
			<p>
				<xsl:value-of select="$i18n.UpdateSettings.description1" />
			</p>
			<p>
				<xsl:value-of select="$i18n.UpdateSettings.description2" />
			</p>
			<p>
				<xsl:value-of select="$i18n.UpdateSettings.description3" />
			</p>
			<p>
				<xsl:value-of select="$i18n.UpdateSettings.description4" />
			</p>
			
			<xsl:apply-templates select="ValidationErrors/validationError"/>
	
			<form method="post" action="{/Document/ModuleURI}/updateflowsettings/{Flow/flowID}">

				<fieldset id="base-info-fieldset" class="inner-fieldset full">
					<legend><xsl:value-of select="$i18n.BaseInfoLegend" /></legend>
			
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="title">
							<xsl:value-of select="$i18n.Settings.title" />
						</label>
						
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'title'" />
								<xsl:with-param name="name" select="'title'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full" for="description">
							<xsl:value-of select="$i18n.Settings.description" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextArea">
								<xsl:with-param name="id" select="'description'" />
								<xsl:with-param name="name" select="'description'" />
								<xsl:with-param name="element" select="Settings" />
								<xsl:with-param name="rows" select="'4'" />
							</xsl:call-template>
						</div>
		
					</div>
				
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="alias">
							<xsl:value-of select="$i18n.Settings.alias" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'alias'" />
								<xsl:with-param name="name" select="'alias'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full" for="municipalCode">
							<xsl:value-of select="$i18n.Settings.municipalCode" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'municipalCode'" />
								<xsl:with-param name="name" select="'municipalCode'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<xsl:choose>
						<xsl:when test="count(SiteProfiles/Profile) > 1">
							<div class="floatleft full bigmarginbottom">
			
								<label class="floatleft full" for="siteProfileID">
									<xsl:value-of select="$i18n.Settings.siteProfileID" />
								</label>
			
								<div class="floatleft full">
									<xsl:call-template name="createDropdown">
										<xsl:with-param name="id" select="'siteProfileID'" />
										<xsl:with-param name="name" select="'siteProfileID'" />
										<xsl:with-param name="element" select="SiteProfiles/Profile" />
										<xsl:with-param name="valueElementName" select="'profileID'" />
										<xsl:with-param name="labelElementName" select="'name'" />
										<xsl:with-param name="selectedValue" select="Settings/siteProfileID" />
										<xsl:with-param name="addEmptyOption" select="$i18n.Settings.siteProfileID.choose" />
									</xsl:call-template>
								</div>
				
							</div>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="createHiddenField">
								<xsl:with-param name="id" select="'siteProfileID'" />
								<xsl:with-param name="name" select="'siteProfileID'" />
								<xsl:with-param name="value" select="SiteProfiles/Profile/profileID" />
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
	
					<xsl:variable name="options">
						<option>
							<name>15</name>
							<value>15</value>
						</option>
						<option>
							<name>25</name>
							<value>25</value>
						</option>
						<option>
							<name>50</name>
							<value>50</value>
						</option>
						<option>
							<name>100</name>
							<value>100</value>
						</option>
						<option>
							<name>200</name>
							<value>200</value>
						</option>
						<option>
							<name>500</name>
							<value>500</value>
						</option>
					</xsl:variable>
						
					<div class="floatleft full bigmarginbottom">
						<label for="columnType" class="floatleft clearboth"><xsl:value-of select="$i18n.PageSize" /></label>
						<div class="floatleft full">
							<xsl:call-template name="createDropdown">
								<xsl:with-param name="id" select="'pageSize'"/>
								<xsl:with-param name="name" select="'pageSize'"/>
								<xsl:with-param name="labelElementName" select="'name'" />
								<xsl:with-param name="valueElementName" select="'value'" />
								<xsl:with-param name="element" select="exsl:node-set($options)/option" />
								<xsl:with-param name="selectedValue" select="Settings/pageSize" />
							</xsl:call-template>
						</div>
					</div>
	
					<div class="floatleft full bigmarginbottom">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'hideAttachedFiles'" />
							<xsl:with-param name="name" select="'hideAttachedFiles'" />
							<xsl:with-param name="value" select="'true'" />
							<xsl:with-param name="element" select="Settings" />
						</xsl:call-template>
						<label for="hideAttachedFiles"><xsl:value-of select="$i18n.HideAttachedFiles" /></label><br/>
					</div>
	
					<div class="floatleft full bigmarginbottom">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'votingActivated'" />
							<xsl:with-param name="name" select="'votingActivated'" />
							<xsl:with-param name="value" select="'true'" />
							<xsl:with-param name="element" select="Settings" />
						</xsl:call-template>
						<label for="votingActivated"><xsl:value-of select="$i18n.VotingActivated" /></label><br/>
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="votingDays">
							<xsl:value-of select="$i18n.Settings.votingDays" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'votingDays'" />
								<xsl:with-param name="name" select="'votingDays'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="requiredVotes">
							<xsl:value-of select="$i18n.Settings.requiredVotes" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'requiredVotes'" />
								<xsl:with-param name="name" select="'requiredVotes'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
				</fieldset>

				<fieldset id="status-settings-fieldset" class="inner-fieldset full">
					<legend><xsl:value-of select="$i18n.StatusSettingsLegend" /></legend>

					<div class="floatleft full bigmarginbottom">
	
						<label id="votingStatusLable" class="floatleft full required" for="publishedStatus">
							<xsl:value-of select="$i18n.Settings.votingStatus" />
						</label>
						<label id="publishStatusLable" class="floatleft full required" for="publishedStatus">						
							<xsl:value-of select="$i18n.Settings.publishStatus" />
						</label>
						<div class="tiny"><xsl:value-of select="$i18n.Settings.votingStatusInfo" /></div>
						
						<div id="published-statuses-list" class="floatleft full margintop marginbottom">
				
							<xsl:choose>
								<xsl:when test="requestparameters">
								
									<xsl:for-each select="requestparameters/parameter[name='publishedStatus']/value">
										<xsl:call-template name="PublishedStatus">
											<xsl:with-param name="statusName" select="."/>
										</xsl:call-template>
									</xsl:for-each>
									
								</xsl:when>
								<xsl:otherwise>
									
									<xsl:apply-templates select="Settings/PublishedStatuses/statusName" name="PublishedStatus" mode="publishedList" />
									
								</xsl:otherwise>
							</xsl:choose>
							
							<div id="published-statuses-template" style="display: none;">
								<xsl:call-template name="PublishedStatus">
									<xsl:with-param name="statusName"></xsl:with-param>
								</xsl:call-template>
							</div>
							
							<input name="connectorURL" disabled="true" hidden="true" value="{/Document/requestinfo/currentURI}/{/Document/module/alias}/statuses/{Flow/FlowFamily/flowFamilyID}"/>
							
						</div>
						
						<div class="floatleft full ui-widget">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'published-statuses-search'" />
								<xsl:with-param name="placeholder" select="$i18n.PublishedStatuses.SearchPlaceholder" />
							</xsl:call-template>
						</div>
		
					</div>
				
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="votePassedStatus">
							<xsl:value-of select="$i18n.Settings.votePassedStatus" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'votePassedStatus'" />
								<xsl:with-param name="name" select="'votePassedStatus'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="voteFailedStatus">
							<xsl:value-of select="$i18n.Settings.voteFailedStatus" />
						</label>
	
						<div class="floatleft full">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'voteFailedStatus'" />
								<xsl:with-param name="name" select="'voteFailedStatus'" />
								<xsl:with-param name="element" select="Settings" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
	
						<label class="floatleft full required" for="archivedStatuses">
							<xsl:value-of select="$i18n.Settings.archivedStatuses" />
						</label>
						
						<div id="archived-statuses-list" class="floatleft full margintop marginbottom">
				
							<xsl:choose>
								<xsl:when test="requestparameters">
								
									<xsl:for-each select="requestparameters/parameter[name='archivedStatus']/value">
										<xsl:call-template name="ArchivedStatus">
											<xsl:with-param name="statusName" select="."/>
										</xsl:call-template>
									</xsl:for-each>
									
								</xsl:when>
								<xsl:otherwise>
									
									<xsl:apply-templates select="Settings/ArchivedStatuses/statusName" mode="archivedList" />
									
								</xsl:otherwise>
							</xsl:choose>
							
							<div id="archived-statuses-template" style="display: none;">
								<xsl:call-template name="ArchivedStatus">
									<xsl:with-param name="statusName"></xsl:with-param>
								</xsl:call-template>
							</div>
							
							<input name="connectorURL" disabled="true" hidden="true" value="{/Document/requestinfo/currentURI}/{/Document/module/alias}/statuses/{Flow/FlowFamily/flowFamilyID}"/>
							
						</div>
						
						<div class="floatleft full ui-widget">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'archived-statuses-search'" />
								<xsl:with-param name="placeholder" select="$i18n.ArchivedStatuses.SearchPlaceholder" />
							</xsl:call-template>
						</div>
		
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'showStatusInList'" />
								<xsl:with-param name="name" select="'showStatusInList'" />
								<xsl:with-param name="element" select="Settings" /> 
								<xsl:with-param name="class" select="'vertical-align-middle'" />
							</xsl:call-template>
								
							<label for="showStatusInList">
								<xsl:value-of select="$i18n.ShowStatusInList" />
							</label>
					    </div>
					</div>
					
				</fieldset>
				
				<fieldset id="advanced-settings-fieldset" class="inner-fieldset full">
					<legend><xsl:value-of select="$i18n.AdvancedSettingsLegend" /></legend>

					<div class="floatleft full bigmarginbottom">
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'additionalAttributes'" />
								<xsl:with-param name="name" select="'additionalAttributes'" />
								<xsl:with-param name="element" select="Settings" /> 
								<xsl:with-param name="class" select="'vertical-align-middle'" />
							</xsl:call-template>
								
							<label for="additionalAttributes">
								<xsl:value-of select="$i18n.ActivateAdditionalAttributes" />
							</label>
					    </div>
					</div>

					<div class="tiny"><xsl:value-of select="$i18n.AdditionalAttributesInfo"/></div>

					<div id="extraAttributeContainer">

						<div class="floatleft full bigmarginbottom">

							<div class="floatleft fourtyfive">
								<label>
									<xsl:value-of select="$i18n.ExtraInfoName1" />
								</label>
							</div>
	
							<div class="floatleft fourtyfive">
								<label>
									<xsl:value-of select="$i18n.ExtraInfoAttribute1" />
								</label>
							</div>
								
							<div class="floatleft ten">
								<label class="block">
									<xsl:value-of select="$i18n.ExtraInfoHideInList1" />
								</label>
							</div>
	
						</div>

						<div class="floatleft full bigmarginbottom">

							<div class="floatleft fourtyfive">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'extraInfoName1'" />
									<xsl:with-param name="name" select="'extraInfoName1'" />
									<xsl:with-param name="title" select="$i18n.ExtraInfoName1"/>
									<xsl:with-param name="type" select="'text'"/>
									<xsl:with-param name="width" select="'90%'"/>
									<xsl:with-param name="element" select="Settings"/>
								</xsl:call-template>
							</div>
	
							<div class="floatleft fourtyfive">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'extraInfoAttribute1'" />
									<xsl:with-param name="name" select="'extraInfoAttribute1'" />
									<xsl:with-param name="title" select="$i18n.ExtraInfoAttribute1"/>
									<xsl:with-param name="type" select="'text'"/>
									<xsl:with-param name="width" select="'90%'"/>
									<xsl:with-param name="element" select="Settings"/>
								</xsl:call-template>
							</div>
								
							<div class="floatleft ten">
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="'hideInList1'" />
									<xsl:with-param name="name" select="'hideInList1'" />
									<xsl:with-param name="element" select="Settings" /> 
									<xsl:with-param name="class" select="'vertical-align-middle'" />
								</xsl:call-template>
							</div>
	
						</div>
	
						<div class="floatleft full bigmarginbottom">
							
							<div class="floatleft fourtyfive">
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'extraInfoName2'" />
									<xsl:with-param name="name" select="'extraInfoName2'" />
									<xsl:with-param name="title" select="$i18n.ExtraInfoName2"/>
									<xsl:with-param name="type" select="'text'"/>
									<xsl:with-param name="width" select="'90%'"/>
									<xsl:with-param name="element" select="Settings"/>
								</xsl:call-template>
							</div>
	
							<div class="floatleft fourtyfive">
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'extraInfoAttribute2'" />
									<xsl:with-param name="name" select="'extraInfoAttribute2'" />
									<xsl:with-param name="title" select="$i18n.ExtraInfoAttribute2"/>
									<xsl:with-param name="type" select="'text'"/>
									<xsl:with-param name="width" select="'90%'"/>
									<xsl:with-param name="element" select="Settings"/>
								</xsl:call-template>
							</div>
							
							<div class="floatleft ten">
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="'hideInList2'" />
									<xsl:with-param name="name" select="'hideInList2'" />
									<xsl:with-param name="element" select="Settings" /> 
									<xsl:with-param name="class" select="'vertical-align-middle'" />
								</xsl:call-template>
							</div>
	
						</div>
	
						<div class="floatleft full bigmarginbottom">
							
							<div class="floatleft fourtyfive">
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'extraInfoName3'" />
									<xsl:with-param name="name" select="'extraInfoName3'" />
									<xsl:with-param name="title" select="$i18n.ExtraInfoName3"/>
									<xsl:with-param name="type" select="'text'"/>
									<xsl:with-param name="width" select="'90%'"/>
									<xsl:with-param name="element" select="Settings"/>
								</xsl:call-template>
							</div>
	
							<div class="floatleft fourtyfive">
						
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'extraInfoAttribute3'" />
									<xsl:with-param name="name" select="'extraInfoAttribute3'" />
									<xsl:with-param name="title" select="$i18n.ExtraInfoAttribute3"/>
									<xsl:with-param name="type" select="'text'"/>
									<xsl:with-param name="width" select="'90%'"/>
									<xsl:with-param name="element" select="Settings"/>
								</xsl:call-template>
							</div>

							<div class="floatleft ten">
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="'hideInList3'" />
									<xsl:with-param name="name" select="'hideInList3'" />
									<xsl:with-param name="element" select="Settings" /> 
									<xsl:with-param name="class" select="'vertical-align-middle'" />
								</xsl:call-template>
							</div>

						</div>
					</div>

					<div class="floatleft full bigmarginbottom">
						<div class="floatleft full">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="id" select="'rssFeedActive'" />
								<xsl:with-param name="name" select="'rssFeedActive'" />
								<xsl:with-param name="element" select="Settings" /> 
								<xsl:with-param name="class" select="'vertical-align-middle'" />
							</xsl:call-template>
								
							<label for="rssFeedActive">
								<xsl:value-of select="$i18n.ActivateRSSFeed" />
							</label>
					    </div>
					</div>

					<div class="tiny"><xsl:value-of select="$i18n.ActivateRSSFeed.Info"/></div>
					
				</fieldset>
				
				<div class="floatright clearboth bigmargintop">
					<input type="submit" value="{$i18n.SaveChanges}" />
				</div>
				
			</form>
			
		</div>
		
	</xsl:template>

	<xsl:template match="statusName" mode="publishedList" name="PublishedStatus">
		<xsl:param name="statusName" select="."/>
		
		<div class="floatleft hover border full marginbottom border-radius lightbackground">
			
			<div class="marginleft margintop floatleft">
				<div class="marginleft">
					<h3>
						<xsl:value-of select="$statusName" />
					</h3>
				</div>
			</div>
			
			<input name="publishedStatus" hidden="true" value="{$statusName}"/>
			
			<div class="padding floatright">
				<div class="floatright marginright">
					<a href="#" onclick="if(confirm('{$i18n.DeletePublishedStatus.Confirm}: {$statusName}?'))$(this).closest('div.border-radius').remove(); return false;" title="{$i18n.DeletePublishedStatus}: {$statusName}">
						<img src="{$imgPath}/delete.png"/>
					</a>
				</div>
			</div>
			
		</div>
		
	</xsl:template>

	
	<xsl:template match="statusName" mode="archivedList" name="ArchivedStatus">
		<xsl:param name="statusName" select="."/>
		
		<div class="floatleft hover border full marginbottom border-radius lightbackground">
			
			<div class="marginleft margintop floatleft">
				<div class="marginleft">
					<h3>
						<xsl:value-of select="$statusName" />
					</h3>
				</div>
			</div>
			
			<input name="archivedStatus" hidden="true" value="{$statusName}"/>
			
			<div class="padding floatright">
				<div class="floatright marginright">
					<a href="#" onclick="if(confirm('{$i18n.DeleteArchivedStatus.Confirm}: {$statusName}?'))$(this).closest('div.border-radius').remove(); return false;" title="{$i18n.DeleteArchivedStatus}: {$statusName}">
						<img src="{$imgPath}/delete.png"/>
					</a>
				</div>
			</div>
			
		</div>
		
	</xsl:template>
	
	<xsl:template match="ListVotings">
	
		<div class="full">
			<div class="heading">
				<h1>
					<xsl:value-of select="Settings/title" />
				</h1>
			</div>
			<xsl:if test="Settings/rssFeedActive = 'true'">
				<div class="rssicon">
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/rss/{Settings/alias}" title="{$i18n.RssFlow}">
						<img src="{$imgPath}/rss.png"/>
					</a>
				</div>
			</xsl:if>
		</div>

		<xsl:apply-templates select="validationError"/>
		
		<div id="active-description" class="floatleft" style="max-width: calc(100% - 220px);">
			<h2><xsl:value-of select="$i18n.ActiveVotings"/></h2>
			<p>
				<xsl:value-of select="Settings/description" />
			</p>
		</div>
		
		<table id="active" class="display oep-table">
			<thead class="hide-mobile">
				<tr>
					<th/> <!-- instanceID -->
					<th><xsl:value-of select="$i18n.Columns.Title" /></th>
					
					<xsl:if test="Settings/showStatusInList = 'true'">
						<th><xsl:value-of select="$i18n.Columns.Status"/></th>
					</xsl:if>
					
					<xsl:if test="Settings/additionalAttributes">
						<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
							<th><xsl:value-of select="Settings/extraInfoName1" /></th>
						</xsl:if>
						<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
							<th><xsl:value-of select="Settings/extraInfoName2" /></th>
						</xsl:if>
						<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
							<th><xsl:value-of select="Settings/extraInfoName3" /></th>
						</xsl:if>
					</xsl:if>
					
					<th><xsl:value-of select="$i18n.Columns.VotingEnding" /></th>
					<th><xsl:value-of select="$i18n.Columns.Votes" /></th>
					<th><xsl:value-of select="$i18n.Columns.Voted" /></th>
				</tr>
			</thead>
			<tbody/>
		</table>
		
		<xsl:variable name="ajaxURL">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/activedata/</xsl:text>
			<xsl:value-of select="Settings/flowFamilyID"/>
		</xsl:variable>
		
		<script type="text/javascript">
			$(function() {
			
				var table = $('#active').DataTable({
					ajax: { url: '<xsl:value-of select="$ajaxURL"/>',
									dataSrc: 'rows',
					},
					deferRender: true,
					columns: [
						{ "name": "instanceID", "visible": false },
						{ "name": "title",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Title"/>");}
						},
						<xsl:if test="Settings/showStatusInList = 'true'">
							{ "name": "showStatusInList",
								createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Status"/>");}
							},
						</xsl:if>
						{ "name": "votingEnding",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.VotingEnding"/>");}
						},
						<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								{ "name": "extraInfoName1",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName1"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								{ "name": "extraInfoName2",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName2"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								{ "name": "extraInfoName3",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName3"/>");}
								},
							</xsl:if>
						</xsl:if>
						{ "name": "votes",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Votes"/>");}
						},
						{ "name": "voted",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Voted"/>");},
							render: function(data, type, row) {
					
								if (type == "display") {
							
									var response = "";
							
									if (data == 1) {
										response += "<xsl:value-of select="$i18n.Columns.Voted.True"/>";
									}
									
									response += '<div class="only-mobile clearboth">';
									response += '<a class="btn btn-light floatleft full bigmargintop">Visa frslag</a>';
									response += '</div>';
									
									return response;
								}
								
								return data;
							}
						},
				  ],
				  order: [[ 2, 'asc' ]],
				  dom: 'frtipl',
					bAutoWidth: false,
					paging: true,
					pagingType: 'simple_numbers',
					pageLength: <xsl:value-of select="Settings/pageSize"/>,
					lengthMenu: [ 15, 25, 50, 100, 200, 500 ],
					language: {
						"decimal":        "<xsl:value-of select="$i18n.DataTable.decimal"/>",
						"emptyTable":     "<xsl:value-of select="$i18n.DataTable.emptyTable"/>",
						"info":           "<xsl:value-of select="$i18n.DataTable.info"/>",
						"infoEmpty":      "<xsl:value-of select="$i18n.DataTable.infoEmpty"/>",
						"infoFiltered":   "<xsl:value-of select="$i18n.DataTable.infoFiltered"/>",
						"infoPostFix":    "<xsl:value-of select="$i18n.DataTable.infoPostFix"/>",
						"thousands":      "<xsl:value-of select="$i18n.DataTable.thousands"/>",
						"lengthMenu":     "<xsl:value-of select="$i18n.DataTable.lengthMenu"/>",
						"loadingRecords": "<xsl:value-of select="$i18n.DataTable.loadingRecords"/>",
						"processing":     "<xsl:value-of select="$i18n.DataTable.processing"/>",
						"search":         "<xsl:value-of select="$i18n.DataTable.search"/>",
						"zeroRecords":    "<xsl:value-of select="$i18n.DataTable.zeroRecords"/>",
						paginate: {
							"first":      "<xsl:value-of select="$i18n.DataTable.paginate.first"/>",
							"last":       "<xsl:value-of select="$i18n.DataTable.paginate.last"/>",
							"next":       "<xsl:value-of select="$i18n.DataTable.paginate.next"/>",
							"previous":   "<xsl:value-of select="$i18n.DataTable.paginate.previous"/>"
						},
						aria: {
							"sortAscending":  "<xsl:value-of select="$i18n.DataTable.aria.sortAscending"/>",
							"sortDescending": "<xsl:value-of select="$i18n.DataTable.aria.sortDescending"/>"
						},
					},
					fixedHeader: true,
				});
				
				$("#active_wrapper").prepend($("#active-description"));
				
				table.on( 'click', 'tbody td', function() {
				
					var td = $(this);
					var tr = td.parent();
					
					if (tr.children("td").first().hasClass("dataTables_empty")){
						return;
					}
					
					if(tr.closest("table").hasClass("collapsed") &amp;&amp; td.is(":first-child")){
						return;
					}
					
					var flowInstanceID = table.cell(tr, "instanceID:name").data();
					window.location = "<xsl:value-of select="/Document/requestinfo/currentURI"/>/<xsl:value-of select="/Document/module/alias"/>/show/" + flowInstanceID;
				});
			});
		</script>
		
		<div class="clearboth floatright bigmargintop">
			<a class="btn btn-light marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/archived/{Settings/alias}" title="{$i18n.ShowArchived}">
				<xsl:value-of select="$i18n.ShowArchived"/>
			</a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="ListArchivedVotings">
	
		<h1>
			<xsl:value-of select="Settings/title" />
		</h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<div id="archived-description" class="floatleft" style="max-width: calc(100% - 220px);">
			<h2><xsl:value-of select="$i18n.ArchivedVotings"/></h2>
		</div>
		
		<table id="archived" class="display oep-table">
			<thead class="hide-mobile">
				<tr>
					<th/> <!-- instanceID -->
					<th><xsl:value-of select="$i18n.Columns.Title" /></th>
					<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName1" /></th>
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName2" /></th>
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName3" /></th>
							</xsl:if>
					</xsl:if>
					<th><xsl:value-of select="$i18n.Columns.Status" /></th>
					<th><xsl:value-of select="$i18n.Columns.VotingEnded" /></th>
					<th><xsl:value-of select="$i18n.Columns.Votes" /></th>
				</tr>
			</thead>
			<tbody/>
		</table>
		
		<xsl:variable name="ajaxURL">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/archiveddata/</xsl:text>
			<xsl:value-of select="Settings/flowFamilyID"/>
		</xsl:variable>
		
		<script type="text/javascript">
			$(function() {
			
				var table = $('#archived').DataTable({
					ajax: { url: '<xsl:value-of select="$ajaxURL"/>',
									dataSrc: 'rows',
					},
					deferRender: true,
					columns: [
						{ "name": "instanceID", "visible": false},
						{ "name": "title",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Title"/>");}
						},
						<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								{ "name": "extraInfoName1",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName1"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								{ "name": "extraInfoName2",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName2"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								{ "name": "extraInfoName3",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName3"/>");}
								},
							</xsl:if>
						</xsl:if>
						{ "name": "status",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Status"/>");}
						},
						{ "name": "votingEnded",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.VotingEnded"/>");}
						},
						{ "name": "votes",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Votes"/>");},
							render: function(data, type, row) {
					
								if (type == "display") {
							
									var response = "";
							
									if (data != null) {
									
										response += data;
									}
									
									response += '<div class="only-mobile clearboth">';
									response += '<a class="btn btn-light floatleft full bigmargintop">Visa frslag</a>';
									response += '</div>';
									
									return response;
								}
								
								return data;
							}
						},
				  ],
				  order: [[ 3, 'desc' ]],
				  dom: 'frtipl',
					bAutoWidth: false,
					paging: true,
					pagingType: 'simple_numbers',
					pageLength: <xsl:value-of select="Settings/pageSize"/>,
					lengthMenu: [ 15, 25, 50, 100, 200, 500 ],
					language: {
						"decimal":        "<xsl:value-of select="$i18n.DataTable.decimal"/>",
						"emptyTable":     "<xsl:value-of select="$i18n.DataTable.emptyTable"/>",
						"info":           "<xsl:value-of select="$i18n.DataTable.info"/>",
						"infoEmpty":      "<xsl:value-of select="$i18n.DataTable.infoEmpty"/>",
						"infoFiltered":   "<xsl:value-of select="$i18n.DataTable.infoFiltered"/>",
						"infoPostFix":    "<xsl:value-of select="$i18n.DataTable.infoPostFix"/>",
						"thousands":      "<xsl:value-of select="$i18n.DataTable.thousands"/>",
						"lengthMenu":     "<xsl:value-of select="$i18n.DataTable.lengthMenu"/>",
						"loadingRecords": "<xsl:value-of select="$i18n.DataTable.loadingRecords"/>",
						"processing":     "<xsl:value-of select="$i18n.DataTable.processing"/>",
						"search":         "<xsl:value-of select="$i18n.DataTable.search"/>",
						"zeroRecords":    "<xsl:value-of select="$i18n.DataTable.zeroRecords"/>",
						paginate: {
							"first":      "<xsl:value-of select="$i18n.DataTable.paginate.first"/>",
							"last":       "<xsl:value-of select="$i18n.DataTable.paginate.last"/>",
							"next":       "<xsl:value-of select="$i18n.DataTable.paginate.next"/>",
							"previous":   "<xsl:value-of select="$i18n.DataTable.paginate.previous"/>"
						},
						aria: {
							"sortAscending":  "<xsl:value-of select="$i18n.DataTable.aria.sortAscending"/>",
							"sortDescending": "<xsl:value-of select="$i18n.DataTable.aria.sortDescending"/>"
						},
					},
					fixedHeader: true,
				});
				
				$("#archived_wrapper").prepend($("#archived-description"));
				
				table.on( 'click', 'tbody td', function() {
				
					var td = $(this);
					var tr = td.parent();
					
					if(tr.children("td").first().hasClass("dataTables_empty")){
						return;
					}
					
					if(tr.closest("table").hasClass("collapsed") &amp;&amp; td.is(":first-child")){
						return;
					}
					
					var flowInstanceID = table.cell(tr, "instanceID:name").data();
					window.location = "<xsl:value-of select="/Document/requestinfo/currentURI"/>/<xsl:value-of select="/Document/module/alias"/>/show/" + flowInstanceID;
				});
			});
		</script>
		
		<div class="clearboth floatright bigmargintop">
			<a class="btn btn-light" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/{Settings/alias}" title="{$i18n.Back}">
				<xsl:value-of select="$i18n.Back"/>
			</a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="VoteForm">

		<div>	
			<div class="floatright">
				<a href="https://www.facebook.com/sharer/sharer.php?u={/Document/requestinfo/url}" title="{$i18n.Share.Facebook}">
					<img src="{$imgPath}/facebook.png"/>
				</a>
				
				<br/>
				
				<a href="https://twitter.com/intent/tweet?button_hashtag=F%C3%B6rslag&amp;ref_src={/Document/requestinfo/url}" title="{$i18n.Share.Twitter}">
					<img src="{$imgPath}/twitter.png" class="margintop"/>
				</a>
			</div>
		
			<h1><xsl:value-of select="$i18n.VoteForm.title" /></h1>
			
			<h3 class="bigmarginbottom"><xsl:value-of select="FlowInstance/userDescription" /></h3>
			
			<xsl:apply-templates select="ValidationErrors/validationError"/>
			
			<div class="floatleft fourtyfive">
			
				<div class="floatleft clearleft bigmarginbottom">
					<strong>Status</strong>
					
					<div>
						<xsl:value-of select="FlowInstance/Status/name"/>
					</div>
				</div>
				
				<xsl:choose>
					<xsl:when test="FlowInstance/Attributes/Attribute[Name = 'decisionDescription']">
					
						<p class="floatleft clearleft">
							<strong>
								<xsl:value-of select="$i18n.VoteForm.DecisionDescription" />
							</strong>				
						
							<br/>
						
							<xsl:call-template name="replaceLineBreak">
								<xsl:with-param name="string" select="FlowInstance/Attributes/Attribute[Name = 'decisionDescription']/Value"/>
							</xsl:call-template>
						</p>
					
					</xsl:when>		
					<xsl:when test="FlowInstance/Attributes/Attribute[Name = 'rejectionDescription']">
					
						<p class="floatleft clearleft">
							<strong class="floatleft clearleft">
								<xsl:value-of select="$i18n.VoteForm.Rejected" />
							</strong>				
						
							<br/>
						
							<xsl:call-template name="replaceLineBreak">
								<xsl:with-param name="string" select="FlowInstance/Attributes/Attribute[Name = 'rejectionDescription']/Value"/>
							</xsl:call-template>
						</p>
					
					</xsl:when>
					<xsl:when test="VoteEnding">
					
						<div class="floatleft clearleft bigmarginbottom" style="margin-right: 20px;">
							<strong>
								<xsl:choose>
									<xsl:when test="Active">
										<xsl:value-of select="$i18n.VoteForm.VotingEnds" />
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="$i18n.VoteForm.VotingEnded" />
									</xsl:otherwise>
								</xsl:choose>
							</strong>
							
							<div>
								<xsl:value-of select="VoteEnding"/>
							</div>
						</div>
						
						<div class="floatleft" style="margin-right: 20px;">
							<strong class="clearleft"><xsl:value-of select="$i18n.Columns.Votes" /></strong>
							
							<div>
								<xsl:value-of select="Votes"/>
							</div>
						</div>
						
						<xsl:if test="Vote">
							<div class="floatleft">
								<xsl:text>(</xsl:text>
								<xsl:value-of select="$i18n.Voting.VotedOn"/>
								<xsl:text> </xsl:text>
								<xsl:value-of select="Vote/timestamp"/>
								<xsl:text>)</xsl:text>
							</div>
						</xsl:if>
					
					</xsl:when>
				</xsl:choose>
				
				<p class="floatleft clearleft">
					<strong class="floatleft full">
						<xsl:value-of select="$i18n.VoteForm.LongDescription" />
					</strong>
		
					<br/>
		
					<xsl:call-template name="replaceLineBreak">
						<xsl:with-param name="string" select="FlowInstance/Attributes/Attribute[Name = 'longdescription']/Value"/>
					</xsl:call-template>
				</p>
				
				<xsl:if test="Files and Settings/hideAttachedFiles != 'true'">
				
					<div class="floatleft clearleft bigmarginbottom">
					
						<p>
							<strong>
								<xsl:value-of select="$i18n.VoteForm.Files" />
							</strong>
							
							<br/>
							
							<xsl:for-each select="Files/File">
								<a class="floatleft clearleft" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/file/{../../FlowInstance/flowInstanceID}/{Index}">
									<xsl:value-of select="FileName"/>
								</a>
							</xsl:for-each>				
						</p>
					
					</div>
				</xsl:if>
				
			</div>
	
			<div class="floatleft fourtyfive">
				<xsl:if test="Settings/additionalAttributes">
					<xsl:if	test="Settings/extraInfoName1">
						<div class="floatleft clearleft bigmarginbottom">
							<strong><xsl:value-of select="Settings/extraInfoName1" /></strong>
							<br/>
							<xsl:call-template name="replaceLineBreak">
								<xsl:with-param name="string" select="extraInfoAttribute1"/>
							</xsl:call-template>
						</div>
					</xsl:if>
					<xsl:if	test="Settings/extraInfoName2">
						<div class="floatleft clearleft bigmarginbottom">
							<strong><xsl:value-of select="Settings/extraInfoName2" /></strong>
							<br/>
							<xsl:call-template name="replaceLineBreak">
								<xsl:with-param name="string" select="extraInfoAttribute2"/>
							</xsl:call-template>
						</div>
					</xsl:if>
					<xsl:if	test="Settings/extraInfoName3">
						<div class="floatleft clearleft bigmarginbottom">
							<strong><xsl:value-of select="Settings/extraInfoName3" /></strong>
							<br/>
							<xsl:call-template name="replaceLineBreak">
								<xsl:with-param name="string" select="extraInfoAttribute3"/>
							</xsl:call-template>
						</div>
					</xsl:if>
				</xsl:if>
			</div>
		</div>		
		
		<xsl:variable name="showURI">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/show/</xsl:text>
			<xsl:value-of select="FlowInstance/flowInstanceID"/>
		</xsl:variable>

		<xsl:variable name="voteURI">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/vote/</xsl:text>
			<xsl:value-of select="FlowInstance/flowInstanceID"/>
		</xsl:variable>

		<div class="clearleft">		
			<xsl:if test="Active">
				<form method="POST" action="{$showURI}">

					<input type="hidden" id="action" name="action" value="none"/>
					
					<xsl:if test="Owner">
					
						<div style="display: none;">
							<div id="prenumeration-modal" class="contentitem" style="max-width: 600px;">
								<div class="modal-content">
								
									<xsl:choose>
										<xsl:when test="ActiveVoteReceivedPrenumeration">				
											<div class="modal-header bigmarginbottom">
												<h1>
													<xsl:value-of select="$i18n.PauseVotePrenumerationForm.title" />
												</h1>
											</div>
											
											<div class="modal-body">
			
												<div class="floatleft full bigmarginbottom">
													<p>
														<xsl:value-of select="$i18n.PauseVotingPrenumeration.description"/>
													</p>
													<p>
														<xsl:value-of select="$i18n.VotingPrenumeration.description"/>
													</p>
												</div>
												
												<input class="btn btn-green confirm floatright bigmarginleft" type="button" value="{$i18n.Voting.ConfirmPauseVotePrenumeration}" />

											</div>											
										</xsl:when>
										<xsl:when test="NoActiveVoteReceivedPrenumeration">
											<div class="modal-header bigmarginbottom">
												<h1>
													<xsl:value-of select="$i18n.ActivateVotePrenumerationForm.title" />
												</h1>
											</div>
											
											<div class="modal-body">

												<div class="floatleft full bigmarginbottom">
													<p>
														<xsl:value-of select="$i18n.ActivateVotingPrenumeration.description"/>
													</p>
													<p>
														<xsl:value-of select="$i18n.VotingPrenumeration.description"/>
													</p>
												</div>
	
												<input class="btn btn-green confirm floatright bigmarginleft" type="button" value="{$i18n.Voting.ConfirmActivateVotePrenumeration}" />
											</div>
										</xsl:when>
									</xsl:choose>
									
									<input class="btn btn-light close floatright" type="button" value="{$i18n.Back}" />
								</div>
							</div>
						</div>

						<xsl:if	test="Settings/votingActivated = 'true'">
							<xsl:choose>
								<xsl:when test="ActiveVoteReceivedPrenumeration">				
									<div class="floatleft">
										<a id="pauseVotingPrenumerationButton" href="#" class="btn btn-light" onclick="pauseVotingPrenumerationModal(event, this, 'pause');">
											<xsl:value-of select="$i18n.Voting.PauseVoteReceivedPrenumeration"/>
										</a>
									</div>
								</xsl:when>
								<xsl:when test="NoActiveVoteReceivedPrenumeration">
									<div class="floatleft">
										<a id="activateVotingPrenumerationButton" href="#" class="btn btn-light" onclick="activateVotingPrenumerationModal(event, this, 'activate');">
											<xsl:value-of select="$i18n.Voting.ActivateVoteReceivedPrenumeration"/>
										</a>
									</div>
								</xsl:when>
							</xsl:choose>
						</xsl:if>	
					</xsl:if>
				
					<div class="floatright marginleft">
					
						<xsl:choose>
							<xsl:when test="Vote">
							
								<a id="removeVoteButton" href="#" class="btn btn-red" onclick="removeVote(this);">
									<xsl:value-of select="$i18n.Voting.RemoveVote"/>
								</a>
							
							</xsl:when>
							<xsl:when test="not(LoggedIn)">
							
								<xsl:attribute name="action"><xsl:value-of select="$voteURI"/></xsl:attribute>
								
								<xsl:if test="Settings/votingActivated = 'true'">
									<a href="#" class="btn btn-green" onclick="$(this).closest('form').trigger('submit'); event.preventDefault();">
										<xsl:value-of select="$i18n.Voting.Vote"/>
									</a>
								</xsl:if>
							
							</xsl:when>
							<xsl:when test="WrongMunicipality">
							
								<div style="display: none;">
									
									<div class="vote-modal contentitem" style="max-width: 600px;">
										<div class="modal-content">
											
											<div class="modal-header bigmarginbottom">
												<h1>
													<xsl:value-of select="$i18n.VoteForm.title" />
												</h1>
											</div>
											
											<div class="modal-body">
												
												<h3 class="bigmarginbottom"><xsl:value-of select="FlowInstance/userDescription" /></h3>
												
												<div class="floatleft full bigmarginbottom">
													<p class="error">
														<xsl:value-of select="$i18n.Validation.WrongMunicipalCode"/>
													</p>
												</div>
												
												<input class="btn btn-light close floatright" type="button" value="{$i18n.Back}" />
												
											</div>
											
										</div>
									</div>
								
								</div>
								
								<xsl:if test="Settings/votingActivated = 'true'">
									<a id="voteButton" href="#" class="btn btn-green" onclick="voteModal(event, this);">
										<xsl:value-of select="$i18n.Voting.Vote"/>
									</a>
								</xsl:if>
							
							</xsl:when>
							<xsl:otherwise>
							
								<div style="display: none;">
									
									<div class="vote-modal contentitem" style="max-width: 600px;">
										<div class="modal-content">
											
											<div class="modal-header bigmarginbottom">
												<h1>
													<xsl:value-of select="$i18n.VoteForm.title" />
												</h1>
											</div>
											
											<div class="modal-body">
												
												<h3 class="bigmarginbottom"><xsl:value-of select="FlowInstance/userDescription" /></h3>
												
												<div class="floatleft full bigmarginbottom">
													<p>
														<xsl:value-of select="$i18n.Voting.description.1"/>
													</p>
													<p>
														<xsl:value-of select="$i18n.Voting.description.2"/>
													</p>
												</div>
												
												<input class="btn btn-green confirm floatright bigmarginleft" type="button" value="{$i18n.Voting.ConfirmVote}" />
												
												<input class="btn btn-light close floatright" type="button" value="{$i18n.Back}" />
												
											</div>
											
										</div>
									</div>
								
								</div>
	
								<xsl:if test="Settings/votingActivated = 'true'">							
<!-- 									<input type="hidden" name="add" value="true"/> -->
									<a id="voteButton" href="#" class="btn btn-green" onclick="voteModal(event, this);">
										<xsl:value-of select="$i18n.Voting.Vote"/>
									</a>
								</xsl:if>							
							</xsl:otherwise>
						</xsl:choose>
						
						<xsl:if test="OpenVoteModal">
							<script>
								$(function() {
	
									$('#voteButton').trigger('click');
								});
							</script>
						</xsl:if>
								
					</div>
				</form>
			</xsl:if>
			
			<div class="floatright marginright">
				<xsl:choose>
					<xsl:when test="Active">
	
						<a class="btn btn-light" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/{Settings/alias}" title="{$i18n.Back}">
							<xsl:value-of select="$i18n.Back"/>
						</a>
					
					</xsl:when>
					<xsl:otherwise>
					
						<a class="btn btn-light" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/archived/{Settings/alias}" title="{$i18n.Back}">
							<xsl:value-of select="$i18n.Back"/>
						</a>
					
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>		
		
	</xsl:template>

	<xsl:template match="ListPropositions">
	
		<div class="full">
			<div class="heading">
				<h1>
					<xsl:value-of select="Settings/title" />
				</h1>
			</div>
			<xsl:if test="Settings/rssFeedActive = 'true'">
				<div class="rssicon">
					<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/rss/{Settings/alias}" title="{$i18n.RssFlow}">
						<img src="{$imgPath}/rss.png"/>
					</a>
				</div>
			</xsl:if>
		</div>
		
		<xsl:apply-templates select="validationError"/>
		
		<div id="active-description" class="floatleft" style="max-width: calc(100% - 220px);">
			<h2><xsl:value-of select="$i18n.ActiveVotings"/></h2>
			<p>
				<xsl:value-of select="Settings/description" />
			</p>
		</div>
		
		<table id="active" class="display oep-table">
			<thead class="hide-mobile">
				<tr>
					<th/> <!-- instanceID -->
					<th><xsl:value-of select="$i18n.Columns.Title" /></th>
					<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName1" /></th>
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName2" /></th>
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName3" /></th>
							</xsl:if>
					</xsl:if>
					<th><xsl:value-of select="$i18n.Columns.PropositionDate" /></th>
					<xsl:if test="Settings/showStatusInList = 'true'">
						<th><xsl:value-of select="$i18n.Columns.Status"/></th>
					</xsl:if>
					<th><xsl:value-of select="$i18n.Columns.Description" /></th>
				</tr>
			</thead>
			<tbody/>
		</table>
		
		<xsl:variable name="ajaxURL">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/activepropositionsdata/</xsl:text>
			<xsl:value-of select="Settings/flowFamilyID"/>
		</xsl:variable>
		
		<script type="text/javascript">
			$(function() {
			
				var table = $('#active').DataTable({
					ajax: { url: '<xsl:value-of select="$ajaxURL"/>',
									dataSrc: 'rows',
					},
					deferRender: true,
					columns: [
						{ "name": "instanceID", "visible": false },
						{ "name": "title",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Title"/>");}
						},
						<xsl:if test="Settings/showStatusInList = 'true'">
							{ "name": "showStatusInList",
								createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Status"/>");}
							},
						</xsl:if>
						<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								{ "name": "extraInfoName1",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName1"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								{ "name": "extraInfoName2",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName2"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								{ "name": "extraInfoName3",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName3"/>");}
								},
							</xsl:if>
						</xsl:if>
						{ "name": "votingEnding",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.PropositionDate"/>");}
						},
						{ "name": "description",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Description"/>");}
						},
				  ],
				  order: [[ 1, 'desc' ]],
				  dom: 'frtipl',
					bAutoWidth: false,
					paging: true,
					pagingType: 'simple_numbers',
					pageLength: <xsl:value-of select="Settings/pageSize"/>,
					lengthMenu: [ 15, 25, 50, 100, 200, 500 ],
					language: {
						"decimal":        "<xsl:value-of select="$i18n.DataTable.decimal"/>",
						"emptyTable":     "<xsl:value-of select="$i18n.DataTable.emptyTable"/>",
						"info":           "<xsl:value-of select="$i18n.DataTable.info"/>",
						"infoEmpty":      "<xsl:value-of select="$i18n.DataTable.infoEmpty"/>",
						"infoFiltered":   "<xsl:value-of select="$i18n.DataTable.infoFiltered"/>",
						"infoPostFix":    "<xsl:value-of select="$i18n.DataTable.infoPostFix"/>",
						"thousands":      "<xsl:value-of select="$i18n.DataTable.thousands"/>",
						"lengthMenu":     "<xsl:value-of select="$i18n.DataTable.lengthMenu"/>",
						"loadingRecords": "<xsl:value-of select="$i18n.DataTable.loadingRecords"/>",
						"processing":     "<xsl:value-of select="$i18n.DataTable.processing"/>",
						"search":         "<xsl:value-of select="$i18n.DataTable.search"/>",
						"zeroRecords":    "<xsl:value-of select="$i18n.DataTable.zeroRecords"/>",
						paginate: {
							"first":      "<xsl:value-of select="$i18n.DataTable.paginate.first"/>",
							"last":       "<xsl:value-of select="$i18n.DataTable.paginate.last"/>",
							"next":       "<xsl:value-of select="$i18n.DataTable.paginate.next"/>",
							"previous":   "<xsl:value-of select="$i18n.DataTable.paginate.previous"/>"
						},
						aria: {
							"sortAscending":  "<xsl:value-of select="$i18n.DataTable.aria.sortAscending"/>",
							"sortDescending": "<xsl:value-of select="$i18n.DataTable.aria.sortDescending"/>"
						},
					},
					fixedHeader: true,
				});
				
				$("#active_wrapper").prepend($("#active-description"));
				
				table.on( 'click', 'tbody td', function() {
				
					var td = $(this);
					var tr = td.parent();
					
					if (tr.children("td").first().hasClass("dataTables_empty")){
						return;
					}
					
					if(tr.closest("table").hasClass("collapsed") &amp;&amp; td.is(":first-child")){
						return;
					}
					
					var flowInstanceID = table.cell(tr, "instanceID:name").data();
					window.location = "<xsl:value-of select="/Document/requestinfo/currentURI"/>/<xsl:value-of select="/Document/module/alias"/>/show/" + flowInstanceID;
				});
			});
		</script>
		
		<div class="clearboth floatright bigmargintop">
			<a class="btn btn-light marginright" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/archived/{Settings/alias}" title="{$i18n.ShowArchived}">
				<xsl:value-of select="$i18n.ShowArchived"/>
			</a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="ListArchivedPropositions">
	
		<h1>
			<xsl:value-of select="Settings/title" />
		</h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<div id="archived-description" class="floatleft" style="max-width: calc(100% - 220px);">
			<h2><xsl:value-of select="$i18n.ArchivedVotings"/></h2>
<!-- 			<p> -->
<!-- 				<xsl:value-of select="Settings/description" /> -->
<!-- 			</p> -->
		</div>
		
		<table id="archived" class="display oep-table">
			<thead class="hide-mobile">
				<tr>
					<th/> <!-- instanceID -->
					<th><xsl:value-of select="$i18n.Columns.Title" /></th>
					<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName1" /></th>
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName2" /></th>
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								<th><xsl:value-of select="Settings/extraInfoName3" /></th>
							</xsl:if>
					</xsl:if>
					<th><xsl:value-of select="$i18n.Columns.PropositionDate" /></th>
					<th><xsl:value-of select="$i18n.Columns.Status" /></th>
					<th><xsl:value-of select="$i18n.Columns.Description" /></th>
				</tr>
			</thead>
			<tbody/>
		</table>
		
		<xsl:variable name="ajaxURL">
			<xsl:value-of select="/Document/requestinfo/currentURI"/>
			<xsl:text>/</xsl:text>
			<xsl:value-of select="/Document/module/alias"/>
			<xsl:text>/archivedpropositionsdata/</xsl:text>
			<xsl:value-of select="Settings/flowFamilyID"/>
		</xsl:variable>
		
		<script type="text/javascript">
			$(function() {
			
				var table = $('#archived').DataTable({
					ajax: { url: '<xsl:value-of select="$ajaxURL"/>',
									dataSrc: 'rows',
					},
					deferRender: true,
					columns: [
						{ "name": "instanceID", "visible": false},
						{ "name": "title",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Title"/>");}
						},
						<xsl:if test="Settings/additionalAttributes">
							<xsl:if test="Settings/extraInfoName1 and Settings/hideInList1 != 'true'">
								{ "name": "extraInfoName1",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName1"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName2 and Settings/hideInList2 != 'true'">
								{ "name": "extraInfoName2",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName2"/>");}
								},
							</xsl:if>
							<xsl:if test="Settings/extraInfoName3 and Settings/hideInList3 != 'true'">
								{ "name": "extraInfoName3",
									createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="Settings/extraInfoName3"/>");}
								},
							</xsl:if>
						</xsl:if>
						{ "name": "propositiondate",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.PropositionDate"/>");}
						},
						{ "name": "status",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="$i18n.Columns.Status"/>");}
						},
						{ "name": "longdescription",
							createdCell: function(td, cellData, rowData, row, col){$(td).attr("data-title", "<xsl:value-of select="i18n.Columns.Description"/>");},
						},
				  ],
				  order: [[ 1, 'desc' ]],
				  dom: 'frtipl',
					bAutoWidth: false,
					paging: true,
					pagingType: 'simple_numbers',
					pageLength: <xsl:value-of select="Settings/pageSize"/>,
					lengthMenu: [ 15, 25, 50, 100, 200, 500 ],
					language: {
						"decimal":        "<xsl:value-of select="$i18n.DataTable.decimal"/>",
						"emptyTable":     "<xsl:value-of select="$i18n.DataTable.emptyTable"/>",
						"info":           "<xsl:value-of select="$i18n.DataTable.info"/>",
						"infoEmpty":      "<xsl:value-of select="$i18n.DataTable.infoEmpty"/>",
						"infoFiltered":   "<xsl:value-of select="$i18n.DataTable.infoFiltered"/>",
						"infoPostFix":    "<xsl:value-of select="$i18n.DataTable.infoPostFix"/>",
						"thousands":      "<xsl:value-of select="$i18n.DataTable.thousands"/>",
						"lengthMenu":     "<xsl:value-of select="$i18n.DataTable.lengthMenu"/>",
						"loadingRecords": "<xsl:value-of select="$i18n.DataTable.loadingRecords"/>",
						"processing":     "<xsl:value-of select="$i18n.DataTable.processing"/>",
						"search":         "<xsl:value-of select="$i18n.DataTable.search"/>",
						"zeroRecords":    "<xsl:value-of select="$i18n.DataTable.zeroRecords"/>",
						paginate: {
							"first":      "<xsl:value-of select="$i18n.DataTable.paginate.first"/>",
							"last":       "<xsl:value-of select="$i18n.DataTable.paginate.last"/>",
							"next":       "<xsl:value-of select="$i18n.DataTable.paginate.next"/>",
							"previous":   "<xsl:value-of select="$i18n.DataTable.paginate.previous"/>"
						},
						aria: {
							"sortAscending":  "<xsl:value-of select="$i18n.DataTable.aria.sortAscending"/>",
							"sortDescending": "<xsl:value-of select="$i18n.DataTable.aria.sortDescending"/>"
						},
					},
					fixedHeader: true,
				});
				
				$("#archived_wrapper").prepend($("#archived-description"));
				
				table.on( 'click', 'tbody td', function() {
				
					var td = $(this);
					var tr = td.parent();
					
					if(tr.children("td").first().hasClass("dataTables_empty")){
						return;
					}
					
					if(tr.closest("table").hasClass("collapsed") &amp;&amp; td.is(":first-child")){
						return;
					}
					
					var flowInstanceID = table.cell(tr, "instanceID:name").data();
					window.location = "<xsl:value-of select="/Document/requestinfo/currentURI"/>/<xsl:value-of select="/Document/module/alias"/>/show/" + flowInstanceID;
				});
			});
		</script>
		
		<div class="clearboth floatright bigmargintop">
			<a class="btn btn-light" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/{Settings/alias}" title="{$i18n.Back}">
				<xsl:value-of select="$i18n.Back"/>
			</a>
		</div>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='FlowFamilyNotFound']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.FlowFamilyNotFound"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='VotingDisabled']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.VotingDisabled"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='WrongMunicipalCode']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.WrongMunicipalCode"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='UnknownStatus']">
		<p class="error">
			<xsl:choose>
				<xsl:when test="fieldName = 'votePassedStatus'">
					<xsl:value-of select="$i18n.Settings.votePassedStatus"/>
				</xsl:when>
				<xsl:when test="fieldName = 'voteFailedStatus'">
					<xsl:value-of select="$i18n.Settings.voteFailedStatus"/>
				</xsl:when>
				<xsl:when test="fieldName = 'archivedStatus'">
					<xsl:value-of select="$i18n.Settings.archivedStatuses"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="fieldName"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:text>:&#x20;</xsl:text>
			<xsl:value-of select="$i18n.Validation.UnkownStatus.1"/>
			<xsl:text>&#x20;"</xsl:text>
			<xsl:value-of select="displayName"/>
			<xsl:text>"&#x20;</xsl:text>
			<xsl:value-of select="$i18n.Validation.UnkownStatus.2"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='DuplicateAlias']">
		<p class="error">
			<xsl:value-of select="$i18n.Validation.DuplicateAlias.1"/>
			<xsl:text>&#x20;"</xsl:text>
			<xsl:value-of select="displayName"/>
			<xsl:text>"&#x20;</xsl:text>
			<xsl:value-of select="$i18n.Validation.DuplicateAlias.2"/>
		</p>
	</xsl:template>
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="fieldName = 'alias'">
						<xsl:value-of select="$i18n.Settings.alias"/>
					</xsl:when>
					<xsl:when test="fieldName = 'municipalCode'">
						<xsl:value-of select="$i18n.Settings.municipalCode"/>
					</xsl:when>
					<xsl:when test="fieldName = 'siteProfileID'">
						<xsl:value-of select="$i18n.Settings.siteProfileID"/>
					</xsl:when>
					<xsl:when test="fieldName = 'title'">
						<xsl:value-of select="$i18n.Settings.title"/>
					</xsl:when>
					<xsl:when test="fieldName = 'description'">
						<xsl:value-of select="$i18n.Settings.description"/>
					</xsl:when>
					<xsl:when test="fieldName = 'votingDays'">
						<xsl:value-of select="$i18n.Settings.votingDays"/>
					</xsl:when>
					<xsl:when test="fieldName = 'requiredVotes'">
						<xsl:value-of select="$i18n.Settings.requiredVotes"/>
					</xsl:when>
					<xsl:when test="fieldName = 'publishedStatus'">
						<xsl:value-of select="$i18n.Settings.publishStatus"/>
					</xsl:when>
					<xsl:when test="fieldName = 'votePassedStatus'">
						<xsl:value-of select="$i18n.Settings.votePassedStatus"/>
					</xsl:when>
					<xsl:when test="fieldName = 'voteFailedStatus'">
						<xsl:value-of select="$i18n.Settings.voteFailedStatus"/>
					</xsl:when>
					<xsl:when test="fieldName = 'archivedStatus'">
						<xsl:value-of select="$i18n.Settings.archivedStatuses"/>
					</xsl:when>
					<xsl:when test="fieldName = 'extraInfoName1'">
						<xsl:value-of select="$i18n.Settings.extraInfoName1"/>
					</xsl:when>
					<xsl:when test="fieldName = 'extraInfoAttribute1'">
						<xsl:value-of select="$i18n.Settings.extraInfoAttribute1"/>
					</xsl:when>
					<xsl:when test="fieldName = 'extraInfoName2'">
						<xsl:value-of select="$i18n.Settings.extraInfoName2"/>
					</xsl:when>
					<xsl:when test="fieldName = 'extraInfoAttribute2'">
						<xsl:value-of select="$i18n.Settings.extraInfoAttribute2"/>
					</xsl:when>
					<xsl:when test="fieldName = 'extraInfoName3'">
						<xsl:value-of select="$i18n.Settings.extraInfoName3"/>
					</xsl:when>
					<xsl:when test="fieldName = 'extraInfoAttribute3'">
						<xsl:value-of select="$i18n.Settings.extraInfoAttribute3"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>
	
</xsl:stylesheet>