package com.nordicpeak.flowengine.evaluators.geometrycontainsaddressquerystateevaluator;

import java.util.ArrayList;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.evaluators.basequerystateevaluator.BaseQueryStateEvaluator;
import com.vividsolutions.jts.geom.Geometry;

@Table(name = "geometry_contains_address_state_evaluators")
@XMLElement
public class GeometryContainsAddressQueryStateEvaluator extends BaseQueryStateEvaluator {

	private static final long serialVersionUID = 7582032280793947029L;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean invert;

	@DAOManaged
	@WebPopulate(maxLength = 65536)
	@XMLElement
	private String geometry;

	private Geometry parsedGeometry;

	private Boolean initialisedState;

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		super.populate(xmlParser);

		List<ValidationError> errors = new ArrayList<ValidationError>(1);

		invert = xmlParser.getPrimitiveBoolean("invert");
		geometry = XMLValidationUtils.validateParameter("geometry", xmlParser, false, 1, 65536, StringPopulator.getPopulator(), errors);

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	public boolean isInverted() {

		return invert;
	}

	public void setInvert(boolean invert) {

		this.invert = invert;
	}

	@Override
	public boolean requiresInitialization() {

		return true;
	}

	public String getGeometry() {

		return geometry;
	}

	public void setGeometry(String geometryStr) {

		this.geometry = geometryStr;
	}

	public Geometry getParsedGeometry() {

		return parsedGeometry;
	}

	public void setParsedGeometry(Geometry geometry) {

		this.parsedGeometry = geometry;
	}

	public Boolean getInitialisedState() {

		return initialisedState;
	}

	public void setInitialisedState(Boolean initialisedState) {

		this.initialisedState = initialisedState;
	}

}
