package com.nordicpeak.flowengine.integration.http;

import java.util.List;

import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.webutils.populators.StringHTTPURLPopulator;

@Table(name = "http_integration_settings")
@XMLElement
public class FlowFamilyIntegrationSettings extends GeneratedElementable {

	@DAOManaged
	@Key
	@XMLElement
	private Integer flowFamilyID;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean enabled;
	
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "password")
	@XMLElement
	private String username;
	
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "username")
	@XMLElement
	private String password;

	@DAOManaged
	@WebPopulate(populator = StringHTTPURLPopulator.class, maxLength = 255)
	@RequiredIfSet(paramNames = "enabled")
	@XMLElement
	private String url;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean triggerOnStatusChanges;	
	
	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<IntegrationParameter> parameters;

	public boolean isEnabled() {

		return enabled;
	}

	public void setEnabled(boolean enabled) {

		this.enabled = enabled;
	}

	public String getUrl() {

		return url;
	}

	public void setUrl(String url) {

		this.url = url;
	}

	public Integer getFlowFamilyID() {

		return flowFamilyID;
	}

	public void setFlowFamilyID(Integer flowFamilyID) {

		this.flowFamilyID = flowFamilyID;
	}

	public List<IntegrationParameter> getParameters() {

		return parameters;
	}

	public void setParameters(List<IntegrationParameter> parameters) {

		this.parameters = parameters;
	}

	
	public String getUsername() {
	
		return username;
	}

	
	public void setUsername(String username) {
	
		this.username = username;
	}

	
	public String getPassword() {
	
		return password;
	}

	
	public void setPassword(String password) {
	
		this.password = password;
	}

	public boolean isPopulated() {

		if(enabled || url != null || username != null || password != null || parameters != null){
		
			return true;
		}
		
		return false;
	}

	
	public boolean isTriggerOnStatusChanges() {
	
		return triggerOnStatusChanges;
	}

	
	public void setTriggerOnStatusChanges(boolean triggerOnStatusChanges) {
	
		this.triggerOnStatusChanges = triggerOnStatusChanges;
	}
}
