<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/js/confirmpost.js
	</xsl:variable>	

	<xsl:variable name="scripts">
		/js/httpintegration.js
	</xsl:variable>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:template match="Document">
	
		<xsl:apply-templates select="ShowIntegrationSettings" />
		<xsl:apply-templates select="UpdateIntegrationSettings" />
			
	</xsl:template>
	
	<xsl:template match="ShowIntegrationSettings">
	
		<a name="httpintegrationsettings" />
		
		<xsl:choose>
			<xsl:when test="FlowFamilyIntegrationSettings">
					
				<xsl:value-of select="$i18n.IntegrationEnabled"/>
				<xsl:text>:&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="FlowFamilyIntegrationSettings/enabled = 'true'">
						<xsl:value-of select="$i18n.Yes"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.No"/>
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:if test="FlowFamilyIntegrationSettings/url">
					<br/>
								
					<xsl:value-of select="$i18n.Url"/>
					<xsl:text>:&#x20;</xsl:text>
					<xsl:value-of select="FlowFamilyIntegrationSettings/url"/>
				</xsl:if>
				
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$i18n.NoFlowFamilyIntegrationSettings" />
			</xsl:otherwise>
		</xsl:choose>
		
		<a href="{/Document/ModuleURI}/update/{Flow/flowID}" class="floatright">
			<xsl:value-of select="$i18n.UpdateFlowFamilyIntegrationSettings" />
			<img class="alignbottom" src="{/Document/StaticContentURL}/pics/pen.png" alt="" />
		</a>
		
		<xsl:if test="FlowFamilyIntegrationSettings">
			<a href="{/Document/ModuleURI}/delete/{Flow/flowID}" class="floatright clearboth" onclick="return confirmPost(this.href, '{$i18n.DeleteFlowFamilyIntegrationSettings.Confirm}');">
				<xsl:value-of select="$i18n.DeleteIntegrationSettings" />
				<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
			</a>		
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="UpdateIntegrationSettings">
		
		<div id="HTTPIntegrationProvider" class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.UpdateIntegrationSettingsTitle"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
				<xsl:text>&#x20;(</xsl:text>
				<xsl:value-of select="$i18n.flowVersion"/>
				<xsl:text>&#x20;</xsl:text>
				<xsl:value-of select="Flow/version"/>
				<xsl:text>)</xsl:text>
			</h1>
	
			<xsl:apply-templates select="validationException/validationError"/>
	
			<form method="post" action="{/Document/ModuleURI}/update/{Flow/flowID}">
			
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'enabled'" />
						<xsl:with-param name="id" select="'enabled'" />
						<xsl:with-param name="element" select="FlowFamilyIntegrationSettings" />       
					</xsl:call-template>
					
					<label for="enabled">
						<xsl:value-of select="$i18n.Enabled" />
					</label>
				</div>
			
				<label for="url" class="floatleft full">
					<xsl:value-of select="$i18n.Url" />
				</label>
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'url'"/>
						<xsl:with-param name="name" select="'url'"/>
						<xsl:with-param name="element" select="FlowFamilyIntegrationSettings" />          
					</xsl:call-template>
				</div>
				
				<label for="username" class="floatleft full">
					<xsl:value-of select="$i18n.Username" />
				</label>				
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'username'"/>
						<xsl:with-param name="name" select="'username'"/>
						<xsl:with-param name="element" select="FlowFamilyIntegrationSettings" />          
					</xsl:call-template>
				</div>
				
				<label for="password" class="floatleft full">
					<xsl:value-of select="$i18n.Password" />
				</label>				
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'password'"/>
						<xsl:with-param name="name" select="'password'"/>
						<xsl:with-param name="element" select="FlowFamilyIntegrationSettings" />          
					</xsl:call-template>
				</div>	
			
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'triggerOnStatusChanges'" />
						<xsl:with-param name="id" select="'triggerOnStatusChanges'" />
						<xsl:with-param name="element" select="FlowFamilyIntegrationSettings" />       
					</xsl:call-template>
					
					<label for="triggerOnStatusChanges">
						<xsl:value-of select="$i18n.TriggerOnStatusChanges" />
					</label>
				</div>			
			
				<div class="full floatleft bigmargintop">
					<h2><xsl:value-of select="$i18n.Parameters" /></h2>
				</div>
			
				<table id="param-table" class="full coloredtable ">
					<thead>
						<tr>
							<th><xsl:value-of select="$i18n.Name" /></th>
							<th><xsl:value-of select="$i18n.Value" /></th>
							<th width="16px"></th>
						</tr>
					</thead>
					<tbody>
					
						<xsl:choose>
							<xsl:when test="requestparameters">
							
								<xsl:apply-templates select="requestparameters/parameter[name = 'parameterID']/value" mode="parameter"/>
							
							</xsl:when>
							<xsl:otherwise>
							
								<xsl:apply-templates select="FlowFamilyIntegrationSettings/Parameters/IntegrationParameter"/>
							
							</xsl:otherwise>
						</xsl:choose>					
					
					</tbody>
				</table>
				
				<div class="floatright">
					<a onclick="addParameter();">
						<xsl:value-of select="$i18n.AddParameter" />
						<img class="alignbottom" src="{/Document/StaticContentURL}/pics/add.png" alt="" />
					</a>
				</div>			
			
				<div class="floatright clearboth bigmargintop">
					<input type="submit" value="{$i18n.SaveChanges}" />
				</div>
			
			</form>
		
			<div style="display: none;">
				
				<table>
					<tr id="parameter-template">
						<td>
							<input type="text" name="name" class="full"/>
						</td>
						<td>
							<input type="text" name="value" class="full"/>
						</td>
						<td>
							<input type="hidden" name="parameterID"/>
							
							<a onclick="deleteParameter(this)">
								<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
							</a>				
						</td>
					</tr>
				</table>
				
			</div>		
		
		</div>

	</xsl:template>
	
	<xsl:template match="IntegrationParameter">
		
		<tr id="parameter-{parameterID}">
			<td>
				<input type="text" name="name-{parameterID}" value="{name}" class="full"/>
			</td>
			<td>
				<input type="text" name="value-{parameterID}" value="{value}" class="full"/>
			</td>
			<td>
				<input type="hidden" name="parameterID" value="{parameterID}"/>
				
				<a onclick="deleteParameter(this)">
					<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
				</a>				
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="value" mode="parameter">
		
 		<xsl:variable name="parameterID" select="."/>
		
		<xsl:variable name="nameParam" select="concat('name-', $parameterID)"/>
		
		<xsl:variable name="valueParam" select="concat('value-', $parameterID)"/>
		
		<tr id="parameter-{$parameterID}">
 			<td>
				<input type="text" name="name-{$parameterID}" value="{../../parameter[name = $nameParam]/value}" class="full"/>
			</td>
			<td>
				<input type="text" name="value-{$parameterID}" value="{../../parameter[name = $valueParam]/value}" class="full"/>
			</td>
			<td>
				<input type="hidden" name="parameterID" value="{$parameterID}"/>
				
				<a onclick="deleteParameter(this)">
					<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
				</a>				
			</td>
		</tr>
	
	</xsl:template>	
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>														
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="displayName">
						<xsl:value-of select="displayName"/>
					</xsl:when>
					<xsl:when test="fieldName = 'url'">
						<xsl:value-of select="$i18n.Url"/>
					</xsl:when>
					<xsl:when test="fieldName = 'username'">
						<xsl:value-of select="$i18n.Username"/>
					</xsl:when>
					<xsl:when test="fieldName = 'password'">
						<xsl:value-of select="$i18n.Password"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>			
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>	
	
</xsl:stylesheet>