<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:variable name="imagePath"><xsl:value-of select="/Document/requestinfo/contextpath" />/static/f/<xsl:value-of select="/Document/module/sectionID" />/<xsl:value-of select="/Document/module/moduleID" />/pics</xsl:variable>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-ui.js?v=1
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
	</xsl:variable>

	<xsl:variable name="scripts">
		/js/iconmapqueryadmin.js?v=2
		/js/colorpicker/jquery.minicolors.min.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/iconmapqueryadmin.css
		/js/colorpicker/jquery.minicolors.css
	</xsl:variable>

	<xsl:template match="Document">	
		
		<div id="IconMapQueryProvider" class="contentitem">
		
			<xsl:apply-templates select="validationError"/>
			<xsl:apply-templates select="UpdateIconMapQuery"/>
		
		</div>
		
		<script type="text/javascript">
			iconMapQueryAdminLanguage = {
				'CONFIRM_DELETE_ICON' : '<xsl:value-of select="$i18n.ConfirmDeleteIcon" />'
			};
		</script>
		
	</xsl:template>
		
	<xsl:template match="UpdateIconMapQuery">
	
		<h1><xsl:value-of select="$i18n.UpdateQuery" /><xsl:text>:&#160;</xsl:text><xsl:value-of select="IconMapQuery/QueryDescriptor/name" /></h1>
		
		<xsl:apply-templates select="validationException/validationError" />
		
		<form id="updateIconMapQueryForm" name="queryAdminForm" method="post" action="{/Document/requestinfo/uri}" enctype="multipart/form-data">
		
			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="IconMapQuery" />
			</xsl:call-template>
			
			<div class="floatleft full bigmarginbottom">
				<label class="floatleft clearboth" for="requiredQueryMessage"><xsl:value-of select="$i18n.RequiredQueryMessage" /></label>
				<div class="clearboth floatleft marginbottom"><xsl:value-of select="$i18n.RequiredQueryMessageDescription" /></div>
				<div class="floatleft full clearboth">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'requiredQueryMessage'" />
						<xsl:with-param name="name" select="'requiredQueryMessage'" />
						<xsl:with-param name="element" select="IconMapQuery" />
					</xsl:call-template>
				</div>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'forceQueryPopulation'"/>
					<xsl:with-param name="name" select="'forceQueryPopulation'"/>
					<xsl:with-param name="value" select="'true'"/>
					<xsl:with-param name="checked" select="IconMapQuery/forceQueryPopulation = 'true'" />
				</xsl:call-template>
				
				<label for="forceQueryPopulation"><xsl:value-of select="$i18n.ForceQueryPopulation" /></label>
			</div>
			
			<xsl:if test="RemoteGeometryEndpoints/Endpoint">
			
				<div class="floatleft full bigmarginbottom">

					<label for="geometryEndpointName">
						<xsl:value-of select="$i18n.GeometryEndpointName" />
					</label>
	
					<div class="floatleft full">
					
						<xsl:call-template name="createDropdown">
							<xsl:with-param name="id" select="'geometryEndpointName'"/>
							<xsl:with-param name="name" select="'geometryEndpointName'"/>
							<xsl:with-param name="element" select="RemoteGeometryEndpoints/Endpoint"/>
							<xsl:with-param name="labelElementName" select="'Name'"/>
							<xsl:with-param name="valueElementName" select="'ID'"/>
							<xsl:with-param name="selectedValue" select="CurrentEndpoint"/>
							<xsl:with-param name="addEmptyOption" select="' '" />
						</xsl:call-template>
					
					</div>
				</div>
					
				<div id="remoteGeometryEndpointSettings" class="floatleft full hidden">
					
					<div class="floatleft full bigmarginbottom">
						<label class="floatleft clearboth" for="noGeometriesMessage"><xsl:value-of select="$i18n.NoGeometriesMessage" /></label>
						<div class="clearboth floatleft marginbottom"><xsl:value-of select="$i18n.NoGeometriesMessageDescription" /></div>
						<div class="floatleft full clearboth">
							<xsl:call-template name="createTextField">
								<xsl:with-param name="id" select="'noGeometriesMessage'" />
								<xsl:with-param name="name" select="'noGeometriesMessage'" />
								<xsl:with-param name="element" select="IconMapQuery" />
							</xsl:call-template>
						</div>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'zoomToGeometries'"/>
							<xsl:with-param name="name" select="'zoomToGeometries'"/>
							<xsl:with-param name="value" select="'true'"/>
							<xsl:with-param name="checked" select="IconMapQuery/zoomToGeometries = 'true'" />
						</xsl:call-template>
						
						<label for="zoomToGeometries"><xsl:value-of select="$i18n.ZoomToGeometries" /></label>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'printAllFetchedGeometries'"/>
							<xsl:with-param name="name" select="'printAllFetchedGeometries'"/>
							<xsl:with-param name="value" select="'true'"/>
							<xsl:with-param name="checked" select="IconMapQuery/printAllFetchedGeometries = 'true'" />
						</xsl:call-template>
						
						<label for="printAllFetchedGeometries"><xsl:value-of select="$i18n.PrintAllFetchedGeometries" /></label>
					</div>
					
					<div class="floatleft full bigmarginbottom">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="id" select="'useSelectableGeometries'"/>
							<xsl:with-param name="name" select="'useSelectableGeometries'"/>
							<xsl:with-param name="value" select="'true'"/>
							<xsl:with-param name="checked" select="IconMapQuery/useSelectableGeometries = 'true'" />
						</xsl:call-template>
						
						<label for="useSelectableGeometries"><xsl:value-of select="$i18n.UseSelectableGeometries" /></label>
					</div>
				
					<div id="selectableGeometriesSettings" class="floatleft full hidden">
					
						<div class="floatleft thirty">
							<label for="minSelectableGeometries"><xsl:value-of select="$i18n.MinSelectableGeometries" /></label>
							<div>
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'minSelectableGeometries'" />
									<xsl:with-param name="name" select="'minSelectableGeometries'" />
									<xsl:with-param name="element" select="IconMapQuery" />
								</xsl:call-template>
							</div>
						</div>
						
						<div class="floatleft thirty bigmarginleft">
							<label for="maxSelectableGeometries"><xsl:value-of select="$i18n.MaxSelectableGeometries" /></label>
							<div>
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'maxSelectableGeometries'" />
									<xsl:with-param name="name" select="'maxSelectableGeometries'" />
									<xsl:with-param name="element" select="IconMapQuery" />
								</xsl:call-template>
							</div>
						</div>
					
						<div class="floatleft full bigmarginbottom">
							<label class="floatleft clearboth" for="missingGeometryMessage"><xsl:value-of select="$i18n.MissingGeometryMessage" /></label>
							<div class="clearboth floatleft marginbottom"><xsl:value-of select="$i18n.MissingGeometryMessageDescription" /></div>
							<div class="floatleft full clearboth">
								<xsl:call-template name="createTextField">
									<xsl:with-param name="id" select="'missingGeometryMessage'" />
									<xsl:with-param name="name" select="'missingGeometryMessage'" />
									<xsl:with-param name="element" select="IconMapQuery" />
								</xsl:call-template>
							</div>
						</div>
						
						<xsl:if test="ReservationAvailable = 'true'">
						
							<div class="floatleft full bigmarginbottom">
								<xsl:call-template name="createCheckbox">
									<xsl:with-param name="id" select="'selectableGeometryReservationEnabled'"/>
									<xsl:with-param name="name" select="'selectableGeometryReservationEnabled'"/>
									<xsl:with-param name="value" select="'true'"/>
									<xsl:with-param name="checked" select="IconMapQuery/selectableGeometryReservationEnabled = 'true'" />
								</xsl:call-template>
								
								<label for="selectableGeometryReservationEnabled"><xsl:value-of select="$i18n.SelectableGeometryReservationEnabled" /></label>
							</div>
						
							<div id="selectableGeometryReservationSettings" class="floatleft full hidden">
	
								<div class="clearboth floatleft full marginbottom"><xsl:value-of select="$i18n.ReservationEnabledLoginRequired" /></div>
							
								<div class="floatleft full">
									<label class="floatleft full" for="reservationMinutes"><xsl:value-of select="$i18n.ReservationMinutes" /></label>
									<div class="clearboth floatleft full marginbottom"><xsl:value-of select="$i18n.ReservationMinutes.Description" /></div>
									<div>
										<xsl:call-template name="createTextField">
											<xsl:with-param name="id" select="'reservationMinutes'" />
											<xsl:with-param name="name" select="'reservationMinutes'" />
											<xsl:with-param name="element" select="IconMapQuery" />
										</xsl:call-template>
									</div>
								</div>
								
								<div class="floatleft full">
									<label class="floatleft full" for="reservedGeometryColor"><xsl:value-of select="$i18n.ReservedGeometryColor" /></label>
									<div class="clearboth floatleft full marginbottom"><xsl:value-of select="$i18n.ReservedGeometryColor.Description" /></div>
									<div>
										<xsl:call-template name="createTextField">
											<xsl:with-param name="id" select="'reservedGeometryColor'" />
											<xsl:with-param name="name" select="'reservedGeometryColor'" />
											<xsl:with-param name="element" select="IconMapQuery" />
										</xsl:call-template>
									</div>
								</div>
							
								<div class="floatleft full bigmarginbottom">
									<label class="floatleft clearboth" for="geometryAlreadyReservedMessage"><xsl:value-of select="$i18n.GeometryAlreadyReservedMessage" /></label>
									<div class="clearboth floatleft marginbottom"><xsl:value-of select="$i18n.GeometryAlreadyReservedMessage.Description" /></div>
									<div class="floatleft full clearboth">
										<xsl:call-template name="createTextField">
											<xsl:with-param name="id" select="'geometryAlreadyReservedMessage'" />
											<xsl:with-param name="name" select="'geometryAlreadyReservedMessage'" />
											<xsl:with-param name="element" select="IconMapQuery" />
										</xsl:call-template>
									</div>
								</div>
							
							</div>
							
						</xsl:if>
					
					</div>
					
				</div>
			
			</xsl:if>
			
			<div class="floatleft full bigmarginbottom">
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'requirePUD'"/>
					<xsl:with-param name="name" select="'requirePUD'"/>
					<xsl:with-param name="value" select="'true'"/>
					<xsl:with-param name="checked" select="IconMapQuery/requirePUD = 'true'" />
				</xsl:call-template>
				
				<label for="requirePUD"><xsl:value-of select="$i18n.RequirePUD" /></label>
			</div>
			
			<div id="iconDrawingSettings">
					
				<div class="floatleft full bigmarginbottom settings">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'useDetailedIconInfo'"/>
						<xsl:with-param name="name" select="'useDetailedIconInfo'"/>
						<xsl:with-param name="value" select="'true'"/>
						<xsl:with-param name="checked" select="IconMapQuery/useDetailedIconInfo = 'true'" />
					</xsl:call-template>
					
					<label for="useDetailedIconInfo"><xsl:value-of select="$i18n.UseDetailedIconInfo" /></label>
				</div>
				
	 			<div class="floatleft full bigmarginbottom settings hidden">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'showIconPUDInfo'"/>
						<xsl:with-param name="name" select="'showIconPUDInfo'"/>
						<xsl:with-param name="value" select="'true'"/>
						<xsl:with-param name="checked" select="IconMapQuery/showIconPUDInfo = 'true'" />
					</xsl:call-template>
					
					<label for="showIconPUDInfo"><xsl:value-of select="$i18n.ShowIconPUDInfo" /></label>
				</div>
				
				<h2 class="floatleft clearboth"><xsl:value-of select="$i18n.MapIcons" /></h2>
				
				<div class="mapicon-container">
				
					<div class="mapicons settings">
					
						<xsl:choose>
							<xsl:when test="requestparameters">
							
								<xsl:apply-templates select="requestparameters/parameter[name = 'mapIconID']/value" mode="mapicon">
									<xsl:with-param name="mapIcons" select="IconMapQuery/Icons/MapIcon"/>
								</xsl:apply-templates>
								
							</xsl:when>
							<xsl:otherwise>
							
								<xsl:apply-templates select="IconMapQuery/Icons/MapIcon" />
								
							</xsl:otherwise>
						</xsl:choose>
				
					</div>
					
					<div class="mapicon-template" style="display: none">
					
						<xsl:call-template name="createMapIcon">
							<xsl:with-param name="mapIconID" select="''" />
							<xsl:with-param name="sortOrder" select="'sortIndex'" />
							<xsl:with-param name="iconImageFilename" select="''" />
							<xsl:with-param name="mapIconName" select="''" />
							<xsl:with-param name="minIcons" select="''" />
							<xsl:with-param name="maxIcons" select="''" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
					
					</div>
				
					<div class="floatright clearboth bigmarginbottom">
				
						<a href="#" onclick="addMapIcon(event)" title="{$i18n.AddIcon}">
							<xsl:value-of select="$i18n.AddIcon"/>
						</a>
						<a href="#" onclick="addMapIcon(event)" title="{$i18n.AddIcon}">
							<img class="vertical-align-bottom marginleft" src="{$imagePath}/add.png"/>
						</a>
				
					</div>
				
				</div>
				
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<h2><xsl:value-of select="$i18n.AdvancedSettings" /></h2>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'setAsAttribute'" />
						<xsl:with-param name="name" select="'setAsAttribute'" />
						<xsl:with-param name="element" select="IconMapQuery" /> 
						<xsl:with-param name="class" select="'vertical-align-middle'" />
					</xsl:call-template>
						
					<label for="setAsAttribute">
						<xsl:value-of select="$i18n.setAsAttribute" />
					</label>
			    </div>
			</div>
			
			<div id="attributeNameContainer" class="floatleft full bigmarginbottom">
			
				<label for="attributeName" class="floatleft clearboth"><xsl:value-of select="$i18n.attributeName" /></label>
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'attributeName'"/>
						<xsl:with-param name="name" select="'attributeName'"/>
						<xsl:with-param name="title" select="$i18n.attributeName"/>
						<xsl:with-param name="element" select="IconMapQuery" />
						<xsl:with-param name="maxlength" select="'255'"/>
					</xsl:call-template>
			    </div>
			    
				<p class="floatleft clearboth"><xsl:value-of select="$i18n.attributeDescription" /></p>
				
				<table class="floatleft clearboth border">
					<thead>
						<th><xsl:value-of select="$i18n.attributes.name" /></th>
						<th><xsl:value-of select="$i18n.attributes.value" /></th>
					</thead>
					<tbody>
						<tr id="mainPropertyUnitDesignationAttribute">
							<td>prefix.mainPropertyUnitDesignation</td>
							<td><xsl:value-of select="$i18n.attributes.mainPropertyUnitDesignation" /></td>
						</tr>
						<tr>
							<td>prefix.wkt</td>
							<td><xsl:value-of select="$i18n.attributes.wkt" /></td>
						</tr>
						<tr>
							<td>prefix.objectID</td>
							<td><xsl:value-of select="$i18n.attributes.objectID" /></td>
						</tr>
						<tr>
							<td>prefix.coordinates</td>
							<td><xsl:value-of select="$i18n.attributes.coordinates" /></td>
						</tr>
						<tr id="propertyUnitDesignationAttribute">
							<td>prefix.propertyUnitDesignation</td>
							<td><xsl:value-of select="$i18n.attributes.propertyUnitDesignation" /></td>
						</tr>
					</tbody>
				</table>
				
			</div>
			
			<div class="floatright bigmargintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>
		
		</form>
		
	</xsl:template>

	<xsl:template match="MapIcon">
		
		<xsl:call-template name="createMapIcon">
			<xsl:with-param name="mapIconID" select="mapIconID" />
			<xsl:with-param name="sortOrder" select="sortIndex" />
			<xsl:with-param name="iconImageFilename" select="iconImageFilename" />
			<xsl:with-param name="mapIconName" select="name" />
			<xsl:with-param name="minIcons" select="minIcons" />
			<xsl:with-param name="maxIcons" select="maxIcons" />
		</xsl:call-template>
			
	</xsl:template>

	<xsl:template match="value" mode="mapicon">
		<xsl:param name="mapIcons" />
		
		<xsl:variable name="id" select="." />
		
		<xsl:call-template name="createMapIcon">
			<xsl:with-param name="mapIconID" select="$id" />
			<xsl:with-param name="sortOrder" select="../../parameter[name = concat('sortOrder_', $id)]/value" />
			<xsl:with-param name="iconImageFilename" select="$mapIcons[mapIconID = $id]/iconImageFilename" />
			<xsl:with-param name="mapIconName" select="../../parameter[name = concat('mapIconName_', $id)]/value" />
			<xsl:with-param name="minIcons" select="../../parameter[name = concat('minIcons_', $id)]/value" />
			<xsl:with-param name="maxIcons" select="../../parameter[name = concat('maxIcons_', $id)]/value" />
		</xsl:call-template>
			
	</xsl:template>

	<xsl:template name="createMapIcon">
		
		<xsl:param name="mapIconID" />
		<xsl:param name="sortOrder" />
		<xsl:param name="mapIconName" />
		<xsl:param name="iconImageFilename" />
		<xsl:param name="minIcons" />
		<xsl:param name="maxIcons" />
		<xsl:param name="disabled" select="null" />
		
		<div class="lightbackground border bigpadding floatleft full border-box bigmarginbottom mapicon-form">
							
			<div class="floatleft">
				<label for="mapIcon"><xsl:value-of select="$i18n.Icon" /></label>
				<div class="map-icon-preview">
					<figure class="map-icon">
						<img>
							<xsl:if test="$iconImageFilename and $mapIconID">
								<xsl:attribute name="src"><xsl:value-of select="/Document/requestinfo/currentURI" />/<xsl:value-of select="/Document/module/alias" />/icon/<xsl:value-of select="$mapIconID" /></xsl:attribute>
							</xsl:if>
						</img>
					</figure>
					<span>
						<input type="button" class="add-image-btn" value="{$i18n.ChooseImage}" />
						<input type="button" class="change-image-btn" value="{$i18n.ChangeImage}" />
						<input id="{concat('icon_', $mapIconID)}" type="file" name="{concat('icon_', $mapIconID)}" size="55" class="bigmarginbottom" />
					</span>
				</div>
			</div>
			
			<xsl:call-template name="createHiddenField">
				<xsl:with-param name="id" select="concat('mapIconID_', $mapIconID)"/>
				<xsl:with-param name="name" select="'mapIconID'"/>
				<xsl:with-param name="value" select="$mapIconID"/>
				<xsl:with-param name="disabled" select="$disabled"/>
			</xsl:call-template>
			
			<xsl:call-template name="createHiddenField">
				<xsl:with-param name="id" select="concat('sortOrder_', $mapIconID)"/>
				<xsl:with-param name="name" select="concat('sortOrder_', $mapIconID)"/>
				<xsl:with-param name="value" select="$sortOrder"/>
				<xsl:with-param name="class" select="'sortorder'"/>
				<xsl:with-param name="disabled" select="$disabled"/>
			</xsl:call-template>
			
			<div class="floatleft thirty bigmarginright">
				<label for="mapIconName"><xsl:value-of select="$i18n.MapIconName" /></label>
				<div>
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="concat('mapIconName_', $mapIconID)" />
						<xsl:with-param name="name" select="concat('mapIconName_', $mapIconID)" />
						<xsl:with-param name="value" select="$mapIconName"/>
						<xsl:with-param name="disabled" select="$disabled" />
					</xsl:call-template>
				</div>
			</div>
			
			<div class="floatleft twenty bigmarginright">
				<label for="minIcons"><xsl:value-of select="$i18n.MinimumIcons" /></label>
				<div>
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="concat('minIcons_', $mapIconID)" />
						<xsl:with-param name="name" select="concat('minIcons_', $mapIconID)"/>
						<xsl:with-param name="value" select="$minIcons"/>
						<xsl:with-param name="disabled" select="$disabled" />
					</xsl:call-template>
				</div>
			</div>
			
			<div class="floatleft twenty">
				<label for="maxIcons"><xsl:value-of select="$i18n.MaxIcons" /></label>
				<div>
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="concat('maxIcons_', $mapIconID)" />
						<xsl:with-param name="name" select="concat('maxIcons_', $mapIconID)" />
						<xsl:with-param name="value" select="$maxIcons"/>
						<xsl:with-param name="disabled" select="$disabled" />
					</xsl:call-template>
				</div>
			</div>
			
			<div class="floatright">
			
				<input type="button" value="{$i18n.DeleteIcon}" class="btn btn-red" onclick="deleteMapIcon(this, event)" />
			
			</div>
			
		</div>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'UpdateFailedIconMapQueryNotFound']">
		
		<p class="error">
			<xsl:value-of select="$i18n.IconMapQueryNotFound" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'NoIconsAdded']">
		
		<p class="error">
			<xsl:value-of select="$i18n.NoIconsAdded" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'NoMapIcon']">
		
		<p class="error">
			<xsl:value-of select="$i18n.NoMapIcon" /><xsl:text> </xsl:text><xsl:value-of select="$i18n.OnRow" /><xsl:text> </xsl:text><xsl:value-of select="displayName" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'MaxIconsSmallerThanMinIcons']">
		
		<p class="error">
			<xsl:value-of select="$i18n.MaxIconsSmallerThanMinIcons" /><xsl:text> </xsl:text><xsl:value-of select="$i18n.OnRow" /><xsl:text> </xsl:text><xsl:value-of select="displayName" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey='InvalidIconFileFormat']">
	
		<p class="error">
			<xsl:value-of select="$i18n.InvalidIconFileFormat" />
		</p>
		
	</xsl:template>

	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />
	
		<xsl:choose>
			<xsl:when test="$fieldName = 'requiredQueryMessage'">
				<xsl:value-of select="$i18n.requiredQueryMessage" />
			</xsl:when>
			<xsl:when test="$fieldName = 'attributeName'">
				<xsl:value-of select="$i18n.attributeName" />
			</xsl:when>
			<xsl:when test="$fieldName = 'geometryEndpointName'">
				<xsl:value-of select="$i18n.GeometryEndpointName" />
			</xsl:when>
			<xsl:when test="$fieldName = 'noGeometriesMessage'">
				<xsl:value-of select="$i18n.NoGeometriesMessage" />
			</xsl:when>
			<xsl:when test="$fieldName = 'minSelectableGeometries'">
				<xsl:value-of select="$i18n.MinSelectableGeometries" />
			</xsl:when>
			<xsl:when test="$fieldName = 'maxSelectableGeometries'">
				<xsl:value-of select="$i18n.MaxSelectableGeometries" />
			</xsl:when>
			<xsl:when test="$fieldName = 'missingGeometryMessage'">
				<xsl:value-of select="$i18n.MissingGeometryMessage" />
			</xsl:when>
			<xsl:when test="$fieldName = 'reservationMinutes'">
				<xsl:value-of select="$i18n.ReservationMinutes" />
			</xsl:when>
			<xsl:when test="$fieldName = 'reservedGeometryColor'">
				<xsl:value-of select="$i18n.ReservedGeometryColor" />
			</xsl:when>
			<xsl:when test="$fieldName = 'geometryAlreadyReservedMessage'">
				<xsl:value-of select="$i18n.GeometryAlreadyReservedMessage" />
			</xsl:when>
			<xsl:when test="starts-with($fieldName, 'mapIconName_') and ../displayName">
				<xsl:value-of select="$i18n.MapIconName" /><xsl:text> </xsl:text><xsl:value-of select="$i18n.OnRow" /><xsl:text> </xsl:text><xsl:value-of select="../displayName" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

</xsl:stylesheet>