package com.nordicpeak.flowengine.queries.iconmapquery.beans;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.standardutils.annotations.PopulateOnlyIfSet;
import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.HexColorPopulator;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;
import se.unlogic.webutils.annotations.URLRewrite;

import com.nordicpeak.flowengine.annotations.TextTagReplace;
import com.nordicpeak.flowengine.queries.basequery.BaseQuery;
import com.nordicpeak.flowengine.remotegeometryendpointprovider.RemoteGeometryQuery;

@Table(name = "icon_map_queries")
@XMLElement
public class IconMapQuery extends BaseQuery implements RemoteGeometryQuery {

	private static final long serialVersionUID = 8034865424806501989L;

	private static final HexColorPopulator HEX_COLOR_POPULATOR = new HexColorPopulator();

	public static final Field ICON_RELATION = ReflectionUtils.getField(IconMapQuery.class, "icons");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryID;

	@TextTagReplace
	@URLRewrite
	@DAOManaged
	@WebPopulate(maxLength = 255, required = true)
	@XMLElement
	private String requiredQueryMessage;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean forceQueryPopulation;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean requirePUD;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useDetailedIconInfo;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showIconPUDInfo;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean setAsAttribute;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "setAsAttribute")
	@XMLElement
	private String attributeName;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String geometryEndpointName;

	@DAOManaged
	@RequiredIfSet(paramNames = "geometryEndpointName")
	@PopulateOnlyIfSet(paramNames = "geometryEndpointName")
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String noGeometriesMessage;

	@DAOManaged
	@PopulateOnlyIfSet(paramNames = "geometryEndpointName")
	@WebPopulate
	@XMLElement
	private boolean zoomToGeometries;

	@DAOManaged
	@PopulateOnlyIfSet(paramNames = "geometryEndpointName")
	@WebPopulate
	@XMLElement
	private boolean printAllFetchedGeometries;

	@DAOManaged
	@PopulateOnlyIfSet(paramNames = "geometryEndpointName")
	@WebPopulate
	@XMLElement
	private boolean useSelectableGeometries;

	@DAOManaged
	@PopulateOnlyIfSet(paramNames = "useSelectableGeometries")
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer minSelectableGeometries;

	@DAOManaged
	@PopulateOnlyIfSet(paramNames = "useSelectableGeometries")
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer maxSelectableGeometries;

	@DAOManaged
	@RequiredIfSet(paramNames = "useSelectableGeometries")
	@PopulateOnlyIfSet(paramNames = "useSelectableGeometries")
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String missingGeometryMessage;

	@DAOManaged
	@PopulateOnlyIfSet(paramNames = "useSelectableGeometries")
	@WebPopulate
	@XMLElement
	private boolean selectableGeometryReservationEnabled;

	@DAOManaged
	@RequiredIfSet(paramNames = "selectableGeometryReservationEnabled")
	@PopulateOnlyIfSet(paramNames = "selectableGeometryReservationEnabled")
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer reservationMinutes;

	@DAOManaged
	@RequiredIfSet(paramNames = "selectableGeometryReservationEnabled")
	@PopulateOnlyIfSet(paramNames = "selectableGeometryReservationEnabled")
	@WebPopulate(maxLength = 255, populator = HexColorPopulator.class)
	@XMLElement
	private String reservedGeometryColor;

	@DAOManaged
	@RequiredIfSet(paramNames = "selectableGeometryReservationEnabled")
	@PopulateOnlyIfSet(paramNames = "selectableGeometryReservationEnabled")
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String geometryAlreadyReservedMessage;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<MapIcon> icons;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<IconMapQueryInstance> instances;

	private Map<Integer, Integer> mapIconsConversionMap;

	@Override
	public Integer getQueryID() {

		return queryID;
	}

	public String getRequiredQueryMessage() {

		return requiredQueryMessage;
	}

	public void setRequiredQueryMessage(String requiredQueryMessage) {

		this.requiredQueryMessage = requiredQueryMessage;
	}

	public void setQueryID(Integer queryID) {

		this.queryID = queryID;
	}

	public List<IconMapQueryInstance> getInstances() {

		return instances;
	}

	public void setInstances(List<IconMapQueryInstance> instances) {

		this.instances = instances;
	}

	public boolean isForceQueryPopulation() {

		return forceQueryPopulation;
	}

	public void setForceQueryPopulation(boolean forceQueryPopulation) {

		this.forceQueryPopulation = forceQueryPopulation;
	}

	public boolean isRequirePUD() {

		return requirePUD;
	}

	public void setRequirePUD(boolean requirePUD) {

		this.requirePUD = requirePUD;
	}

	public boolean isUseDetailedIconInfo() {

		return useDetailedIconInfo;
	}

	public void setUseDetailedIconInfo(boolean useDetailedIconInfo) {

		this.useDetailedIconInfo = useDetailedIconInfo;
	}

	public boolean isShowIconPUDInfo() {

		return showIconPUDInfo;
	}

	public void setShowIconPUDInfo(boolean showIconPUDInfo) {

		this.showIconPUDInfo = showIconPUDInfo;
	}

	public List<MapIcon> getIcons() {

		return icons;
	}

	public void setIcons(List<MapIcon> icons) {

		this.icons = icons;
	}

	@Override
	public String toString() {

		if (this.queryDescriptor != null) {

			return queryDescriptor.getName() + " (queryID: " + queryID + ")";
		}

		return "IconMapQuery (queryID: " + queryID + ")";
	}

	@Override
	public String getXSDTypeName() {

		return "IconMapQuery" + getQueryID();
	}

	@Override
	public void toXSD(Document doc) {

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		complexTypeElement.setAttribute("name", getXSDTypeName());
		doc.getDocumentElement().appendChild(complexTypeElement);

		Element complexContentElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexContent");
		complexTypeElement.appendChild(complexContentElement);

		Element extensionElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:extension");
		extensionElement.setAttribute("base", "Query");
		complexContentElement.appendChild(extensionElement);

		Element sequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		extensionElement.appendChild(sequenceElement);

		Element nameElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		nameElement.setAttribute("name", "Name");
		nameElement.setAttribute("type", "xs:string");
		nameElement.setAttribute("minOccurs", "1");
		nameElement.setAttribute("maxOccurs", "1");
		nameElement.setAttribute("fixed", queryDescriptor.getName());
		sequenceElement.appendChild(nameElement);

		addElementType("Extent", "xs:string", true, doc, sequenceElement);
		addElementType("EPSG", "xs:string", true, doc, sequenceElement);
		addElementType("VisibleBaseLayer", "xs:string", true, doc, sequenceElement);

		appendInstancePrintsElement(doc, sequenceElement);

		if (useSelectableGeometries) {

			appendSelectedGeometriesElement(doc, sequenceElement);

		} else {

			appendGeometriesElement(doc, sequenceElement);
		}

		appendInstancePrintXSDType(doc);

		if (useSelectableGeometries) {

			appendSelectedGeometryXSDType(doc);

		} else {

			appendGeometryXSDType(doc);
		}
	}

	private void appendInstancePrintsElement(Document doc, Element sequenceElement) {

		Element instancePrintsElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		instancePrintsElement.setAttribute("name", "InstancePrints");
		instancePrintsElement.setAttribute("minOccurs", "0");
		instancePrintsElement.setAttribute("maxOccurs", "1");
		sequenceElement.appendChild(instancePrintsElement);

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		instancePrintsElement.appendChild(complexTypeElement);

		Element nestedSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		complexTypeElement.appendChild(nestedSequenceElement);

		addElementType("InstancePrint", "InstancePrint" + queryID, 1, null, doc, nestedSequenceElement);
	}

	private void appendGeometriesElement(Document doc, Element sequenceElement) {

		Element geometriesElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		geometriesElement.setAttribute("name", "Geometries");
		geometriesElement.setAttribute("minOccurs", "0");
		geometriesElement.setAttribute("maxOccurs", "1");
		sequenceElement.appendChild(geometriesElement);

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		geometriesElement.appendChild(complexTypeElement);

		Element nestedSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		complexTypeElement.appendChild(nestedSequenceElement);

		Integer maxOccurs = 0;

		if (icons != null) {

			for (MapIcon icon : icons) {

				if (icon.getMaxIcons() == null) {
					maxOccurs = -1;
					break;
				}

				maxOccurs += icon.getMaxIcons();
			}
		}

		addElementType("Geometry", "Geometry" + queryID, 1, maxOccurs, doc, nestedSequenceElement);
	}

	private void appendSelectedGeometriesElement(Document doc, Element sequenceElement) {

		Element selectedGeometriesElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		selectedGeometriesElement.setAttribute("name", "SelectedGeometries");
		selectedGeometriesElement.setAttribute("minOccurs", "0");
		selectedGeometriesElement.setAttribute("maxOccurs", "1");
		sequenceElement.appendChild(selectedGeometriesElement);

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		selectedGeometriesElement.appendChild(complexTypeElement);

		Element nestedSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		complexTypeElement.appendChild(nestedSequenceElement);

		addElementType("Geometry", "Geometry" + queryID, minSelectableGeometries, maxSelectableGeometries, doc, nestedSequenceElement);
	}

	public void appendInstancePrintXSDType(Document doc) {

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		complexTypeElement.setAttribute("name", "InstancePrint" + queryID);

		Element sequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		complexTypeElement.appendChild(sequenceElement);

		addElementType("MapImage", "xs:string", true, doc, sequenceElement);
		addElementType("DPI", "xs:string", true, doc, sequenceElement);
		addElementType("Scale", "xs:string", true, doc, sequenceElement);
		addElementType("Layout", "xs:string", true, doc, sequenceElement);
		addElementType("Format", "xs:string", true, doc, sequenceElement);

		doc.getDocumentElement().appendChild(complexTypeElement);
	}

	public void appendGeometryXSDType(Document doc) {

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		complexTypeElement.setAttribute("name", "Geometry" + queryID);

		Element sequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		complexTypeElement.appendChild(sequenceElement);

		addElementType("Type", "xs:string", true, doc, sequenceElement);
		addElementType("Comment", "xs:string", true, doc, sequenceElement);
		addElementType("PropertyUnitDesignation", "xs:string", true, doc, sequenceElement);
		addElementType("WKT", "xs:string", true, doc, sequenceElement);

		doc.getDocumentElement().appendChild(complexTypeElement);
	}

	public void appendSelectedGeometryXSDType(Document doc) {

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		complexTypeElement.setAttribute("name", "SelectedGeometry" + queryID);

		Element sequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		complexTypeElement.appendChild(sequenceElement);

		addElementType("ObjectID", "xs:string", true, doc, sequenceElement);
		addElementType("Name", "xs:string", true, doc, sequenceElement);
		addElementType("Description", "xs:string", true, doc, sequenceElement);
		addElementType("WKT", "xs:string", true, doc, sequenceElement);

		doc.getDocumentElement().appendChild(complexTypeElement);
	}

	protected void addElementType(String name, String type, boolean required, Document doc, Element sequenceElement) {

		addElementType(name, type, required ? 1 : 0, 1, doc, sequenceElement);
	}

	protected void addElementType(String name, String type, int minOccurs, Integer maxOccurs, Document doc, Element sequenceElement) {

		Element fieldElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		fieldElement.setAttribute("name", name);
		fieldElement.setAttribute("type", type);
		fieldElement.setAttribute("minOccurs", Integer.toString(minOccurs));

		if (maxOccurs != null) {

			fieldElement.setAttribute("maxOccurs", maxOccurs.toString());

		} else {

			fieldElement.setAttribute("maxOccurs", "unbounded");
		}

		sequenceElement.appendChild(fieldElement);
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<>();

		description = XMLValidationUtils.validateParameter("description", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);

		requiredQueryMessage = XMLValidationUtils.validateParameter("requiredQueryMessage", xmlParser, true, 1, 255, StringPopulator.getPopulator(), errors);
		forceQueryPopulation = xmlParser.getPrimitiveBoolean("forceQueryPopulation");
		requirePUD = xmlParser.getPrimitiveBoolean("requirePUD");
		useDetailedIconInfo = xmlParser.getPrimitiveBoolean("useDetailedIconInfo");
		showIconPUDInfo = xmlParser.getPrimitiveBoolean("showIconPUDInfo");

		attributeName = XMLValidationUtils.validateParameter("attributeName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);

		if (attributeName != null) {

			setAsAttribute = xmlParser.getPrimitiveBoolean("setAsAttribute");
		}

		geometryEndpointName = XMLValidationUtils.validateParameter("geometryEndpointName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		noGeometriesMessage = XMLValidationUtils.validateParameter("noGeometriesMessage", xmlParser, geometryEndpointName != null, 1, 255, StringPopulator.getPopulator(), errors);

		zoomToGeometries = xmlParser.getPrimitiveBoolean("zoomToGeometries");
		printAllFetchedGeometries = xmlParser.getPrimitiveBoolean("printAllFetchedGeometries");
		useSelectableGeometries = xmlParser.getPrimitiveBoolean("useSelectableGeometries");
		minSelectableGeometries = xmlParser.getInteger("minSelectableGeometries");
		maxSelectableGeometries = xmlParser.getInteger("maxSelectableGeometries");

		missingGeometryMessage = XMLValidationUtils.validateParameter("missingGeometryMessage", xmlParser, useSelectableGeometries, 1, 255, StringPopulator.getPopulator(), errors);

		selectableGeometryReservationEnabled = xmlParser.getPrimitiveBoolean("selectableGeometryReservationEnabled");
		reservationMinutes = XMLValidationUtils.validateParameter("reservationMinutes", xmlParser, selectableGeometryReservationEnabled, 1, 255, PositiveStringIntegerPopulator.getPopulator(), errors);
		reservedGeometryColor = XMLValidationUtils.validateParameter("reservedGeometryColor", xmlParser, selectableGeometryReservationEnabled, 1, 255, HEX_COLOR_POPULATOR, errors);
		geometryAlreadyReservedMessage = XMLValidationUtils.validateParameter("geometryAlreadyReservedMessage", xmlParser, selectableGeometryReservationEnabled, 1, 255, StringPopulator.getPopulator(), errors);

		List<XMLParser> xmlParsers = xmlParser.getNodes("Icons/MapIcon");

		if (xmlParsers != null) {

			icons = new ArrayList<>(xmlParsers.size());

			for (XMLParser parser : xmlParsers) {

				MapIcon mapIcon = new MapIcon();

				mapIcon.populate(parser);
				mapIcon.setIconMapQuery(this);

				icons.add(mapIcon);

			}

		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}

	}

	public Map<Integer, Integer> getMapIconsConversionMap() {

		return mapIconsConversionMap;
	}

	public void setMapIconsConversionMap(Map<Integer, Integer> mapIconsConversionMap) {

		this.mapIconsConversionMap = mapIconsConversionMap;
	}

	public boolean isSetAsAttribute() {

		return setAsAttribute;
	}

	public void setSetAsAttribute(boolean setAsAttribute) {

		this.setAsAttribute = setAsAttribute;
	}

	public String getAttributeName() {

		return attributeName;
	}

	public void setAttributeName(String attributeName) {

		this.attributeName = attributeName;
	}

	public String getGeometryEndpointName() {

		return geometryEndpointName;
	}

	public void setGeometryEndpointName(String geometryEndpointName) {

		this.geometryEndpointName = geometryEndpointName;
	}

	public String getMissingGeometryMessage() {

		return missingGeometryMessage;
	}

	public void setMissingGeometryMessage(String missingGeometryMessage) {

		this.missingGeometryMessage = missingGeometryMessage;
	}

	public boolean isSelectableGeometryReservationEnabled() {

		return selectableGeometryReservationEnabled;
	}

	public void setSelectableGeometryReservationEnabled(boolean selectableGeometryReservationEnabled) {

		this.selectableGeometryReservationEnabled = selectableGeometryReservationEnabled;
	}

	public Integer getReservationMinutes() {

		return reservationMinutes;
	}

	public void setReservationMinutes(Integer reservationMinutes) {

		this.reservationMinutes = reservationMinutes;
	}

	public String getReservedGeometryColor() {

		return reservedGeometryColor;
	}

	public void setReservedGeometryColor(String reservedGeometryColor) {

		this.reservedGeometryColor = reservedGeometryColor;
	}

	public String getGeometryAlreadyReservedMessage() {

		return geometryAlreadyReservedMessage;
	}

	public void setGeometryAlreadyReservedMessage(String geometryAlreadyReservedMessage) {

		this.geometryAlreadyReservedMessage = geometryAlreadyReservedMessage;
	}

	@Override
	public String getRemoteGeometryEnpointName() {

		return geometryEndpointName;
	}

	public boolean isZoomToGeometries() {

		return zoomToGeometries;
	}

	public void setZoomToGeometries(boolean zoomToGeometries) {

		this.zoomToGeometries = zoomToGeometries;
	}

	public boolean isPrintAllFetchedGeometries() {

		return printAllFetchedGeometries;
	}

	public void setPrintAllFetchedGeometries(boolean printAllFetchedGeometries) {

		this.printAllFetchedGeometries = printAllFetchedGeometries;
	}

	public boolean isUseSelectableGeometries() {

		return useSelectableGeometries;
	}

	public void setUseSelectableGeometries(boolean useSelectableGeometries) {

		this.useSelectableGeometries = useSelectableGeometries;
	}

	public Integer getMinSelectableGeometries() {

		return minSelectableGeometries;
	}

	public void setMinSelectableGeometries(Integer minSelectableGeometries) {

		this.minSelectableGeometries = minSelectableGeometries;
	}

	public Integer getMaxSelectableGeometries() {

		return maxSelectableGeometries;
	}

	public void setMaxSelectableGeometries(Integer maxSelectableGeometries) {

		this.maxSelectableGeometries = maxSelectableGeometries;
	}

	public String getNoGeometriesMessage() {

		return noGeometriesMessage;
	}

	public void setNoGeometriesMessage(String noGeometriesMessage) {

		this.noGeometriesMessage = noGeometriesMessage;
	}

}
