package com.nordicpeak.flowengine.queries.iconmapquery.beans;

import java.io.IOException;
import java.io.Serializable;
import java.sql.Blob;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.sql.rowset.serial.SerialBlob;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.base64.Base64;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLParserPopulateable;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLValidationUtils;

@Table(name = "icon_map_query_icons")
@XMLElement
public class MapIcon extends GeneratedElementable implements Serializable, XMLParserPopulateable {

	private static final long serialVersionUID = -9117896918710518834L;

	@Key
	@DAOManaged(autoGenerated = true)
	@XMLElement
	private Integer mapIconID;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	private IconMapQuery iconMapQuery;

	@DAOManaged
	@XMLElement
	private String name;

	@DAOManaged
	@OrderBy
	@XMLElement
	private Integer sortIndex;

	@DAOManaged
	@XMLElement
	private String iconImageFilename;

	@DAOManaged
	private transient Blob iconImage;

	@DAOManaged
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer minIcons;

	@DAOManaged
	@WebPopulate(populator = PositiveStringIntegerPopulator.class)
	@XMLElement
	private Integer maxIcons;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<Geometry> geometries;

	public Integer getMapIconID() {

		return mapIconID;
	}

	public void setMapIconID(Integer mapIconID) {

		this.mapIconID = mapIconID;
	}

	public IconMapQuery getIconMapQuery() {

		return iconMapQuery;
	}

	public void setIconMapQuery(IconMapQuery iconMapQuery) {

		this.iconMapQuery = iconMapQuery;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public Integer getSortIndex() {

		return sortIndex;
	}

	public void setSortIndex(Integer sortIndex) {

		this.sortIndex = sortIndex;
	}

	public String getIconImageFilename() {

		return iconImageFilename;
	}

	public void setIconImageFilename(String iconImageFilename) {

		this.iconImageFilename = iconImageFilename;
	}

	public Blob getIconImage() {

		return iconImage;
	}

	public void setIconImage(Blob iconImage) {

		this.iconImage = iconImage;
	}

	public Integer getMinIcons() {

		return minIcons;
	}

	public void setMinIcons(Integer minIcons) {

		this.minIcons = minIcons;
	}

	public Integer getMaxIcons() {

		return maxIcons;
	}

	public List<Geometry> getGeometries() {

		return geometries;
	}

	public void setGeometries(List<Geometry> geometries) {

		this.geometries = geometries;
	}

	public void setMaxIcons(Integer maxIcons) {

		this.maxIcons = maxIcons;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<>();

		mapIconID = XMLValidationUtils.validateParameter("mapIconID", xmlParser, true, PositiveStringIntegerPopulator.getPopulator(), errors);
		name = XMLValidationUtils.validateParameter("name", xmlParser, true, 1, 45, StringPopulator.getPopulator(), errors);
		minIcons = XMLValidationUtils.validateParameter("minIcons", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);
		maxIcons = XMLValidationUtils.validateParameter("maxIcons", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);
		sortIndex = XMLValidationUtils.validateParameter("sortIndex", xmlParser, true, IntegerPopulator.getPopulator(), errors);

		iconImageFilename = XMLValidationUtils.validateParameter("iconImageFilename", xmlParser, true, 1, 255, StringPopulator.getPopulator(), errors);

		String iconImageStr = xmlParser.getString("iconImage");

		if (iconImageStr != null) {

			try {
				iconImage = new SerialBlob(Base64.decode(iconImageStr));
			} catch (SQLException | IOException e) {}

		}

	}

	@Override
	public Element toXML(Document doc) {

		Element element = super.toXML(doc);

		try {

			if (iconImage != null) {
				XMLUtils.appendNewElement(doc, element, "iconImage", Base64.encodeBytes(iconImage.getBytes(1, (int) iconImage.length())));
			}

		} catch (SQLException e) {

		}

		return element;
	}

	protected final Object writeReplace() {

		try {

			if (iconImage != null) {
				iconImage = new SerialBlob(iconImage);
			}

		} catch (SQLException e) {

		}

		return this;

	}
}
