package com.nordicpeak.flowengine.queries.iconmapquery.utils;

import org.apache.log4j.Logger;

import se.unlogic.standardutils.json.JsonArray;
import se.unlogic.standardutils.json.JsonNode;
import se.unlogic.standardutils.json.JsonObject;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.LineString;
import com.vividsolutions.jts.geom.MultiLineString;
import com.vividsolutions.jts.geom.MultiPoint;
import com.vividsolutions.jts.geom.MultiPolygon;
import com.vividsolutions.jts.geom.Point;
import com.vividsolutions.jts.geom.Polygon;

public class GeoJSONUtils {

	protected static Logger log = Logger.getLogger(GeoJSONUtils.class);

	public static JsonNode getJSONForGeometry(Geometry geometry) {

		JsonArray coordinatesArray = new JsonArray();

		if (geometry instanceof Point) {

			Point point = (Point) geometry;
			Coordinate coordinate = point.getCoordinate();

			coordinatesArray.addNode(coordinate.x);
			coordinatesArray.addNode(coordinate.y);

			if (!Double.isNaN(coordinate.z)) {

				coordinatesArray.addNode(coordinate.z);
			}

		} else if (geometry instanceof MultiPoint) {

			for (Coordinate coordinate : geometry.getCoordinates()) {

				JsonArray coordinateArray = new JsonArray();
				coordinateArray.addNode(coordinate.x);
				coordinateArray.addNode(coordinate.y);

				if (!Double.isNaN(coordinate.z)) {

					coordinateArray.addNode(coordinate.z);
				}

				coordinatesArray.addNode(coordinateArray);
			}

		} else if (geometry instanceof LineString) {

			for (Coordinate coordinate : geometry.getCoordinates()) {

				JsonArray coordinateArray = new JsonArray();
				coordinateArray.addNode(coordinate.x);
				coordinateArray.addNode(coordinate.y);

				coordinatesArray.addNode(coordinateArray);

			}

		} else if (geometry instanceof MultiLineString) {

			JsonArray lineStringArray = new JsonArray();

			for (Coordinate coordinate : geometry.getCoordinates()) {

				JsonArray coordinateArray = new JsonArray();
				coordinateArray.addNode(coordinate.x);
				coordinateArray.addNode(coordinate.y);

				lineStringArray.addNode(coordinateArray);

			}

			coordinatesArray.addNode(lineStringArray);

		} else if (geometry instanceof Polygon) {

			Polygon polygon = (Polygon) geometry;

			addPolygonCoordinates(coordinatesArray, polygon);

		} else if (geometry instanceof MultiPolygon) {

			JsonArray multiPolygonArray = new JsonArray();

			MultiPolygon multiPolygon = (MultiPolygon) geometry;

			for (int i = 0; i < multiPolygon.getNumGeometries(); i++) {

				Polygon polygon = (Polygon) multiPolygon.getGeometryN(i);

				addPolygonCoordinates(multiPolygonArray, polygon);
			}

			coordinatesArray.addNode(multiPolygonArray);

		} else {

			log.warn("Unknown geometry type: " + geometry.getGeometryType());
		}

		if (coordinatesArray.size() == 0) {

			return null;
		}

		JsonObject object = new JsonObject();

		object.putField("coordinates", coordinatesArray);
		object.putField("type", geometry.getGeometryType());

		return object;
	}

	private static void addPolygonCoordinates(JsonArray coordinatesArray, Polygon polygon) {

		JsonArray polygonArray = new JsonArray();

		for (Coordinate coordinate : polygon.getExteriorRing().getCoordinates()) {

			JsonArray coordinateArray = new JsonArray();
			coordinateArray.addNode(coordinate.x);
			coordinateArray.addNode(coordinate.y);

			if (!Double.isNaN(coordinate.z)) {

				coordinateArray.addNode(coordinate.z);
			}

			polygonArray.addNode(coordinateArray);
		}

		coordinatesArray.addNode(polygonArray);

		for (int i = 0; i < polygon.getNumInteriorRing(); i++) {

			polygonArray = new JsonArray();

			for (Coordinate coordinate : polygon.getInteriorRingN(i).getCoordinates()) {

				JsonArray coordinateArray = new JsonArray();
				coordinateArray.addNode(coordinate.x);
				coordinateArray.addNode(coordinate.y);

				if (!Double.isNaN(coordinate.z)) {

					coordinateArray.addNode(coordinate.z);
				}

				polygonArray.addNode(coordinateArray);
			}

			coordinatesArray.addNode(polygonArray);
		}
	}

}
