package com.nordicpeak.flowengine.queries.infoquery;

import java.lang.reflect.Field;
import java.util.Collections;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.beans.BaseInvoiceLine;
import com.nordicpeak.flowengine.interfaces.InvoiceLine;
import com.nordicpeak.flowengine.interfaces.NonColumnExportableQueryInstance;
import com.nordicpeak.flowengine.interfaces.PaymentQueryInstance;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;

@Table(name = "info_query_instances")
@XMLElement
public class InfoQueryInstance extends BaseQueryInstance implements NonColumnExportableQueryInstance, PaymentQueryInstance{

	private static final long serialVersionUID = -7761759005604863873L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(InfoQueryInstance.class, "query");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private InfoQuery query;

	public Integer getQueryInstanceID() {

		return queryInstanceID;
	}

	public void setQueryInstanceID(Integer queryInstanceID) {

		this.queryInstanceID = queryInstanceID;
	}

	@Override
	public String toString() {

		return this.getClass().getSimpleName() + " (queryInstanceID=" + queryInstanceID + ")";
	}

	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {

		Element element = getBaseExportXML(doc);

		return element;
	}

	@Override
	public InfoQuery getQuery() {

		return query;
	}

	public void setQuery(InfoQuery query) {

		this.query = query;
	}

	@Override
	public void reset(MutableAttributeHandler attributeHandler) {

		if (query.isSetAsAttribute() && attributeHandler.isSet(query.getAttributeName()) && attributeHandler.getString(query.getAttributeName()).equals(query.getDescription())) {

			attributeHandler.removeAttribute(query.getAttributeName());
		}

		super.reset(attributeHandler);
	}

	@Override
	public List<? extends InvoiceLine> getInvoiceLines() {

		if(query.isEnablePaymentSupport()) {
			
			return Collections.singletonList(new BaseInvoiceLine(1, query.getPrice(), query.getPaymentDescription(),""));
		}

		return null;
	}
}
