package com.nordicpeak.flowengine.internalalternativelist;

import java.io.InputStream;
import java.sql.SQLException;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.fileupload.FileItem;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellType;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.fileuploadutils.MultipartRequest;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.crud.IntegerBeanIDParser;
import se.unlogic.hierarchy.core.validationerrors.InvalidFileExtensionValidationError;
import se.unlogic.hierarchy.core.validationerrors.UnableToParseFileValidationError;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.date.DateUtils;
import se.unlogic.standardutils.io.CloseUtils;
import se.unlogic.standardutils.io.FileUtils;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.threads.ExeptionHandlingRunnable;
import se.unlogic.standardutils.threads.ThreadUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.alternativelist.provider.BaseAlternativeListCRUD;
import com.nordicpeak.flowengine.internalalternativelist.beans.InternalAlternative;
import com.nordicpeak.flowengine.internalalternativelist.beans.InternalAlternativeList;
import com.nordicpeak.flowengine.internalalternativelist.beans.InternalAlternativeListEvent;
import com.nordicpeak.flowengine.internalalternativelist.beans.InternalAlternativeListInstance;
import com.nordicpeak.flowengine.internalalternativelist.beans.InternalCombinedList;

public class InternalAlternativeListCRUD extends BaseAlternativeListCRUD<InternalAlternativeList, InternalAlternativeListInstance, InternalAlternativeListCRUD, InternalAlternativeListProviderModule, InternalAlternativeListEvent> {

	protected static InternalAlternativePopulator ALTERNATIVES_POPLATOR = new InternalAlternativePopulator();

	public InternalAlternativeListCRUD(AnnotatedDAOWrapper<InternalAlternativeList, Integer> queryDAO, BeanRequestPopulator<InternalAlternativeList> populator, InternalAlternativeListProviderModule callback) {

		super(IntegerBeanIDParser.getInstance(), queryDAO, populator, "AlternativeList", "internal alternative list", "/", callback);
	}

	@Override
	protected void appendBean(InternalAlternativeList list, Element targetElement, Document doc, User user) {

		Element listElement = list.toXML(doc);

		if (callback.hasListAccess(user, list)) {

			targetElement.appendChild(listElement);
			
			if(!callback.hasFullAccess(user)) {
				
				XMLUtils.appendNewElement(doc, listElement, "HideDeleteLink");
			}
		}
	}

	@Override
	protected void appendAllBeans(Document doc, Element listTypeElement, User user, HttpServletRequest req, URIParser uriParser, List<ValidationError> validationError) throws SQLException {

		List<InternalAlternativeList> lists = getAllBeans(user, req, uriParser);

		if (!CollectionUtils.isEmpty(lists)) {

			Element listsElement = XMLUtils.appendNewElement(doc, listTypeElement, this.typeElementPluralName);

			lists.forEach(list -> appendBean(list, listsElement, doc, user));
		}
	}

	@Override
	protected void appendListFormData(Document doc, Element listTypeElement, User user, HttpServletRequest req, URIParser uriParser, List<ValidationError> validationError) throws SQLException {

		super.appendListFormData(doc, listTypeElement, user, req, uriParser, validationError);

		List<InternalCombinedList> combinedLists = callback.getAllCombinedLists();

		if (!CollectionUtils.isEmpty(combinedLists)) {

			boolean fullAccess = callback.hasFullAccess(user);
			
			Element listsElement = XMLUtils.appendNewElement(doc, listTypeElement, "CombinedLists");

			for (InternalCombinedList combinedList : combinedLists) {

				combinedList.setAlternatives(callback.getCombinedInstance(combinedList, null).getAlternatives());

				if (callback.hasListAccess(user, combinedList)) {

					Element listElement = combinedList.toXML(doc);
					listsElement.appendChild(listElement);
					
					if(!fullAccess) {
						
						XMLUtils.appendNewElement(doc, listElement, "HideDeleteLink");
					}
				}
			}
		}
		
		if(callback.hasFullAccess(user)) {
			
			XMLUtils.appendNewElement(doc, listTypeElement, "HasFullAccess");
		}
	}

	@Override
	protected void appendUpdateFormData(InternalAlternativeList list, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {

		super.appendUpdateFormData(list, doc, updateTypeElement, user, req, uriParser);

		Element adminsElement = XMLUtils.appendNewElement(doc, updateTypeElement, "Admins");

		AccessUtils.appendAllowedGroupsAndUsers(doc, adminsElement, list, callback.getUserHandler(), callback.getGroupHandler());
	}

	@Override
	protected InternalAlternativeList populateFromAddRequest(HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		InternalAlternativeList list = super.populateFromAddRequest(req, user, uriParser);

		populate(list, null, req, user, uriParser);

		return list;
	}

	@Override
	protected InternalAlternativeList populateFromUpdateRequest(InternalAlternativeList oldList, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		InternalAlternativeList list = super.populateFromUpdateRequest(oldList, req, user, uriParser);

		populate(list, oldList, req, user, uriParser);

		return list;
	}

	protected InternalAlternativeList populate(final InternalAlternativeList list, InternalAlternativeList oldList, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		List<ValidationError> validationErrors = new ArrayList<ValidationError>();

		List<InternalAlternative> alternatives = null;

		if (oldList == null || CollectionUtils.isEmpty(oldList.getAlternatives())) {
			
			MultipartRequest mreq = (MultipartRequest) req;
			FileItem fileItem = mreq.getFile("importFile");

			if (fileItem != null && fileItem.getSize() > 0) {
				
				String filename = fileItem.getName();
				
				if (!"xlsx".equals(FileUtils.getFileExtension(filename))) {
					
					validationErrors.add(new InvalidFileExtensionValidationError(filename, ".xlsx"));
					
				} else {
					InputStream inputStream = null;
	
					try {
						inputStream = fileItem.getInputStream();
						final InputStream inputStreamFinal = inputStream;
						
						List<InternalAlternative> importedAlternatives = new ArrayList<>();
						
						//Workaround for thread local usage in XMLBeans used by XSSF
						ExeptionHandlingRunnable runnable = new ExeptionHandlingRunnable() {
				
							private Exception exception;
				
							@Override
							public void run() {
								Workbook workbook = null;

								try {
									try {
										workbook = new XSSFWorkbook(inputStreamFinal);
				
									} catch (Exception e) {
				
										log.info("Unable to parse file " + filename, e);
										throw new ValidationException(new UnableToParseFileValidationError(filename));
									}
				
									Sheet sheet = null;
				
									if (workbook.getNumberOfSheets() > 0) {
				
										sheet = workbook.getSheetAt(0);
									}
				
									if (sheet == null) {
				
										log.info("Error parsing file " + filename + ", unable to find sheet");
										throw new ValidationException(new ValidationError("ErrorImportingExcel", "Hittar inget blad att importera rader ifrn"));
									}
				
									Row headerRow = sheet.getRow(sheet.getFirstRowNum() + 1);
				
									if (headerRow == null) {
				
										log.info("Error parsing file " + filename + ", unable to find header row");
										throw new ValidationException(new ValidationError("ErrorImportingExcel", "Hittar inte sidhuvudet (andra raden med kolumnnamn)"));
									}
				
									int columnCount = 0;
									int rowCount = sheet.getLastRowNum() - headerRow.getRowNum();
				
									// Fix for header styling counting as column count
									for (int i = 0; i < headerRow.getLastCellNum(); i++) {
										
										Cell cell = headerRow.getCell(i);
										
										if (!StringUtils.isEmpty(getCellValue(cell))) {
											columnCount ++;
										}
									}
									
									if (columnCount != 5) {
				
										log.info("Error parsing file " + filename + ", wrong column count " + columnCount + ", expected 5");
										throw new ValidationException(new ValidationError("ErrorImportingExcel", "Hittar " + columnCount + " kolumner. Frvntas 5 fr att kunna importera."));
									}
				
									if (rowCount < 1) {
				
										log.info("Error parsing file " + filename + ", too few rows " + rowCount);
										throw new ValidationException(new ValidationError("ErrorImportingExcel", "Hittar inga rader att importera"));
									}
									
									List<ValidationError> validationErrors = new ArrayList<ValidationError>();
				
									for (int rowIndex = headerRow.getRowNum() + 1; rowIndex <= sheet.getLastRowNum(); rowIndex++) {
			
										Row row = sheet.getRow(rowIndex);
			
										if (row != null) {
											
											String name = getCellValue(row.getCell(0));
											String xmlValue = getCellValue(row.getCell(1));
											String attributeValue = getCellValue(row.getCell(2));
											Date fromDate = null;
											Date toDate = null;
											
											if (ObjectUtils.isNull(name, xmlValue, attributeValue, fromDate, toDate)) {
												continue;
											}
											
											if (StringUtils.isEmpty(name)) {
			
												validationErrors.add(new ValidationError("ErrorImportingExcel", "Namn saknas p rad " + (rowIndex + 1)));
											}
											
											if (list.isUseDateLimits()) {
												
												try {
													fromDate = getCellDateValue(row.getCell(3));
												} catch (ParseException e) {
													validationErrors.add(new ValidationError("ErrorImportingExcel", "Ogiltigt frn och med datum p rad " + (rowIndex + 1)));
												}
												
												try {
													toDate = getCellDateValue(row.getCell(4));
												} catch (ParseException e) {
													validationErrors.add(new ValidationError("ErrorImportingExcel", "Ogiltigt till och med datum p rad " + (rowIndex + 1)));
												}
											}
											
											InternalAlternative alternative = new InternalAlternative();
											alternative.setName(name);
											alternative.setExportXMLValue(xmlValue);
											alternative.setAttributeValue(attributeValue);
											alternative.setSortIndex(rowIndex);
											
											if (fromDate != null) {
												alternative.setValidFrom(new java.sql.Date(fromDate.getTime()));
											}
											
											if (toDate != null) {
												alternative.setValidTo(new java.sql.Date(toDate.getTime()));
											}
			
											importedAlternatives.add(alternative);
										}
									}
			
									if (!validationErrors.isEmpty()) {
			
										throw new ValidationException(validationErrors);
									}
				
								} catch (Exception e) {
				
									exception = e;
				
								} finally {
				
									CloseUtils.close(workbook);
								}
							}
				
							@Override
							public Exception getException() {
				
								return exception;
							}
							
							private String getCellValue(Cell cell) {
								
								if (cell != null) {
									
									CellType type = cell.getCellType();
									
									if (type == CellType.NUMERIC) {
										
										return Integer.toString((int) cell.getNumericCellValue());
										
									} else if (type == CellType.STRING) {
										
										String value = cell.getStringCellValue();
										
										if (StringUtils.isEmpty(value) || "NULL".equalsIgnoreCase(value) || "-".equals(value)) {
											return null;
										}
										
										return value.trim();
									}
									
									return cell.toString();
								}
								
								return null;
							}
							
							private Date getCellDateValue(Cell cell) throws ParseException {
								
								if (cell != null) {
									
									CellType type = cell.getCellType();
									
									if (type == CellType.NUMERIC && DateUtil.isCellDateFormatted(cell)) {
										
										return cell.getDateCellValue();
										
									} else if (type == CellType.STRING) {
										
										String value = cell.getStringCellValue();
										
										if (StringUtils.isEmpty(value) || "NULL".equalsIgnoreCase(value) || "-".equals(value)) {
											return null;
										}
										
										return DateUtils.DATE_FORMATTER.parse(value.trim());
									}
								}
								
								return null;
							}
						};
				
						try {
							ThreadUtils.runAndWait(runnable, "Internal alternative list importing for user " + user, true);
							
							if (runnable.getException() != null) {
					
								if (runnable.getException() instanceof ValidationException) {
					
									validationErrors.addAll(((ValidationException) runnable.getException()).getErrors());
									
								} else {
					
									log.error("Error importing internal alternative list for user " + user + "", runnable.getException());
									validationErrors.add(new UnableToParseFileValidationError(filename));
								}
								
							} else {
								alternatives = importedAlternatives;
							}
							
						} catch (Throwable e) {
							
							log.error("Error importing internal alternative list for user " + user + "", e);
							validationErrors.add(new UnableToParseFileValidationError(filename));
						}
						
					} finally {
	
						CloseUtils.close(inputStream);
					}
				}
			}
		}
		
		if (alternatives == null) {
			alternatives = ALTERNATIVES_POPLATOR.populate(list, oldList != null ? oldList.getAlternatives() : null, req, validationErrors);
		}
		
		super.validate(list, req, user, uriParser, validationErrors);

		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}

		list.setAlternatives(alternatives);

		return list;
	}

	@Override
	protected void validateAddPopulation(InternalAlternativeList list, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, SQLException, Exception {

		super.validateAddPopulation(list, req, user, uriParser);

		validatePopulation(list, req, user, uriParser);
	}

	@Override
	protected void validateUpdatePopulation(InternalAlternativeList list, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, SQLException, Exception {

		super.validateUpdatePopulation(list, req, user, uriParser);

		validatePopulation(list, req, user, uriParser);
	}

	private void validatePopulation(InternalAlternativeList list, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException {

		if (!callback.hasListAccess(user, list)) {

			throw new ValidationException(new ValidationError("CantRemoveOwnAccess"));
		}
	}

	@Override
	protected void checkShowAccess(InternalAlternativeList bean, User user, HttpServletRequest req, URIParser uriParser) throws AccessDeniedException, URINotFoundException, SQLException {
		
		checkAdminAccess(user, bean);
	}

	@Override
	protected void checkAddAccess(User user, HttpServletRequest req, URIParser uriParser) throws AccessDeniedException, URINotFoundException, SQLException {

		checkFullAccess(user);
	}

	@Override
	protected void checkUpdateAccess(InternalAlternativeList list, User user, HttpServletRequest req, URIParser uriParser) throws AccessDeniedException, URINotFoundException, SQLException {

		super.checkUpdateAccess(list, user, req, uriParser);

		checkAdminAccess(user, list);
	}

	@Override
	protected void checkDeleteAccess(InternalAlternativeList list, User user, HttpServletRequest req, URIParser uriParser) throws AccessDeniedException, URINotFoundException, SQLException {

		super.checkDeleteAccess(list, user, req, uriParser);

		checkFullAccess(user);
	}

	private void checkAdminAccess(User user, InternalAlternativeList list) throws AccessDeniedException {

		if (!callback.hasListAccess(user, list)) {

			throw new AccessDeniedException("User " + user + " is not an administrator for list " + list);
		}
	}

	private void checkFullAccess(User user) throws AccessDeniedException, SQLException {

		if (!callback.hasFullAccess(user)) {

			throw new AccessDeniedException("User " + user + " is not a full administrator");
		}
	}
}
