package com.nordicpeak.flowengine.internalalternativelist.beans;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.util.Collection;
import java.util.List;

import se.unlogic.standardutils.annotations.NoDuplicates;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToMany;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.alternativelist.provider.BaseAlternativeList;
import com.nordicpeak.flowengine.internalalternativelist.InternalListAccessInterface;

@Table(name = "internal_alternative_lists")
@XMLElement(name = "AlternativeList")
public class InternalAlternativeList extends BaseAlternativeList<InternalAlternativeList, InternalAlternativeListEvent> implements Serializable, InternalListAccessInterface {

	private static final long serialVersionUID = -842191226937409416L;

	public static final Field ALTERNATIVES_RELATION = ReflectionUtils.getField(InternalAlternativeList.class, "alternatives");
	public static final Field EVENTS_RELATION = ReflectionUtils.getField(InternalAlternativeList.class, "events");

	@Key
	@DAOManaged(autoGenerated = true)
	@XMLElement
	private Integer listID;

	@DAOManaged
	@OrderBy
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String name;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useDateLimits;

	@DAOManaged
	@OneToMany(autoUpdate = true, autoAdd = true)
	@XMLElement(fixCase = true)
	private List<InternalAlternative> alternatives;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<InternalAlternativeListEvent> events;

	@DAOManaged
	@ManyToMany(linkTable = "internal_combined_list_alternatives")
	private List<InternalCombinedList> lists;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean adminAccessControlEnabled;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "internal_alternative_list_admin_groups", remoteValueColumnName = "groupID")
	@WebPopulate(paramName = "adminGroup")
	@NoDuplicates
	@XMLElement
	private List<Integer> adminGroups;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "internal_alternative_list_admin_users", remoteValueColumnName = "userID")
	@WebPopulate(paramName = "adminUser")
	@NoDuplicates
	@XMLElement
	private List<Integer> adminUsers;

	@Override
	public Integer getListID() {

		return listID;
	}

	public void setListID(Integer sourceID) {

		this.listID = sourceID;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public boolean isUseDateLimits() {

		return useDateLimits;
	}

	public void setUseDateLimits(boolean useDateLimits) {

		this.useDateLimits = useDateLimits;
	}

	public List<InternalAlternative> getAlternatives() {

		return alternatives;
	}

	public void setAlternatives(List<InternalAlternative> alternatives) {

		this.alternatives = alternatives;
	}

	@Override
	public String getListName() {

		return name;
	}

	@Override
	public List<InternalAlternativeListEvent> getEvents() {

		return events;
	}

	@Override
	public void setEvents(List<InternalAlternativeListEvent> events) {

		this.events = events;
	}

	@Override
	public boolean allowsAdminAccess() {

		return false;
	}

	@Override
	public boolean allowsUserAccess() {

		return false;
	}

	@Override
	public boolean allowsAnonymousAccess() {

		return false;
	}

	@Override
	public Collection<Integer> getAllowedGroupIDs() {

		return adminGroups;
	}

	@Override
	public Collection<Integer> getAllowedUserIDs() {

		return adminUsers;
	}

	@Override
	public boolean isAdminAccessControlEnabled() {

		return adminAccessControlEnabled;
	}

}
