package com.nordicpeak.flowengine.queries.internalcontactdetails;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import org.apache.log4j.Level;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextAreaSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.handlers.UserHandler;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.hierarchy.core.utils.FCKUtils;
import se.unlogic.hierarchy.core.utils.ModuleUtils;
import se.unlogic.standardutils.annotations.SplitOnLineBreak;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.Stringyfier;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.url.URLRewriter;

import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.QueryResponse;
import com.nordicpeak.flowengine.enums.QueryState;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.MutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryContentFilter;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUDCallback;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryProviderModule;
import com.nordicpeak.flowengine.queries.internalcontactdetails.beans.InternalContactDetailQuery;
import com.nordicpeak.flowengine.queries.internalcontactdetails.beans.InternalContactDetailQueryInstance;
import com.nordicpeak.flowengine.queries.internalcontactdetails.beans.ManagerAttributeValue;
import com.nordicpeak.flowengine.queries.internalcontactdetails.beans.SelectedManagerAttribute;
import com.nordicpeak.flowengine.queries.internalcontactdetails.beans.SelectedUserAttribute;
import com.nordicpeak.flowengine.queries.internalcontactdetails.beans.UserAttributeValue;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesAttributeDescriptor;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesConstants;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesSelectedAttribute;
import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQueryProvider;
import com.nordicpeak.flowengine.utils.CitizenIdentifierUtils;
import com.nordicpeak.flowengine.utils.JTidyUtils;
import com.nordicpeak.flowengine.utils.TextTagReplacer;

public class InternalContactDetailQueryProviderModule extends BaseQueryProviderModule<InternalContactDetailQueryInstance> implements BaseQueryCRUDCallback, CommonInternalUserQueryProvider {
	
	@XSLVariable(prefix = "java.")
	private String exportFirstName;

	@XSLVariable(prefix = "java.")
	private String exportLastName;

	@XSLVariable(prefix = "java.")
	private String exportUsername;

	@XSLVariable(prefix = "java.")
	private String exportEmail;

	@XSLVariable(prefix = "java.")
	private String exportManager;

	@ModuleSetting
	@SplitOnLineBreak
	@TextAreaSettingDescriptor(name = "Supported attributes", description = "The format is name:[display_name[:formatterClass]] (without brackets). Only the name is required", required = true)
	private List<String> supportedAttributes;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Username formatter", description = "formatter to use for usernames")
	private String usernameFormatter;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable closest manager", description = "Enable info and multisign support for posters closest manager")
	private boolean enableClosestManager;

	private List<InternalUserQueriesAttributeDescriptor> attributeDescriptors;

	private AnnotatedDAO<InternalContactDetailQuery> queryDAO;
	private AnnotatedDAO<InternalContactDetailQueryInstance> queryInstanceDAO;

	private InternalContactDetailQueryCRUD queryCRUD;

	private QueryParameterFactory<InternalContactDetailQuery, Integer> queryIDParamFactory;
	private QueryParameterFactory<InternalContactDetailQueryInstance, Integer> queryInstanceIDParamFactory;

	protected Stringyfier<String> usernameStringFormatter;
	protected Map<String, Stringyfier<String>> attributeStringFormatter = new HashMap<String, Stringyfier<String>>();

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		// Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, InternalContactDetailQueryProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		SimpleAnnotatedDAOFactory daoFactory = new SimpleAnnotatedDAOFactory(dataSource);

		queryDAO = daoFactory.getDAO(InternalContactDetailQuery.class);
		queryInstanceDAO = daoFactory.getDAO(InternalContactDetailQueryInstance.class);

		queryCRUD = new InternalContactDetailQueryCRUD(queryDAO.getWrapper(Integer.class), new AnnotatedRequestPopulator<InternalContactDetailQuery>(InternalContactDetailQuery.class), "ContactDetailQuery", "query", null, this);

		queryIDParamFactory = queryDAO.getParamFactory("queryID", Integer.class);
		queryInstanceIDParamFactory = queryInstanceDAO.getParamFactory("queryInstanceID", Integer.class);
	}

	@Override
	protected synchronized void moduleConfigured() throws Exception {

		super.moduleConfigured();

		if (ModuleUtils.checkRequiredModuleSettings(moduleDescriptor, this, systemInterface, Level.ERROR)) {

			attributeDescriptors = parseAttributes();

		} else {

			attributeDescriptors = null;
		}
	}

	private List<InternalUserQueriesAttributeDescriptor> parseAttributes() {

		usernameStringFormatter = null;

		if (usernameFormatter != null) {
			try {
				@SuppressWarnings("unchecked")
				Stringyfier<String> stringFormatter2 = (Stringyfier<String>) ReflectionUtils.getInstance(usernameFormatter);
				usernameStringFormatter = stringFormatter2;
			} catch (Exception e) {
				log.error("Unable to find stringformatter for username.");
			}
		}

		attributeStringFormatter.clear();
		List<InternalUserQueriesAttributeDescriptor> attributeDescriptors = new ArrayList<InternalUserQueriesAttributeDescriptor>(supportedAttributes.size());

		for (String attribute : supportedAttributes) {

			String[] attributeParts = attribute.replace("\r", "").split(":");

			if (attributeParts.length == 0 || attributeParts.length > 3) {

				log.warn("Unable to parse format of attribute: " + attribute + ", ignoring attribute.");
				continue;
			}

			String name = attributeParts[0];;
			String displayName;
			Stringyfier<String> stringFormatter = null;

			if (attributeParts.length > 1) {

				displayName = attributeParts[1];

			} else {

				displayName = null;
			}

			if (attributeParts.length >= 3) {

				try {
					@SuppressWarnings("unchecked")
					Stringyfier<String> stringFormatter2 = (Stringyfier<String>) ReflectionUtils.getInstance(attributeParts[2]);
					stringFormatter = stringFormatter2;

					attributeStringFormatter.put(name, stringFormatter);
				} catch (Exception e) {
					log.warn("Unable to find stringformatter of attribute: " + attribute + ", adding without formatter.");
				}
			}

			attributeDescriptors.add(new InternalUserQueriesAttributeDescriptor(name, displayName, stringFormatter));
		}

		if (attributeDescriptors.isEmpty()) {

			return null;

		} else {

			return attributeDescriptors;
		}
	}

	@Override
	public Query createQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {

		InternalContactDetailQuery query = new InternalContactDetailQuery();

		query.setQueryID(descriptor.getQueryID());

		this.queryDAO.add(query, transactionHandler, null);

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public Query importQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap, QueryContentFilter contentFilter) throws Throwable {

		InternalContactDetailQuery query = new InternalContactDetailQuery();

		query.setQueryID(descriptor.getQueryID());

		query.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(query.getClass())));
		
		contentFilter.filterHTML(query);

		if (query.getSelectedUserAttributes() != null) {

			if (getAttributeDescriptors() == null) {

				query.setSelectedUserAttributes(null);

			} else {

				List<SelectedUserAttribute> refreshedSelectedAttributes = new ArrayList<>(query.getSelectedUserAttributes().size());

				for (SelectedUserAttribute selectedAttribute : query.getSelectedUserAttributes()) {

					InternalUserQueriesAttributeDescriptor attributeDescriptor = getAttributeDescriptor(selectedAttribute);

					if (attributeDescriptor != null) {

						refreshedSelectedAttributes.add(new SelectedUserAttribute(attributeDescriptor.getName(), attributeDescriptor.getDisplayName(), selectedAttribute.getSortIndex()));
					}
				}

				query.setSelectedUserAttributes(refreshedSelectedAttributes);
			}
		}

		this.queryDAO.add(query, transactionHandler, null);

		return query;
	}

	private InternalUserQueriesAttributeDescriptor getAttributeDescriptor(SelectedUserAttribute selectedAttribute) {

		for (InternalUserQueriesAttributeDescriptor attributeDescriptor : attributeDescriptors) {
			if (attributeDescriptor.getName().equalsIgnoreCase(selectedAttribute.getName())) {
				return attributeDescriptor;
			}
		}

		return null;
	}

	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, boolean extraData) throws SQLException {

		InternalContactDetailQuery query = this.getQuery(descriptor.getQueryID());

		if (query == null) {

			return null;
		}

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		InternalContactDetailQuery query = this.getQuery(descriptor.getQueryID(), transactionHandler);

		if (query == null) {

			return null;
		}

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public QueryInstance getQueryInstance(MutableQueryInstanceDescriptor descriptor, String instanceManagerID, HttpServletRequest req, User user, User poster, InstanceMetadata instanceMetadata) throws SQLException {

		InternalContactDetailQueryInstance queryInstance;

		// Check if we should create a new instance or get an existing one
		if (descriptor.getQueryInstanceID() == null) {

			queryInstance = new InternalContactDetailQueryInstance();

			queryInstance.setQuery(getQuery(descriptor.getQueryDescriptor().getQueryID()));

			if (queryInstance.getQuery() == null) {

				return null;
			}

			if (poster != null) {

				queryInstance.set(descriptor);
				getUserDetails(queryInstance, poster);
			}

		} else {

			queryInstance = getQueryInstance(descriptor.getQueryInstanceID());

			if (queryInstance == null) {

				return null;
			}

			queryInstance.setQuery(getQuery(descriptor.getQueryDescriptor().getQueryID()));

			if (queryInstance.getQuery() == null) {

				return null;
			}
		}

		if (req != null) {

			FCKUtils.setAbsoluteFileUrls(queryInstance.getQuery(), RequestUtils.getFullContextPathURL(req) + ckConnectorModuleAlias);

			URLRewriter.setAbsoluteLinkUrls(queryInstance.getQuery(), req, true);
		}

		queryInstance.getQuery().scanAttributeTags();

		TextTagReplacer.replaceTextTags(queryInstance.getQuery(), instanceMetadata.getSiteProfile());

		queryInstance.set(descriptor);

		return queryInstance;
	}

	private InternalContactDetailQuery getQuery(Integer queryID) throws SQLException {

		HighLevelQuery<InternalContactDetailQuery> query = new HighLevelQuery<InternalContactDetailQuery>();

		query.addParameter(queryIDParamFactory.getParameter(queryID));

		return queryDAO.get(query);
	}

	private InternalContactDetailQuery getQuery(Integer queryID, TransactionHandler transactionHandler) throws SQLException {

		HighLevelQuery<InternalContactDetailQuery> query = new HighLevelQuery<InternalContactDetailQuery>();

		query.addParameter(queryIDParamFactory.getParameter(queryID));

		return queryDAO.get(query, transactionHandler);
	}

	private InternalContactDetailQueryInstance getQueryInstance(Integer queryInstanceID) throws SQLException {

		HighLevelQuery<InternalContactDetailQueryInstance> query = new HighLevelQuery<InternalContactDetailQueryInstance>(InternalContactDetailQueryInstance.QUERY_RELATION);

		query.addParameter(queryInstanceIDParamFactory.getParameter(queryInstanceID));

		return queryInstanceDAO.get(query);
	}

	@Override
	public void save(InternalContactDetailQueryInstance queryInstance, TransactionHandler transactionHandler, InstanceRequestMetadata requestMetadata) throws Throwable {

		if (queryInstance.getQueryInstanceID() == null || !queryInstance.getQueryInstanceID().equals(queryInstance.getQueryInstanceDescriptor().getQueryInstanceID())) {

			queryInstance.setQueryInstanceID(queryInstance.getQueryInstanceDescriptor().getQueryInstanceID());

			this.queryInstanceDAO.add(queryInstance, transactionHandler, null);

		} else {

			this.queryInstanceDAO.update(queryInstance, transactionHandler, null);
		}
	}

	@Override
	public QueryResponse getFormHTML(InternalContactDetailQueryInstance queryInstance, HttpServletRequest req, User user, User poster, List<ValidationError> validationErrors, boolean enableAjaxPosting, String queryRequestURL, InstanceRequestMetadata requestMetadata, AttributeHandler attributeHandler) throws Throwable {

		InternalContactDetailQuery query = queryInstance.getQuery();

		if (validationErrors == null && !queryInstance.isPopulated()) {

			if (poster == null) {

				validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, new ValidationError("UserNotLoggedIn"));

			} else {

				getUserDetails(queryInstance, poster);

				if (!queryInstance.isPopulated()) {

					validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, new ValidationError("UnableToGetUserDetails"));
				}
			}
		}

		if (validationErrors == null && queryInstance.isPopulated() && this.enableClosestManager) {

			if ((query.isShowManagerInfo() || query.isRequireManagerSigning()) && !queryInstance.isManagerPopulated()) {

				validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, new ValidationError("UnableToGetManagerDetails"));

			} else if (query.isRequireManagerSigning() && (queryInstance.getManagerCitizenID() == null || (queryInstance.getManagerEmail() == null && queryInstance.getManagerMobilePhone() == null))) {

				validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, new ValidationError("ManagerDoesNotHaveRequiredFieldsForSigning"));
			}
		}

		return super.getFormHTML(queryInstance, req, user, poster, validationErrors, enableAjaxPosting, queryRequestURL, requestMetadata, attributeHandler);
	}

	@Override
	public void populate(InternalContactDetailQueryInstance queryInstance, HttpServletRequest req, User user, User poster, boolean allowPartialPopulation, MutableAttributeHandler attributeHandler, InstanceRequestMetadata requestMetadata) throws ValidationException {

		InternalContactDetailQuery query = queryInstance.getQuery();

		if (poster == null) {

			throw new ValidationException(new ValidationError("UserNotLoggedIn"));

		} else if (!queryInstance.isPopulated()) {

			getUserDetails(queryInstance, poster);

			if (!queryInstance.isPopulated() && !(allowPartialPopulation || queryInstance.getQueryInstanceDescriptor().getQueryState() != QueryState.VISIBLE_REQUIRED)) {

				throw new ValidationException(new ValidationError("UnableToGetUserDetails"));
			}
		}

		if (queryInstance.isPopulated() && this.enableClosestManager) {

			if ((query.isShowManagerInfo() || query.isRequireManagerSigning()) && !queryInstance.isManagerPopulated()) {

				throw new ValidationException(new ValidationError("UnableToGetManagerDetails"));

			} else if (query.isRequireManagerSigning() && (queryInstance.getManagerCitizenID() == null || (queryInstance.getManagerEmail() == null && queryInstance.getManagerMobilePhone() == null))) {

				throw new ValidationException(new ValidationError("ManagerDoesNotHaveRequiredFieldsForSigning"));
			}
		}

		if (queryInstance.getQuery().isSetAsAttribute()) {

			queryInstance.resetFlowInstanceAttributes(attributeHandler);
			queryInstance.setFlowInstanceAttributes(attributeHandler);
		}
	}

	public void getUserDetails(InternalContactDetailQueryInstance queryInstance, User poster) {

		InternalContactDetailQuery query = queryInstance.getQuery();

		if (query.isShowName()) {
			queryInstance.setFirstname(poster.getFirstname());
			queryInstance.setLastname(poster.getLastname());
		}

		if (query.isShowUsername()) {
			queryInstance.setUsername(formatUsername(poster.getUsername()));
		}

		if (query.isShowEmail()) {
			queryInstance.setEmail(poster.getEmail());
		}

		if (query.getSelectedUserAttributes() != null) {

			queryInstance.setUserAttributeValues(new ArrayList<UserAttributeValue>());

			for (SelectedUserAttribute selectedAttribute : queryInstance.getQuery().getSelectedUserAttributes()) {

				String value = poster.getAttributeHandler().getString(selectedAttribute.getName());

				if (value != null) {
					queryInstance.getUserAttributeValues().add(new UserAttributeValue(selectedAttribute.getName(), formatAttribute(selectedAttribute, value)));
				}
			}
		}

		if (query.isShowManagerInfo() || query.isRequireManagerSigning()) {

			String managerUsername = poster.getAttributeHandler().getString(InternalUserQueriesConstants.USER_MANAGER_USERNAME_ATTRIBUTE);

			if (managerUsername != null) {

				User manager = systemInterface.getUserHandler().getUserByUsername(managerUsername, false, true);

				if (manager != null) {

					queryInstance.setManagerUsername(managerUsername);
					queryInstance.setManagerCitizenID(CitizenIdentifierUtils.getUserOrManagerCitizenIdentifier(manager));
					queryInstance.setManagerEmail(manager.getEmail());
					queryInstance.setManagerFirstname(manager.getFirstname());
					queryInstance.setManagerLastname(manager.getLastname());
					queryInstance.setManagerMobilePhone(manager.getAttributeHandler().getString("mobilePhone"));

					if (query.isShowManagerInfo() && query.getSelectedManagerAttributes() != null) {

						queryInstance.setManagerAttributeValues(new ArrayList<ManagerAttributeValue>());

						for (SelectedManagerAttribute selectedAttribute : queryInstance.getQuery().getSelectedManagerAttributes()) {

							String value = manager.getAttributeHandler().getString(selectedAttribute.getName());

							if (value != null) {
								queryInstance.getManagerAttributeValues().add(new ManagerAttributeValue(selectedAttribute.getName(), formatAttribute(selectedAttribute, value)));
							}
						}
					}
				}
			}
		}

		queryInstance.getQueryInstanceDescriptor().setPopulated(queryInstance.isPopulated());
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureQuery(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.queryCRUD.update(req, res, user, uriParser);
	}

	@Override
	public boolean deleteQuery(ImmutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {

		InternalContactDetailQuery query = getQuery(descriptor.getQueryID());

		if (query == null) {

			return false;
		}

		this.queryDAO.delete(query, transactionHandler);

		return true;
	}

	@Override
	public boolean deleteQueryInstance(ImmutableQueryInstanceDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		InternalContactDetailQueryInstance queryInstance = this.getQueryInstance(descriptor.getQueryInstanceID());

		if (queryInstance == null) {

			return false;
		}

		this.queryInstanceDAO.delete(queryInstance, transactionHandler);

		return true;
	}

	@Override
	public String getTitlePrefix() {

		return this.moduleDescriptor.getName();
	}

	@Override
	public void copyQuery(MutableQueryDescriptor sourceQueryDescriptor, MutableQueryDescriptor copyQueryDescriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap) throws SQLException {

		InternalContactDetailQuery query = getQuery(sourceQueryDescriptor.getQueryID(), transactionHandler);

		query.setQueryID(copyQueryDescriptor.getQueryID());

		queryDAO.add(query, transactionHandler, null);
	}

	@Override
	protected void appendPDFData(Document doc, Element showQueryValuesElement, InternalContactDetailQueryInstance queryInstance, AttributeHandler attributeHandler) {

		super.appendPDFData(doc, showQueryValuesElement, queryInstance, attributeHandler);

		if (queryInstance.getQuery().getDescription() != null) {

			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "Description", JTidyUtils.getXHTML(queryInstance.getQuery().getDescription(attributeHandler), systemInterface.getEncoding()));
			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "isHTMLDescription", queryInstance.getQuery().getDescription().contains("<") && queryInstance.getQuery().getDescription().contains(">"));
		}
	}

	@Override
	protected Class<InternalContactDetailQueryInstance> getQueryInstanceClass() {

		return InternalContactDetailQueryInstance.class;
	}
	
	@Override
	public String getExportFirstName() {

		return exportFirstName;
	}

	@Override
	public String getExportLastName() {

		return exportLastName;
	}

	@Override
	public String getExportUsername() {

		return exportUsername;
	}

	@Override
	public String getExportEmail() {

		return exportEmail;
	}

	@Override
	public String getExportManager() {

		return exportManager;
	}

	public String getContactFieldDisplayName(String name) {

		if (name.equals("firstname")) {

			return exportFirstName;
		}

		if (name.equals("lastname")) {

			return exportLastName;
		}

		if (name.equals("username")) {

			return exportUsername;
		}

		if (name.equals("email")) {

			return exportEmail;
		}

		if (name.equals("manager")) {

			return exportManager;
		}

		if (name.equals("managerFirstname")) {

			return exportManager + " " + exportFirstName.toLowerCase();
		}

		if (name.equals("managerLastname")) {

			return exportManager + " " + exportLastName.toLowerCase();
		}

		if (name.equals("managerUsername")) {

			return exportManager + " " + exportUsername.toLowerCase();
		}

		if (name.equals("managerEmail")) {

			return exportManager + " " + exportEmail.toLowerCase();
		}

		return null;
	}

	public List<InternalUserQueriesAttributeDescriptor> getAttributeDescriptors() {
		return attributeDescriptors;
	}

	public String formatUsername(String username) {

		if (usernameStringFormatter != null) {
			return usernameStringFormatter.format(username);
		}

		return username;
	}

	public String formatAttribute(InternalUserQueriesSelectedAttribute attribute, String value) {

		Stringyfier<String> formatter = attributeStringFormatter.get(attribute.getName());

		if (formatter != null) {
			return formatter.format(value);
		}

		return value;
	}

	public boolean isEnableClosestManager() {
		return enableClosestManager;
	}

	public UserHandler getUserHandler() {
		return systemInterface.getUserHandler();
	}
}
