package com.nordicpeak.flowengine.queries.internaluserqueries;

import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.SimpleAttribute;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.XMLUtils;

import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQuery;
import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQueryInstance;
import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQueryProvider;

public class InternalUserQueriesUtils {
	
	public static void toXSD(CommonInternalUserQuery query, Element sequenceElement, Document doc) {
		
		if (query.isShowName()) {

			appendFieldDefinition(AttributeNames.FIRSTNAME_ATTRIBUTE, true, doc, sequenceElement);
			appendFieldDefinition(AttributeNames.LASTNAME_ATTRIBUTE, true, doc, sequenceElement);
		}

		if (query.isShowUsername()) {

			appendFieldDefinition(AttributeNames.USERNAME_ATTRIBUTE, false, doc, sequenceElement);
		}

		if (query.isShowEmail()) {

			appendFieldDefinition(AttributeNames.EMAIL_ATTRIBUTE, false, doc, sequenceElement);
		}
		
		if (query.getSelectedUserAttributes() != null) {

			for (InternalUserQueriesSelectedAttribute selectedAttribute : query.getSelectedUserAttributes()) {

				appendFieldDefinition(selectedAttribute.getName(), false, doc, sequenceElement);
			}
		}

		toXSDManager(query, sequenceElement, doc);
	}
	
	public static void toXSDManager(CommonInternalUserQuery query, Element sequenceElement, Document doc) {
		
		if (query.isShowManagerInfo()) {

			if (query.isShowManagerName()) {

				appendFieldDefinition("manager" + StringUtils.toFirstLetterUppercase(AttributeNames.FIRSTNAME_ATTRIBUTE), true, doc, sequenceElement);
				appendFieldDefinition("manager" + StringUtils.toFirstLetterUppercase(AttributeNames.LASTNAME_ATTRIBUTE), true, doc, sequenceElement);
			}

			if (query.isShowManagerUsername()) {

				appendFieldDefinition("manager" + StringUtils.toFirstLetterUppercase(AttributeNames.USERNAME_ATTRIBUTE), false, doc, sequenceElement);
			}

			if (query.isShowManagerEmail()) {

				appendFieldDefinition("manager" + StringUtils.toFirstLetterUppercase(AttributeNames.EMAIL_ATTRIBUTE), false, doc, sequenceElement);
			}

			if (query.getSelectedManagerAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute selectedAttribute : query.getSelectedManagerAttributes()) {

					appendFieldDefinition("manager" + StringUtils.toFirstLetterUppercase(selectedAttribute.getName()), false, doc, sequenceElement);
				}
			}
		}
	}
	
	private static void appendFieldDefinition(String name, boolean required, Document doc, Element sequenceElement) {

		Element fieldElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		fieldElement.setAttribute("name", name);
		fieldElement.setAttribute("type", "xs:string");
		fieldElement.setAttribute("minOccurs", required ? "1" : "0");
		fieldElement.setAttribute("maxOccurs", "1");

		sequenceElement.appendChild(fieldElement);
	}

	public static void toExportXML(CommonInternalUserQuery query, CommonInternalUserQueryInstance queryInstance, Element element, Document doc) throws Exception {

		if (query.isShowName()) {
			XMLUtils.appendNewCDATAElement(doc, element, AttributeNames.FIRSTNAME_ATTRIBUTE, queryInstance.getFirstname());
			XMLUtils.appendNewCDATAElement(doc, element, AttributeNames.LASTNAME_ATTRIBUTE, queryInstance.getLastname());
		}

		if (query.isShowUsername()) {
			XMLUtils.appendNewCDATAElement(doc, element, AttributeNames.USERNAME_ATTRIBUTE, queryInstance.getUsername());
		}

		if (query.isShowEmail()) {
			XMLUtils.appendNewCDATAElement(doc, element, AttributeNames.EMAIL_ATTRIBUTE, queryInstance.getEmail());
		}
		
		if (query.getSelectedUserAttributes() != null) {

			for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedUserAttributes()) {

				XMLUtils.appendNewCDATAElement(doc, element, attribute.getName(), getAttributeValue(attribute.getName(), queryInstance.getUserAttributeValues()));
			}
		}

		toExportXMLManager(query, queryInstance, element, doc);
	}
	
	public static void toExportXMLManager(CommonInternalUserQuery query, CommonInternalUserQueryInstance queryInstance, Element element, Document doc) {
		
		if (query.isShowManagerInfo()) {

			if (query.isShowManagerName()) {
				XMLUtils.appendNewCDATAElement(doc, element, "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.FIRSTNAME_ATTRIBUTE), queryInstance.getManagerFirstname());
				XMLUtils.appendNewCDATAElement(doc, element, "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.LASTNAME_ATTRIBUTE), queryInstance.getManagerLastname());
			}

			if (query.isShowManagerUsername()) {
				XMLUtils.appendNewCDATAElement(doc, element, "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.USERNAME_ATTRIBUTE), queryInstance.getManagerUsername());
			}

			if (query.isShowManagerEmail()) {
				XMLUtils.appendNewCDATAElement(doc, element, "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.EMAIL_ATTRIBUTE), queryInstance.getManagerEmail());
			}

			if (query.getSelectedManagerAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedManagerAttributes()) {

					XMLUtils.appendNewCDATAElement(doc, element, "manager" + StringUtils.toFirstLetterUppercase(attribute.getName()), getAttributeValue(attribute.getName(), queryInstance.getManagerAttributeValues()));
				}
			}
		}
	}

	public static void setFlowInstanceAttributes(CommonInternalUserQuery query, CommonInternalUserQueryInstance queryInstance, MutableAttributeHandler attributeHandler) {

		if (query.isShowName()) {

			attributeHandler.setAttribute(query.getAttributeName() + "." + AttributeNames.FIRSTNAME_ATTRIBUTE, queryInstance.getFirstname());
			attributeHandler.setAttribute(query.getAttributeName() + "." + AttributeNames.LASTNAME_ATTRIBUTE, queryInstance.getLastname());
		}

		if (query.isShowUsername()) {

			attributeHandler.setAttribute(query.getAttributeName() + "." + AttributeNames.USERNAME_ATTRIBUTE, queryInstance.getUsername());
		}

		if (query.isShowEmail()) {

			attributeHandler.setAttribute(query.getAttributeName() + "." + AttributeNames.EMAIL_ATTRIBUTE, queryInstance.getEmail());
		}

		if (query.getSelectedUserAttributes() != null) {

			for (InternalUserQueriesSelectedAttribute selectedAttribute : query.getSelectedUserAttributes()) {

				String value = getAttributeValue(selectedAttribute.getName(), queryInstance.getUserAttributeValues());
				attributeHandler.setAttribute(query.getAttributeName() + "." + selectedAttribute.getName(), value);
			}
		}

		if (query.isShowManagerInfo()) {

			if (query.isShowManagerName()) {

				attributeHandler.setAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.FIRSTNAME_ATTRIBUTE), queryInstance.getManagerFirstname());
				attributeHandler.setAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.LASTNAME_ATTRIBUTE), queryInstance.getManagerLastname());
			}

			if (query.isShowManagerUsername()) {

				attributeHandler.setAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.USERNAME_ATTRIBUTE), queryInstance.getManagerUsername());
			}

			if (query.isShowManagerEmail()) {

				attributeHandler.setAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.EMAIL_ATTRIBUTE), queryInstance.getManagerEmail());
			}

			if (query.getSelectedManagerAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute selectedAttribute : query.getSelectedManagerAttributes()) {

					String value = getAttributeValue(selectedAttribute.getName(), queryInstance.getManagerAttributeValues());
					attributeHandler.setAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(selectedAttribute.getName()), value);
				}
			}
		}
	}

	public static void resetFlowInstanceAttributes(CommonInternalUserQuery query, CommonInternalUserQueryInstance queryInstance, MutableAttributeHandler attributeHandler) {

		if (query.isShowName()) {

			attributeHandler.removeAttribute(query.getAttributeName() + "." + AttributeNames.FIRSTNAME_ATTRIBUTE);
			attributeHandler.removeAttribute(query.getAttributeName() + "." + AttributeNames.LASTNAME_ATTRIBUTE);
		}

		if (query.isShowUsername()) {

			attributeHandler.removeAttribute(query.getAttributeName() + "." + AttributeNames.USERNAME_ATTRIBUTE);
		}

		if (query.isShowEmail()) {

			attributeHandler.removeAttribute(query.getAttributeName() + "." + AttributeNames.EMAIL_ATTRIBUTE);
		}

		if (query.getSelectedUserAttributes() != null) {

			for (InternalUserQueriesSelectedAttribute selectedAttribute : query.getSelectedUserAttributes()) {

				attributeHandler.removeAttribute(query.getAttributeName() + "." + selectedAttribute.getName());
			}
		}

		if (query.isShowManagerInfo()) {

			if (query.isShowManagerName()) {

				attributeHandler.removeAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.FIRSTNAME_ATTRIBUTE));
				attributeHandler.removeAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.LASTNAME_ATTRIBUTE));
			}

			if (query.isShowManagerUsername()) {

				attributeHandler.removeAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.USERNAME_ATTRIBUTE));
			}

			if (query.isShowManagerEmail()) {

				attributeHandler.removeAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(AttributeNames.EMAIL_ATTRIBUTE));
			}

			if (query.getSelectedManagerAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute selectedAttribute : query.getSelectedManagerAttributes()) {

					attributeHandler.removeAttribute(query.getAttributeName() + "." + "manager" + StringUtils.toFirstLetterUppercase(selectedAttribute.getName()));
				}
			}
		}
	}

	public static List<String> getColumnLabels(CommonInternalUserQuery query, CommonInternalUserQueryInstance queryInstance, CommonInternalUserQueryProvider provider) {

		List<String> labels = new ArrayList<String>();

		if (query.isShowName()) {

			labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportFirstName());
			labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportLastName());
		}

		if (query.isShowUsername()) {

			labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportUsername());
		}

		if (query.isShowEmail()) {

			labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportEmail());
		}
		
		if (query.getSelectedUserAttributes() != null) {

			for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedUserAttributes()) {

				labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + attribute.getDisplayName());
			}
		}

		if (query.isShowManagerInfo()) {

			if (query.isShowManagerName()) {

				labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportManager() + " " + provider.getExportFirstName());
				labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportManager() + " " + provider.getExportLastName());
			}

			if (query.isShowManagerUsername()) {

				labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportManager() + " " + provider.getExportUsername());
			}

			if (query.isShowManagerEmail()) {

				labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportManager() + " " + provider.getExportEmail());
			}

			if (query.getSelectedManagerAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedManagerAttributes()) {

					labels.add(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + provider.getExportManager() + " " + attribute.getDisplayName());
				}
			}
		}

		return labels;
	}

	public static List<String> getColumnValues(CommonInternalUserQuery query, CommonInternalUserQueryInstance queryInstance) {

		List<String> columnValues = new ArrayList<String>();

		if (queryInstance.isPopulated()) {
			
			if (query.isShowName()) {

				columnValues.add(queryInstance.getFirstname());
				columnValues.add(queryInstance.getLastname());
			}

			if (query.isShowUsername()) {

				columnValues.add(queryInstance.getUsername());
			}

			if (query.isShowEmail()) {

				columnValues.add(queryInstance.getEmail());
			}

			if (query.getSelectedUserAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedUserAttributes()) {

					String value = getAttributeValue(attribute.getName(), queryInstance.getUserAttributeValues());

					if (value != null) {

						columnValues.add(value);

					} else {

						columnValues.add("");
					}
				}
			}

			if (query.isShowManagerInfo()) {

				if (query.isShowManagerName()) {

					columnValues.add(queryInstance.getManagerFirstname());
					columnValues.add(queryInstance.getManagerLastname());
				}

				if (query.isShowManagerUsername()) {

					columnValues.add(queryInstance.getManagerUsername());
				}

				if (query.isShowManagerEmail()) {

					columnValues.add(queryInstance.getManagerEmail());
				}

				if (query.getSelectedManagerAttributes() != null) {

					for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedManagerAttributes()) {

						String value = getAttributeValue(attribute.getName(), queryInstance.getManagerAttributeValues());

						if (value != null) {

							columnValues.add(value);

						} else {

							columnValues.add("");
						}
					}
				}
			}

		} else {

			if (query.isShowName()) {
				columnValues.add(null);
				columnValues.add(null);
			}

			if (query.isShowUsername()) {
				columnValues.add(null);
			}

			if (query.isShowEmail()) {
				columnValues.add(null);
			}

			if (query.getSelectedUserAttributes() != null) {

				for (int i = 0; i < query.getSelectedUserAttributes().size(); i++) {
					columnValues.add(null);
				}
			}

			if (query.isShowManagerInfo()) {

				if (query.isShowManagerName()) {
					columnValues.add(null);
					columnValues.add(null);
				}

				if (query.isShowManagerUsername()) {
					columnValues.add(null);
				}

				if (query.isShowManagerEmail()) {
					columnValues.add(null);
				}

				if (query.getSelectedManagerAttributes() != null) {

					for (int i = 0; i < query.getSelectedManagerAttributes().size(); i++) {
						columnValues.add(null);
					}
				}
			}
		}

		return columnValues;
	}

	public static String getAttributeValue(String attributeName, List<? extends SimpleAttribute> attributeValues) {

		if (attributeValues != null) {

			for (SimpleAttribute attributeValue : attributeValues) {

				if (attributeValue.getName().equals(attributeName)) {

					return attributeValue.getValue();
				}
			}
		}

		return null;
	}
}
