package com.nordicpeak.flowengine.queries.internaluserquery.beans;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.SigningParty;
import com.nordicpeak.flowengine.interfaces.ColumnExportableQueryInstance;
import com.nordicpeak.flowengine.interfaces.ContactFieldQueryInstance;
import com.nordicpeak.flowengine.interfaces.MultiSignQueryinstance;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.QueryRequestProcessor;
import com.nordicpeak.flowengine.interfaces.UserValueQueryInstance;
import com.nordicpeak.flowengine.interfaces.UserValuesQueryInstance;
import com.nordicpeak.flowengine.interfaces.UsersClosestManagerQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryUtils;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesUtils;
import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQueryInstance;
import com.nordicpeak.flowengine.queries.internaluserquery.InternalUserQueryProviderModule;

@Table(name = "internal_user_query_instances")
@XMLElement
public class InternalUserQueryInstance extends BaseQueryInstance implements UserValueQueryInstance, ColumnExportableQueryInstance, UserValuesQueryInstance, MultiSignQueryinstance, CommonInternalUserQueryInstance, ContactFieldQueryInstance, UsersClosestManagerQueryInstance {

	private static final long serialVersionUID = -7761759005604863873L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(InternalUserQueryInstance.class, "query");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private InternalUserQuery query;

	@DAOManaged
	@XMLElement
	private Integer userID;

	@DAOManaged
	@XMLElement
	private String firstname;

	@DAOManaged
	@XMLElement
	private String lastname;

	@DAOManaged
	@XMLElement
	private String username;

	@DAOManaged
	@XMLElement
	private String email;

	@DAOManaged
	@XMLElement
	private String citizenIdentifier;

	@DAOManaged
	@XMLElement
	private String managerCitizenID;

	@DAOManaged
	@XMLElement
	private String managerUsername;

	@DAOManaged
	@XMLElement
	private String managerFirstname;

	@DAOManaged
	@XMLElement
	private String managerLastname;

	@DAOManaged
	@XMLElement
	private String managerEmail;

	@DAOManaged
	@XMLElement
	private String managerMobilePhone;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<UserAttributeValue> userAttributeValues;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<ManagerAttributeValue> managerAttributeValues;

	private List<Integer> groupIDs;

	public Integer getQueryInstanceID() {

		return queryInstanceID;
	}

	public void setQueryInstanceID(Integer queryInstanceID) {

		this.queryInstanceID = queryInstanceID;
	}

	@Override
	public InternalUserQuery getQuery() {

		return query;
	}

	public void setQuery(InternalUserQuery query) {

		this.query = query;
	}

	public Integer getUserID() {

		return userID;
	}

	public void setUserID(Integer userID) {

		this.userID = userID;
	}

	@Override
	public String getFirstname() {

		return firstname;
	}

	public void setFirstname(String firstname) {

		this.firstname = firstname;
	}

	@Override
	public String getLastname() {

		return lastname;
	}

	public void setLastname(String lastname) {

		this.lastname = lastname;
	}

	@Override
	public String getUsername() {

		return username;
	}

	public void setUsername(String username) {

		this.username = username;
	}

	@Override
	public String getEmail() {

		return email;
	}

	public void setEmail(String email) {

		this.email = email;
	}

	@Override
	public List<UserAttributeValue> getUserAttributeValues() {

		return userAttributeValues;
	}

	public void setUserAttributeValues(List<UserAttributeValue> attributeValues) {

		this.userAttributeValues = attributeValues;
	}

	@Override
	public boolean isPopulated() {

		return !ObjectUtils.isNull(userID, firstname, lastname, username, email, citizenIdentifier, userAttributeValues);
	}

	public boolean isManagerPopulated() {

		return !ObjectUtils.isNull(managerFirstname, managerLastname, managerUsername, managerEmail, managerAttributeValues);
	}

	@Override
	public void reset(MutableAttributeHandler attributeHandler) {

		userID = null;
		firstname = null;
		lastname = null;
		email = null;
		username = null;
		citizenIdentifier = null;

		managerCitizenID = null;
		managerFirstname = null;
		managerLastname = null;
		managerUsername = null;
		managerEmail = null;
		managerMobilePhone = null;

		userAttributeValues = null;
		managerAttributeValues = null;

		if (query.isSetAsAttribute() && attributeHandler != null) {

			resetFlowInstanceAttributes(attributeHandler);
		}

		super.reset(attributeHandler);
	}

	public void resetFlowInstanceAttributes(MutableAttributeHandler attributeHandler) {

		InternalUserQueriesUtils.resetFlowInstanceAttributes(query, this, attributeHandler);
	}

	public void setFlowInstanceAttributes(MutableAttributeHandler attributeHandler) {

		InternalUserQueriesUtils.setFlowInstanceAttributes(query, this, attributeHandler);
	}

	@Override
	public String toString() {

		return this.getClass().getName() + " (queryInstanceID=" + queryInstanceID + ")";
	}

	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {

		Element element = getBaseExportXML(doc);

		InternalUserQueriesUtils.toExportXML(query, this, element, doc);

		return element;
	}

	@Override
	public List<String> getColumnLabels(QueryHandler queryHandler) {

		if (!query.hasFields()) {

			return Collections.emptyList();
		}

		InternalUserQueryProviderModule queryProvider = queryHandler.getQueryProvider(getQueryInstanceDescriptor().getQueryDescriptor().getQueryTypeID(), InternalUserQueryProviderModule.class);

		return InternalUserQueriesUtils.getColumnLabels(query, this, queryProvider);
	}

	@Override
	public List<String> getColumnValues() {

		if (!query.hasFields()) {

			return Collections.emptyList();
		}

		return InternalUserQueriesUtils.getColumnValues(query, this);
	}

	@Override
	public User getUserValue(QueryHandler queryHandler) {

		if (userID != null) {

			InternalUserQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), InternalUserQueryProviderModule.class);
			return queryProviderModule.getUserHandler().getUser(userID, false, true);
		}

		return null;
	}

	@Override
	public Collection<User> getUserValues(QueryHandler queryHandler) {

		User user = getUserValue(queryHandler);

		if (user != null) {

			return CollectionUtils.getList(user);
		}

		return null;
	}

	@Override
	public QueryRequestProcessor getQueryRequestProcessor(HttpServletRequest req, User user, User poster, URIParser uriParser, QueryHandler queryHandler, InstanceRequestMetadata requestMetadata) throws Exception {

		return BaseQueryUtils.getGenericQueryInstanceProvider(this.getClass(), queryHandler, queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID()).getQueryRequestProcessor(this, req, user, poster, uriParser, requestMetadata);
	}

	@Override
	public List<? extends SigningParty> getSigningParties() {

		if ((!query.requiresMultipartSigning() || userID == null) && !query.isRequireManagerSigning()) {
			return null;
		}

		List<SigningParty> signingParties = new ArrayList<>(2);

		if (query.requiresMultipartSigning() && userID != null) {

			String mobilePhone = null;

			if (userAttributeValues != null) {

				for (UserAttributeValue userAttributeValue : userAttributeValues) {

					if (userAttributeValue.getName().equals("mobile") || userAttributeValue.getName().equals("mobilePhone")) {

						mobilePhone = userAttributeValue.getValue();
						break;
					}
				}
			}

			signingParties.add(new SigningParty(firstname, lastname, email, mobilePhone, citizenIdentifier, query.isSetMultipartsAsOwners()));
		}

		if (query.isRequireManagerSigning()) {
			signingParties.add(new SigningParty(managerFirstname, managerLastname, managerEmail, managerMobilePhone, managerCitizenID, false));
		}

		return signingParties;
	}

	@Override
	public String getCitizenIdentifier() {

		return citizenIdentifier;
	}

	public void setCitizenIdentifier(String citizenIdentifier) {

		this.citizenIdentifier = citizenIdentifier;
	}

	@Override
	public String getManagerCitizenID() {

		return managerCitizenID;
	}

	public void setManagerCitizenID(String managerCitizenID) {

		this.managerCitizenID = managerCitizenID;
	}

	@Override
	public String getManagerUsername() {

		return managerUsername;
	}

	public void setManagerUsername(String managerUsername) {

		this.managerUsername = managerUsername;
	}

	@Override
	public String getManagerFirstname() {

		return managerFirstname;
	}

	public void setManagerFirstname(String managerFirstname) {

		this.managerFirstname = managerFirstname;
	}

	@Override
	public String getManagerLastname() {

		return managerLastname;
	}

	public void setManagerLastname(String managerLastname) {

		this.managerLastname = managerLastname;
	}

	@Override
	public String getManagerEmail() {

		return managerEmail;
	}

	public void setManagerEmail(String managerEmail) {

		this.managerEmail = managerEmail;
	}

	@Override
	public String getManagerMobilePhone() {

		return managerMobilePhone;
	}

	public void setManagerMobilePhone(String managerMobilePhone) {

		this.managerMobilePhone = managerMobilePhone;
	}

	@Override
	public List<ManagerAttributeValue> getManagerAttributeValues() {

		return managerAttributeValues;
	}

	public void setManagerAttributeValues(List<ManagerAttributeValue> managerAttributeValues) {

		this.managerAttributeValues = managerAttributeValues;
	}

	@Override
	public User getClosestManager(QueryHandler queryHandler) {

		InternalUserQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), InternalUserQueryProviderModule.class);

		return queryProviderModule.getUserHandler().getUserByUsername(managerUsername, false, true);
	}

	public List<Integer> getGroupIDs() {

		return groupIDs;
	}

	public void setGroupIDs(List<Integer> groupIDs) {

		this.groupIDs = groupIDs;
	}

	@Override
	public String getContactFieldValue(String contactFieldName) throws IllegalArgumentException, IllegalAccessException {

		if (contactFieldName.equals("firstname")) {

			return firstname;
		}

		if (contactFieldName.equals("lastname")) {

			return lastname;
		}

		if (contactFieldName.equals("username")) {

			return username;
		}

		if (contactFieldName.equals("email")) {

			return email;
		}

		UserAttributeValue userAttributeValue = CollectionUtils.find(userAttributeValues, v -> v.getName().equals(contactFieldName));

		if (userAttributeValue != null) {

			return userAttributeValue.getValue();
		}

		ManagerAttributeValue managerAttributeValue = CollectionUtils.find(managerAttributeValues, v -> v.getName().equals(contactFieldName));

		if (managerAttributeValue != null) {

			return managerAttributeValue.getValue();
		}

		return null;
	}

}
