<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>
	
	<xsl:variable name="staticcontent"><xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/></xsl:variable>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-ui.js?v=1
	</xsl:variable>

	<xsl:variable name="scripts">
		/js/listsearchquery.js?v=1
	</xsl:variable>

	<xsl:variable name="links">
		/css/listsearchquery.css?v=1
	</xsl:variable>

	<xsl:template match="Document">	
		
		<xsl:apply-templates select="ShowQueryValues"/>
		<xsl:apply-templates select="ShowQueryForm"/>
		
	</xsl:template>
	
	<xsl:template match="ShowQueryValues">
		
		<div class="query">
			
			<xsl:attribute name="class">
				<xsl:text>query</xsl:text>
				<xsl:if test="ListSearchQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
			</xsl:attribute>
			
			<article class="listsearchquery show-mode">
				
				<div class="heading-wrapper">
					<h2>
						<xsl:attribute name="class">
							<xsl:if test="ListSearchQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
								<xsl:text>required</xsl:text>
							</xsl:if>
						</xsl:attribute>
						<xsl:value-of select="ListSearchQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
					</h2>
					
					<xsl:call-template name="createUpdateButton">
						<xsl:with-param name="queryID" select="ListSearchQueryInstance/ListSearchQuery/queryID" />
					</xsl:call-template>
					
				</div>

				<xsl:if test="ListSearchQueryInstance/ListSearchQuery/description">
					<span class="italic">
						<xsl:value-of select="ListSearchQueryInstance/ListSearchQuery/description" disable-output-escaping="yes" />
					</span>
				</xsl:if>
				
				<div class="clearboth"/>
				
					<p>
						<xsl:apply-templates select="ListSearchQueryInstance/Alternatives/Alternative" mode="show" />
					</p>

			</article>
				
		</div>
		
	</xsl:template>
	
	<xsl:template match="ShowQueryForm">
	
		<xsl:variable name="shortQueryID" select="concat('q', ListSearchQueryInstance/ListSearchQuery/queryID)" />
	
		<xsl:variable name="queryID" select="concat('query_', ListSearchQueryInstance/ListSearchQuery/queryID)" />
	
		<div class="query" id="{$queryID}">
			
			<xsl:attribute name="class">
				<xsl:text>query</xsl:text>
				<xsl:if test="EnableAjaxPosting"> enableAjaxPosting</xsl:if>
				<xsl:if test="ListSearchQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
				<xsl:if test="ListSearchQueryInstance/ListSearchQuery/showAlternativesOnEmptySearch = 'true'"> allowemptysearch</xsl:if>
			</xsl:attribute>
			
			<a name="{$queryID}" />
		
			<xsl:if test="ValidationErrors/validationError">
				<div id="{$queryID}-validationerrors" class="validationerrors">
					<div class="info-box error">
					
						<xsl:choose>
							<xsl:when test="ValidationErrors/validationError[messageKey]">
								<xsl:apply-templates select="ValidationErrors/validationError[messageKey]"/>
							</xsl:when>
							<xsl:otherwise><span/></xsl:otherwise>
						</xsl:choose>
						
						<div class="marker"/>
					</div>
				</div>
			</xsl:if>
			
			<article class="listsearchquery">
			
				<xsl:if test="ValidationErrors/validationError">
					<xsl:attribute name="class">listsearchquery error</xsl:attribute>
				</xsl:if>
				
				<div class="heading-wrapper">
					
					<h2>
						<xsl:attribute name="class">
							<xsl:if test="ListSearchQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
								<xsl:text>required</xsl:text>
							</xsl:if>
						</xsl:attribute>
						<xsl:value-of select="ListSearchQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
					</h2>
					
					<xsl:if test="ListSearchQueryInstance/ListSearchQuery/helpText">
						<xsl:apply-templates select="ListSearchQueryInstance/ListSearchQuery/helpText" />
					</xsl:if>
				
				</div>

				<xsl:if test="ListSearchQueryInstance/ListSearchQuery/description">
					<span class="italic">
						<xsl:if test="/Document/useCKEditorForDescription = 'true'"><xsl:attribute name="class">italic html-description</xsl:attribute></xsl:if>
						<xsl:value-of select="ListSearchQueryInstance/ListSearchQuery/description" disable-output-escaping="yes" />
					</span>
				</xsl:if>
				
				<fieldset>
				
					<ul class="list-style-type-none margintop alternative-list" id="{$queryID}-list">
						
						<input type="hidden" name="connectorURL" disabled="disabled">
							<xsl:attribute name="value"><xsl:value-of select="queryRequestURL"/>
							</xsl:attribute>
						</input>

						<xsl:choose>
							<xsl:when test="requestparameters">
							
								<xsl:variable name="name"><xsl:value-of select="$shortQueryID"/>_alternative</xsl:variable> 
							
								<xsl:apply-templates select="requestparameters/parameter[name=$name]/value" mode="alternative">
									<xsl:with-param name="prefix">
										<xsl:value-of select="$shortQueryID"/>
										<xsl:text>_alternative</xsl:text>
									</xsl:with-param>
								</xsl:apply-templates>
							</xsl:when>
							
							<xsl:otherwise>
								<xsl:apply-templates select="ListSearchQueryInstance/Alternatives/Alternative" mode="ajaxlist">
									<xsl:with-param name="prefix">
										<xsl:value-of select="$shortQueryID"/>
										<xsl:text>_alternative</xsl:text>
									</xsl:with-param>
								</xsl:apply-templates>
							</xsl:otherwise>
							
						</xsl:choose>
						
						<li id="{$shortQueryID}_alternative-template" class="hidden">
							<input type="hidden" name="{$shortQueryID}_alternative" disabled="disabled"/>
							<input type="hidden" name="{$shortQueryID}_alternative-name" disabled="disabled"/>
			
							<i class="icon">></i>
							
							<xsl:text>&#x20;</xsl:text>
							
							<span class="text"/>
			
							<div class="floatright">
								<a class="delete" href="#" title="{$i18n.DeleteUser}:">
									<i class="icon">x</i>
								</a>
							</div>
						</li>
					</ul>
				
				</fieldset>
				
				<div class="ui-widget">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id">
							<xsl:value-of select="$shortQueryID" />
							<xsl:value-of select="'_list-search-input'" />
						</xsl:with-param>
						<xsl:with-param name="class">
							<xsl:text>full border-box </xsl:text>
						</xsl:with-param>
						<xsl:with-param name="width" select="''" />
						<xsl:with-param name="placeholder" select="ListSearchQueryInstance/ListSearchQuery/placeholderText" />
					</xsl:call-template>
				</div>
				
				<script type="text/javascript">initListSearchQuery('<xsl:value-of select="ListSearchQueryInstance/ListSearchQuery/queryID" />');</script>
				
				<xsl:if test="EnableAjaxPosting">
					<div class="validation-error-templates" style="display: none;">
						
						<span data-messagekey="InvalidAlternative">
							<strong data-icon-before="!">
								<xsl:value-of select="$i18n.Error.InvalidAlternative"/>
							</strong>
						</span>
					
						<span data-messagekey="TooManyAlternativesSelected">
							<strong data-icon-before="!">
								<xsl:value-of select="$i18n.TooManyAlternativesSelected.part1"/>
								<xsl:value-of select="ListSearchQueryInstance/ListSearchQuery/maxChecked"/>
								<xsl:value-of select="$i18n.TooManyAlternativesSelected.part2"/>
								<xsl:text>$checked</xsl:text>
								<xsl:value-of select="$i18n.TooManyAlternativesSelected.part3"/>
							</strong>
						</span>
					
						<span data-messagekey="TooFewAlternativesSelected">
							<strong data-icon-before="!">
							<xsl:value-of select="$i18n.TooFewAlternativesSelected.part1"/>
							<xsl:value-of select="ListSearchQueryInstance/ListSearchQuery/minChecked"/>
							<xsl:value-of select="$i18n.TooFewAlternativesSelected.part2"/>
							<xsl:text>$checked</xsl:text>
							<xsl:value-of select="$i18n.TooFewAlternativesSelected.part3"/>
							</strong>
						</span>
					
					</div>
				</xsl:if>
				
			</article>
			
		</div>
		
	</xsl:template>
	
	<xsl:template match="Alternative" mode="ajaxlist">
		<xsl:param name="prefix" />
		
		<li id="{$prefix}_{alternativeID}" class="{$prefix}-list-entry">
			<input type="hidden" name="{$prefix}" value="{alternativeID}"/>
			<input type="hidden" name="{$prefix}-name{alternativeID}" value="{name}"/>

			<i class="icon">></i>
			
			<xsl:text>&#x20;</xsl:text>
			
			<span class="text">
				<xsl:value-of select="name"/>
			</span>

			<div class="floatright">
				<a class="delete" href="#" title="{$i18n.DeleteUser}:">
					<i class="icon">x</i>
				</a>
			</div>
		</li>
		
	</xsl:template>

	<xsl:template match="value" mode="alternative">
		<xsl:param name="prefix" />
		
		<xsl:variable name="name"><xsl:value-of select="$prefix"/>-name<xsl:value-of select="."/></xsl:variable>
		<xsl:variable name="nameValue"><xsl:value-of select="../../parameter[name=$name]/value"/></xsl:variable>
		
		<li id="{$prefix}_{.}" class="{$prefix}-list-entry">
			<input type="hidden" name="{$prefix}" value="{.}"/>
			<input type="hidden" name="{$prefix}-name{.}" value="{$nameValue}"/>

			<i class="icon">></i>
			
			<xsl:text>&#x20;</xsl:text>
			
			<span class="text">
				<xsl:value-of select="$nameValue"/>
			</span>

			<div class="floatright">
				<a class="delete" href="#" title="{$i18n.DeleteUser}:">
					<i class="icon">x</i>
				</a>
			</div>
		</li>
		
	</xsl:template>

	<xsl:template match="Alternative" mode="show">

		<xsl:value-of select="name"/>
		
		<xsl:if test="position() != last()"><br/></xsl:if>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'RequiredQuery']">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.Error.Required"/>
			</strong>
		</span>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'InvalidAlternative']">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.Error.InvalidAlternative"/>
			</strong>
		</span>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'TooManyAlternativesSelected']">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.TooManyAlternativesSelected.part1"/>
				<xsl:value-of select="maxChecked"/>
				<xsl:value-of select="$i18n.TooManyAlternativesSelected.part2"/>
				<xsl:value-of select="checked"/>
				<xsl:value-of select="$i18n.TooManyAlternativesSelected.part3"/>
			</strong>
		</span>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'TooFewAlternativesSelected']">
		
		<span>
			<strong data-icon-before="!">
			<xsl:value-of select="$i18n.TooFewAlternativesSelected.part1"/>
			<xsl:value-of select="minChecked"/>
			<xsl:value-of select="$i18n.TooFewAlternativesSelected.part2"/>
			<xsl:value-of select="checked"/>
			<xsl:value-of select="$i18n.TooFewAlternativesSelected.part3"/>
			</strong>
		</span>
		
	</xsl:template>
	
	<xsl:template match="validationError">
	
		<xsl:choose>
			<xsl:when test="fieldName != ''">
				
				<i data-icon-after="!" title="{$i18n.Error.UnknownValidationError}"></i>
				
			</xsl:when>
			<xsl:otherwise>
				
				<span>
					<strong data-icon-before="!">
						<xsl:value-of select="$i18n.Error.UnknownValidationError"/>
					</strong>
				</span>
				
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
		
</xsl:stylesheet>