$(function() {

	setQueryRequiredFunctions["ListSearchQueryInstance"] = makeListSearchQueryRequired;
	setQueryValidationErrorFunctions["ListSearchQueryInstance"] = setListSearchQueryValidationError;
});

function makeListSearchQueryRequired(queryID) {

	$("#query_" + queryID).find(".heading-wrapper h2").addClass("required");
}

function initListSearchQuery(queryID) {

	var query = $("#query_" + queryID);
	var prefix = "q" + queryID + "_alternative";
	var list = query.find(".alternative-list");
	var url = list.find("input[name='connectorURL']").val();
	var template = getListSearchQueryTemplate(prefix);
	
	var searchInput = $( "#" + "q" + queryID + "_list-search-input");
	
	if (searchInput.data('ui-autocomplete') != undefined) {
		return;
	}
	
	searchInput.autocomplete({
		source: function(request, response) {
			return searchListSearchQuery(request, response, url, searchInput, template);
		},
		
		select: function( event, ui ) {
			
			if (ui.item.value != "null") {
				
				addListSearchQueryEntry(ui.item, list, prefix);
				$(this).val("");
			}
			
			return false;
		},
		
		focus: function(event, ui) {
			event.preventDefault();
		},
		
		minLength: query.hasClass("allowemptysearch") ? 0 : 1
	});
	
	if (query.hasClass("allowemptysearch")) {
		
		searchInput.on("focus click", function() {
			if (searchInput.val() == "") {
				searchInput.autocomplete("search", "");
			}
		});
	}
	
	var entries = list.find("li");
	
	entries.each(function() {
		var entry = $(this);
		initListSearchQueryDeleteButton(entry, list, prefix);
	});
	
	list.on("change", function() {
		list.find("li").removeClass("lightbackground");
		list.find("li:odd").addClass("lightbackground");
	});
	
	list.trigger("change");
	
	list.on("change", function() {
		if (query.hasClass("enableAjaxPosting")) {
			
			removeListSearchQueryValidationErrors(queryID);
			
			var parameters = [];
			
			list.find("input:enabled").each(function(){
				var input = $(this);
				parameters.push({name: input.attr("name"), value: input.val()});
			});
			
			parameters.push({name: "queryID", value: queryID});
			
			runQueryEvaluators(queryID, parameters);
		}
	});
}

function getListSearchQueryTemplate(prefix){
	return $("#" + prefix + "-template");
}

function searchListSearchQuery(request, response, searchURL, searchInput, template) {
	
	searchInput.addClass("ui-autocomplete-loading");
	
	$.ajax({
		url : searchURL,
		dataType : "json",
		contentType: "application/x-www-form-urlencoded;charset=UTF-8",
		data : {
			q : encodeURIComponent(request.term)
		},
		success : function(data) {
			
			if(data.hits != undefined && data.hits.length > 0) {
				
				response($.map(data.hits, function(item) {
					
					return {
						label : item.Name,
						value : item.ID,
						Name  : item.Name,
						ID : item.ID,
					}
				}));
			} else {
				response(null);
			}
			
			searchInput.removeClass("ui-autocomplete-loading");
			
		},
		error : function() {
			
			searchInput.removeClass("ui-autocomplete-loading");
		}
	});
}

function addListSearchQueryEntry(item, list, prefix, template, showUserURL){
	
	if($("#" + prefix + "_" + item.value).length > 0) {
		return;
	}
	
	var clone = getListSearchQueryTemplate(prefix).clone();
	
	clone.find("span.text").text(item.Name);
	clone.find("input[name='" + prefix + "']").removeAttr("disabled").val(item.value);
	clone.find("input[name='" + prefix + "-id']").removeAttr("disabled").attr('name', prefix + "-id" + item.value).val(item.value);
	clone.find("input[name='" + prefix + "-name']").removeAttr("disabled").attr('name', prefix + "-name" + item.value).val(item.Name);
	clone.attr("id", prefix + "_" + item.value);
	clone.attr("class", prefix + "-list-entry");
	
	var deleteButton = initListSearchQueryDeleteButton(clone, list, prefix);
	deleteButton.attr("title", deleteButton.attr("title") + " " + item.Name);
	
	list.find("li:last").before(clone);
	clone.show();
	
	list.trigger("change");
}

function initListSearchQueryDeleteButton(entry, list, prefix) {
	
	var deleteButton = entry.find("a.delete");
	
	deleteButton.on("click", function(e) {
		e.preventDefault();
		entry.remove();
		
		list.trigger("change");
	});
	
	return deleteButton;
}

function removeListSearchQueryValidationErrors(queryID) {
	var $query = $("#query_" + queryID);
	
	$query.children("article").removeClass("error");
	$("#query_" + queryID + "-validationerrors").remove();
}

function setListSearchQueryValidationError(queryID, validationErrors) {
	
	var $query = $("#query_" + queryID);
	
	var errorMessages = "";
	
	$.each(validationErrors, function(i, error) {
		
		var message;
		
		if (error.messageKey && (message = $query.find(".validation-error-templates span[data-messagekey='" + error.messageKey + "']")[0].outerHTML) != "") {
		
			errorMessages += message.replace("$checked", $query.find(".alternative-list .q" + queryID +"_alternative-list-entry").length);
	
		} else {
			
			errorMessages += '<span><strong data-icon-before="!" />' + getValidationErrorMessage(error) + '</span>';
		}
	});
	
	$query.children("article").addClass("error").before(
		'<div id="query_' + queryID + '-validationerrors" class="validationerrors">' +
			'<div class="info-box error">' +
				errorMessages +
				'<div class="marker"></div>' +
			'</div>' +
		'</div>'
	);
}