<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js
		/jquery/jquery-migrate.js
		/jquery/jquery-ui.js
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
	</xsl:variable>	

	<xsl:variable name="scripts">
		/common/js/queryadmin.js
	</xsl:variable>

	<xsl:template match="Document">	
		
		<div id="ManualCheckboxQueryProvider" class="contentitem">
		
			<xsl:apply-templates select="validationError"/>
			<xsl:apply-templates select="UpdateManualCheckboxQuery"/>
		
		</div>
		
	</xsl:template>
		
	<xsl:template match="UpdateManualCheckboxQuery">
	
		<h1><xsl:value-of select="$i18n.UpdateQuery" /><xsl:text>:&#160;</xsl:text><xsl:value-of select="ManualCheckboxQuery/QueryDescriptor/name" /></h1>
		
		<xsl:apply-templates select="validationException/validationError" />
		
		<form id="updateManualCheckboxQueryForm" name="queryAdminForm" method="post" action="{/Document/requestinfo/uri}">
		
			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="ManualCheckboxQuery" />
			</xsl:call-template>
			
			<xsl:call-template name="createManualCheckboxAlternativesForm">
				<xsl:with-param name="alternatives" select="ManualCheckboxQuery/Alternatives/CheckboxAlternative" />
				<xsl:with-param name="freeTextAlternative" select="ManualCheckboxQuery/freeTextAlternative" />
			</xsl:call-template>
			
			<xsl:variable name="options">
				<option>
					<name><xsl:value-of select="$i18n.Columns.One"/></name>
					<value>ONE</value>
				</option>
				<option>
					<name><xsl:value-of select="$i18n.Columns.Two"/></name>
					<value>TWO</value>
				</option>
				<option>
					<name><xsl:value-of select="$i18n.Columns.Three"/></name>
					<value>THREE</value>
				</option>
			</xsl:variable>
				
			<div class="floatleft full bigmarginbottom">
				<label for="columnType" class="floatleft clearboth"><xsl:value-of select="$i18n.Columns" /></label>
				<div class="floatleft full">
					<xsl:call-template name="createDropdown">
						<xsl:with-param name="id" select="'columns'"/>
						<xsl:with-param name="name" select="'columns'"/>
						<xsl:with-param name="labelElementName" select="'name'" />
						<xsl:with-param name="valueElementName" select="'value'" />
						<xsl:with-param name="element" select="exsl:node-set($options)/option" />
						<xsl:with-param name="selectedValue" select="ManualCheckboxQuery/columns" />
					</xsl:call-template>
		    </div>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'hidePrintInfoText'"/>
					<xsl:with-param name="name" select="'hidePrintInfoText'"/>
					<xsl:with-param name="title" select="$i18n.HidePrintInfoText"/>
					<xsl:with-param name="element" select="ManualCheckboxQuery" />
					</xsl:call-template>
					
					<label for="hidePrintInfoText"><xsl:value-of select="$i18n.HidePrintInfoText" /></label>
				</div>
			</div>
				
			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>
		
		</form>
		
	</xsl:template>
	
	<xsl:template name="createManualCheckboxAlternativesForm">
		
		<xsl:param name="alternatives" />
		<xsl:param name="freeTextAlternative" />
		<xsl:param name="allowFreeTextAlternative" select="'true'"/>
		<xsl:param name="requestparameters" select="requestparameters" />
		
		<script type="text/javascript">
			Alternativesi18n = {
				deleteConfirm: "<xsl:value-of select="$i18n.DeleteAlternativeConfirm"/>"
			};
		</script>
		
		<div class="alternatives-container full floatleft bigmarginbottom">
			<label for="alternative" class="floatleft clearboth"><xsl:value-of select="$i18n.Alternative" /></label>
			
			<div class="alternatives full floatleft marginleft sortable">
				
				<xsl:choose>
					<xsl:when test="$requestparameters">
						<xsl:apply-templates select="$requestparameters/parameter[starts-with(name,'alternative_')]" mode="alternative" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="$alternatives" />
					</xsl:otherwise>
				</xsl:choose>
			
			</div>
			
			<div class="alternative-template" style="display: none;">
				<xsl:call-template name="createManualCheckboxAlternative">
					<xsl:with-param name="alternativeID" select="''" />
					<xsl:with-param name="sortOrder" select="'sortIndex'" />
					<xsl:with-param name="value" select="''" />
					<xsl:with-param name="disabled" select="'true'" />
					<xsl:with-param name="checked" select="'false'" />
				</xsl:call-template>
			</div>
			
			<div class="floatright marginright margintop">
				<a href="javascript:void(0);" onclick="addAlternative(this, event)" title="{$i18n.AddAlternative}">
					<xsl:value-of select="$i18n.AddAlternative"/>
				</a>
				<a href="javascript:void(0);" onclick="addAlternative(this, event)" title="{$i18n.AddAlternative}">
					<img class="vertical-align-bottom marginleft" src="{$commonImagePath}/add.png"/>
				</a>
			</div>
		
			<xsl:if test="$allowFreeTextAlternative = 'true'">
				<label for="useFreeTextAlternative" class="floatleft clearboth"><xsl:value-of select="$i18n.FreeTextAlternative" /></label>
				<div class="clearboth floatleft marginbottom"><xsl:value-of select="$i18n.FreeTextAlternativeDescription" /></div>
				<div class="floatleft full marginbottom">
					<xsl:text>&#160;</xsl:text>
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'useFreeTextAlternative'" />
						<xsl:with-param name="name" select="'useFreeTextAlternative'" />
						<xsl:with-param name="title" select="$i18n.FreeTextAlternative" />
						<xsl:with-param name="checked">
							<xsl:if test="$freeTextAlternative">true</xsl:if>
						</xsl:with-param>
					</xsl:call-template>
					<xsl:text>&#160;</xsl:text>
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'freeTextAlternative'"/>
						<xsl:with-param name="name" select="'freeTextAlternative'"/>
						<xsl:with-param name="title" select="$i18n.FreeTextAlternative"/>
						<xsl:with-param name="value" select="name"/>
						<xsl:with-param name="width" select="'89%'"/>
						<xsl:with-param name="value" select="$freeTextAlternative"/>
						<xsl:with-param name="disabled" select="'disabled'"/>
					</xsl:call-template>
				</div>
			</xsl:if>
		
		</div>
		
	</xsl:template>
	
	<xsl:template name="createManualCheckboxAlternative">
		
		<xsl:param name="alternativeID" />
		<xsl:param name="sortOrder" />
		<xsl:param name="value" />
		<xsl:param name="checked" />
		<xsl:param name="disabled" select="null" />
		
		<div class="alternative full floatleft margintop marginbottom">
			<img class="vertical-align-middle marginright cursor-move" src="{$commonImagePath}/move.png" title="{$i18n.MoveAlternative}"/>
			
			<!-- TODO Use of //requestparameters below is very slow and needs to be replaced -->
			
			<xsl:call-template name="createHiddenField">
				<xsl:with-param name="id" select="concat('alternativeID_', $alternativeID)"/>
				<xsl:with-param name="name" select="'alternativeID'"/>
				<xsl:with-param name="value" select="$alternativeID"/>
				<xsl:with-param name="disabled" select="$disabled"/>
			</xsl:call-template>
			<xsl:call-template name="createHiddenField">
				<xsl:with-param name="id" select="concat('sortorder_', $alternativeID)" />
				<xsl:with-param name="name" select="concat('sortorder_', $alternativeID)" />
				<xsl:with-param name="value" select="$sortOrder" />
				<xsl:with-param name="class" select="'sortorder'" />
				<xsl:with-param name="requestparameters" select="//requestparameters" />
				<xsl:with-param name="disabled" select="$disabled"/>
			</xsl:call-template>
			<xsl:call-template name="createCheckbox">
				<xsl:with-param name="id" select="concat('checked_', $alternativeID)"/>
				<xsl:with-param name="name" select="concat('checked_', $alternativeID)"/>
				<xsl:with-param name="value" select="'true'"/> 
				<xsl:with-param name="checked" select="$checked" />
				<xsl:with-param name="class" select="'marginleft'"/>
				<xsl:with-param name="disabled" select="$disabled"/> 
			</xsl:call-template>
			<xsl:call-template name="createTextField">
				<xsl:with-param name="id" select="concat('alternative_', $alternativeID)"/>
				<xsl:with-param name="name" select="concat('alternative_', $alternativeID)"/>
				<xsl:with-param name="title" select="name"/>
				<xsl:with-param name="value" select="name"/>
				<xsl:with-param name="width" select="'85%'"/>
				<xsl:with-param name="requestparameters" select="//requestparameters" />
				<xsl:with-param name="class" select="'marginleft'"/>
				<xsl:with-param name="disabled" select="$disabled"/>
			</xsl:call-template>
			
			<a href="#" onclick="deleteAlternative(this, event)" title="{$i18n.DeleteAlternative}">
				<img class="vertical-align-middle marginleft" src="{$commonImagePath}/delete.png"/>
			</a>
			
		</div>
		
	</xsl:template>

	<xsl:template match="CheckboxAlternative">
		
		<xsl:call-template name="createManualCheckboxAlternative">
			<xsl:with-param name="alternativeID" select="alternativeID" />
			<xsl:with-param name="sortOrder" select="sortIndex" />
			<xsl:with-param name="value" select="name" />
			<xsl:with-param name="checked" select="checked" />
		</xsl:call-template>
			
	</xsl:template>
	
	<xsl:template match="parameter" mode="alternative">
		
		<xsl:variable name="id" select="substring(name,13,47)" />
		
		<xsl:call-template name="createManualCheckboxAlternative">
			<xsl:with-param name="alternativeID" select="$id" />
			<xsl:with-param name="sortOrder" select="../parameter[name = concat('sortorder_',$id)]/value" />
			<xsl:with-param name="value" select="value" />
			<xsl:with-param name="checked" select="../parameter[name = concat('checked_',$id)]/value" />
		</xsl:call-template>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'UpdateFailedManualCheckboxQueryNotFound']">
		
		<p class="error">
			<xsl:value-of select="$i18n.ManualCheckboxQueryNotFound" />
		</p>
		
	</xsl:template>

	<xsl:template match="validationError[messageKey = 'TooFewAlternatives1Min']">
		
		<p class="error">
			<xsl:value-of select="$i18n.TooFewAlternatives1Min" />
		</p>
		
	</xsl:template>

	<xsl:template match="fieldName">
	
		<xsl:variable name="fieldName" select="." />
	
		<xsl:choose>
			<xsl:when test="$fieldName = ''">
				<xsl:value-of select="''" />
			</xsl:when>
			<xsl:when test="$fieldName = 'columns'">
				<xsl:value-of select="$i18n.Columns" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

</xsl:stylesheet>