package com.nordicpeak.flowengine.queries.manualcheckboxquery;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationErrorType;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.populators.AlternativesPopulator;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUD;

public class ManualCheckboxQueryCRUD extends BaseQueryCRUD<ManualCheckboxQuery, ManualCheckboxQueryProviderModule> {

	protected AnnotatedDAOWrapper<ManualCheckboxQuery, Integer> queryDAO;

	protected static AlternativesPopulator<CheckboxAlternative> ALTERNATIVES_POPLATOR = new ManualCheckboxAlternativesPopulator(CheckboxAlternative.class);

	public ManualCheckboxQueryCRUD(AnnotatedDAOWrapper<ManualCheckboxQuery, Integer> queryDAO, BeanRequestPopulator<ManualCheckboxQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, ManualCheckboxQueryProviderModule callback) {

		super(ManualCheckboxQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);

		this.queryDAO = queryDAO;
	}

	@Override
	protected ManualCheckboxQuery populateFromUpdateRequest(ManualCheckboxQuery bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		ManualCheckboxQuery query = super.populateFromUpdateRequest(bean, req, user, uriParser);

		List<ValidationError> validationErrors = new ArrayList<ValidationError>();

		this.populateQueryDescriptor((QueryDescriptor) query.getQueryDescriptor(), req, validationErrors);

		if(req.getParameter("useFreeTextAlternative") != null && StringUtils.isEmpty(bean.getFreeTextAlternative())) {
			validationErrors.add(new ValidationError("freeTextAlternative", ValidationErrorType.RequiredField));
		}

		List<CheckboxAlternative> alternatives = ALTERNATIVES_POPLATOR.populate(bean.getAlternatives(), req, 1024, 0, validationErrors);

		if(CollectionUtils.isEmpty(alternatives)) {

			validationErrors.add(new ValidationError("TooFewAlternatives1Min"));
		}

		if(!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}

		query.setAlternatives(alternatives);

		return query;

	}

	@Override
	protected List<Field> getBeanRelations() {

		return Arrays.asList(ManualCheckboxQuery.ALTERNATIVES_RELATION);
	}

}
