<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js
	</xsl:variable>
	
	<xsl:variable name="links">
		/css/manualcheckboxquery.css
	</xsl:variable>

	<xsl:template match="Document">	
		
		<xsl:apply-templates select="ShowQueryValues"/>
		<xsl:apply-templates select="ShowQueryForm"/>
		
	</xsl:template>
	
	<xsl:template match="ShowQueryValues">
	
		<div class="query">
			<xsl:attribute name="class">
				<xsl:text>query</xsl:text>
				<xsl:if test="ManualCheckboxQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
			</xsl:attribute>
		
			<article>
				
				<div class="heading-wrapper">
					<h2>
						<xsl:attribute name="class">
							<xsl:if test="ManualCheckboxQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
								<xsl:text>required</xsl:text>
							</xsl:if>
						</xsl:attribute>
						<xsl:value-of select="ManualCheckboxQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
					</h2>
					
				</div>

				<xsl:call-template name="form"/>
				
			</article>
		
		</div>
	
	</xsl:template>
		
	<xsl:template match="ShowQueryForm">
	
		<xsl:variable name="queryID" select="concat('query_', ManualCheckboxQueryInstance/ManualCheckboxQuery/queryID)" />
	
		<div class="query manualcheckboxquery" id="{$queryID}">
	
			<xsl:attribute name="class">
				<xsl:text>query manualcheckboxquery</xsl:text>
				<xsl:if test="EnableAjaxPosting"> enableAjaxPosting</xsl:if>
				<xsl:if test="ManualCheckboxQueryInstance/QueryInstanceDescriptor/QueryDescriptor/mergeWithPreviousQuery = 'true'"> mergewithpreviousquery</xsl:if>
			</xsl:attribute>

	
			<a name="{$queryID}" />
	
			<xsl:if test="ValidationErrors/validationError">
				<div id="{$queryID}-validationerrors" class="validationerrors">
					<div class="info-box error">
						<xsl:apply-templates select="ValidationErrors/validationError"/>
						<div class="marker"></div>
					</div>
				</div>
			</xsl:if>
	
			<article>
			
				<xsl:if test="ValidationErrors/validationError">
					<xsl:attribute name="class">error</xsl:attribute>
				</xsl:if>
			
				<div class="heading-wrapper">
					
					<h2>
						<xsl:attribute name="class">
							<xsl:if test="ManualCheckboxQueryInstance/QueryInstanceDescriptor/queryState = 'VISIBLE_REQUIRED'">
								<xsl:text>required</xsl:text>
							</xsl:if>
						</xsl:attribute>
						<xsl:value-of select="ManualCheckboxQueryInstance/QueryInstanceDescriptor/QueryDescriptor/name"/>
					</h2>
					
					<xsl:if test="ManualCheckboxQueryInstance/ManualCheckboxQuery/helpText">		
						<xsl:apply-templates select="ManualCheckboxQueryInstance/ManualCheckboxQuery/helpText" />
					</xsl:if>

				</div>
				
				<xsl:call-template name="form"/>
				
			</article>
	
		</div>
		
	</xsl:template>
	
	<xsl:template name="form">
	
		<xsl:if test="ManualCheckboxQueryInstance/ManualCheckboxQuery/description">
			<span class="italic">
				<xsl:if test="/Document/useCKEditorForDescription = 'true'"><xsl:attribute name="class">italic html-description</xsl:attribute></xsl:if>
				<xsl:value-of select="ManualCheckboxQueryInstance/ManualCheckboxQuery/description" disable-output-escaping="yes" />
			</span>
		</xsl:if>
		
		<div class="clearboth"/>
		
		<xsl:if test="ManualCheckboxQueryInstance/ManualCheckboxQuery/hidePrintInfoText = 'false' and ManualCheckboxQueryInstance/ManualCheckboxQuery/Alternatives/CheckboxAlternative/checked = 'false'">
			<p class="tiny">
				<xsl:value-of select="$i18n.FilledAfterPrint"/>
			</p>
		</xsl:if>
		
		<xsl:apply-templates select="ManualCheckboxQueryInstance/ManualCheckboxQuery/Alternatives/CheckboxAlternative" mode="form"/>

		<xsl:if test="ManualCheckboxQueryInstance/ManualCheckboxQuery/freeTextAlternative">
		
			<div class="alternative">
			
				<xsl:attribute name="class">
					<xsl:text>alternative</xsl:text>
					<xsl:choose>
						<xsl:when test="ManualCheckboxQueryInstance/ManualCheckboxQuery/columns = 'TWO'"> floatleft fifty</xsl:when>
						<xsl:when test="ManualCheckboxQueryInstance/ManualCheckboxQuery/columns = 'THREE'"> floatleft thirty</xsl:when>
					</xsl:choose>
				</xsl:attribute>
				
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="class" select="'vertical-align-bottom freeTextAlternative'" />
					<xsl:with-param name="disabled" select="'true'"/>
				</xsl:call-template>
				
				<label class="checkbox disabled"><xsl:value-of select="ManualCheckboxQueryInstance/ManualCheckboxQuery/freeTextAlternative" /></label>
				
			</div>
			
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="CheckboxAlternative" mode="form">

		<div class="alternative">
		
			<xsl:attribute name="class">
				<xsl:text>alternative</xsl:text>
				<xsl:choose>
					<xsl:when test="../../columns = 'TWO'"> floatleft fifty</xsl:when>
					<xsl:when test="../../columns = 'THREE'"> floatleft thirty</xsl:when>
				</xsl:choose>
			</xsl:attribute>
	
			<xsl:call-template name="createCheckbox">
				<xsl:with-param name="class" select="'vertical-align-bottom'" />
				<xsl:with-param name="disabled" select="'true'"/>
				<xsl:with-param name="checked" select="checked"/>
			</xsl:call-template>
			<label class="checkbox disabled"><xsl:value-of select="name" /></label>
	
		</div>
	
	</xsl:template>
	
	<xsl:template match="validationError">
		
		<span>
			<strong data-icon-before="!">
				<xsl:value-of select="$i18n.UnknownValidationError"/>
			</strong>
		</span>
		
	</xsl:template>		
	
</xsl:stylesheet>