<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>
	
	<xsl:variable name="globalscripts">
		/js/confirmpost.js
	</xsl:variable>	
	
	<xsl:variable name="scripts">
		/js/multisigninghandler2.js
	</xsl:variable>
	
	<xsl:template match="Document">
		
		<xsl:apply-templates select="SigningStatus"/>
		<xsl:apply-templates select="SignFlowInstance"/>
		<xsl:apply-templates select="Signing"/>
		<xsl:apply-templates select="Message"/>
		<xsl:apply-templates select="ListFlowInstancesExtension"/>
		<xsl:apply-templates select="MisconfiguredMultisigning"/>
		
	</xsl:template>
		
	<xsl:template match="SigningStatus">
		
		<p>
			<xsl:value-of select="$i18n.SigningStatus.Description"/>
		</p>
		
		<table class="full signingstatustable">
			<thead>
				<tr>
					<th>
						<xsl:value-of select="$i18n.Firstname"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.Lastname"/>
					</th>
					<xsl:if test="not(HideCitizenIdentifier = 'true')">
						<th>
							<xsl:value-of select="$i18n.Identifier"/>
						</th>
					</xsl:if>
					<th>
						<xsl:value-of select="$i18n.Email"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.Mobilephone"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.Signed"/>
					</th>
				</tr>
			</thead>
			
			<tbody>
				<xsl:apply-templates select="SigningSession/SigningParties/SigningSessionParty">
					<xsl:with-param name="hideCitizenIdentifier"><xsl:value-of select="HideCitizenIdentifier" /></xsl:with-param>
				</xsl:apply-templates>
			</tbody>
			
		</table>
		
		<p>
			<xsl:choose>
				<xsl:when test="SigningSession/sequential = 'true'">
					<xsl:value-of select="$i18n.SigningLinkMessage.Sequential"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$i18n.SigningLinkMessage"/>
				</xsl:otherwise>
			</xsl:choose>
		</p>
		
		<p>
			<a href="{SigningLink}">
				<xsl:value-of select="SigningLink"/>
			</a>
		</p>
		
		<xsl:if test="LoggedIn">
			<p>
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/signingpdf/{FlowInstance/flowInstanceID}/{SigningSession/sessionID}">
					<img alt="" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/pdf.png" />
					<xsl:text>&#160;</xsl:text>
					<xsl:value-of select="$i18n.DownloadFlowInstancePDF"/>
				</a>
			</p>
			
			<div class="text-align-center">
				
				<a class="btn btn-inline btn-red" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/cancel/{FlowInstance/flowInstanceID}/{SigningSession/sessionID}" onclick="return confirmPost(this.href, '{$i18n.CancelSigning.Confirm}')">
					<xsl:value-of select="$i18n.CancelSigning"/>
				</a>
				
			</div>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="SigningSessionParty">
		<xsl:param name="hideCitizenIdentifier" />
		
		<tr>
			<td data-name="{$i18n.Firstname}">
				<xsl:choose>
					<xsl:when test="firstname">
						<xsl:value-of select="firstname"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>-</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td data-name="{$i18n.Lastname}">
				<xsl:choose>
					<xsl:when test="lastname">
						<xsl:value-of select="lastname"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>-</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<xsl:if test="not($hideCitizenIdentifier = 'true')">
				<td data-name="{$i18n.Identifier}">
					<xsl:choose>
						<xsl:when test="identifier">
							<xsl:value-of select="identifier"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>-</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</td>
			</xsl:if>
			<td data-name="{$i18n.Email}">
				<xsl:choose>
					<xsl:when test="email">
						<xsl:value-of select="email"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>-</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td data-name="{$i18n.Mobilephone}">
				<xsl:choose>
					<xsl:when test="mobilePhone">
						<xsl:value-of select="mobilePhone"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>-</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td data-name="{$i18n.Signed}">
				
				<xsl:choose>
					<xsl:when test="signedDate">
						<xsl:value-of select="signedDate"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.No"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</td>
		</tr>

	</xsl:template>
	
	<xsl:template match="SignFlowInstance">
	
		<div class="contentitem">
			<section>
				<div class="section-full">
			
					<h1 style="padding-left: 0;">
						<xsl:value-of select="$i18n.SignFlowInstance"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="FlowInstance/Flow/name"/>
						<xsl:text>&#160;#</xsl:text>
						<xsl:value-of select="FlowInstance/flowInstanceID"/>
					</h1>
					
					<xsl:value-of select="Message" disable-output-escaping="yes"/>
					
					<xsl:if test="SequentialSigningBlock">
						<p>
							<xsl:value-of select="$i18n.SequentialSigningBlock.message"/>
						</p>
					</xsl:if>
					
					<div class="divider" />
						
					<div class="heading-wrapper">
						
						<a class="btn btn-right btn-light xl hide-mobile" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/signingpdf/{FlowInstance/flowInstanceID}/{SigningSession/sessionID}/{SigningSessionParty/unsecureKey}">
<!-- 							<img class="bigmarginright" style="vertical-align: baseline;" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/pdf.png" alt="" /> -->
							
							<xsl:choose>
								<xsl:when test="SigningSession/completedDate or SigningSessionParty/signedDate">
									<xsl:value-of select="$i18n.DownloadSigningFlowInstancePDF"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="$i18n.DownloadFlowInstancePDF"/>
								</xsl:otherwise>
							</xsl:choose>
						</a>
						
						<div class="heading">
							<h2><xsl:value-of select="$i18n.Description" /></h2>
						</div>
						
						<div>
								<xsl:value-of select="FlowInstance/Flow/shortDescription" disable-output-escaping="yes" />
						</div>
					</div>
					
					<div class="service">
						<div class="queries bigpaddingbottom">
							<xsl:apply-templates select="ManagerResponses/ManagerResponse"/>
						</div>
						
						<div class="bigmargintop">
						
							<xsl:if test="FlowInstance/Flow/showPreviousSignaturesToSigners = 'true' and SigningSession/SigningParties/SigningSessionParty/signedDate">
								
								<div class="bigmarginbottom">
									<p>
										<xsl:value-of select="$i18n.PreviousSigners" />
									</p>
									
									<table class="signingstatustable">
										<thead>
											<tr>
												<th class="paddingright">
													<xsl:value-of select="$i18n.Firstname"/>
												</th>
												<th class="paddingright">
													<xsl:value-of select="$i18n.Lastname"/>
												</th>
												<th class="paddingright">
													<xsl:value-of select="$i18n.Signed"/>
												</th>
											</tr>
										</thead>
										<tbody>
											<xsl:apply-templates select="SigningSession/SigningParties/SigningSessionParty[signedDate]" mode="previousSigners" />
										</tbody>
									</table>
								</div>
								
							</xsl:if>
						
							<xsl:choose>
								<xsl:when test="SigningSession/completedDate and not(RequiresPayment)">
								
									<a class="btn btn-green xl next arrow-mobile" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/signedpdf/{FlowInstance/flowInstanceID}/{SigningSession/sessionID}/{SigningSessionParty/unsecureKey}">
<!-- 										<img class="bigmarginright" style="vertical-align: baseline;" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/pdf.png" alt="" /> -->
										<xsl:value-of select="$i18n.DownloadSignedFlowInstancePDF"/>
									</a>
									
								</xsl:when>
								<xsl:when test="SequentialSigningBlock">
								
									<p>
										<xsl:value-of select="$i18n.SequentialSigningBlock.message"/>
									</p>
									
								</xsl:when>
								<xsl:when test="not(SigningSessionParty/signedDate)">
								
									<a class="btn btn-green xl next arrow-mobile" href="{/Document/requestinfo/uri}?sign=true">
										
										<span class="only-mobile">
											<xsl:value-of select="$i18n.SignFlowInstanceButton"/>
										</span>
										
										<span class="hide-mobile">
											<xsl:value-of select="$i18n.SignFlowInstanceButton"/>
										</span>
									</a>
									
									<a class="btn btn-red bigmargintop" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/cancel/{FlowInstance/flowInstanceID}/{SigningSession/sessionID}/{SigningSessionParty/unsecureKey}" onclick="return confirmPost(this.href, '{$i18n.CancelSigning.Party.Confirm}')">
										
										<span class="only-mobile">
											<xsl:value-of select="$i18n.CancelSigning.Party"/>
										</span>
										
										<span class="hide-mobile">
											<xsl:value-of select="$i18n.CancelSigning.Party"/>
										</span>
										
									</a>
								
								</xsl:when>
							</xsl:choose>
							
						</div>
						
					</div>
					
				</div>
			</section>
		</div>
	
	</xsl:template>
	
	<xsl:template match="ManagerResponse">

		<xsl:variable name="stepID" select="currentStepID"/>
	
		<div class="section-full preview" style="padding-left: 0; padding-right: 0;">
			
			<h2 data-icon-before="c" class="h1">
				<xsl:value-of select="currentStepIndex + 1"/>
				<xsl:text>. </xsl:text>
				<xsl:value-of select="../../FlowInstance/Flow/Steps/Step[stepID = $stepID]/name"/>
			</h2>
			
			<xsl:choose>
				<xsl:when test="QueryResponses">
					<xsl:apply-templates select="QueryResponses/QueryResponse"/>
				</xsl:when>
				<xsl:otherwise>
					<p><xsl:value-of select="$i18n.noAnsweredQueriesInThisStep"/></p>
				</xsl:otherwise>
			</xsl:choose>
		</div>
	
		<xsl:if test="position() != last()">
			<div class="divider preview" />
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="QueryResponse">
	
		<xsl:choose>
			<xsl:when test="HTML">
				<xsl:value-of select="HTML" disable-output-escaping="yes"/>
			</xsl:when>
			<xsl:otherwise>
				<div id="query_{QueryDescriptor/queryID}" class="hidden" />
			</xsl:otherwise>
		</xsl:choose>
	
	</xsl:template>
	
	<xsl:template match="SigningSessionParty" mode="previousSigners">
		
		<tr>
			<td data-name="{$i18n.Firstname}">
				<xsl:choose>
					<xsl:when test="firstname">
						<xsl:value-of select="firstname"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>-</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td data-name="{$i18n.Lastname}">
				<xsl:choose>
					<xsl:when test="lastname">
						<xsl:value-of select="lastname"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>-</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td data-name="{$i18n.Signed}">
				<xsl:value-of select="signedDate"/>
			</td>
		</tr>

	</xsl:template>
	
	<xsl:template match="Signing">
	
		<div class="contentitem">
	
			<h1 class="bigmarginbottom">
				<xsl:value-of select="$i18n.SignFlowInstance"/>
				<xsl:text>&#160;</xsl:text>
				<xsl:value-of select="FlowInstance/Flow/name"/>
				<xsl:text>&#160;#</xsl:text>
				<xsl:value-of select="FlowInstance/flowInstanceID"/>
			</h1>

			<xsl:value-of select="ViewFragment/HTML" disable-output-escaping="yes"/>
			
			<div class="navigator-buttons">
			
				<a class="btn btn-light prev arrow-mobile" href="{SigningLink}">
					
					<span class="only-mobile">
						<xsl:value-of select="$i18n.Signing.BackButton"/>
					</span>
					
					<span class="hide-mobile">
						<xsl:value-of select="$i18n.Signing.BackButton"/>
					</span>
				</a>
			</div>
	
		</div>
		
	</xsl:template>
	
	<xsl:template match="ListFlowInstancesExtension">
	
		<xsl:variable name="flowInstanceCount" select="count(WaitingMultiSignFlowInstances/FlowInstance)" />

		<div class="errands-wrapper draft">
			<div class="heading-wrapper">
				<h2><xsl:value-of select="$i18n.WaitingMultiSignFlowInstancesTitle" /></h2>
				<h3 class="clearboth"><xsl:value-of select="$i18n.WaitingMultiSignFlowInstances.Part1" />
				<xsl:text>&#160;</xsl:text>
				<strong>
					<xsl:value-of select="$flowInstanceCount" />
					<xsl:text>&#160;</xsl:text>
					<xsl:choose>
						<xsl:when test="$flowInstanceCount > 1">
							<xsl:value-of select="$i18n.WaitingMultiSignFlowInstances.Part2.Plural" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.WaitingMultiSignFlowInstances.Part2" />
						</xsl:otherwise>
					</xsl:choose>
				</strong>
				<xsl:text>&#160;</xsl:text><xsl:value-of select="$i18n.WaitingMultiSignFlowInstances.Part3" /></h3>
				<xsl:call-template name="createHelpDialog">
					<xsl:with-param name="id" select="'waiting-multisign'" />
					<xsl:with-param name="text" select="$i18n.WaitingMultiSignFlowInstancesHelp" />
				</xsl:call-template>
			</div>
			<table class="oep-table errand-table">
				<thead>
					<tr>
						<th class="icon"></th>
						<th class="service"><span><xsl:value-of select="$i18n.FlowName" /></span></th>
						
						<xsl:if test="SiteProfiles">
							<th class="status"><span><xsl:value-of select="$i18n.SiteProfile" /></span></th>
						</xsl:if>
						
						<th class="status"><span><xsl:value-of select="$i18n.Status" /></span></th>
						<th class="date"><span><xsl:value-of select="$i18n.Updated" /></span></th>
						<th class="link"></th>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="WaitingMultiSignFlowInstances/FlowInstance" mode="waiting-multisign" />
				</tbody>
			</table>
		</div>
	
		<div class="divider errands"></div>
	
	</xsl:template>
	
	<xsl:template match="FlowInstance" mode="waiting-multisign">
	
		<tr>
			<td class="icon"><i data-icon-before="w"></i></td>
			<td data-title="{$i18n.FlowName}" class="service"><xsl:value-of select="Flow/name" /></td>
			
			<xsl:call-template name="printSiteProfile"/>
			
			<td data-title="{$i18n.Status}" class="status"><xsl:value-of select="Status/name" /></td>
			<td data-title="{$i18n.Updated}" class="date">
				<xsl:choose>
					<xsl:when test="updated"><xsl:value-of select="updated" /></xsl:when>
					<xsl:otherwise><xsl:value-of select="added" /></xsl:otherwise>
				</xsl:choose>
			</td>
			<td class="link">
				<a class="btn btn-green vertical-align-middle" href="{MultiSignURL}"><xsl:value-of select="$i18n.WaitingForYourSignature" /></a>
			</td>
		</tr>
		
	</xsl:template>
	
	<xsl:template match="MisconfiguredMultisigning">
		
		<p>
			<xsl:value-of select="$i18n.MisconfiguredMultisigning"/>
		</p>
		
	</xsl:template>
	
	<xsl:template name="createHelpDialog">
		
		<xsl:param name="id" />
		<xsl:param name="text" />
		<xsl:param name="class" select="''" />
		
		<div class="help {$class}">
			<a class="open-help" href="#" data-icon-after="?" data-help-box="helpdialog_{$id}"><span><xsl:value-of select="$i18n.Help" /></span></a>
			<div class="help-box" data-help-box="helpdialog_{$id}">
				<div>
						<div>
							<a class="close" href="#" data-icon-after="x"></a>
							<xsl:copy-of select="$text" />
						</div>
				</div>
			</div>
		</div>
		
		<div class="help-backdrop" data-help-box="helpdialog_{$id}" />
		
	</xsl:template>
	
	<xsl:template name="printSiteProfile">
	
		<xsl:if test="../../SiteProfiles">
			
			<td data-title="{$i18n.SiteProfile}" class="siteProfile">
				
				<xsl:choose>
					<xsl:when test="Attributes/Attribute/Name = 'siteProfileName'">
					
						<xsl:value-of select="Attributes/Attribute[Name = 'siteProfileName']/Value"/>
					
					</xsl:when>
					<xsl:otherwise>
					
						<xsl:variable name="profileID" select="profileID"/>
						
						<xsl:value-of select="../../SiteProfiles/Profile[profileID = $profileID]/name" />
					
					</xsl:otherwise>
				</xsl:choose>
			</td>
					
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="Message[@messageKey='FlowDisabled']">
	
		<div class="contentitem">
		
			<h1><xsl:value-of select="$i18n.FlowDisabled.title"/></h1>
			
			<p><xsl:value-of select="$i18n.FlowDisabled.message"/></p>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="Message[@messageKey='SigningPartyNotFound']">
	
		<div class="contentitem">
		
			<h1><xsl:value-of select="$i18n.SigningPartyNotFound.title"/></h1>
			
			<p><xsl:value-of select="$i18n.SigningPartyNotFound.message"/></p>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="Message[@messageKey='SequentialSigningBlock']">
	
		<div class="contentitem">
		
			<h1><xsl:value-of select="$i18n.SequentialSigningBlock.title"/></h1>
			
			<p><xsl:value-of select="$i18n.SequentialSigningBlock.message"/></p>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="Message[@messageKey='WrongStatusContentType']">
	
		<div class="contentitem">
		
			<h1><xsl:value-of select="$i18n.WrongStatusContentType.title"/></h1>
			
			<p><xsl:value-of select="$i18n.WrongStatusContentType.message"/></p>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="Message[@messageKey='MayNotCancelSubmittedFlowInstance']">
	
		<div class="contentitem">
		
			<h1><xsl:value-of select="$i18n.MayNotCancelSubmittedFlowInstance.title"/></h1>
			
			<p><xsl:value-of select="$i18n.MayNotCancelSubmittedFlowInstance.message"/></p>
		
		</div>
	
	</xsl:template>
	
	<xsl:template match="Message">
	
		<div class="contentitem">
		
			<h1>Oknt fel</h1>
			
			<p>Ett oknt fel har uppsttt</p>
		
		</div>
	
	</xsl:template>
	
</xsl:stylesheet>