package com.nordicpeak.flowengine.evaluators.multipartsigningmailevaluator;

import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;

@Table(name = "multipart_signing_mail_evaluators")
@XMLElement
public class MultipartSigningMailEvaluatorEvaluator extends BaseEvaluator {

	private static final long serialVersionUID = 5501896243489595373L;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "multipart_signing_mail_evaluators_recipients", remoteValueColumnName = "emailAddress")
	@XMLElement
	private List<String> emailRecipients;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String emailSubject;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 65536)
	@XMLElement
	private String emailMessage;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean usePosterContactAsSender;

	public String getEmailSubject() {

		return emailSubject;
	}

	public void setEmailSubject(String emailSubject) {

		this.emailSubject = emailSubject;
	}

	public String getEmailMessage() {

		return emailMessage;
	}

	public void setEmailMessage(String emailMessage) {

		this.emailMessage = emailMessage;
	}

	public List<String> getEmailRecipients() {

		return emailRecipients;
	}

	public void setEmailRecipients(List<String> emailRecipients) {

		this.emailRecipients = emailRecipients;
	}

	public boolean isUsePosterContactAsSender() {

		return usePosterContactAsSender;
	}

	public void setUsePosterContactAsSender(boolean usePosterContactAsSender) {

		this.usePosterContactAsSender = usePosterContactAsSender;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		emailRecipients = xmlParser.getStrings("emailRecipients/value");

		emailSubject = xmlParser.getString("emailSubject");

		emailMessage = xmlParser.getString("emailMessage");
	}

	@Override
	public String toString() {

		return evaluatorDescriptor.toString();
	}

}
