package com.nordicpeak.flowengine.queries.paragraphinfoquery;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.FCKContent;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToMany;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.NonNegativeStringIntegerPopulator;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLValidationUtils;
import se.unlogic.webutils.annotations.URLRewrite;

import com.nordicpeak.flowengine.annotations.TextTagReplace;
import com.nordicpeak.flowengine.utils.JTidyUtils;

@Table(name="paragraph_info_query_paragraphs")
@XMLElement
public class Paragraph extends GeneratedElementable implements Serializable, Comparable<Paragraph>{

	private static final long serialVersionUID = 3196733628150587561L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(Paragraph.class, "query");
	
	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	private Integer paragraphID;

	@DAOManaged
	@TextTagReplace
	@WebPopulate(maxLength = 255, required=true)
	@XMLElement(cdata = true)
	private String name;
	
	@DAOManaged
	@FCKContent
	@TextTagReplace
	@URLRewrite
	@WebPopulate(maxLength = 65535, required= true)
	@XMLElement(cdata = true)
	private String text;

	@DAOManaged
	@OrderBy
	@XMLElement
	private Integer sortIndex;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean visible;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	private ParagraphInfoQuery query;
	
	@DAOManaged
	@ManyToMany(linkTable="paragraph_info_query_instance_paragraphs")
	@XMLElement(fixCase=true)
	private List<ParagraphInfoQueryInstance> queryInstances;

	public Integer getParagraphID() {

		return paragraphID;
	}

	public void setParagraphID(Integer paragraphID) {

		this.paragraphID = paragraphID;
	}

	public String getText() {

		return text;
	}

	public void setText(String text) {

		this.text = text;
	}

	public Integer getSortIndex() {

		return sortIndex;
	}

	public void setSortIndex(Integer sortIndex) {

		this.sortIndex = sortIndex;
	}

	public boolean isVisible() {

		return visible;
	}

	public void setVisible(boolean visible) {

		this.visible = visible;
	}

	public ParagraphInfoQuery getQuery() {

		return query;
	}

	public void setQuery(ParagraphInfoQuery query) {

		this.query = query;
	}

	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();
		
		paragraphID = XMLValidationUtils.validateParameter("paragraphID", xmlParser, true, PositiveStringIntegerPopulator.getPopulator(), errors);
		name = XMLValidationUtils.validateParameter("name", xmlParser, true, 1, 255, StringPopulator.getPopulator(), errors);
		text = XMLValidationUtils.validateParameter("text", xmlParser, true, 1, 65535, StringPopulator.getPopulator(), errors);
		visible = xmlParser.getPrimitiveBoolean("visible");
		sortIndex = XMLValidationUtils.validateParameter("sortIndex", xmlParser, true, NonNegativeStringIntegerPopulator.getPopulator(), errors);

		if(!errors.isEmpty()){

			throw new ValidationException(errors);
		}
	}

	
	public String getName() {
	
		return name;
	}

	
	public void setName(String name) {
	
		this.name = name;
	}

	@Override
	public Element toXML(Document doc) {
		
		Element element = super.toXML(doc);
		
		XMLUtils.appendNewCDATAElement(doc, element, "Text", JTidyUtils.getXHTML(text, "ISO-8859-1"));
		
		return element;
	}

	@Override
	public int hashCode() {

		final int prime = 31;
		int result = 1;
		result = prime * result + ((paragraphID == null) ? 0 : paragraphID.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {

		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		Paragraph other = (Paragraph) obj;
		if (paragraphID == null) {
			if (other.paragraphID != null) {
				return false;
			}
		} else if (!paragraphID.equals(other.paragraphID)) {
			return false;
		}
		return true;
	}

	@Override
	public int compareTo(Paragraph otherParagraph) {

		return sortIndex.compareTo(otherParagraph.getSortIndex());
	}
}
