package com.nordicpeak.flowengine.paymentlog.beans;

import java.lang.reflect.Field;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;

@XMLElement(name = "Chart")
@Table(name = "payment_chart_of_accounts")
public class ChartOfAccounts extends GeneratedElementable {
	
	public static final Field ACCOUNTS_RELATION = ReflectionUtils.getField(ChartOfAccounts.class, "accounts");
	public static final Field ACCOUNT_NUMBER_PART_DEFINITIONS_RELATION = ReflectionUtils.getField(ChartOfAccounts.class, "accountNumberPartDefinitions");
	
	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	private Integer chartID;
	
	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String name;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean archived;
	
	@DAOManaged
	@OneToMany(autoGet = true, autoAdd = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<AccountNumberPartDefinition> accountNumberPartDefinitions;
	
	@DAOManaged
	@OneToMany
	@XMLElement(fixCase = true)
	private List<Account> accounts;
	
	public Integer getChartID() {
		return chartID;
	}
	
	public void setChartID(Integer chartID) {
		this.chartID = chartID;
	}
	
	public String getName() {
		return name;
	}
	
	public void setName(String name) {
		this.name = name;
	}
	
	public boolean isArchived() {
		return archived;
	}
	
	public void setArchived(boolean archived) {
		this.archived = archived;
	}
	
	public List<AccountNumberPartDefinition> getAccountNumberPartDefinitions() {
		return accountNumberPartDefinitions;
	}
	
	public void setAccountNumberPartDefinitions(List<AccountNumberPartDefinition> accountNumberPartDefinitions) {
		this.accountNumberPartDefinitions = accountNumberPartDefinitions;
	}
	
	public List<Account> getAccounts() {
		return accounts;
	}
	
	public void setAccounts(List<Account> accounts) {
		this.accounts = accounts;
	}
	
	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((chartID == null) ? 0 : chartID.hashCode());
		return result;
	}
	
	@Override
	public boolean equals(Object obj) {
		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		ChartOfAccounts other = (ChartOfAccounts) obj;
		if (chartID == null) {
			if (other.chartID != null) {
				return false;
			}
		} else if (!chartID.equals(other.chartID)) {
			return false;
		}
		return true;
	}
	
	@Override
	public String toString() {
		
		return StringUtils.toLogFormat(name, 30) + " (chartID: " + chartID + ")";
	}
}
