<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
	</xsl:variable>

	<xsl:template match="Document">

		<div id="PlotQueryProvider" class="contentitem">

			<xsl:apply-templates select="validationError" />
			<xsl:apply-templates select="UpdatePlotQuery" />

		</div>

	</xsl:template>

	<xsl:template match="UpdatePlotQuery">

		<h1>
			<xsl:value-of select="$i18n.UpdateQuery" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="PlotQuery/QueryDescriptor/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form id="updatePlotQueryForm" name="queryAdminForm" method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="PlotQuery" />
			</xsl:call-template>

			<div class="floatleft full marginbottom">
						
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'requireBookableDate'"/>
					<xsl:with-param name="name" select="'requireBookableDate'"/>
					<xsl:with-param name="element" select="PlotQuery" />
				</xsl:call-template>
				
				<label for="requireBookableDate" title="{$i18n.RequireBookableDate.Description}"><xsl:value-of select="$i18n.RequireBookableDate" /></label>
				
			</div>	

			<div class="floatleft full bigmargintop">
				<h2><xsl:value-of select="$i18n.AdvancedSettings" /></h2>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="id" select="'setAsAttribute'" />
						<xsl:with-param name="name" select="'setAsAttribute'" />
						<xsl:with-param name="element" select="PlotQuery" /> 
						<xsl:with-param name="class" select="'vertical-align-middle'" />
					</xsl:call-template>
						
					<label for="setAsAttribute">
						<xsl:value-of select="$i18n.SetAsAttribute" />
					</label>
			    </div>
			</div>
			
			<div class="floatleft full bigmarginbottom">
				<label for="attributeName" class="floatleft clearboth"><xsl:value-of select="$i18n.AttributeName" /></label>
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'attributeName'"/>
						<xsl:with-param name="name" select="'attributeName'"/>
						<xsl:with-param name="title" select="$i18n.AttributeName"/>
						<xsl:with-param name="element" select="PlotQuery" />
						<xsl:with-param name="maxlength" select="'255'"/>
					</xsl:call-template>
			  </div>
			</div>
			
			<p class="floatleft clearboth"><xsl:value-of select="$i18n.attributeDescription" /></p>
			
			<table class="floatleft clearboth border">
				<thead>
					<th><xsl:value-of select="$i18n.attributes.name" /></th>
					<th><xsl:value-of select="$i18n.attributes.value" /></th>
				</thead>
				<tbody>
					<tr>
						<td>prefix.objectid</td>
						<td><xsl:value-of select="$i18n.attributes.objectid" /></td>
					</tr>
					<tr>
						<td>prefix.timestamp</td>
						<td><xsl:value-of select="$i18n.attributes.timestamp" /></td>
					</tr>
					<tr>
						<td>prefix.propertyUnitDesignation</td>
						<td><xsl:value-of select="$i18n.attributes.propertyUnitDesignation" /></td>
					</tr>
					<tr>
						<td>prefix.address</td>
						<td><xsl:value-of select="$i18n.attributes.address" /></td>
					</tr>
					<tr>
						<td>prefix.area</td>
						<td><xsl:value-of select="$i18n.attributes.area" /></td>
					</tr>
					<tr>
						<td>prefix.connectionFee</td>
						<td><xsl:value-of select="$i18n.attributes.connectionFee" /></td>
					</tr>
					<tr>
						<td>prefix.price</td>
						<td><xsl:value-of select="$i18n.attributes.price" /></td>
					</tr>
					<tr>
						<td>prefix.location</td>
						<td><xsl:value-of select="$i18n.attributes.location" /></td>
					</tr>
					<tr>
						<td>prefix.comment</td>
						<td><xsl:value-of select="$i18n.attributes.comment" /></td>
					</tr>
				</tbody>
			</table>

			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>

		</form>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'UpdateFailedPlotQueryNotFound']">

		<p class="error">
			<xsl:value-of select="$i18n.PlotQueryNotFound" />
		</p>

	</xsl:template>
	
	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
			<xsl:when test="$fieldName = ''">
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>