package com.nordicpeak.flowengine.queries.predefineduserquery.beans;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLPopulationUtils;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.interfaces.MultiSignQuery;
import com.nordicpeak.flowengine.interfaces.UserValueQuery;
import com.nordicpeak.flowengine.interfaces.UserValuesQuery;
import com.nordicpeak.flowengine.interfaces.UsersClosestManagerQuery;
import com.nordicpeak.flowengine.queries.basequery.BaseQuery;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesConstants;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesSelectedAttribute;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesUtils;
import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQuery;

@Table(name = "predefined_user_queries")
@XMLElement
public class PredefinedUserQuery extends BaseQuery implements UserValuesQuery, UserValueQuery, UsersClosestManagerQuery, MultiSignQuery, CommonInternalUserQuery {

	private static final long serialVersionUID = -842191226937409429L;

	public static final Field USERS_RELATION = ReflectionUtils.getField(PredefinedUserQuery.class, "userIDs");
	public static final Field GROUPS_RELATION = ReflectionUtils.getField(PredefinedUserQuery.class, "groupIDs");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryID;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "predefined_user_query_users", remoteValueColumnName = "userID")
	@WebPopulate(paramName = "user")
	@XMLElement(childName = "userID")
	private List<Integer> userIDs;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "predefined_user_query_groups", remoteValueColumnName = "groupID")
	@WebPopulate(paramName = "group")
	@XMLElement(childName = "groupID")
	private List<Integer> groupIDs;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private Integer preSelectedUserID;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showDropDownUsername;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showDropDownCitizenIdentifier;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean limitSelectionToMyEmployees;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean excludeInactiveUsers;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showName = true;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showUsername;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showEmail;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showCitizenIdentifier;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showManagerInfo;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showManagerName;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showManagerUsername;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showManagerEmail;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<SelectedDropDownAttribute> selectedDropDownAttributes;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<SelectedUserAttribute> selectedUserAttributes;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<SelectedManagerAttribute> selectedManagerAttributes;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useForMultipartSigning;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean setMultipartsAsOwners;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean requireManagerSigning;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean maskCitizenIDLastFourDigits;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean lockOnOwnershipTransfer;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean setAsAttribute;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "setAsAttribute")
	@XMLElement
	private String attributeName;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<PredefinedUserQueryInstance> instances;

	private List<User> selectableUsers;
	private Map<String, User> selectableManagers;

	@Override
	public Integer getQueryID() {

		return queryID;
	}

	public List<PredefinedUserQueryInstance> getInstances() {

		return instances;
	}

	public void setInstances(List<PredefinedUserQueryInstance> instances) {

		this.instances = instances;
	}

	public List<Integer> getUserIDs() {

		return userIDs;
	}

	public void setUserIDs(List<Integer> userIDs) {

		this.userIDs = userIDs;
	}

	public List<Integer> getGroupIDs() {

		return groupIDs;
	}

	public void setGroupIDs(List<Integer> groupIDs) {

		this.groupIDs = groupIDs;
	}

	@Override
	public boolean isShowUsername() {

		return showUsername;
	}

	public void setShowUsername(boolean showUsername) {

		this.showUsername = showUsername;
	}

	public List<User> getSelectableUsers() {

		return selectableUsers;
	}

	public void setSelectableUsers(List<User> selectableUsers) {

		this.selectableUsers = selectableUsers;
	}

	public Map<String, User> getSelectableManagers() {
		return selectableManagers;
	}

	public void setSelectableManagers(Map<String, User> selectableManagers) {
		this.selectableManagers = selectableManagers;
	}

	public boolean isUseForMultipartSigning() {

		return useForMultipartSigning;
	}

	public void setQueryID(int queryID) {

		this.queryID = queryID;
	}

	public void setQueryID(Integer queryID) {

		this.queryID = queryID;
	}

	public boolean isShowCitizenIdentifier() {

		return showCitizenIdentifier;
	}

	public void setShowCitizenIdentifier(boolean showCitizenIdentifier) {

		this.showCitizenIdentifier = showCitizenIdentifier;
	}

	@Override
	public boolean requiresMultipartSigning() {

		return useForMultipartSigning;
	}

	public void setUseForMultipartSigning(boolean useForMultiSigning) {

		this.useForMultipartSigning = useForMultiSigning;
	}

	public boolean isSetMultipartsAsOwners() {

		return setMultipartsAsOwners;
	}

	public void setSetMultipartsAsOwners(boolean setMultipartsAsOwners) {

		this.setMultipartsAsOwners = setMultipartsAsOwners;
	}

	@Override
	public String toString() {

		if (this.queryDescriptor != null) {

			return queryDescriptor.getName() + " (queryID: " + queryID + ")";
		}

		return getClass().getSimpleName() + " (queryID: " + queryID + ")";
	}

	@Override
	public String getXSDTypeName() {

		return getClass().getSimpleName() + queryID;
	}

	@Override
	public void toXSD(Document doc) {

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		complexTypeElement.setAttribute("name", getXSDTypeName());

		Element complexContentElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexContent");
		complexTypeElement.appendChild(complexContentElement);

		Element extensionElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:extension");
		extensionElement.setAttribute("base", "Query");
		complexContentElement.appendChild(extensionElement);

		Element sequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		extensionElement.appendChild(sequenceElement);

		Element nameElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		nameElement.setAttribute("name", "Name");
		nameElement.setAttribute("type", "xs:string");
		nameElement.setAttribute("minOccurs", "1");
		nameElement.setAttribute("maxOccurs", "1");
		nameElement.setAttribute("fixed", queryDescriptor.getName());
		sequenceElement.appendChild(nameElement);

		Element userElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		userElement.setAttribute("name", "User");
		userElement.setAttribute("type", getXSDTypeName() + "User");
		userElement.setAttribute("minOccurs", "1");
		userElement.setAttribute("maxOccurs", "1");

		sequenceElement.appendChild(userElement);

		doc.getDocumentElement().appendChild(complexTypeElement);

		// User type
		Element userComplexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		userComplexTypeElement.setAttribute("name", getXSDTypeName() + "User");

		Element userSequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		userComplexTypeElement.appendChild(userSequenceElement);

		addElementType(doc, userSequenceElement, "UserID", "xs:string");
		addElementType(doc, userSequenceElement, "Username", "xs:string", false);
		addElementType(doc, userSequenceElement, "Firstname", "xs:string");
		addElementType(doc, userSequenceElement, "Lastname", "xs:string");
		addElementType(doc, userSequenceElement, "CitizenIdentifier", "xs:string", false);
		addElementType(doc, userSequenceElement, "Email", "xs:string", false);
		addElementType(doc, userSequenceElement, "Phone", "xs:string", false);

		if (getSelectedUserAttributes() != null) {

			for (InternalUserQueriesSelectedAttribute selectedAttribute : getSelectedUserAttributes()) {

				appendFieldDefinition(selectedAttribute.getName(), false, doc, sequenceElement);
			}
		}

		InternalUserQueriesUtils.toXSDManager(this, userSequenceElement, doc);

		doc.getDocumentElement().appendChild(userComplexTypeElement);
	}

	private void appendFieldDefinition(String name, boolean required, Document doc, Element sequenceElement) {

		Element fieldElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		fieldElement.setAttribute("name", name);
		fieldElement.setAttribute("type", "xs:string");
		fieldElement.setAttribute("minOccurs", required ? "1" : "0");
		fieldElement.setAttribute("maxOccurs", "1");

		sequenceElement.appendChild(fieldElement);
	}

	public void addElementType(Document doc, Element sequenceElement, String name, String type) {

		addElementType(doc, sequenceElement, name, type, null, true);
	}

	public void addElementType(Document doc, Element sequenceElement, String name, String type, boolean required) {

		addElementType(doc, sequenceElement, name, type, null, required);
	}

	public void addElementType(Document doc, Element sequenceElement, String name, String type, String fixed) {

		addElementType(doc, sequenceElement, name, type, fixed, true);
	}

	public void addElementType(Document doc, Element sequenceElement, String name, String type, String fixed, boolean required) {

		Element element = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		element.setAttribute("name", name);
		element.setAttribute("type", type);
		element.setAttribute("minOccurs", required ? "1" : "0");
		element.setAttribute("maxOccurs", "1");

		if (!StringUtils.isEmpty(fixed)) {
			element.setAttribute("fixed", fixed);
		}

		sequenceElement.appendChild(element);
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();

		description = XMLValidationUtils.validateParameter("description", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);

		showDropDownUsername = xmlParser.getPrimitiveBoolean("showDropDownUsername");
		showDropDownCitizenIdentifier = xmlParser.getPrimitiveBoolean("showDropDownCitizenIdentifier");
		limitSelectionToMyEmployees = xmlParser.getPrimitiveBoolean("limitSelectionToMyEmployees");
		excludeInactiveUsers = xmlParser.getPrimitiveBoolean("excludeInactiveUsers");

		showName = xmlParser.getPrimitiveBoolean("showName");
		showUsername = xmlParser.getPrimitiveBoolean("showUsername");
		showEmail = xmlParser.getPrimitiveBoolean("showEmail");
		showCitizenIdentifier = xmlParser.getPrimitiveBoolean("showCitizenIdentifier");

		selectedDropDownAttributes = XMLPopulationUtils.populateBeans(xmlParser, "SelectedDropDownAttributes/SelectedDropDownAttribute", SelectedDropDownAttribute.class, errors);

		if (xmlParser.getNode("SelectedAttributes") != null) {
			
			selectedUserAttributes = XMLPopulationUtils.populateBeans(xmlParser, "SelectedAttributes/SelectedAttribute", SelectedUserAttribute.class, errors);
			
		} else {
			
			selectedUserAttributes = XMLPopulationUtils.populateBeans(xmlParser, "SelectedUserAttributes/SelectedUserAttribute", SelectedUserAttribute.class, errors);
		}

		showManagerInfo = xmlParser.getPrimitiveBoolean("showManagerInfo");

		if (showManagerInfo) {

			showManagerName = xmlParser.getPrimitiveBoolean("showManagerName");
			showManagerUsername = xmlParser.getPrimitiveBoolean("showManagerUsername");
			showManagerEmail = xmlParser.getPrimitiveBoolean("showManagerEmail");

			selectedManagerAttributes = XMLPopulationUtils.populateBeans(xmlParser, "SelectedManagerAttributes/SelectedManagerAttribute", SelectedManagerAttribute.class, errors);
		}

		useForMultipartSigning = xmlParser.getPrimitiveBoolean("useForMultipartSigning");
		setMultipartsAsOwners = xmlParser.getPrimitiveBoolean("setMultipartsAsOwners");
		requireManagerSigning = xmlParser.getPrimitiveBoolean("requireManagerSigning");

		lockOnOwnershipTransfer = xmlParser.getPrimitiveBoolean("lockOnOwnershipTransfer");

		attributeName = XMLValidationUtils.validateParameter("attributeName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);

		if (attributeName != null) {

			setAsAttribute = xmlParser.getPrimitiveBoolean("setAsAttribute");
		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	public boolean isSetAsAttribute() {
		return setAsAttribute;
	}

	public void setSetAsAttribute(boolean setAsAttribute) {
		this.setAsAttribute = setAsAttribute;
	}

	@Override
	public String getAttributeName() {
		return attributeName;
	}

	public void setAttributeName(String attributeName) {
		this.attributeName = attributeName;
	}
	
	public boolean isMaskCitizenIDLastFourDigits() {

		return maskCitizenIDLastFourDigits;
	}

	public void setMaskCitizenIDLastFourDigits(boolean maskCitizenIDLastFourDigits) {

		this.maskCitizenIDLastFourDigits = maskCitizenIDLastFourDigits;
	}

	public boolean isLockOnOwnershipTransfer() {
		return lockOnOwnershipTransfer;
	}

	public void setLockOnOwnershipTransfer(boolean lockOnOwnershipTransfer) {
		this.lockOnOwnershipTransfer = lockOnOwnershipTransfer;
	}

	public Integer getPreSelectedUserID() {
		return preSelectedUserID;
	}

	public void setPreSelectedUserID(Integer preSelectedUserID) {
		this.preSelectedUserID = preSelectedUserID;
	}

	public boolean isShowDropDownUsername() {
		return showDropDownUsername;
	}

	public void setShowDropDownUsername(boolean showDropDownUsername) {
		this.showDropDownUsername = showDropDownUsername;
	}

	public boolean isShowDropDownCitizenIdentifier() {
		return showDropDownCitizenIdentifier;
	}

	public void setShowDropDownCitizenIdentifier(boolean showDropDownCitizenIdentifier) {
		this.showDropDownCitizenIdentifier = showDropDownCitizenIdentifier;
	}

	@Override
	public boolean isShowName() {
		return showName;
	}

	public void setShowName(boolean showName) {
		this.showName = showName;
	}

	@Override
	public boolean isShowEmail() {
		return showEmail;
	}

	public void setShowEmail(boolean showEmail) {
		this.showEmail = showEmail;
	}

	public List<SelectedDropDownAttribute> getSelectedDropDownAttributes() {
		return selectedDropDownAttributes;
	}

	public void setSelectedDropDownAttributes(List<SelectedDropDownAttribute> selectedDropDownAttributes) {
		this.selectedDropDownAttributes = selectedDropDownAttributes;
	}

	@Override
	public List<SelectedUserAttribute> getSelectedUserAttributes() {
		return selectedUserAttributes;
	}

	public void setSelectedUserAttributes(List<SelectedUserAttribute> selectedAttributes) {
		this.selectedUserAttributes = selectedAttributes;
	}

	@Override
	public Element toXML(Document doc) {

		Element element = super.toXML(doc);

		if (selectableUsers != null) {

			Element selectableUsersElement = XMLUtils.appendNewElement(doc, element, "selectableUsers");

			for (User user : selectableUsers) {

				Element userElement = user.toXML(doc);

				if (user.getAttributeHandler() != null) {

					userElement.appendChild(user.getAttributeHandler().toXML(doc));
				}

				if (showManagerInfo || requireManagerSigning) {

					String managerUsername = user.getAttributeHandler().getString(InternalUserQueriesConstants.USER_MANAGER_USERNAME_ATTRIBUTE);

					if (managerUsername != null) {

						User manager = selectableManagers.get(managerUsername);

						if (manager != null) {

							Element managerElement = manager.toXML(doc);

							if (manager.getAttributeHandler() != null) {

								managerElement.appendChild(manager.getAttributeHandler().toXML(doc));
							}

							userElement.appendChild(managerElement);
						}
					}
				}

				selectableUsersElement.appendChild(userElement);
			}
		}

		return element;
	}

	public boolean hasFields() {

		return showEmail || showName || showUsername || showCitizenIdentifier || selectedUserAttributes != null;
	}

	@Override
	public boolean isShowManagerInfo() {
		return showManagerInfo;
	}

	public void setShowManagerInfo(boolean showManagerInfo) {
		this.showManagerInfo = showManagerInfo;
	}

	@Override
	public boolean isShowManagerName() {
		return showManagerName;
	}

	public void setShowManagerName(boolean showManagerName) {
		this.showManagerName = showManagerName;
	}

	@Override
	public boolean isShowManagerUsername() {
		return showManagerUsername;
	}

	public void setShowManagerUsername(boolean showManagerUsername) {
		this.showManagerUsername = showManagerUsername;
	}

	@Override
	public boolean isShowManagerEmail() {
		return showManagerEmail;
	}

	public void setShowManagerEmail(boolean showManagerEmail) {
		this.showManagerEmail = showManagerEmail;
	}

	@Override
	public List<SelectedManagerAttribute> getSelectedManagerAttributes() {
		return selectedManagerAttributes;
	}

	public void setSelectedManagerAttributes(List<SelectedManagerAttribute> selectedManagerAttributes) {
		this.selectedManagerAttributes = selectedManagerAttributes;
	}

	@Override
	public boolean isRequireManagerSigning() {
		return requireManagerSigning;
	}

	public void setRequireManagerSigning(boolean requireManagerSigning) {
		this.requireManagerSigning = requireManagerSigning;
	}

	public boolean isLimitSelectionToMyEmployees() {
		return limitSelectionToMyEmployees;
	}

	public void setLimitSelectionToMyEmployees(boolean limitSearchToMyEmployees) {
		this.limitSelectionToMyEmployees = limitSearchToMyEmployees;
	}

	public boolean isExcludeInactiveUsers() {
		return excludeInactiveUsers;
	}

	public void setExcludeInactiveUsers(boolean excludeInactiveUsers) {
		this.excludeInactiveUsers = excludeInactiveUsers;
	}
}
