package com.nordicpeak.flowengine.queries.predefineduserquery.beans;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.Constants;
import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.SigningParty;
import com.nordicpeak.flowengine.interfaces.ColumnExportableQueryInstance;
import com.nordicpeak.flowengine.interfaces.MultiSignQueryinstance;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.QueryRequestProcessor;
import com.nordicpeak.flowengine.interfaces.UserValueQueryInstance;
import com.nordicpeak.flowengine.interfaces.UserValuesQueryInstance;
import com.nordicpeak.flowengine.interfaces.UsersClosestManagerQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryUtils;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesSelectedAttribute;
import com.nordicpeak.flowengine.queries.internaluserqueries.InternalUserQueriesUtils;
import com.nordicpeak.flowengine.queries.internaluserqueries.interfaces.CommonInternalUserQueryInstance;
import com.nordicpeak.flowengine.queries.predefineduserquery.PredefinedUserQueryProviderModule;

@Table(name = "predefined_user_query_instances")
@XMLElement
public class PredefinedUserQueryInstance extends BaseQueryInstance implements UserValuesQueryInstance, UserValueQueryInstance, UsersClosestManagerQueryInstance, ColumnExportableQueryInstance, MultiSignQueryinstance, CommonInternalUserQueryInstance {

	private static final long serialVersionUID = -7761759005604863873L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(PredefinedUserQueryInstance.class, "query");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private PredefinedUserQuery query;

	@DAOManaged
	@XMLElement
	private Integer userID;

	@DAOManaged
	@XMLElement
	private String firstname;

	@DAOManaged
	@XMLElement
	private String lastname;

	@DAOManaged
	@XMLElement
	private String username;

	@DAOManaged
	@XMLElement
	private String citizenIdentifier;

	@DAOManaged
	@XMLElement
	private String email;

	@DAOManaged
	@XMLElement
	private String phone;

	@DAOManaged
	@XMLElement
	private String managerCitizenID;

	@DAOManaged
	@XMLElement
	private String managerUsername;

	@DAOManaged
	@XMLElement
	private String managerFirstname;

	@DAOManaged
	@XMLElement
	private String managerLastname;

	@DAOManaged
	@XMLElement
	private String managerEmail;

	@DAOManaged
	@XMLElement
	private String managerMobilePhone;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<UserAttributeValue> userAttributeValues;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<ManagerAttributeValue> managerAttributeValues;

	public Integer getQueryInstanceID() {

		return queryInstanceID;
	}

	public void setQueryInstanceID(Integer queryInstanceID) {

		this.queryInstanceID = queryInstanceID;
	}

	@Override
	public PredefinedUserQuery getQuery() {

		return query;
	}

	@Override
	public List<UserAttributeValue> getUserAttributeValues() {
		return userAttributeValues;
	}

	public void setUserAttributeValues(List<UserAttributeValue> attributeValues) {
		this.userAttributeValues = attributeValues;
	}

	public String getAttributeValue(String name) {

		if (userAttributeValues != null) {

			for (UserAttributeValue attributeValue : userAttributeValues) {

				if (attributeValue.getName().equals(name)) {

					return attributeValue.getValue();
				}
			}
		}

		return null;
	}

	public Integer getUserID() {

		return userID;
	}

	public void setUserID(Integer userID) {

		this.userID = userID;
	}

	@Override
	public String getFirstname() {

		return firstname;
	}

	public void setFirstname(String firstname) {

		this.firstname = firstname;
	}

	@Override
	public String getLastname() {

		return lastname;
	}

	public void setLastname(String lastname) {

		this.lastname = lastname;
	}

	@Override
	public String getUsername() {

		return username;
	}

	public void setUsername(String username) {

		this.username = username;
	}

	@Override
	public String getCitizenIdentifier() {

		return citizenIdentifier;
	}

	public void setCitizenIdentifier(String citizenIdentifier) {

		this.citizenIdentifier = citizenIdentifier;
	}

	@Override
	public String getEmail() {

		return email;
	}

	public void setEmail(String email) {

		this.email = email;
	}

	public String getPhone() {

		return phone;
	}

	public void setPhone(String phone) {

		this.phone = phone;
	}

	public void setQuery(PredefinedUserQuery query) {

		this.query = query;
	}

	@Override
	public boolean isPopulated() {

		return !ObjectUtils.isNull(userID, firstname, lastname, username, citizenIdentifier, email, phone, userAttributeValues);
	}

	public boolean isManagerPopulated() {

		return !ObjectUtils.isNull(managerFirstname, managerLastname, managerUsername, managerEmail, managerAttributeValues);
	}

	@Override
	public void reset(MutableAttributeHandler attributeHandler) {

		userID = null;
		firstname = null;
		lastname = null;
		username = null;
		citizenIdentifier = null;
		email = null;
		phone = null;
		
		managerCitizenID = null;
		managerFirstname = null;
		managerLastname = null;
		managerUsername = null;
		managerEmail = null;
		managerMobilePhone = null;

		userAttributeValues = null;
		managerAttributeValues = null;

		if (query.isSetAsAttribute() && attributeHandler != null) {
			resetAttributes(attributeHandler);
		}
		
		super.reset(attributeHandler);
	}

	public void resetAttributes(MutableAttributeHandler attributeHandler) {

		attributeHandler.removeAttribute(query.getAttributeName());
		attributeHandler.removeAttribute(query.getAttributeName() + "." + Constants.USER_CITIZEN_IDENTIFIER_ATTRIBUTE);
		
		InternalUserQueriesUtils.resetFlowInstanceAttributes(query, this, attributeHandler);
	}

	public void setAttributes(MutableAttributeHandler attributeHandler) {

		if (userID != null) {

			if (username == null) {

				attributeHandler.setAttribute(query.getAttributeName(), firstname + " " + lastname);

			} else {

				attributeHandler.setAttribute(query.getAttributeName(), firstname + " " + lastname + " (" + username + ")");
			}
			
			attributeHandler.setAttribute(query.getAttributeName() + "." + Constants.USER_CITIZEN_IDENTIFIER_ATTRIBUTE, citizenIdentifier);
		}

		InternalUserQueriesUtils.setFlowInstanceAttributes(query, this, attributeHandler);
	}

	@Override
	public QueryRequestProcessor getQueryRequestProcessor(HttpServletRequest req, User user, User poster, URIParser uriParser, QueryHandler queryHandler, InstanceRequestMetadata requestMetadata) throws Exception {

		return BaseQueryUtils.getGenericQueryInstanceProvider(this.getClass(), queryHandler, queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID()).getQueryRequestProcessor(this, req, user, poster, uriParser, requestMetadata);
	}

	@Override
	public Element toXML(Document doc) {

		Element element = XMLGenerator.toXML(this, doc);

		return element;
	}

	@Override
	public String toString() {

		return getClass().getSimpleName() + " (queryInstanceID=" + queryInstanceID + ")";
	}

	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {

		Element element = getBaseExportXML(doc);

		if (userID != null) {

			Element userElement = doc.createElement("User");

			XMLUtils.appendNewElement(doc, userElement, "UserID", userID);
			XMLUtils.appendNewCDATAElement(doc, userElement, "Username", username);
			XMLUtils.appendNewCDATAElement(doc, userElement, "Firstname", firstname);
			XMLUtils.appendNewCDATAElement(doc, userElement, "Lastname", lastname);
			XMLUtils.appendNewElement(doc, userElement, "CitizenIdentifier", citizenIdentifier);
			XMLUtils.appendNewElement(doc, userElement, "Email", email);
			XMLUtils.appendNewElement(doc, userElement, "Phone", phone);

			if (query.getSelectedUserAttributes() != null) {

				for (InternalUserQueriesSelectedAttribute attribute : query.getSelectedUserAttributes()) {

					XMLUtils.appendNewCDATAElement(doc, element, attribute.getName(), InternalUserQueriesUtils.getAttributeValue(attribute.getName(), getUserAttributeValues()));
				}
			}

			InternalUserQueriesUtils.toExportXMLManager(query, this, userElement, doc);

			element.appendChild(userElement);
		}

		return element;
	}

	@Override
	public User getUserValue(QueryHandler queryHandler) {

		if (userID != null) {

			PredefinedUserQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), PredefinedUserQueryProviderModule.class);
			return queryProviderModule.getUserHandler().getUser(userID, false, true);
		}

		return null;
	}

	@Override
	public Collection<User> getUserValues(QueryHandler queryHandler) {

		User user = getUserValue(queryHandler);

		if (user != null) {

			return CollectionUtils.getList(user);
		}

		return null;
	}

	@Override
	public List<? extends SigningParty> getSigningParties() {

		if ((!query.requiresMultipartSigning() || userID == null) && !query.isRequireManagerSigning()) {
			return null;
		}

		List<SigningParty> signingParties = new ArrayList<SigningParty>(2);

		if (query.requiresMultipartSigning() && userID != null) {
			signingParties.add(new SigningParty(firstname, lastname, email, phone, citizenIdentifier, query.isSetMultipartsAsOwners()));
		}
		
		if (query.isRequireManagerSigning()) {
			signingParties.add(new SigningParty(managerFirstname, managerLastname, managerEmail, managerMobilePhone, managerCitizenID, false));
		}

		return signingParties;
	}

	@Override
	public List<String> getColumnLabels(QueryHandler queryHandler) {

		if (!query.hasFields()) {

			return Collections.emptyList();
		}

		PredefinedUserQueryProviderModule queryProvider = queryHandler.getQueryProvider(getQueryInstanceDescriptor().getQueryDescriptor().getQueryTypeID(), PredefinedUserQueryProviderModule.class);

		List<String> labels = InternalUserQueriesUtils.getColumnLabels(query, this, queryProvider);

		if (query.isShowCitizenIdentifier()) {

			labels.add(queryProvider.getExportCitizenID());
		}

		return labels;
	}

	@Override
	public List<String> getColumnValues() {

		if (!query.hasFields()) {

			return Collections.emptyList();
		}

		List<String> columnValues = InternalUserQueriesUtils.getColumnValues(query, this);

		if (isPopulated()) {

			if (query.isShowCitizenIdentifier()) {

				columnValues.add(citizenIdentifier);
			}

		} else {

			if (query.isShowCitizenIdentifier()) {

				columnValues.add(null);
			}
		}

		return columnValues;
	}

	@Override
	public String getManagerCitizenID() {
		return managerCitizenID;
	}

	public void setManagerCitizenID(String managerCitizenID) {
		this.managerCitizenID = managerCitizenID;
	}

	@Override
	public String getManagerUsername() {
		return managerUsername;
	}

	public void setManagerUsername(String managerUsername) {
		this.managerUsername = managerUsername;
	}

	@Override
	public String getManagerFirstname() {
		return managerFirstname;
	}

	public void setManagerFirstname(String managerFirstname) {
		this.managerFirstname = managerFirstname;
	}

	@Override
	public String getManagerLastname() {
		return managerLastname;
	}

	public void setManagerLastname(String managerLastname) {
		this.managerLastname = managerLastname;
	}

	@Override
	public String getManagerEmail() {
		return managerEmail;
	}

	public void setManagerEmail(String managerEmail) {
		this.managerEmail = managerEmail;
	}

	@Override
	public String getManagerMobilePhone() {
		return managerMobilePhone;
	}

	public void setManagerMobilePhone(String managerMobilePhone) {
		this.managerMobilePhone = managerMobilePhone;
	}

	@Override
	public List<ManagerAttributeValue> getManagerAttributeValues() {
		return managerAttributeValues;
	}

	public void setManagerAttributeValues(List<ManagerAttributeValue> managerAttributeValues) {
		this.managerAttributeValues = managerAttributeValues;
	}

	@Override
	public User getClosestManager(QueryHandler queryHandler) {

		PredefinedUserQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), PredefinedUserQueryProviderModule.class);
		
		return queryProviderModule.getUserHandler().getUserByUsername(managerUsername, false, true);
		
	}

}
