package com.nordicpeak.flowengine.queries.priorityquery;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;

import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.annotations.TextTagReplace;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesBaseQuery;

@Table(name = "priority_queries")
@XMLElement
public class PriorityQuery extends FixedAlternativesBaseQuery {
	
	
	private static final long serialVersionUID = -842191226937409416L;
	
	public static final Field ALTERNATIVES_RELATION = ReflectionUtils.getField(PriorityQuery.class, "alternatives");
	
	@DAOManaged
	@Key
	@XMLElement
	private Integer queryID;
	
	@TextTagReplace
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String shortDescription;
	
	@DAOManaged
	@OneToMany(autoUpdate = true, autoAdd = true)
	@XMLElement(fixCase = true)
	private List<PriorityAlternative> alternatives;
	
	@WebPopulate(required = true)
	@DAOManaged
	@XMLElement
	private Integer minChoices;
	
	@WebPopulate(required = true)
	@DAOManaged
	@XMLElement
	private Integer maxChoices;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean setAsAttribute;
	
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "setAsAttribute")
	@XMLElement
	private String attributeName;
	
	@DAOManaged
	@OneToMany
	@XMLElement
	private List<PriorityQueryInstance> instances;
	
	public static long getSerialversionuid() {
		
		return serialVersionUID;
	}
	
	@Override
	public Integer getQueryID() {
		
		return queryID;
	}
	
	@Override
	public List<PriorityAlternative> getAlternatives() {
		
		return alternatives;
	}
	
	public void setAlternatives(List<PriorityAlternative> alternatives) {
		
		this.alternatives = alternatives;
	}
	
	public Integer getMinChoices() {
		
		return minChoices;
	}
	
	public void setMinChoices(Integer minChoices) {
		
		this.minChoices = minChoices;
	}
	
	public Integer getMaxChoices() {
		
		return maxChoices;
	}
	
	public void setMaxChoices(Integer maxChoices) {
		
		this.maxChoices = maxChoices;
	}
	
	public List<PriorityQueryInstance> getInstances() {
		
		return instances;
	}
	
	public void setInstances(List<PriorityQueryInstance> instances) {
		
		this.instances = instances;
	}
	
	public void setQueryID(int queryID) {
		
		this.queryID = queryID;
	}
	
	public String getShortDescription() {
		
		return shortDescription;
	}
	
	public void setShortDescription(String shortDescription) {
		
		this.shortDescription = shortDescription;
	}
	
	@Override
	public String toString() {
		
		if (this.queryDescriptor != null) {
			
			return queryDescriptor.getName() + " (queryID: " + queryID + ")";
		}
		
		return getClass().getSimpleName() + " (queryID: " + queryID + ")";
	}
	
	@Override
	public String getXSDTypeName() {
		
		return "PriorityQuery" + queryID;
	}
	
	@Override
	public void toXSD(Document doc) {
		
		toXSD(doc, minChoices, maxChoices);
	}
	
	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {
		
		List<ValidationError> errors = new ArrayList<ValidationError>();
		
		shortDescription = XMLValidationUtils.validateParameter("shortDescription", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		description = XMLValidationUtils.validateParameter("description", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		minChoices = XMLValidationUtils.validateParameter("minChoices", xmlParser, false, 1, 255, IntegerPopulator.getPopulator(), errors);
		maxChoices = XMLValidationUtils.validateParameter("maxChoices", xmlParser, false, 1, 255, IntegerPopulator.getPopulator(), errors);
		
		attributeName = XMLValidationUtils.validateParameter("attributeName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		
		if (attributeName != null) {
			
			setAsAttribute = xmlParser.getPrimitiveBoolean("setAsAttribute");
		}
		
		alternatives = PriorityQueryCRUD.ALTERNATIVES_POPLATOR.populate(xmlParser, errors);
		
		if (!errors.isEmpty()) {
			
			throw new ValidationException(errors);
		}
		
	}
	
	@Override
	public String getFreeTextAlternative() {
		
		return null;
	}
	
	public boolean isSetAsAttribute() {
		
		return setAsAttribute;
	}
	
	public void setSetAsAttribute(boolean setAsAttribute) {
		
		this.setAsAttribute = setAsAttribute;
	}
	
	public String getAttributeName() {
		
		return attributeName;
	}
	
	public void setAttributeName(String attributeName) {
		
		this.attributeName = attributeName;
	}
}
