package com.nordicpeak.flowengine.queue;

import java.lang.reflect.Field;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import org.apache.log4j.Level;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.emailutils.framework.Attachment;
import se.unlogic.emailutils.framework.EmailUtils;
import se.unlogic.emailutils.framework.InvalidEmailAddressException;
import se.unlogic.emailutils.framework.SimpleEmail;
import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.EventListener;
import se.unlogic.hierarchy.core.annotations.HTMLEditorSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextAreaSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.Group;
import se.unlogic.hierarchy.core.beans.LinkTag;
import se.unlogic.hierarchy.core.beans.ScriptTag;
import se.unlogic.hierarchy.core.beans.SimpleSMS;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.CRUDAction;
import se.unlogic.hierarchy.core.enums.EventSource;
import se.unlogic.hierarchy.core.enums.EventTarget;
import se.unlogic.hierarchy.core.events.CRUDEvent;
import se.unlogic.hierarchy.core.handlers.GroupHandler;
import se.unlogic.hierarchy.core.handlers.UserHandler;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.SectionDescriptor;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.ViewFragment;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.interfaces.sms.SMSSender;
import se.unlogic.hierarchy.core.settings.Setting;
import se.unlogic.hierarchy.core.settings.TextFieldSetting;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.AttributeTagUtils;
import se.unlogic.hierarchy.core.utils.CRUDCallback;
import se.unlogic.hierarchy.core.utils.HierarchyAnnotatedDAOFactory;
import se.unlogic.hierarchy.core.utils.ModuleUtils;
import se.unlogic.hierarchy.core.utils.ModuleViewFragmentTransformer;
import se.unlogic.hierarchy.core.utils.UserUtils;
import se.unlogic.hierarchy.core.utils.ViewFragmentModule;
import se.unlogic.hierarchy.core.utils.crud.CRUDEventFilter;
import se.unlogic.hierarchy.core.utils.crud.FragmentLinkScriptFilter;
import se.unlogic.hierarchy.core.utils.extensionlinks.ExtensionLink;
import se.unlogic.hierarchy.core.utils.usergroupadminextensions.GroupAdminExtensionProvider;
import se.unlogic.hierarchy.core.utils.usergroupadminextensions.UserAdminExtensionProvider;
import se.unlogic.hierarchy.core.utils.usergroupadminextensions.UserGroupAdminExtensionHandler;
import se.unlogic.hierarchy.core.utils.usergrouplist.UserGroupListConnector;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.ProfileSettingHandler;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfile;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfileHandler;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfileSettingProvider;
import se.unlogic.standardutils.annotations.SplitOnLineBreak;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.LowLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.dao.querys.ObjectQuery;
import se.unlogic.standardutils.db.DBUtils;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.string.AnnotatedBeanTagSourceFactory;
import se.unlogic.standardutils.string.SingleTagSource;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.string.TagReplacer;
import se.unlogic.standardutils.string.TagSource;
import se.unlogic.standardutils.time.TimeUtils;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.Constants;
import com.nordicpeak.flowengine.beans.Contact;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.beans.FlowInstanceEvent;
import com.nordicpeak.flowengine.dao.FlowEngineDAOFactory;
import com.nordicpeak.flowengine.enums.EventType;
import com.nordicpeak.flowengine.enums.SenderType;
import com.nordicpeak.flowengine.events.SubmitEvent;
import com.nordicpeak.flowengine.interfaces.FlowNotificationHandler;
import com.nordicpeak.flowengine.managers.FlowInstanceManager;
import com.nordicpeak.flowengine.queries.contactdetailquery.ContactDetailQueryInstance;
import com.nordicpeak.flowengine.queue.beans.ExternalMessage;
import com.nordicpeak.flowengine.queue.beans.ExternalMessageAttachment;
import com.nordicpeak.flowengine.queue.beans.InternalMessage;
import com.nordicpeak.flowengine.queue.beans.ManualContact;
import com.nordicpeak.flowengine.queue.beans.PrimaryContact;
import com.nordicpeak.flowengine.queue.beans.Queue;
import com.nordicpeak.flowengine.queue.beans.QueueSlot;
import com.nordicpeak.flowengine.queue.beans.QueueSlotEvent;
import com.nordicpeak.flowengine.queue.cruds.QueueCRUD;
import com.nordicpeak.flowengine.queue.enums.ExternalMessageType;
import com.nordicpeak.flowengine.queue.events.ExternalMessageAddedEvent;
import com.nordicpeak.flowengine.queue.events.QueueSlotArchiveEvent;
import com.nordicpeak.flowengine.queue.events.QueueSlotManuallyAddedEvent;
import com.nordicpeak.flowengine.queue.events.QueueSlotRequestLeaveEvent;
import com.nordicpeak.flowengine.queue.query.QueueQueryInstance;
import com.nordicpeak.flowengine.utils.TextTagReplacer;
import com.nordicpeak.openhierarchy.payment.exceptions.PaymentConfigurationIDNotUsed;
import com.nordicpeak.openhierarchy.payment.interfaces.PaymentConfigurationInformationProvider;
import com.nordicpeak.openhierarchy.payment.interfaces.PaymentProvider;

public class QueueAdminModule extends AnnotatedForegroundModule implements CRUDCallback<User>, SiteProfileSettingProvider, PaymentConfigurationInformationProvider, UserAdminExtensionProvider, GroupAdminExtensionProvider, ViewFragmentModule<ForegroundModuleDescriptor> {

	private static final AnnotatedBeanTagSourceFactory<Queue> QUEUE_TAG_SOURCE_FACTORY = new AnnotatedBeanTagSourceFactory<>(Queue.class, "$queue.");
	private static final AnnotatedBeanTagSourceFactory<QueueSlot> QUEUE_SLOT_TAG_SOURCE_FACTORY = new AnnotatedBeanTagSourceFactory<>(QueueSlot.class, "$queueSlot.");
	private static final AnnotatedBeanTagSourceFactory<Contact> CONTACT_TAG_SOURCE_FACTORY = new AnnotatedBeanTagSourceFactory<>(Contact.class, "$contact.");
	private static final AnnotatedBeanTagSourceFactory<User> MANAGER_TAG_SOURCE_FACTORY = new AnnotatedBeanTagSourceFactory<>(User.class, "$manager.");

	@XSLVariable(prefix = "java.")
	private String secondaryContactInternalMessagePrefix = "Secondary contact";

	@XSLVariable(prefix = "java.")
	protected String defaultEventPaymentInvoiceMessage = "eventPaymentInvoiceMessage";

	@XSLVariable(prefix = "java.")
	protected String eventSubmittedWithCommentMessage = "eventSubmittedWithCommentMessage";

	@XSLVariable(prefix = "java.")
	protected String i18nUserQueueSlotModuleAlias = "User queue slot module URL";

	@XSLVariable(prefix = "java.")
	protected String i18nUserQueueSlotModuleAliasDescription = "The full URL of the user queue slot module";

	@XSLVariable(prefix = "java.")
	protected String i18nQueueSlotAdminModuleAlias = "Queue slot admin module URL";

	@XSLVariable(prefix = "java.")
	protected String i18nQueueSlotAdminModuleAliasDescription = "The full URL of the queue slot admin module";

	@ModuleSetting(allowsNull = true)
	@SplitOnLineBreak
	@TextAreaSettingDescriptor(name = "Supported actionID's", description = "The action ID's which will trigger this module when a submit event is detected", required = true)
	private List<String> supportedActionIDs = CollectionUtils.getList("com.nordicpeak.flowengine.FlowBrowserModule.submit");

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable profile support", description = "Controls of if profile support for queues is enabled")
	private boolean enableProfileSupport = false;

	@ModuleSetting
	@TextAreaSettingDescriptor(name = "SMS to users when new messages are received", description = "The SMS messages sent to the users when they receive new messages.", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedUserSMS;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "New message received email subject (users)", description = "The subject of emails sent to the users when new messages are received", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedUserEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "New message received email message (users)", description = "The message of emails sent to the users when new messages are received", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedUserEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "New message received email subject (managers)", description = "The subject of emails sent to the managers when new messages are received", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedManagerEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "New message received email message (managers)", description = "The message of emails sent to the managers when new messages are received", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedManagerEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "New message received email subject (global)", description = "The subject of emails sent when new messages are received", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedGlobalEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "New message received email message (global)", description = "The message of emails sent when new messages are received", required = true)
	@XSLVariable(prefix = "java.")
	private String externalMessageReceivedGlobalEmailMessage;

	@ModuleSetting
	@TextAreaSettingDescriptor(name = "SMS to users when manually added to queue", description = "The SMS messages sent to the users when they are manually added to queue.", required = true)
	@XSLVariable(prefix = "java.")
	private String manualEntranceSMS;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Manually added to queue email subject (users)", description = "The subject of emails sent to the users when they are manually added to queue", required = true)
	@XSLVariable(prefix = "java.")
	private String manualEntranceEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Manually added to queue email message (users)", description = "The message of emails sent to the users when they are manually added to queue", required = true)
	@XSLVariable(prefix = "java.")
	private String manualEntranceEmailMessage;

	@ModuleSetting
	@TextAreaSettingDescriptor(name = "SMS to users when removed from queue", description = "The SMS messages sent to the users when they are removed from queue.", required = true)
	@XSLVariable(prefix = "java.")
	private String exitUserSMS;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Removed from queue email subject (users)", description = "The subject of emails sent to the users when removed from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitUserEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Removed from queue email message (users)", description = "The message of emails sent to the users when removed from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitUserEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Removed from queue email subject (managers)", description = "The subject of emails sent to the managers when removed from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitManagerEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Removed from queue email message (managers)", description = "The message of emails sent to the managers when removed from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitManagerEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Removed from queue email subject (global)", description = "The subject of emails sent when removed from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitGlobalEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Removed from queue email message (global)", description = "The message of emails sent when removed from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitGlobalEmailMessage;

	@ModuleSetting
	@TextAreaSettingDescriptor(name = "SMS to users when requesting removal from queue", description = "The SMS messages sent to the users when they are requesting removal from queue.", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestUserSMS;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Requesting removal from queue email subject (users)", description = "The subject of emails sent to the users when requesting removal from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestUserEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Requesting removal from queue email message (users)", description = "The message of emails sent to the users when requesting removal from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestUserEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Requesting removal from queue email subject (managers)", description = "The subject of emails sent to the managers when requesting removal from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestManagerEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Requesting removal from queue email message (managers)", description = "The message of emails sent to the managers when requesting removal from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestManagerEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Requesting removal from queue email subject (global)", description = "The subject of emails sent when requesting removal from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestGlobalEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Requesting removal from queue email message (global)", description = "The message of emails sent when requesting removal from queue", required = true)
	@XSLVariable(prefix = "java.")
	private String exitRequestGlobalEmailMessage;

	@ModuleSetting
	@TextAreaSettingDescriptor(name = "SMS to users when payment is requested for queue", description = "The SMS messages sent to the users when admin is requesting payment for queue", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentRequestSMS;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Subject to users for email when payment is requested for queue", description = "The subject of emails sent to the users when admin is requesting payment for queue", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentRequestEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Message to users for email when payment is requested for queue", description = "The message of emails sent to the users when admin is requesting payment for queue", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentRequestEmailMessage;

	@ModuleSetting
	@TextAreaSettingDescriptor(name = "SMS when payment is complete (users)", description = "The SMS messages sent to the users when their payment for queue is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentCompleteUserSMS;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Subject for email when payment is complete (users)", description = "The subject of emails sent to the users when their payment for queue slot is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentCompleteUserEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Message for email when payment is complete (users)", description = "The message of emails sent to the users when their payment for queue slot is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentCompleteUserEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Subject for email when direct payment is complete (managers)", description = "The subject of emails sent when users direct payment for queue slot is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentDirectManagerEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Message for email when direct payment is complete (managers)", description = "The message of emails sent when users direct payment for queue slot is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentDirectManagerEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Subject for email when direct payment is complete (global)", description = "The subject of emails sent when users direct payment for queue slot is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentDirectGlobalEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Message for email when direct payment is complete (global)", description = "The message of emails sent when users direct payment for queue slot is complete", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentDirectGlobalEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Subject for email when invoice payment is selected (managers)", description = "The subject of emails sent when users selects invoice payment for queue slot", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentInvoiceManagerEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Message for email when invoice payment is selected (managers)", description = "The message of emails sent when users selects invoice payment for queue slot", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentInvoiceManagerEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Subject for email when invoice payment is selected (global)", description = "The subject of emails sent when users selects invoice payment for queue slot", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentInvoiceGlobalEmailSubject;

	@ModuleSetting
	@HTMLEditorSettingDescriptor(name = "Message for email when invoice payment is selected (global)", description = "The message of emails sent when users selects invoice payment for queue slot", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentInvoiceGlobalEmailMessage;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "User queue slot module URL", description = "The full URL of the user queue slot module", required = true)
	protected String userQueueSlotModuleAlias = "not set";

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Admin queue slot module URL", description = "The full URL of the admin queue slot module", required = true)
	protected String queueSlotAdminModuleAlias = "not set";

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Secondary contact firstname attribute", description = "The name of the attribute containing the firstname of the secondary contact")
	protected String secondaryContactFirstnameAttribute = null;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Secondary contact lastname attribute", description = "The name of the attribute containing the lastname of the secondary contact")
	protected String secondaryContactLastnameAttribute = null;

	@ModuleSetting(allowsNull = true)
	@TextFieldSettingDescriptor(name = "Secondary contact citizen identifier attribute", description = "The name of the attribute containing the citizen identifier attribute")
	protected String secondaryContactCitizenIdentifierAttribute = null;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Allow email sender override", description = "Controls of the email sender name and address is allowed to be set on each queue.")
	private boolean allowEmailSenderOverride = false;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable fragment XML debug", description = "Enables debugging of fragment XML")
	private boolean debugFragmentXML;

	@InstanceManagerDependency
	protected PaymentProvider paymentProvider;

	@InstanceManagerDependency(required = true)
	protected FlowNotificationHandler notificationHandler;

	private SiteProfileHandler siteProfileHandler;

	private List<Setting> profileSettings;

	private UserGroupListConnector userGroupListConnector;

	protected AnnotatedDAO<Queue> queueDAO;
	protected AnnotatedDAO<QueueSlot> queueSlotDAO;
	protected AnnotatedDAO<QueueSlotEvent> queueSlotEventDAO;
	protected AnnotatedDAO<FlowInstanceEvent> flowInstanceEventDAO;
	protected AnnotatedDAO<ExternalMessage> extrernalMessageDAO;

	protected AnnotatedDAOWrapper<Queue, Integer> queueDAOWrapper;

	protected QueryParameterFactory<FlowInstanceEvent, FlowInstance> flowInstanceEventFlowInstanceParamFactory;

	protected QueueCRUD queueCRUD;

	@InstanceManagerDependency
	protected SMSSender smsSender;

	private ModuleViewFragmentTransformer<ForegroundModuleDescriptor> viewFragmentTransformer;

	private UserGroupAdminExtensionHandler userGroupAdminExtensionHandler;

	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {

		viewFragmentTransformer = new ModuleViewFragmentTransformer<>(sectionInterface.getForegroundModuleXSLTCache(), this, sectionInterface.getSystemInterface().getEncoding());

		super.init(moduleDescriptor, sectionInterface, dataSource);

		if (!systemInterface.getInstanceHandler().addInstance(QueueAdminModule.class, this)) {

			throw new RuntimeException("Unable to register module in global instance handler using key " + QueueAdminModule.class.getSimpleName() + ", another instance is already registered using this key.");
		}
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		super.createDAOs(dataSource);

		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, QueueAdminModule.class.getName(), new XMLDBScriptProvider(QueueAdminModule.class.getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		userGroupListConnector = new UserGroupListConnector(systemInterface);

		HierarchyAnnotatedDAOFactory daoFactory = new HierarchyAnnotatedDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler(), false, true, false);

		queueDAO = daoFactory.getDAO(Queue.class);
		queueSlotDAO = daoFactory.getDAO(QueueSlot.class);
		queueSlotEventDAO = daoFactory.getDAO(QueueSlotEvent.class);
		extrernalMessageDAO = daoFactory.getDAO(ExternalMessage.class);

		queueDAOWrapper = queueDAO.getWrapper(Integer.class);
		queueDAOWrapper.addRelations(Queue.MANAGER_USERS_RELATION, Queue.MANAGER_GROUPS_RELATION, Queue.INTERNAL_GROUPS_RELATION);
		queueDAOWrapper.setUseRelationsOnAdd(true);
		queueDAOWrapper.setUseRelationsOnGet(true);
		queueDAOWrapper.setUseRelationsOnUpdate(true);

		queueCRUD = new QueueCRUD(queueDAOWrapper, this);
		queueCRUD.addModuleResponseFilter(new FragmentLinkScriptFilter<Queue>());
		queueCRUD.addBeanFilter(new CRUDEventFilter<Queue>(Queue.class, systemInterface.getEventHandler()));

		FlowEngineDAOFactory flowEngineDAOFactory = new FlowEngineDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler());

		flowInstanceEventDAO = flowEngineDAOFactory.getFlowInstanceEventDAO();

		flowInstanceEventFlowInstanceParamFactory = flowInstanceEventDAO.getParamFactory("flowInstance", FlowInstance.class);
	}

	@Override
	protected void moduleConfigured() throws Exception {

		super.moduleConfigured();

		ModuleUtils.checkRequiredModuleSettings(moduleDescriptor, this, systemInterface, Level.WARN);

		if (enableProfileSupport) {

			profileSettings = new ArrayList<>(2);

			profileSettings.add(new TextFieldSetting("userQueueSlotModuleAliasSetting", i18nUserQueueSlotModuleAlias, i18nUserQueueSlotModuleAliasDescription, "", false));
			profileSettings.add(new TextFieldSetting("queueSlotAdminModuleAliasSetting", i18nQueueSlotAdminModuleAlias, i18nQueueSlotAdminModuleAliasDescription, "", false));

		} else {

			profileSettings = null;
		}

		viewFragmentTransformer.setDebugXML(debugFragmentXML);
	}

	@Override
	public void unload() throws Exception {

		systemInterface.getInstanceHandler().removeInstance(QueueAdminModule.class, this);

		if (siteProfileHandler != null) {

			siteProfileHandler.removeSettingProvider(this);
		}

		if (userGroupAdminExtensionHandler != null) {

			setUserGroupAdminExtensionHandler(null);
		}

		super.unload();
	}

	@InstanceManagerDependency(required = true)
	public void setSiteProfileHandler(SiteProfileHandler siteProfileHandler) {

		if (siteProfileHandler != null) {

			siteProfileHandler.addSettingProvider(this);

		} else {

			this.siteProfileHandler.removeSettingProvider(this);
		}

		this.siteProfileHandler = siteProfileHandler;
	}

	public Queue getQueue(Integer queueID) throws SQLException {

		return queueDAOWrapper.get(queueID);
	}

	public List<Queue> getQueues() throws SQLException {

		LowLevelQuery<Queue> query = new LowLevelQuery<>("SELECT * FROM " + queueDAO.getTableName() + " WHERE enabled = 1 ORDER BY name ASC");

		return queueDAO.getAll(query);
	}

	@Override
	public ForegroundModuleResponse defaultMethod(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return queueCRUD.list(req, res, user, uriParser, null);
	}

	@WebPublic(alias = "add")
	public ForegroundModuleResponse addQueue(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return queueCRUD.add(req, res, user, uriParser);
	}

	@WebPublic(alias = "update")
	public ForegroundModuleResponse updateQueue(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return queueCRUD.update(req, res, user, uriParser);
	}

	@WebPublic(alias = "delete")
	public ForegroundModuleResponse deleteQueue(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return queueCRUD.delete(req, res, user, uriParser);
	}

	public boolean hasQueueAdminAccess(Queue queue, User user) {

		return AccessUtils.checkAccess(user, queue);
	}

	@Override
	public Document createDocument(HttpServletRequest req, URIParser uriParser, User user) {

		Document doc = XMLUtils.createDomDocument();
		Element document = doc.createElement("Document");

		document.appendChild(RequestUtils.getRequestInfoAsXML(doc, req, uriParser));
		document.appendChild(this.moduleDescriptor.toXML(doc));

		XMLUtils.appendNewElement(doc, document, "EnableProfileSupport", enableProfileSupport);

		XMLUtils.appendNewElement(doc, document, "ShowSenderEmailAddress", allowEmailSenderOverride);

		doc.appendChild(document);
		return doc;
	}

	@Override
	public String getTitlePrefix() {

		return moduleDescriptor.getName();
	}

	public SectionDescriptor getSectionDescriptor() {

		return sectionInterface.getSectionDescriptor();
	}

	@WebPublic(alias = "users")
	public ForegroundModuleResponse getUsers(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return userGroupListConnector.getUsers(req, res, user, uriParser);
	}

	@WebPublic(alias = "groups")
	public ForegroundModuleResponse getGroups(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return userGroupListConnector.getGroups(req, res, user, uriParser);
	}

	public UserHandler getUserHandler() {

		return systemInterface.getUserHandler();
	}

	public GroupHandler getGroupHandler() {

		return systemInterface.getGroupHandler();
	}

	@EventListener(channel = FlowInstanceManager.class)
	public void processEvent(SubmitEvent event, EventSource source) {

		try {
			if (source.isLocal()) {

				if (event.getEvent() == null || event.getEvent().getEventType() != EventType.SUBMITTED || event.getActionID() == null || !supportedActionIDs.contains(event.getActionID())) {

					return;
				}

				Timestamp now = new Timestamp(System.currentTimeMillis());

				FlowInstanceManager flowInstanceManager = event.getFlowInstanceManager();

				List<QueueQueryInstance> queueQueryInstances = flowInstanceManager.getQueries(QueueQueryInstance.class);

				if (!CollectionUtils.isEmpty(queueQueryInstances)) {

					User poster = flowInstanceManager.getFlowInstance().getPoster();
					FlowInstance flowInstance = (FlowInstance) flowInstanceManager.getFlowInstance();

					for (QueueQueryInstance queryInstance : queueQueryInstances) {

						log.info("Queue query instance detected " + queryInstance);

						if (queryInstance.getQueryInstanceDescriptor().isPopulated() && queryInstance.isAccepted()) {

							Queue queue = queryInstance.getQuery().getQueue();

							QueueSlot queueSlot = new QueueSlot();
							queueSlot.setQueue(queue);
							queueSlot.setAdded(now);
							queueSlot.setFlowInstanceID(flowInstance.getFlowInstanceID());

							if (flowInstance.getManagerDescription() != null) {
								queueSlot.getAttributeHandler().setAttribute(Constants.FLOW_INSTANCE_DESCRIPTION_ATTRIBUTE, flowInstance.getManagerDescription());
							}

							if (!StringUtils.isEmpty(queryInstance.getComment())) {

								ExternalMessage commentMessage = new ExternalMessage();
								commentMessage.setMessage(queryInstance.getComment());
								commentMessage.setType(ExternalMessageType.ENTRANCE);
								commentMessage.setAdded(event.getEvent().getAdded());
								commentMessage.setPoster(poster);

								queueSlot.addExternalMessage(commentMessage);
							}

							PrimaryContact primaryContact = null;

							List<ContactDetailQueryInstance> contactDetailQueryInstances = flowInstanceManager.getQueries(ContactDetailQueryInstance.class);

							if (!CollectionUtils.isEmpty(contactDetailQueryInstances)) {

								ContactDetailQueryInstance contactDetailQueryInstance = contactDetailQueryInstances.get(0);

								if (contactDetailQueryInstance.getQueryInstanceDescriptor().isPopulated()) {

									primaryContact = new PrimaryContact(contactDetailQueryInstance, poster);
								}

								if (contactDetailQueryInstances.size() > 1) {

									log.warn("Flow " + flowInstance.getFlow() + " contains multiple " + ContactDetailQueryInstance.class + " queries.");
								}
							}

							if (primaryContact == null) {

								primaryContact = new PrimaryContact(poster);
							}

							queueSlot.setPrimaryContact(primaryContact);

							List<QueueSlotEvent> events = new ArrayList<>();

							List<FlowInstanceEvent> flowInstanceEvents = getFlowInstanceEvents(flowInstance);

							if (flowInstanceEvents != null) {

								for (FlowInstanceEvent flowInstanceEvent : flowInstanceEvents) {

									if (flowInstanceEvent.getEventType() == EventType.PAYED) {

										if (flowInstanceEvent.getAttributeHandler() != null && flowInstanceEvent.getAttributeHandler().getPrimitiveBoolean("directPayment")) {

											queueSlot.setLastPaymentDate(flowInstanceEvent.getAdded());
											events.add(new QueueSlotEvent(flowInstanceEvent));

										} else {

											events.add(new QueueSlotEvent(flowInstanceEvent));
										}
									}
								}
							}

							events.add(new QueueSlotEvent(now, poster, com.nordicpeak.flowengine.queue.enums.QueueSlotEventType.SUBMITTED, StringUtils.isEmpty(queryInstance.getComment()) ? null : eventSubmittedWithCommentMessage, null));

							queueSlot.setEvents(events);

							//Secondary contact
							if (secondaryContactFirstnameAttribute != null && secondaryContactLastnameAttribute != null && secondaryContactCitizenIdentifierAttribute != null) {

								String secondaryContactFirstname = flowInstance.getAttributeHandler().getString(secondaryContactFirstnameAttribute);
								String secondaryContactLastname = flowInstance.getAttributeHandler().getString(secondaryContactLastnameAttribute);
								String secondaryContactCitizenIdentifier = flowInstance.getAttributeHandler().getString(secondaryContactCitizenIdentifierAttribute);

								if (secondaryContactFirstname != null && secondaryContactLastname != null && secondaryContactCitizenIdentifier != null) {

									InternalMessage secondaryContactMessage = new InternalMessage();

									secondaryContactMessage.setMessage(secondaryContactInternalMessagePrefix + " " + secondaryContactFirstname + " " + secondaryContactLastname + " " + secondaryContactCitizenIdentifier);
									secondaryContactMessage.setAdded(event.getEvent().getAdded());

									ArrayList<InternalMessage> internalMessages = new ArrayList<>(1);
									internalMessages.add(secondaryContactMessage);
									queueSlot.setInternalMessages(internalMessages);
								}
							}

							TransactionHandler transactionHandler = null;

							try {
								transactionHandler = queueSlotDAO.createTransaction();

								ObjectQuery<Integer> daoQuery = transactionHandler.getObjectQuery("SELECT MAX(queueIndex) FROM " + queueSlotDAO.getTableName() + " WHERE queueID = ?", IntegerPopulator.getPopulator());
								daoQuery.setInt(1, queue.getQueueID());

								queueSlot.setQueueIndex(1 + daoQuery.executeQuery());

								HighLevelQuery<QueueSlot> highLevelQuery = new HighLevelQuery<>(QueueSlot.EVENTS_RELATION, QueueSlot.CONTACT_RELATION, QueueSlot.INTERNAL_MESSAGES_RELATION, QueueSlot.EXTERNAL_MESSAGES_RELATION, QueueSlot.ATTRIBUTES_RELATION);
								queueSlotDAO.add(queueSlot, transactionHandler, highLevelQuery);

								transactionHandler.commit();
								systemInterface.getEventHandler().sendEvent(QueueSlot.class, new CRUDEvent<>(CRUDAction.ADD, queueSlot), EventTarget.ALL);

								log.info("Added user " + poster + " to queue " + queue + " as " + queueSlot);

							} finally {
								TransactionHandler.autoClose(transactionHandler);
							}
						}
					}
				}
			}

		} catch (Exception e) {

			log.error("Error ", e);
		}
	}

	protected List<FlowInstanceEvent> getFlowInstanceEvents(FlowInstance flowInstance) throws SQLException {

		HighLevelQuery<FlowInstanceEvent> query = new HighLevelQuery<>(FlowInstanceEvent.ATTRIBUTES_RELATION);

		query.addParameter(flowInstanceEventFlowInstanceParamFactory.getParameter(flowInstance));

		return flowInstanceEventDAO.getAll(query);
	}

	public boolean isActiveMemberOfQueue(Queue queue, String citizenIdentifier) throws SQLException {

		return QueueUtils.isActiveMemberOfQueue(dataSource, queue, citizenIdentifier);
	}

	public LocalDate getWaitingPeriodDate(Queue queue, String citizenIdentifier) throws SQLException {

		return QueueUtils.getLatestWaitingDate(dataSource, queue, citizenIdentifier);

	}

	@EventListener(channel = QueueSlot.class)
	public void processEvent(ExternalMessageAddedEvent event, EventSource eventSource) throws SQLException {

		QueueSlot queueSlot = event.getQueueSlot();
		Queue queue = queueSlot.getQueue();

		Contact contact = getContact(queueSlot);

		if (event.getSenderType() == SenderType.MANAGER) {

			if (queue.isSendExternalMessageReceivedUserEmail() || queue.isSendExternalMessageReceivedUserSMS()) {

				if (contact != null) {

					if (queue.isSendExternalMessageReceivedUserEmail()) {

						event.setEmailNotificationSent(sendContactEmail(queueSlot, contact, externalMessageReceivedUserEmailSubject, externalMessageReceivedUserEmailMessage, null));
					}

					if (queue.isSendExternalMessageReceivedUserSMS()) {

						event.setSmsNotificationSent(sendContactSMS(queueSlot, contact, externalMessageReceivedUserSMS));
					}
				}
			}

		} else if (event.getSenderType() == SenderType.USER) {

			if (queue.isSendExternalMessageReceivedManagerEmail()) {

				sendManagerEmails(queueSlot, contact, externalMessageReceivedManagerEmailSubject, externalMessageReceivedManagerEmailMessage, null);
			}

			if (queue.isSendExternalMessageReceivedGlobalEmail() && queue.getExternalMessageReceivedGlobalEmailAddresses() != null) {

				for (String email : queue.getExternalMessageReceivedGlobalEmailAddresses()) {

					sendGlobalEmail(queueSlot, contact, email, externalMessageReceivedGlobalEmailSubject, externalMessageReceivedGlobalEmailMessage);
				}
			}

		} else {

			log.warn("External message added event received with unsupported sender type: " + event.getSenderType());
		}
	}

	@EventListener(channel = QueueSlot.class)
	public void processEvent(QueueSlotManuallyAddedEvent event, EventSource source) {

		try {
			if (source.isLocal()) {

				QueueSlot queueSlot = event.getQueueSlot();
				Queue queue = queueSlot.getQueue();

				if (queue.isSendEnteredUserEmail() || queue.isSendEnteredUserSMS()) {

					QueueUtils.getCalculatedQueuePosition(dataSource, queueSlot);

					Contact contact = getContact(queueSlot);

					if (contact != null) {

						if (queue.isSendEnteredUserEmail()) {

							sendContactEmail(queueSlot, contact, manualEntranceEmailSubject, manualEntranceEmailMessage, null);
						}

						if (queue.isSendEnteredUserSMS()) {

							sendContactSMS(queueSlot, contact, manualEntranceSMS);
						}
					}
				}
			}

		} catch (Exception e) {

			log.error("Error ", e);
		}
	}

	@EventListener(channel = QueueSlot.class)
	public void processEvent(QueueSlotRequestLeaveEvent event, EventSource source) {

		try {
			if (source.isLocal()) {

				QueueSlot queueSlot = event.getQueueSlot();
				Queue queue = queueSlot.getQueue();

				if (queue.isSendExitRequestUserEmail() || queue.isSendExitRequestUserSMS() || queue.isSendExitRequestManagerEmail() || queue.isSendExitRequestGlobalEmail()) {

					Contact contact = getContact(queueSlot);

					if (contact != null) {

						if (queue.isSendExitRequestUserEmail()) {

							sendContactEmail(queueSlot, contact, exitRequestUserEmailSubject, exitRequestUserEmailMessage, null);
						}

						if (queue.isSendExitRequestUserSMS()) {

							sendContactSMS(queueSlot, contact, exitRequestUserSMS);
						}

						if (queue.isSendExitRequestManagerEmail()) {

							sendManagerEmails(queueSlot, contact, exitRequestManagerEmailSubject, exitRequestManagerEmailMessage, null);
						}

						if (queue.isSendExitRequestGlobalEmail() && queue.getExitRequestGlobalEmailAddresses() != null) {

							for (String email : queue.getExitRequestGlobalEmailAddresses()) {

								sendGlobalEmail(queueSlot, contact, email, exitRequestGlobalEmailSubject, exitRequestGlobalEmailMessage);
							}
						}
					}
				}
			}

		} catch (Exception e) {

			log.error("Error ", e);
		}
	}

	@EventListener(channel = QueueSlot.class)
	public void processEvent(QueueSlotArchiveEvent event, EventSource source) {

		try {
			if (source.isLocal()) {

				QueueSlot queueSlot = event.getQueueSlot();
				Queue queue = queueSlot.getQueue();

				Contact contact = getContact(queueSlot);

				if (contact != null) {

					sendContactEmail(queueSlot, contact, exitUserEmailSubject, exitUserEmailMessage, null);

					if (queue.isSendExitUserSMS()) {

						sendContactSMS(queueSlot, contact, exitUserSMS);
					}

					if (queue.isSendExitManagerEmail()) {

						sendManagerEmails(queueSlot, contact, exitManagerEmailSubject, exitManagerEmailMessage, null);
					}

					if (queue.isSendExitGlobalEmail() && queue.getExitGlobalEmailAddresses() != null) {

						for (String email : queue.getExitGlobalEmailAddresses()) {

							sendGlobalEmail(queueSlot, contact, email, exitGlobalEmailSubject, exitGlobalEmailMessage);
						}
					}
				}
			}

		} catch (Exception e) {

			log.error("Error ", e);
		}
	}

	public boolean sendContactEmail(QueueSlot queueSlot, Contact contact, String subject, String message, List<Attachment> attachments) {

		if (!contact.isContactByEmail() || contact.getEmail() == null || subject == null || message == null) {

			return false;
		}

		if (queueSlot.getQueue() == null) {

			log.warn("Queue slot queue is not set");
		}

		TagReplacer tagReplacer = new TagReplacer();

		tagReplacer.addTagSource(QUEUE_SLOT_TAG_SOURCE_FACTORY.getTagSource(queueSlot));
		tagReplacer.addTagSource(QUEUE_TAG_SOURCE_FACTORY.getTagSource(queueSlot.getQueue()));
		tagReplacer.addTagSource(CONTACT_TAG_SOURCE_FACTORY.getTagSource(contact));
		tagReplacer.addTagSource(new SingleTagSource("$queueSlot.url", getUserQueueSlotModuleAlias(queueSlot) + "/overview/" + queueSlot.getQueueSlotID()));
		tagReplacer.addTagSource(new SingleTagSource("$queueSlot.messagesUrl", getUserQueueSlotModuleAlias(queueSlot) + "/messages/" + queueSlot.getQueueSlotID()));

		SimpleEmail email = new SimpleEmail(systemInterface.getEncoding());

		try {
			email.addRecipient(contact.getEmail());
			email.setMessageContentType(SimpleEmail.HTML);

			setEmailSender(email, queueSlot.getQueue());

			email.setSubject(replaceTags(subject, tagReplacer, queueSlot));

			email.setMessage(EmailUtils.addMessageBody(replaceTags(message, tagReplacer, queueSlot)));

			if (!CollectionUtils.isEmpty(attachments)) {

				for (Attachment attachment : attachments) {

					email.add(attachment);
				}
			}

			systemInterface.getEmailHandler().send(email);
			return true;

		} catch (Exception e) {

			log.info("Error generating/sending email " + email, e);
		}

		return false;
	}

	public boolean sendContactSMS(QueueSlot queueSlot, Contact contact, String message) {

		return sendContactSMS(queueSlot, contact, message, false);
	}

	public boolean sendContactSMS(QueueSlot queueSlot, Contact contact, String message, boolean alwaysSend) {

		if ((!contact.isContactBySMS() && !alwaysSend) || contact.getMobilePhone() == null || smsSender == null || message == null) {

			return false;
		}

		if (queueSlot.getQueue() == null) {

			log.warn("Queue slot queue is not set");
		}

		TagReplacer tagReplacer = new TagReplacer();

		tagReplacer.addTagSource(QUEUE_SLOT_TAG_SOURCE_FACTORY.getTagSource(queueSlot));
		tagReplacer.addTagSource(QUEUE_TAG_SOURCE_FACTORY.getTagSource(queueSlot.getQueue()));
		tagReplacer.addTagSource(CONTACT_TAG_SOURCE_FACTORY.getTagSource(contact));
		tagReplacer.addTagSource(new SingleTagSource("$queueSlot.url", getUserQueueSlotModuleAlias(queueSlot) + "/overview/" + queueSlot.getQueueSlotID()));
		tagReplacer.addTagSource(new SingleTagSource("$queueSlot.messagesUrl", getUserQueueSlotModuleAlias(queueSlot) + "/messages/" + queueSlot.getQueueSlotID()));

		SimpleSMS sms = new SimpleSMS();

		try {
			sms.setSenderName(getSmsSenderName(queueSlot));
			sms.setMessage(replaceTags(message, tagReplacer, queueSlot));
			sms.addRecipient(contact.getMobilePhone());

			return smsSender.send(sms);

		} catch (Exception e) {

			log.info("Error generating/sending sms " + sms, e);
		}

		return false;
	}

	public ExternalMessage sendContactExternalMessage(QueueSlot queueSlot, Contact contact, boolean postedByManager, User user, String externalMessage, List<ExternalMessageAttachment> attachements) throws SQLException {

		if (contact == null || user == null || externalMessage == null) {

			return null;
		}

		TagReplacer tagReplacer = new TagReplacer();

		ExternalMessage message = new ExternalMessage();
		message.setAdded(TimeUtils.getCurrentTimestamp());
		message.setQueueSlot(queueSlot);
		message.setMessage(replaceTags(externalMessage, tagReplacer, queueSlot));
		message.setPostedByManager(postedByManager);
		message.setPoster(user);

		if (!CollectionUtils.isEmpty(attachements)) {

			List<ExternalMessageAttachment> attachementCopy = new ArrayList<>(attachements.size());

			for (ExternalMessageAttachment attachement : attachements) {

				attachementCopy.add(new ExternalMessageAttachment(attachement));
			}

			message.setAttachments(attachementCopy);
		}

		extrernalMessageDAO.add(message);

		return message;
	}

	public void sendManagerEmails(QueueSlot queueSlot, Contact contact, String subject, String message, List<User> excludedManagers) throws SQLException {

		if (subject == null || message == null) {

			return;
		}

		if (queueSlot.getQueue() == null) {

			log.warn("Queue slot queue is not set");
		}

		List<User> managers = new ArrayList<>();

		if (!CollectionUtils.isEmpty(queueSlot.getQueue().getManagerUserIDs())) {

			List<User> users = getUserHandler().getUsers(queueSlot.getQueue().getManagerUserIDs(), false, true);

			if (users != null) {
				managers.addAll(users);
			}
		}

		if (!CollectionUtils.isEmpty(queueSlot.getQueue().getManagerGroupIDs())) {

			List<User> users = getUserHandler().getUsersByGroups(queueSlot.getQueue().getManagerGroupIDs(), true);

			if (users != null) {
				managers.addAll(users);
			}
		}

		if (managers == null || excludedManagers != null && excludedManagers.containsAll(managers)) {

			return;
		}

		if (excludedManagers != null) {

			managers.removeAll(excludedManagers);
		}

		List<TagSource> sharedTagSources = new ArrayList<>(4);

		sharedTagSources.add(QUEUE_SLOT_TAG_SOURCE_FACTORY.getTagSource(queueSlot));
		sharedTagSources.add(QUEUE_TAG_SOURCE_FACTORY.getTagSource(queueSlot.getQueue()));
		sharedTagSources.add(new SingleTagSource("$queue.url", getQueueSlotAdminModuleAlias(queueSlot) + "/list/" + queueSlot.getQueue().getQueueID()));
		sharedTagSources.add(new SingleTagSource("$queueSlot.url", getQueueSlotAdminModuleAlias(queueSlot) + "/show/" + queueSlot.getQueueSlotID()));
		sharedTagSources.add(new SingleTagSource("$queueSlot.messagesUrl", getQueueSlotAdminModuleAlias(queueSlot) + "/messages/" + queueSlot.getQueueSlotID()));

		if (contact != null) {

			sharedTagSources.add(CONTACT_TAG_SOURCE_FACTORY.getTagSource(contact));
		}

		for (User manager : managers) {

			if (!StringUtils.isEmpty(manager.getEmail())) {

				TagReplacer tagReplacer = new TagReplacer();

				tagReplacer.addTagSource(MANAGER_TAG_SOURCE_FACTORY.getTagSource(manager));
				tagReplacer.addTagSources(sharedTagSources);

				SimpleEmail email = new SimpleEmail(systemInterface.getEncoding());

				try {
					email.addRecipient(manager.getEmail());
					email.setMessageContentType(SimpleEmail.HTML);

					setEmailSender(email, queueSlot.getQueue());

					email.setSubject(replaceTags(subject, tagReplacer, queueSlot));
					email.setMessage(EmailUtils.addMessageBody(replaceTags(message, tagReplacer, queueSlot)));

					systemInterface.getEmailHandler().send(email);

				} catch (Exception e) {

					log.info("Error generating/sending email " + email, e);
				}
			}
		}
	}

	public void sendGlobalEmail(QueueSlot queueSlot, Contact contact, String address, String subject, String message) {

		if (subject == null || message == null) {

			return;
		}

		TagReplacer tagReplacer = new TagReplacer();

		tagReplacer.addTagSource(QUEUE_SLOT_TAG_SOURCE_FACTORY.getTagSource(queueSlot));
		tagReplacer.addTagSource(QUEUE_TAG_SOURCE_FACTORY.getTagSource(queueSlot.getQueue()));
		tagReplacer.addTagSource(new SingleTagSource("$queue.url", getQueueSlotAdminModuleAlias(queueSlot) + "/list/" + queueSlot.getQueue().getQueueID()));
		tagReplacer.addTagSource(new SingleTagSource("$queueSlot.url", getQueueSlotAdminModuleAlias(queueSlot) + "/show/" + queueSlot.getQueueSlotID()));
		tagReplacer.addTagSource(new SingleTagSource("$queueSlot.messagesUrl", getQueueSlotAdminModuleAlias(queueSlot) + "/messages/" + queueSlot.getQueueSlotID()));

		if (contact != null) {

			tagReplacer.addTagSource(CONTACT_TAG_SOURCE_FACTORY.getTagSource(contact));
		}

		SimpleEmail email = new SimpleEmail(systemInterface.getEncoding());

		try {
			email.addRecipient(address);
			email.setMessageContentType(SimpleEmail.HTML);

			setEmailSender(email, queueSlot.getQueue());

			email.setSubject(replaceTags(subject, tagReplacer, queueSlot));
			email.setMessage(EmailUtils.addMessageBody(replaceTags(message, tagReplacer, queueSlot)));

			systemInterface.getEmailHandler().send(email);

		} catch (Exception e) {

			log.info("Error generating/sending email " + email, e);
		}

	}

	private Contact getContact(QueueSlot queueSlot) {

		return getContact(queueSlot, getUserHandler());
	}

	public static Contact getContact(QueueSlot queueSlot, UserHandler userHandler) {

		PrimaryContact primaryContact = queueSlot.getPrimaryContact();
		User poster = queueSlot.getPoster(userHandler);

		if (poster != null) {

			Contact contact = new Contact();

			contact.setFirstname(poster.getFirstname());
			contact.setLastname(poster.getLastname());
			contact.setEmail(poster.getEmail());
			contact.setCitizenIdentifier(primaryContact.getCitizenIdentifier());
			contact.setMobilePhone(UserUtils.getAttribute("mobilePhone", poster));
			contact.setAddress(UserUtils.getAttribute("address", poster));
			contact.setPostalAddress(UserUtils.getAttribute("postalAddress", poster));
			contact.setZipCode(UserUtils.getAttribute("zipCode", poster));

			contact.setContactBySMS(UserUtils.getBooleanAttribute("contactBySMS", poster));
			contact.setContactByEmail(true);

			if (StringUtils.isEmpty(contact.getEmail())) {

				contact.setEmail(primaryContact.getEmail());
			}

			if (StringUtils.isEmpty(contact.getAddress())) {

				contact.setAddress(primaryContact.getAddress());
				contact.setPostalAddress(primaryContact.getPostalAddress());
				contact.setZipCode(primaryContact.getZipCode());
			}

			return contact;
		}

		ManualContact manualContact = queueSlot.getManualContact();

		if (manualContact != null) {

			Contact contact = new Contact();

			contact.setFirstname(manualContact.getFirstname());
			contact.setLastname(manualContact.getLastname());
			contact.setEmail(manualContact.getEmail());
			contact.setMobilePhone(manualContact.getMobilePhone());
			contact.setCitizenIdentifier(primaryContact.getCitizenIdentifier());
			contact.setAddress(manualContact.getAddress());
			contact.setPostalAddress(manualContact.getPostalAddress());
			contact.setZipCode(manualContact.getZipCode());

			if (StringUtils.isEmpty(contact.getFirstname())) {

				contact.setFirstname(primaryContact.getFirstname());
			}

			if (StringUtils.isEmpty(contact.getLastname())) {

				contact.setLastname(primaryContact.getLastname());
			}

			if (StringUtils.isEmpty(contact.getEmail())) {

				contact.setEmail(primaryContact.getEmail());
			}

			if (StringUtils.isEmpty(contact.getMobilePhone())) {

				contact.setMobilePhone(primaryContact.getMobilePhone());
			}

			if (StringUtils.isEmpty(contact.getAddress())) {

				contact.setAddress(primaryContact.getAddress());
			}

			if (StringUtils.isEmpty(contact.getPostalAddress())) {

				contact.setPostalAddress(primaryContact.getPostalAddress());
			}

			if (StringUtils.isEmpty(contact.getZipCode())) {

				contact.setZipCode(primaryContact.getZipCode());
			}

			contact.setContactByEmail(true);

			return contact;
		}

		Contact contact = new Contact();

		contact.setFirstname(primaryContact.getFirstname());
		contact.setLastname(primaryContact.getLastname());
		contact.setEmail(primaryContact.getEmail());
		contact.setCitizenIdentifier(primaryContact.getCitizenIdentifier());
		contact.setMobilePhone(primaryContact.getMobilePhone());
		contact.setAddress(primaryContact.getAddress());
		contact.setPostalAddress(primaryContact.getPostalAddress());
		contact.setZipCode(primaryContact.getZipCode());

		contact.setContactByEmail(true);

		return contact;
	}

	public String getPaymentRequestSMS() {

		return paymentRequestSMS;
	}

	public String getPaymentRequestEmailSubject() {

		return paymentRequestEmailSubject;
	}

	public String getPaymentRequestEmailMessage() {

		return paymentRequestEmailMessage;
	}

	public String getPaymentCompleteUserSMS() {

		return paymentCompleteUserSMS;
	}

	public String getPaymentCompleteUserEmailSubject() {

		return paymentCompleteUserEmailSubject;
	}

	public String getPaymentCompleteUserEmailMessage() {

		return paymentCompleteUserEmailMessage;
	}

	public String getPaymentDirectGlobalEmailSubject() {

		return paymentDirectGlobalEmailSubject;
	}

	public String getPaymentDirectGlobalEmailMessage() {

		return paymentDirectGlobalEmailMessage;
	}

	public String getPaymentDirectManagerEmailSubject() {

		return paymentDirectManagerEmailSubject;
	}

	public String getPaymentDirectManagerEmailMessage() {

		return paymentDirectManagerEmailMessage;
	}

	public String getPaymentInvoiceManagerEmailSubject() {

		return paymentInvoiceManagerEmailSubject;
	}

	public String getPaymentInvoiceManagerEmailMessage() {

		return paymentInvoiceManagerEmailMessage;
	}

	public String getPaymentInvoiceGlobalEmailSubject() {

		return paymentInvoiceGlobalEmailSubject;
	}

	public String getPaymentInvoiceGlobalEmailMessage() {

		return paymentInvoiceGlobalEmailMessage;
	}

	public String getDefaultEventPaymentInvoiceMessage() {

		return defaultEventPaymentInvoiceMessage;
	}

	public PaymentProvider getPaymentProvider() {

		return paymentProvider;
	}

	public Integer getModuleID() {

		return moduleDescriptor.getModuleID();
	}

	public String replaceTags(String template, TagReplacer tagReplacer, QueueSlot queueSlot) {

		template = AttributeTagUtils.replaceTags(tagReplacer.replace(template), queueSlot.getAttributeHandler());

		if (queueSlot.getQueue().getProfileID() != null) {

			SiteProfile profile = siteProfileHandler.getProfile(queueSlot.getQueue().getProfileID());

			template = TextTagReplacer.replaceTextTags(template, profile.getSettingHandler());
		}

		return template;

	}

	public String getUserQueueSlotModuleAlias(QueueSlot queueSlot) {

		if (enableProfileSupport && siteProfileHandler != null && queueSlot.getQueue().getProfileID() != null) {

			ProfileSettingHandler settingHandler = siteProfileHandler.getProfileSettingHandler(queueSlot.getQueue().getProfileID());

			if (settingHandler != null) {

				return settingHandler.getString("userQueueSlotModuleAliasSetting");
			}
		}

		return userQueueSlotModuleAlias;
	}

	private String getSmsSenderName(QueueSlot queueSlot) {

		if (enableProfileSupport && siteProfileHandler != null && queueSlot.getQueue().getProfileID() != null) {

			ProfileSettingHandler settingHandler = siteProfileHandler.getProfileSettingHandler(queueSlot.getQueue().getProfileID());

			if (settingHandler != null) {

				return settingHandler.getString("smsSenderNameSetting");
			}
		}

		return notificationHandler.getSMSSenderName(null);
	}

	private String getQueueSlotAdminModuleAlias(QueueSlot queueSlot) {

		if (enableProfileSupport && siteProfileHandler != null && queueSlot.getQueue().getProfileID() != null) {

			ProfileSettingHandler settingHandler = siteProfileHandler.getProfileSettingHandler(queueSlot.getQueue().getProfileID());

			if (settingHandler != null) {

				return settingHandler.getString("queueSlotAdminModuleAliasSetting");
			}
		}

		return queueSlotAdminModuleAlias;
	}

	public boolean isEnableProfileSupport() {

		return enableProfileSupport;
	}

	public void setEnableProfileSupport(boolean enableProfileSupport) {

		this.enableProfileSupport = enableProfileSupport;
	}

	public SiteProfileHandler getSiteProfileHandler() {

		return siteProfileHandler;
	}

	@Override
	public List<Setting> getSiteProfileSettings() {

		return profileSettings;
	}

	@Override
	public List<Setting> getSiteSubProfileSettings() {

		return null;
	}

	@Override
	public String getModuleName() {

		return moduleDescriptor.getName();
	}

	@Override
	public ExtensionLink getPaymentConfigurationExtensionLink(String configurationID) throws PaymentConfigurationIDNotUsed {

		if (!configurationID.startsWith("queue-")) {
			return null;
		}

		Integer queueID = NumberUtils.toInt(configurationID.substring("queue-".length()));

		if (queueID != null) {

			try {
				Queue queue = getQueue(queueID);

				if (queue != null && queue.getPrice() != null && queue.getPrice() > 0) {

					return new ExtensionLink(queue.getName(), getFullAlias(), null, null);

				} else {
					throw new PaymentConfigurationIDNotUsed();
				}

			} catch (SQLException e) {
				log.error("Error getting queue for configurationID " + configurationID, e);
			}
		}

		return null;
	}

	public List<Queue> getQueues(User user, Field... relations) throws SQLException {

		return getQueues(user, user.getGroups(), relations);
	}

	public List<Queue> getQueues(User user, Collection<Group> groups, Field... relations) throws SQLException {

		if (user == null && CollectionUtils.isEmpty(groups)) {
			throw new NullPointerException("user and groups may not both be null");
		}

		StringBuilder sql = new StringBuilder();

		sql.append("SELECT q.* FROM " + queueDAO.getTableName() + " q");

		if (user != null) {
			sql.append(" LEFT JOIN queue_manager_users u ON u.queueID = q.queueID");
		}

		if (!CollectionUtils.isEmpty(groups)) {
			sql.append(" LEFT JOIN queue_manager_groups g ON g.queueID = q.queueID");
		}

		sql.append(" WHERE q.enabled = 1 AND (");

		if (user != null) {

			sql.append("u.userID = ?");
		}

		if (!CollectionUtils.isEmpty(groups)) {

			if (user != null) {
				sql.append(" OR ");
			}

			sql.append("g.groupID IN (" + DBUtils.getPreparedStatementQuestionMarks(groups) + ")");
		}

		sql.append(") GROUP by q.queueID");

		LowLevelQuery<Queue> query = new LowLevelQuery<>(sql.toString());

		if (user != null) {
			query.addParameter(user.getUserID());
		}

		if (!CollectionUtils.isEmpty(groups)) {
			for (Group group : groups) {

				query.addParameter(group.getGroupID());
			}
		}

		if (relations != null) {

			query.addRelations(relations);
		}

		return queueDAO.getAll(query);
	}

	@InstanceManagerDependency
	public void setUserGroupAdminExtensionHandler(UserGroupAdminExtensionHandler userGroupAdminExtensionHandler) {

		if (this.userGroupAdminExtensionHandler != null) {

			this.userGroupAdminExtensionHandler.removeUserAdminExtensionProvider(this);
			this.userGroupAdminExtensionHandler.removeGroupAdminExtensionProvider(this);
		}

		this.userGroupAdminExtensionHandler = userGroupAdminExtensionHandler;

		if (userGroupAdminExtensionHandler != null) {

			userGroupAdminExtensionHandler.addUserAdminExtensionProvider(this);
			userGroupAdminExtensionHandler.addGroupAdminExtensionProvider(this);
		}
	}

	@Override
	public ViewFragment getUserAdminExtensionViewFragment(User requestedUser, HttpServletRequest req, URIParser uriParser, User user) throws Exception {

		Document doc = createDocument(req, uriParser, user);

		Element extensionElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "QueueUserAdminExtension");

		List<Queue> queues = getQueues(requestedUser);

		if (queues != null) {

			Element queuesElement = XMLUtils.appendNewElement(doc, extensionElement, "Queues");

			for (Queue queue : queues) {

				Element queueElement = XMLUtils.appendNewElement(doc, queuesElement, "Queue");

				XMLUtils.appendNewElement(doc, queueElement, "queueID", queue.getQueueID());
				XMLUtils.appendNewElement(doc, queueElement, "name", queue.getName());
			}

			XMLUtils.appendNewElement(doc, extensionElement, "QueueAdminURL", req.getContextPath() + getSectionDescriptor().getFullAlias() + "/" + this.moduleDescriptor.getAlias());

			return viewFragmentTransformer.createViewFragment(doc);
		}

		return null;
	}

	@Override
	public ViewFragment getGroupAdminExtensionViewFragment(Group requestedGroup, HttpServletRequest req, URIParser uriParser, User user) throws Exception {

		Document doc = createDocument(req, uriParser, user);

		Element extensionElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "QueueUserAdminExtension");

		List<Queue> queues = getQueues(null, Collections.singletonList(requestedGroup));

		if (queues != null) {

			Element queuesElement = XMLUtils.appendNewElement(doc, extensionElement, "Queues");

			for (Queue queue : queues) {

				Element queueElement = XMLUtils.appendNewElement(doc, queuesElement, "Queue");

				XMLUtils.appendNewElement(doc, queueElement, "queueID", queue.getQueueID());
				XMLUtils.appendNewElement(doc, queueElement, "name", queue.getName());
			}

			XMLUtils.appendNewElement(doc, extensionElement, "QueueAdminURL", req.getContextPath() + getSectionDescriptor().getFullAlias() + "/" + this.moduleDescriptor.getAlias());

			return viewFragmentTransformer.createViewFragment(doc);
		}

		return null;
	}

	@Override
	public int getPriority() {

		return 3;
	}

	@Override
	public ForegroundModuleDescriptor getModuleDescriptor() {

		return moduleDescriptor;
	}

	@Override
	public List<LinkTag> getLinkTags() {

		return null;
	}

	@Override
	public List<ScriptTag> getScriptTags() {

		return null;
	}
	
	public void setEmailSender(SimpleEmail email, Queue queue) throws InvalidEmailAddressException {
		
		if (allowEmailSenderOverride) {

			email.setSenderName(ObjectUtils.getFirstNotNull(queue.getEmailSenderName(), notificationHandler.getEmailSenderName(null)));
			email.setSenderAddress(ObjectUtils.getFirstNotNull(queue.getEmailSenderAddress(), notificationHandler.getEmailSenderAddress(null)));

		} else {

			email.setSenderName(notificationHandler.getEmailSenderName(null));
			email.setSenderAddress(notificationHandler.getEmailSenderAddress(null));
		}
	}
}
