package com.nordicpeak.flowengine.queue;

import java.io.IOException;
import java.io.Serializable;
import java.lang.reflect.Field;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.EventListener;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.CRUDAction;
import se.unlogic.hierarchy.core.enums.EventSource;
import se.unlogic.hierarchy.core.enums.EventTarget;
import se.unlogic.hierarchy.core.events.CRUDEvent;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.exceptions.ModuleConfigurationException;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.interfaces.AccessInterface;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.ViewFragment;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.UserUtils;
import se.unlogic.hierarchy.core.utils.ViewFragmentUtils;
import se.unlogic.hierarchy.core.utils.crud.FragmentLinkScriptFilter;
import se.unlogic.hierarchy.core.utils.extensionlinks.ExtensionLink;
import se.unlogic.hierarchy.foregroundmodules.rest.RESTMethod;
import se.unlogic.hierarchy.foregroundmodules.rest.URIParam;
import se.unlogic.openhierarchy.foregroundmodules.siteprofile.interfaces.SiteProfile;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.LowLevelQuery;
import se.unlogic.standardutils.io.BinarySizeFormater;
import se.unlogic.standardutils.io.BinarySizes;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.Constants;
import com.nordicpeak.flowengine.UserFlowInstanceMenuModule;
import com.nordicpeak.flowengine.beans.Contact;
import com.nordicpeak.flowengine.enums.SenderType;
import com.nordicpeak.flowengine.interfaces.UserMenuProvider;
import com.nordicpeak.flowengine.queue.beans.ExternalMessage;
import com.nordicpeak.flowengine.queue.beans.Queue;
import com.nordicpeak.flowengine.queue.beans.QueueSlot;
import com.nordicpeak.flowengine.queue.beans.QueueSlotEvent;
import com.nordicpeak.flowengine.queue.beans.QueueSlotPaymentCallback;
import com.nordicpeak.flowengine.queue.enums.ExternalMessageType;
import com.nordicpeak.flowengine.queue.enums.QueueSlotEventType;
import com.nordicpeak.flowengine.queue.events.ExternalMessageAddedEvent;
import com.nordicpeak.flowengine.queue.events.QueueSlotArchiveEvent;
import com.nordicpeak.flowengine.queue.events.QueueSlotRequestLeaveEvent;
import com.nordicpeak.flowengine.utils.CitizenIdentifierUtils;
import com.nordicpeak.openhierarchy.payment.enums.PaymentType;
import com.nordicpeak.openhierarchy.payment.events.DelayedPaymentEvent;
import com.nordicpeak.openhierarchy.payment.interfaces.Invoice;
import com.nordicpeak.openhierarchy.payment.interfaces.PaymentProvider;
import com.nordicpeak.openhierarchy.payment.interfaces.PaymentResponse;

public class UserQueueSlotModule extends BaseQueueSlotModule implements UserMenuProvider {

	private final Comparator<QueueSlot> QUEUE_SLOT_QUEUE_NAME_COMPARATOR = new QueueSlotQueueNameComparator();

	@XSLVariable(prefix = "java.")
	private String userMenuTabTitle = "My queues";

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Payment invoice title", description = "The title for the invoice.", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentInvoiceTitle;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Payment invoice description", description = "The description for what the user is paying for.", required = true)
	@XSLVariable(prefix = "java.")
	private String paymentInvoiceDescription;

	@ModuleSetting
	@TextFieldSettingDescriptor(name = "User menu item slot", description = "User menu item slot")
	protected String userMenuExtensionLinkSlot = "40";

	protected AnnotatedDAOWrapper<QueueSlot, Integer> queueSlotDAOWrapper;

	@InstanceManagerDependency
	protected PaymentProvider paymentProvider;

	@InstanceManagerDependency(required = true)
	protected QueueAdminModule queueAdminModule;

	protected UserFlowInstanceMenuModule userFlowInstanceMenuModule;

	protected ExtensionLink userMenuLink;

	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {

		super.init(moduleDescriptor, sectionInterface, dataSource);

		if (!systemInterface.getInstanceHandler().addInstance(UserQueueSlotModule.class, this)) {

			throw new RuntimeException("Unable to register module " + this.moduleDescriptor + " in global instance handler using key " + UserQueueSlotModule.class.getSimpleName() + ", another instance is already registered using this key.");
		}
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		super.createDAOs(dataSource);

		queueSlotDAOWrapper = queueSlotDAO.getWrapper(Integer.class);
	}

	@Override
	public void unload() throws Exception {

		systemInterface.getInstanceHandler().removeInstance(UserQueueSlotModule.class, this);

		if (userFlowInstanceMenuModule != null) {

			setUserFlowInstanceMenuModule(null);
		}

		super.unload();
	}

	@Override
	protected void moduleConfigured() throws Exception {

		super.moduleConfigured();

		this.userMenuLink = new ExtensionLink(userMenuTabTitle, getFullAlias(), ">", userMenuExtensionLinkSlot);

		if (userFlowInstanceMenuModule != null) {

			userFlowInstanceMenuModule.sortProviders();
		}
	}

	@InstanceManagerDependency
	public void setUserFlowInstanceMenuModule(UserFlowInstanceMenuModule userFlowInstanceMenuModule) {

		if (userFlowInstanceMenuModule == null && this.userFlowInstanceMenuModule != null) {

			this.userFlowInstanceMenuModule.removeUserMenuProvider(this);
		}

		this.userFlowInstanceMenuModule = userFlowInstanceMenuModule;

		if (this.userFlowInstanceMenuModule != null) {

			this.userFlowInstanceMenuModule.addUserMenuProvider(this);
		}
	}

	@Override
	public ForegroundModuleResponse defaultMethod(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws SQLException, AccessDeniedException {

		if (user == null) {

			throw new AccessDeniedException("User needs to be logged in");
		}

		log.info("User " + user + " listing queue slots");

		Document doc = createDocument(req, uriParser, user);

		Element userQueueSlots = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "ListUserQueueSlots");

		XMLUtils.append(doc, userQueueSlots, getUserQueueSlots(user));

		return new SimpleForegroundModuleResponse(doc, moduleDescriptor.getName(), getDefaultBreadcrumb());
	}

	@RESTMethod(alias = "overview/{queueSlotID}", method = { "get", "post" }, requireLogin = true)
	public ForegroundModuleResponse showQueueSlotOverview(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, @URIParam(name = "queueSlotID") Integer queueSlotID) throws SQLException, URINotFoundException, IOException {

		QueueSlot queueSlot = getQueueSlot(user, queueSlotID, QueueSlot.EXTERNAL_MESSAGES_RELATION, ExternalMessage.ATTACHMENTS_RELATION, ExternalMessage.QUOTED_MESSAGE_RELATION);

		if (queueSlot == null) {

			throw new URINotFoundException(uriParser);
		}

		log.info("User " + user + " requested queue slot " + queueSlot);

		Document doc = createDocument(req, uriParser, user);

		Element showQueueSlotOverview = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "ShowQueueSlotOverview");

		if (isReverseOrderMessages() && queueSlot.getExternalMessages() != null) {

			Collections.reverse(queueSlot.getExternalMessages());
			XMLUtils.appendNewElement(doc, showQueueSlotOverview, "DefaultMessageOrder", "DESC");
		}

		showQueueSlotOverview.appendChild(queueSlot.toXML(doc));

		XMLUtils.appendNewElement(doc, showQueueSlotOverview, "FormatedMaxExternalMessageFileSize", BinarySizeFormater.getFormatedSize(maxMessageFileSize * BinarySizes.MegaByte));

		if (req.getParameter("requestedleave") != null) {

			XMLUtils.appendNewElement(doc, showQueueSlotOverview, "RequestedLeave");
		}

		if (req.getMethod().equalsIgnoreCase("POST")) {

			//TODO append message or request parameters
			ExternalMessage externalMessage = externalMessageCRUD.add(req, res, uriParser, user, doc, showQueueSlotOverview, queueSlot, false);

			if (externalMessage != null) {

				queueSlot = getQueueSlot(user, queueSlotID, QueueSlot.EXTERNAL_MESSAGES_RELATION, ExternalMessage.ATTACHMENTS_RELATION, Queue.MANAGER_USERS_RELATION, Queue.MANAGER_GROUPS_RELATION);

				QueueSlotEvent queueSlotEvent = addQueueSlotEvent(queueSlot, QueueSlotEventType.CUSTOMER_MESSAGE_SENT, null, user, null, null);

				getEventHandler().sendEvent(QueueSlot.class, new ExternalMessageAddedEvent(queueSlot, queueSlotEvent, externalMessage, SenderType.USER), EventTarget.ALL);
				getEventHandler().sendEvent(ExternalMessage.class, new CRUDEvent<>(CRUDAction.ADD, externalMessage), EventTarget.ALL);

				res.sendRedirect(req.getContextPath() + uriParser.getFormattedURI() + "#messages");

				return null;
			}
		}

		return new SimpleForegroundModuleResponse(doc, moduleDescriptor.getName(), getDefaultBreadcrumb());
	}

	@WebPublic(alias = "messages")
	public ForegroundModuleResponse showQueueSlotMessages(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws ModuleConfigurationException, SQLException, AccessDeniedException, IOException, URINotFoundException {

		if (uriParser.size() == 3 && NumberUtils.isInt(uriParser.get(2))) {

			redirectToMethod(req, res, "/overview/" + uriParser.get(2) + "#messages");

			return null;
		}

		throw new URINotFoundException(uriParser);
	}

	@RESTMethod(alias = "leavequeue/{queueSlotID}", method = "post", requireLogin = true)
	public ForegroundModuleResponse leaveQueue(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, @URIParam(name = "queueSlotID") Integer queueSlotID) throws SQLException, URINotFoundException, IOException {

		QueueSlot queueSlot = getQueueSlot(user, queueSlotID);

		if (queueSlot == null) {

			throw new URINotFoundException(uriParser);
		}

		if (!queueSlot.isArchived()) {

			String comment = req.getParameter("comment");

			if (queueSlot.getQueue().isLeavingRequiresManagerConfirmation()) {

				log.info("User " + user + " requesting leave queue slot " + queueSlot + " with reason: " + StringUtils.toLogFormat(comment, 50));

				addQueueSlotEvent(queueSlot, QueueSlotEventType.ARCHIVE_REQUEST, eventRequestLeaveMessage + (StringUtils.isEmpty(comment) ? "" : eventSeeExternalMessage), user, null, null);

				queueSlotDAO.update(queueSlot);

				if (!StringUtils.isEmpty(comment)) {
					addQueueSlotExternalMessage(queueSlot, comment, false, user, ExternalMessageType.ARCHIVE_REQUEST, null);
				}

				getEventHandler().sendEvent(QueueSlot.class, new CRUDEvent<>(CRUDAction.UPDATE, queueSlot), EventTarget.ALL);
				getEventHandler().sendEvent(QueueSlot.class, new QueueSlotRequestLeaveEvent(queueSlot, user, comment), EventTarget.ALL);

				redirectToMethod(req, res, "/overview/" + queueSlot.getQueueSlotID() + "?requestedleave=1");
				return null;

			} else {

				log.info("User " + user + " archiving queue slot " + queueSlot + " with reason: " + StringUtils.toLogFormat(comment, 50));

				addQueueSlotEvent(queueSlot, QueueSlotEventType.ARCHIVED, eventLeaveMessage + (StringUtils.isEmpty(comment) ? "" : eventSeeExternalMessage), user, null, null);

				queueSlot.setArchived(true);
				queueSlotDAO.update(queueSlot);

				if (!StringUtils.isEmpty(comment)) {
					addQueueSlotExternalMessage(queueSlot, comment, false, user, ExternalMessageType.ARCHIVE_BY_USER, null);
				}

				getEventHandler().sendEvent(QueueSlot.class, new CRUDEvent<>(CRUDAction.UPDATE, queueSlot), EventTarget.ALL);
				getEventHandler().sendEvent(QueueSlot.class, new QueueSlotArchiveEvent(queueSlot, user), EventTarget.ALL);

				redirectToDefaultMethod(req, res);
				return null;
			}
		}

		redirectToDefaultMethod(req, res);
		return null;
	}

	private QueueSlot getQueueSlot(User user, Integer queueSlotID, Field... relations) throws SQLException {

		String citizenIdentifier = CitizenIdentifierUtils.getUserOrManagerCitizenIdentifier(user);

		if (citizenIdentifier == null) {

			return null;
		}

		LowLevelQuery<QueueSlot> query = new LowLevelQuery<>("SELECT queue_slots.* FROM queue_slots INNER JOIN queue_slot_contacts ON queue_slots.queueSlotID = queue_slot_contacts.queueSlotID INNER JOIN queues ON queue_slots.queueID = queues.queueID WHERE queues.enabled = true AND queue_slots.queueSlotID = ? AND queue_slot_contacts.citizenIdentifier = ?");

		query.addRelations(QueueSlot.CONTACT_RELATION, QueueSlot.EVENTS_RELATION, QueueSlot.QUEUE_RELATION, QueueSlotEvent.ATTRIBUTES_RELATION, Queue.MANAGER_GROUPS_RELATION, Queue.MANAGER_USERS_RELATION, Queue.INTERNAL_GROUPS_RELATION);

		if (relations != null) {
			query.addRelations(relations);
		}

		query.addParameter(queueSlotID);
		query.addParameter(citizenIdentifier);

		QueueSlot queueSlot = queueSlotDAO.get(query);

		if (queueSlot != null) {

			QueueUtils.getCalculatedQueuePosition(dataSource, queueSlot);
		}

		return queueSlot;
	}

	private List<QueueSlot> getUserQueueSlots(User user) throws SQLException {

		boolean internalUser = false;

		String citizenIdentifier = UserUtils.getAttribute(Constants.USER_CITIZEN_IDENTIFIER_ATTRIBUTE, user);

		if (StringUtils.isEmpty(citizenIdentifier)) {

			citizenIdentifier = UserUtils.getAttribute(Constants.MANAGER_CITIZEN_IDENTIFIER_ATTRIBUTE, user);

			if (!StringUtils.isEmpty(citizenIdentifier)) {

				internalUser = true;
			}
		}

		if (citizenIdentifier == null) {

			return null;
		}

		LowLevelQuery<QueueSlot> query = new LowLevelQuery<>("SELECT queue_slots.* FROM queue_slots INNER JOIN queue_slot_contacts ON queue_slots.queueSlotID = queue_slot_contacts.queueSlotID INNER JOIN queues ON queue_slots.queueID = queues.queueID WHERE queues.enabled = true AND queue_slot_contacts.citizenIdentifier = ?");

		query.addRelations(QueueSlot.CONTACT_RELATION, QueueSlot.EVENTS_RELATION, QueueSlot.QUEUE_RELATION, Queue.INTERNAL_GROUPS_RELATION);

		query.addParameter(citizenIdentifier);

		List<QueueSlot> queueSlots = queueSlotDAO.getAll(query);

		if (queueSlots != null) {

			for (QueueSlot queueSlot : queueSlots) {

				QueueUtils.getCalculatedQueuePosition(dataSource, queueSlot);
			}

			Collections.sort(queueSlots, QUEUE_SLOT_QUEUE_NAME_COMPARATOR);

			internalGroupFilter(queueSlots, user, internalUser);
		}

		return queueSlots;
	}

	private void internalGroupFilter(List<QueueSlot> queueSlots, User user, boolean internalUser) {

		for (Iterator<QueueSlot> it = queueSlots.iterator(); it.hasNext();) {

			QueueSlot queueSlot = it.next();

			if (!queueSlot.getQueue().isUseQueueForInternalUsers()) {

				continue;
			}

			List<Integer> internalGroupIDs = queueSlot.getQueue().getInternalGroupIDs();

			if (!CollectionUtils.isEmpty(internalGroupIDs)) {

				List<Integer> userGroupIDs = UserUtils.getUserGroupIDs(user);

				if (CollectionUtils.isEmpty(userGroupIDs) || Collections.disjoint(internalGroupIDs, userGroupIDs) || !internalUser) {

					it.remove();
				}
			}
		}
	}

	@RESTMethod(alias = "pay/{queueSlotID}", method = { "get", "post" }, requireLogin = true)
	public ForegroundModuleResponse payForQueueSlot(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, @URIParam(name = "queueSlotID") Integer queueSlotID) throws Exception {

		QueueSlot queueSlot = getQueueSlot(user, queueSlotID);

		if (queueSlot == null) {

			throw new URINotFoundException(uriParser);
		}

		if (queueSlot.getPendingPaymentRequestDate() == null || queueSlot.isArchived()) {

			redirectToMethod(req, res, "/overview/" + queueSlot.getQueueSlotID());
			return null;

		} else {

			log.info("User " + user + " requesting payment form for queue slot " + queueSlot);

			return showPaymentForm(req, res, user, uriParser, queueSlot, null);
		}
	}

	private ForegroundModuleResponse showPaymentForm(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, QueueSlot queueSlot, List<ValidationError> validationErrors) throws Exception {

		if (queueSlot.getPendingPaymentRequestDate() == null) {

			redirectToMethod(req, res, "/overview/" + queueSlot.getQueueSlotID());
			return null;

		} else {

			if (paymentProvider == null) {
				throw new ModuleConfigurationException("paymentProvider is null");
			}

			Document doc = createDocument(req, uriParser, user);

			Element paymentElement = XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "Payment");

			Invoice invoice = queueSlot.getPaymentInvoice(this);

			ViewFragment viewFragment = paymentProvider.showPaymentForm(queueSlot.getQueue().getPaymentConfigurationID(), invoice, req, user, uriParser, new QueueSlotPaymentCallback(this, queueSlot, getSiteName(user, req, uriParser), req), validationErrors);

			paymentElement.appendChild(queueSlot.toXML(doc));
			paymentElement.appendChild(invoice.toXML(doc));
			paymentElement.appendChild(viewFragment.toXML(doc));
			FragmentLinkScriptFilter.addViewFragment(viewFragment, req);

			SimpleForegroundModuleResponse response = new SimpleForegroundModuleResponse(doc, moduleDescriptor.getName(), getDefaultBreadcrumb());
			ViewFragmentUtils.appendLinksAndScripts(response, viewFragment);

			return response;
		}
	}

	private String getSiteName(User user, HttpServletRequest req, URIParser uriParser) {

		String siteName = null;

		if (queueAdminModule.getSiteProfileHandler() != null) {

			SiteProfile siteProfile = queueAdminModule.getSiteProfileHandler().getCurrentProfile(user, req, uriParser);

			if (siteProfile != null) {

				siteName = siteProfile.getName();
			}
		}

		return siteName;
	}

	@RESTMethod(alias = "processPayment/{queueSlotID}", method = { "post", "get" }, requireLogin = true)
	public ForegroundModuleResponse processPayment(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, @URIParam(name = "queueSlotID") Integer queueSlotID) throws Exception {

		QueueSlot queueSlot = getQueueSlot(user, queueSlotID);

		if (queueSlot == null) {

			throw new URINotFoundException(uriParser);
		}

		if (queueSlot.getPendingPaymentRequestDate() == null || queueSlot.isArchived()) {

			redirectToMethod(req, res, "/overview/" + queueSlot.getQueueSlotID());
			return null;

		} else {

			if (paymentProvider == null) {
				throw new ModuleConfigurationException("paymentProvider is null");
			}

			log.info("User " + user + " processing payment for queue slot " + queueSlot);

			List<ValidationError> validationErrors = null;

			try {
				PaymentResponse paymentResponse = paymentProvider.processPayment(queueSlot.getQueue().getPaymentConfigurationID(), queueSlot.getPaymentInvoice(this), req, res, user, uriParser, new QueueSlotPaymentCallback(this, queueSlot, getSiteName(user, req, uriParser), req));

				if (res.isCommitted()) {
					return null;
				}

				if (paymentResponse != null) {

					if (paymentResponse.getPaymentType() == PaymentType.DIRECT || paymentResponse.getPaymentType() == PaymentType.INVOICE) {

						log.info("User " + user + " payed for queue slot " + queueSlot);

						Timestamp now = new Timestamp(System.currentTimeMillis());

						if (paymentResponse.getPaymentType() == PaymentType.DIRECT) {

							queueSlot.setLastPaymentDate(now);
							queueSlot.setPendingPaymentRequestDate(null);
							queueSlot.addEvent(new QueueSlotEvent(now, user, QueueSlotEventType.PAYED, getEventPaymentDirectMessage() + " " + paymentProvider.getProviderName() + " (" + paymentResponse.getPaymentAmount().toPlainString() + " " + paymentResponse.getCurrencyCode() + ")", paymentResponse.getPaymentAttributes()));

						} else if (paymentResponse.getPaymentType() == PaymentType.INVOICE) {

							queueSlot.setPendingPaymentRequestDate(null);
							queueSlot.addEvent(new QueueSlotEvent(now, user, QueueSlotEventType.PAYED, queueSlot.getQueue().getEventPaymentInvoiceMessage() + " (" + paymentResponse.getPaymentAmount().toPlainString() + " " + paymentResponse.getCurrencyCode() + ")", paymentResponse.getPaymentAttributes()));
						}

						HighLevelQuery<QueueSlot> query = new HighLevelQuery<>(QueueSlot.EVENTS_RELATION, QueueSlotEvent.ATTRIBUTES_RELATION);
						queueSlotDAO.update(queueSlot, query);

						getEventHandler().sendEvent(QueueSlot.class, new CRUDEvent<Serializable>(CRUDAction.UPDATE, queueSlot), EventTarget.ALL);

						sendPaymentNotification(queueSlot, paymentResponse.getPaymentType());

						redirectToMethod(req, res, "/overview/" + queueSlot.getQueueSlotID());
						return null;

					} else {

						throw new Exception("Unknown payment type: " + paymentResponse + " for queue slot " + queueSlot);
					}

				} else {

					log.warn("Payment failed");
				}

			} catch (ValidationException e) {

				validationErrors = new ArrayList<>();
				validationErrors.addAll(e.getErrors());
			}

			return showPaymentForm(req, res, user, uriParser, queueSlot, validationErrors);
		}
	}

	@EventListener(channel = PaymentProvider.class)
	public void processDelayedPaymentEvent(DelayedPaymentEvent paymentEvent, EventSource source) {

		PaymentResponse paymentResponse = paymentEvent.getPaymentResponse();
		User user = paymentEvent.getUser();
		Timestamp now = paymentEvent.getTimestamp();

		try {
			if ("queueslot".equals(paymentEvent.getSourceType())) {

				Integer queueSlotID = paymentEvent.getSourceID();
				QueueSlot queueSlot = getQueueSlot(user, queueSlotID);

				if (queueSlot == null) {

					//TODO send email for missing queue slot
					log.error("Got delayed payment event for queue slot ID " + queueSlotID + " which does not exist");

				} else {

					if (queueSlot.getPendingPaymentRequestDate() == null) {

						log.error("Got delayed payment event for queue slot " + queueSlotID + " which has no payment request");

					} else {

						if (paymentResponse.getPaymentType() == PaymentType.DIRECT || paymentResponse.getPaymentType() == PaymentType.INVOICE) {

							log.info("User " + user + " completed delayed payment of queue slot " + queueSlot);

							queueSlot.setLastPaymentDate(now);
							queueSlot.setPendingPaymentRequestDate(null);
							queueSlot.addEvent(new QueueSlotEvent(now, user, QueueSlotEventType.PAYED, getEventPaymentDirectMessage() + " " + paymentProvider.getProviderName() + " (" + paymentResponse.getPaymentAmount().toPlainString() + " " + paymentResponse.getCurrencyCode() + ")", paymentResponse.getPaymentAttributes()));

							HighLevelQuery<QueueSlot> query = new HighLevelQuery<>(QueueSlot.EVENTS_RELATION, QueueSlotEvent.ATTRIBUTES_RELATION);
							queueSlotDAO.update(queueSlot, query);

							getEventHandler().sendEvent(QueueSlot.class, new CRUDEvent<Serializable>(CRUDAction.UPDATE, queueSlot), EventTarget.ALL);

							sendPaymentNotification(queueSlot, PaymentType.DIRECT);

						} else {

							throw new Exception("Unknown payment type: " + paymentResponse + " for queue slot " + queueSlot);
						}
					}
				}
			}
		} catch (Exception e) {

			log.error("Error handling delayed payment for " + paymentEvent, e);
		}
	}

	protected void sendPaymentNotification(QueueSlot queueSlot, PaymentType paymentType) throws SQLException {

		Contact contact = QueueAdminModule.getContact(queueSlot, getUserHandler());

		if (paymentType == PaymentType.DIRECT) {

			log.info("Sending payment received message to queue slot " + queueSlot);

			if (queueSlot.getQueue().isSendPaymentCompleteUserEmail() && contact.isContactByEmail() && !StringUtils.isEmpty(contact.getEmail())) {

				queueAdminModule.sendContactEmail(queueSlot, contact, queueAdminModule.getPaymentCompleteUserEmailSubject(), queueAdminModule.getPaymentCompleteUserEmailMessage(), null);
			}

			if (queueSlot.getQueue().isSendPaymentCompleteUserSMS() && contact.isContactBySMS() && !StringUtils.isEmpty(contact.getMobilePhone())) {

				queueAdminModule.sendContactSMS(queueSlot, contact, queueAdminModule.getPaymentCompleteUserSMS());
			}

			if (queueSlot.getQueue().isSendPaymentCompleteManagerEmail()) {

				queueAdminModule.sendManagerEmails(queueSlot, contact, queueAdminModule.getPaymentDirectManagerEmailSubject(), queueAdminModule.getPaymentDirectManagerEmailMessage(), null);
			}

			if (queueSlot.getQueue().isSendPaymentCompleteGlobalEmail() && queueSlot.getQueue().getPaymentCompleteGlobalEmailAddresses() != null) {

				for (String email : queueSlot.getQueue().getPaymentCompleteGlobalEmailAddresses()) {

					queueAdminModule.sendGlobalEmail(queueSlot, contact, email, queueAdminModule.getPaymentDirectGlobalEmailSubject(), queueAdminModule.getPaymentDirectGlobalEmailMessage());
				}
			}

		} else if (paymentType == PaymentType.INVOICE) {

			if (queueSlot.getQueue().isSendPaymentCompleteManagerEmail()) {

				queueAdminModule.sendManagerEmails(queueSlot, contact, queueAdminModule.getPaymentInvoiceManagerEmailSubject(), queueAdminModule.getPaymentInvoiceManagerEmailMessage(), null);
			}

			if (queueSlot.getQueue().isSendPaymentCompleteGlobalEmail() && queueSlot.getQueue().getPaymentCompleteGlobalEmailAddresses() != null) {

				for (String email : queueSlot.getQueue().getPaymentCompleteGlobalEmailAddresses()) {

					queueAdminModule.sendGlobalEmail(queueSlot, contact, email, queueAdminModule.getPaymentInvoiceGlobalEmailSubject(), queueAdminModule.getPaymentInvoiceGlobalEmailMessage());
				}
			}
		}
	}

	@Override
	public Document createDocument(HttpServletRequest req, URIParser uriParser, User user) {

		Document doc = super.createDocument(req, uriParser, user);

		XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "ModuleURL", uriParser.getContextPath() + getFullAlias());
		return doc;
	}

	public String getPaymentInvoiceDescription() {

		return paymentInvoiceDescription;
	}

	public String getPaymentInvoiceTitle() {

		return paymentInvoiceTitle;
	}

	@Override
	public AccessInterface getAccessInterface() {

		return moduleDescriptor;
	}

	@Override
	public String getUserMenuAlias() {

		return getFullAlias();
	}

	@Override
	public ExtensionLink getUserMenuExtensionLink(User user) {

		return userMenuLink;
	}

	@Override
	public String getUserMenuPriority() {

		return userMenuExtensionLinkSlot;
	}
}
