package com.nordicpeak.flowengine.queue.beans;

import java.io.Serializable;
import java.sql.Timestamp;
import java.util.List;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.enums.Order;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;

public abstract class BaseMessage extends GeneratedElementable implements Serializable {

	private static final long serialVersionUID = 5587221770250423388L;

	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	protected Integer messageID;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 65535)
	@XMLElement
	protected String message;

	@DAOManaged(dontUpdateIfNull = true)
	@XMLElement(name = "poster")
	protected User poster;

	@DAOManaged
	@OrderBy(order = Order.ASC)
	@XMLElement
	protected Timestamp added;

	@DAOManaged(dontUpdateIfNull = true)
	@XMLElement(name = "editor")
	protected User editor;

	@DAOManaged
	@XMLElement
	protected Timestamp updated;

	public abstract List<? extends BaseAttachment> getAttachments();

	public Integer getMessageID() {

		return messageID;
	}

	public void setMessageID(Integer messageID) {

		this.messageID = messageID;
	}

	public String getMessage() {

		return message;
	}

	public void setMessage(String message) {

		this.message = message;
	}

	public User getPoster() {

		return poster;
	}

	public void setPoster(User poster) {

		this.poster = poster;
	}

	public Timestamp getAdded() {

		return added;
	}

	public void setAdded(Timestamp added) {

		this.added = added;
	}

	public User getEditor() {

		return editor;
	}

	public void setEditor(User editor) {

		this.editor = editor;
	}

	public Timestamp getUpdated() {

		return updated;
	}

	public void setUpdated(Timestamp updated) {

		this.updated = updated;
	}

	public abstract QueueSlot getQueueSlot();

	@Override
	public String toString() {

		return StringUtils.toLogFormat(message, 50) + " (ID: " + messageID + ")";
	}
}
