package com.nordicpeak.flowengine.queue.beans;

import java.lang.reflect.Field;
import java.util.List;

import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.queue.enums.ExternalMessageType;

@Table(name = "queue_slot_external_messages")
@XMLElement
public class ExternalMessage extends BaseMessage {

	private static final long serialVersionUID = -5166683291745202612L;

	public static final Field ATTACHMENTS_RELATION = ReflectionUtils.getField(ExternalMessage.class, "attachments");
	public static final Field QUEUE_SLOT_RELATION = ReflectionUtils.getField(ExternalMessage.class, "queueSlot");
	public static final Field QUOTED_MESSAGE_RELATION = ReflectionUtils.getField(ExternalMessage.class, "quotedMessage");

	@DAOManaged(columnName = "queueSlotID")
	@ManyToOne
	@XMLElement
	private QueueSlot queueSlot;

	@DAOManaged
	@XMLElement
	private boolean postedByManager;

	@DAOManaged
	@XMLElement
	private ExternalMessageType type;

	@DAOManaged
	@OneToMany(autoAdd = true)
	@XMLElement
	private List<ExternalMessageAttachment> attachments;

	@DAOManaged(columnName = "quotedMessageID")
	@ManyToOne(autoAdd = true)
	@XMLElement(name = "QuotedMessage")
	private ExternalMessage quotedMessage;

	@DAOManaged
	@OneToMany
	private List<ExternalMessage> quotedByMessages;

	@Override
	public List<ExternalMessageAttachment> getAttachments() {

		return attachments;
	}

	public void setAttachments(List<ExternalMessageAttachment> attachments) {

		this.attachments = attachments;
	}

	@Override
	public QueueSlot getQueueSlot() {

		return queueSlot;
	}

	public void setQueueSlot(QueueSlot flowInstance) {

		this.queueSlot = flowInstance;
	}

	public boolean isPostedByManager() {

		return postedByManager;
	}

	public void setPostedByManager(boolean postedByManager) {

		this.postedByManager = postedByManager;
	}

	public ExternalMessageType getType() {

		return type;
	}

	public void setType(ExternalMessageType eventType) {

		this.type = eventType;
	}

	public ExternalMessage getQuotedMessage() {

		return quotedMessage;
	}

	public void setQuotedMessage(ExternalMessage quotedMessage) {

		this.quotedMessage = quotedMessage;
	}

}
