package com.nordicpeak.flowengine.queue.beans;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.handlers.SourceAttributeHandler;
import se.unlogic.hierarchy.core.handlers.UserHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeSource;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.hierarchy.core.utils.UserUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.OneToOne;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.enums.Order;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.StringTag;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLGeneratorDocument;
import se.unlogic.standardutils.xml.XMLUtils;

import com.nordicpeak.flowengine.Constants;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.queue.QueueUtils;
import com.nordicpeak.flowengine.queue.UserQueueSlotModule;
import com.nordicpeak.openhierarchy.payment.beans.SimpleInvoice;
import com.nordicpeak.openhierarchy.payment.beans.SimpleInvoiceLine;
import com.nordicpeak.openhierarchy.payment.interfaces.Invoice;

@Table(name = "queue_slots")
@XMLElement
public class QueueSlot extends GeneratedElementable implements Serializable, AttributeSource {

	private static final long serialVersionUID = 9041413820791856640L;

	public static final Field EVENTS_RELATION = ReflectionUtils.getField(QueueSlot.class, "events");
	public static final Field QUEUE_RELATION = ReflectionUtils.getField(QueueSlot.class, "queue");
	public static final Field CONTACT_RELATION = ReflectionUtils.getField(QueueSlot.class, "primaryContact");
	public static final Field MANUAL_CONTACT_RELATION = ReflectionUtils.getField(QueueSlot.class, "manualContact");
	public static final Field INTERNAL_MESSAGES_RELATION = ReflectionUtils.getField(QueueSlot.class, "internalMessages");
	public static final Field EXTERNAL_MESSAGES_RELATION = ReflectionUtils.getField(QueueSlot.class, "externalMessages");
	public static final Field ATTRIBUTES_RELATION = ReflectionUtils.getField(QueueSlot.class, "attributes");

	public static final Field SKIP_USER_ATTRIBUTES = ReflectionUtils.getField(QueueSlot.class,"SKIP_USER_ATTRIBUTES");
	
	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	private Integer queueSlotID;

	@DAOManaged(columnName = "queueID")
	@ManyToOne
	@XMLElement
	private Queue queue;

	@DAOManaged
	@OrderBy(order = Order.ASC)
	@XMLElement
	private Integer queueIndex;

	@DAOManaged
	@XMLElement
	private Integer flowInstanceID;

	@DAOManaged
	@StringTag
	@XMLElement
	private Timestamp added;

	@DAOManaged
	@XMLElement
	private Timestamp updated;

	@DAOManaged
	@StringTag
	@XMLElement
	private Timestamp lastPaymentDate;

	@DAOManaged
	@StringTag
	@XMLElement
	private Timestamp pendingPaymentRequestDate;

	@DAOManaged
	@OneToMany
	@XMLElement(fixCase = true)
	private List<QueueSlotEvent> events;

	@XMLElement
	private FlowInstance flowInstance;

	@StringTag
	@XMLElement
	private Integer position;

	@DAOManaged
	@OneToOne
	@XMLElement(name = "PrimaryContact")
	private PrimaryContact primaryContact;

	@DAOManaged
	@OneToOne
	@XMLElement(name = "ManualContact")
	private ManualContact manualContact;

	@DAOManaged
	@XMLElement
	private boolean archived;

	@DAOManaged
	@XMLElement
	private Timestamp archivedDate;
	
	@DAOManaged
	@XMLElement
	private Timestamp waitingPeriodTime;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<InternalMessage> internalMessages;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<ExternalMessage> externalMessages;

	@DAOManaged
	@OneToMany
	@XMLElement(fixCase = true)
	private List<QueueSlotAttribute> attributes;
	
	private SourceAttributeHandler attributeHandler;

	private User poster;

	public Integer getQueueSlotID() {

		return queueSlotID;
	}

	public void setQueueSlotID(Integer queueSlotID) {

		this.queueSlotID = queueSlotID;
	}

	public Queue getQueue() {

		return queue;
	}

	public void setQueue(Queue queue) {

		this.queue = queue;
	}

	public Integer getQueueIndex() {

		return queueIndex;
	}

	public void setQueueIndex(Integer queueIndex) {

		this.queueIndex = queueIndex;
	}

	public Integer getFlowInstanceID() {

		return flowInstanceID;
	}

	public void setFlowInstanceID(Integer flowInstanceID) {

		this.flowInstanceID = flowInstanceID;
	}

	public Timestamp getAdded() {

		return added;
	}

	public void setAdded(Timestamp added) {

		this.added = added;
	}

	public Timestamp getUpdated() {

		return updated;
	}

	public void setUpdated(Timestamp updated) {

		this.updated = updated;
	}

	public Timestamp getLastPaymentDate() {

		return lastPaymentDate;
	}

	public void setLastPaymentDate(Timestamp lastPaymentDate) {

		this.lastPaymentDate = lastPaymentDate;
	}

	public List<QueueSlotEvent> getEvents() {

		return events;
	}

	public void setEvents(List<QueueSlotEvent> events) {

		this.events = events;
	}

	public FlowInstance getFlowInstanceXMLOnly() {

		return flowInstance;
	}

	public void setFlowInstanceXMLOnly(FlowInstance flowInstance) {

		this.flowInstance = flowInstance;
	}

	public Integer getCalculatedPosition() {

		return position;
	}

	public void setCalculatedPosition(Integer position) {

		this.position = position;
	}

	public PrimaryContact getPrimaryContact() {

		return primaryContact;
	}

	public void setPrimaryContact(PrimaryContact primaryContact) {

		this.primaryContact = primaryContact;
	}

	public ManualContact getManualContact() {

		return manualContact;
	}

	public void setManualContact(ManualContact secondaryContact) {

		this.manualContact = secondaryContact;
	}

	public List<InternalMessage> getInternalMessages() {

		return internalMessages;
	}

	public void setInternalMessages(List<InternalMessage> internalMessages) {

		this.internalMessages = internalMessages;
	}

	public List<ExternalMessage> getExternalMessages() {

		return externalMessages;
	}

	public void setExternalMessages(List<ExternalMessage> externalMessages) {

		this.externalMessages = externalMessages;
	}

	public boolean isArchived() {

		return archived;
	}

	public void setArchived(boolean archived) {

		this.archived = archived;
		this.archivedDate = archived ? new Timestamp(System.currentTimeMillis()) : null;
	}

	public Timestamp getArchivedDate() {

		return archivedDate;
	}
	
	public void setWaitingPeriodTime(Timestamp waitingPeriodTime) {
		this.waitingPeriodTime = waitingPeriodTime;
	}
	
	public Timestamp getWaitingPeriodTime() {
		return this.waitingPeriodTime;
	}

	
	public Timestamp getPendingPaymentRequestDate() {

		return pendingPaymentRequestDate;
	}

	public void setPendingPaymentRequestDate(Timestamp pendingPaymentRequestDate) {

		this.pendingPaymentRequestDate = pendingPaymentRequestDate;
	}

	@Override
	public String toString() {

		if (queue != null) {

			if (position != null) {

				return position + " (ID: " + queueSlotID + ") in " + queue;
			}

			return "(ID: " + queueSlotID + ")" + " in " + queue;
		}

		if (queueSlotID != null) {

			return "(ID: " + queueSlotID + ")";
		}

		return null;
	}

	public User getPoster(UserHandler userHandler) {

		if (poster == null && userHandler != null) {

			if (queue.isUseQueueForInternalUsers() && !CollectionUtils.isEmpty(queue.getInternalGroupIDs())) {

				poster = userHandler.getUserByAttribute(Constants.MANAGER_CITIZEN_IDENTIFIER_ATTRIBUTE, getPrimaryContact().getCitizenIdentifier(), false, true);

			} else {

				poster = userHandler.getUserByAttribute(Constants.USER_CITIZEN_IDENTIFIER_ATTRIBUTE, getPrimaryContact().getCitizenIdentifier(), false, true);

				if (poster == null) {

					poster = userHandler.getUserByAttribute(Constants.MANAGER_CITIZEN_IDENTIFIER_ATTRIBUTE, getPrimaryContact().getCitizenIdentifier(), false, true);
				}
			}
		}

		return poster;
	}

	public void setPosterFromPrimaryContactCitizenIdentifier(User poster) {

		this.poster = poster;
	}

	@Override
	public Element toXML(Document doc) {

		Element element = super.toXML(doc);

		if (poster != null) {

			boolean skipUserAttributes = doc instanceof XMLGeneratorDocument && ((XMLGeneratorDocument)doc).isIgnoredField(SKIP_USER_ATTRIBUTES);
			
			Element posterElement = XMLUtils.appendNewElement(doc, element, "Poster");
			UserUtils.appendUsers(doc, posterElement, Collections.singletonList(poster), !skipUserAttributes);
		}
		
		if(waitingPeriodTime != null) {
			XMLUtils.appendNewElement(doc, element, "waitingPeriod", new SimpleDateFormat("yyyy-MM-dd").format(waitingPeriodTime));
		}

		return element;
	}

	public Element toXML(Document doc, UserHandler userHandler) {

		getPoster(userHandler);

		Element element = toXML(doc);

		if (QueueUtils.isDigitalMember(this, userHandler)) {

			XMLUtils.appendNewElement(doc, element, "Digital");
		}

		return element;
	}

	public Invoice getPaymentInvoice(UserQueueSlotModule userQueueSlotModule) {

		List<SimpleInvoiceLine> invoiceLines = new ArrayList<>();

		invoiceLines.add(new SimpleInvoiceLine(1, queue.getPrice(), userQueueSlotModule.getPaymentInvoiceDescription(), "kr"));

		return new SimpleInvoice("queueslot", queueSlotID, "queue-slot-" + queueSlotID + "-" + pendingPaymentRequestDate.getTime(), userQueueSlotModule.getPaymentInvoiceTitle() + " " + queue.getName(), userQueueSlotModule.getPaymentInvoiceTitle() + " " + queue.getName(), invoiceLines);
	}

	public void addEvent(QueueSlotEvent event) {

		if (events == null) {

			events = new ArrayList<>();
		}

		events.add(event);
	}

	public void addExternalMessage(ExternalMessage externalMessage) {

		if (externalMessages == null) {

			externalMessages = new ArrayList<>();
		}

		externalMessages.add(externalMessage);
	}

	@Override
	public List<QueueSlotAttribute> getAttributes() {

		return attributes;
	}

	public void setAttributes(List<QueueSlotAttribute> attributes) {

		this.attributes = attributes;
	}

	@Override
	public void addAttribute(String name, String value) {

		if (this.attributes == null) {

			attributes = new ArrayList<>();
		}

		attributes.add(new QueueSlotAttribute(name, value));
	}

	public synchronized MutableAttributeHandler getAttributeHandler() {

		if (attributeHandler == null) {

			this.attributeHandler = new SourceAttributeHandler(this, 255, 65536);
		}

		return attributeHandler;
	}
}
