package com.nordicpeak.flowengine.queue.beans;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.handlers.SourceAttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeSource;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.OrderBy;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.beans.FlowInstanceEvent;
import com.nordicpeak.flowengine.queue.enums.QueueSlotEventType;

@Table(name = "queue_slot_events")
@XMLElement
public class QueueSlotEvent extends GeneratedElementable implements Serializable, AttributeSource {

	private static final long serialVersionUID = -7272910298485758740L;

	public static final Field QUEUE_SLOT_RELATION = ReflectionUtils.getField(QueueSlotEvent.class, "queueSlot");
	public static final Field ATTRIBUTES_RELATION = ReflectionUtils.getField(QueueSlotEvent.class, "attributes");

	@DAOManaged(autoGenerated = true)
	@Key
	@XMLElement
	private Integer eventID;

	@DAOManaged(columnName = "queueSlotID")
	@ManyToOne
	private QueueSlot queueSlot;

	@DAOManaged
	@OrderBy
	@XMLElement
	protected Timestamp added;

	@DAOManaged(dontUpdateIfNull = true)
	@XMLElement(name = "poster")
	protected User poster;

	@DAOManaged
	@XMLElement
	private QueueSlotEventType eventType;

	@DAOManaged
	@XMLElement
	protected String details;

	@DAOManaged
	@OneToMany
	@XMLElement(fixCase = true)
	private List<QueueSlotEventAttribute> attributes;

	private SourceAttributeHandler attributeHandler;

	public QueueSlotEvent() {}

	public QueueSlotEvent(Timestamp added, User poster, QueueSlotEventType eventType, String details, Map<String, String> attributes) {

		super();

		this.added = added;
		this.poster = poster;
		this.details = details;
		this.eventType = eventType;

		if (!CollectionUtils.isEmpty(attributes)) {

			for (Entry<String, String> attribute : attributes.entrySet()) {

				getAttributeHandler().setAttribute(attribute.getKey(), attribute.getValue());
			}
		}
	}

	public QueueSlotEvent(FlowInstanceEvent flowInstanceEvent) {

		added = flowInstanceEvent.getAdded();
		poster = flowInstanceEvent.getPoster();

		if (flowInstanceEvent.getEventType() == com.nordicpeak.flowengine.enums.EventType.PAYED) {

			eventType = QueueSlotEventType.PAYED;

		} else {

			eventType = QueueSlotEventType.OTHER;
		}

		details = flowInstanceEvent.getDetails();

		if (!CollectionUtils.isEmpty(flowInstanceEvent.getAttributes())) {

			for (Entry<String, String> attribute : flowInstanceEvent.getAttributeHandler().getAttributeMap().entrySet()) {

				getAttributeHandler().setAttribute(attribute.getKey(), attribute.getValue());
			}
		}
	}

	public Integer getEventID() {

		return eventID;
	}

	public void setEventID(Integer eventID) {

		this.eventID = eventID;
	}

	public Timestamp getAdded() {

		return added;
	}

	public void setAdded(Timestamp added) {

		this.added = added;
	}

	public User getPoster() {

		return poster;
	}

	public void setPoster(User poster) {

		this.poster = poster;
	}

	public String getDetails() {

		return details;
	}

	public void setDetails(String details) {

		this.details = details;
	}

	public QueueSlot getQueueSlot() {

		return queueSlot;
	}

	public void setQueueSlot(QueueSlot queueSlot) {

		this.queueSlot = queueSlot;
	}

	public QueueSlotEventType getEventType() {

		return eventType;
	}

	public void setEventType(QueueSlotEventType eventType) {

		this.eventType = eventType;
	}

	@Override
	public String toString() {

		return "(ID=" + eventID + ", queueSlot=" + queueSlot + ", added=" + added + ", poster=" + poster + ", details=" + details + ")";
	}

	@Override
	public List<QueueSlotEventAttribute> getAttributes() {

		return attributes;
	}

	public void setAttributes(List<QueueSlotEventAttribute> attributes) {

		this.attributes = attributes;
	}

	@Override
	public void addAttribute(String name, String value) {

		if (this.attributes == null) {

			attributes = new ArrayList<>();
		}

		attributes.add(new QueueSlotEventAttribute(name, value));
	}

	public synchronized MutableAttributeHandler getAttributeHandler() {

		if (attributeHandler == null) {

			this.attributeHandler = new SourceAttributeHandler(this, 255, 65536);
		}

		return attributeHandler;
	}

}
