package com.nordicpeak.flowengine.queue.cruds;

import java.io.IOException;
import java.lang.reflect.Field;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.fileuploadutils.MultipartRequest;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.time.TimeUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationErrorType;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.validation.ValidationUtils;

import com.nordicpeak.flowengine.interfaces.MessageCRUDCallback;
import com.nordicpeak.flowengine.queue.beans.ExternalMessage;
import com.nordicpeak.flowengine.queue.beans.ExternalMessageAttachment;
import com.nordicpeak.flowengine.queue.beans.QueueSlot;

public class ExternalMessageCRUD extends BaseMessageCRUD<ExternalMessage, ExternalMessageAttachment> {

	public ExternalMessageCRUD(AnnotatedDAO<ExternalMessage> messageDAO, AnnotatedDAO<ExternalMessageAttachment> attachmentDAO, MessageCRUDCallback callback, boolean manager) {

		super(messageDAO, attachmentDAO, callback, ExternalMessage.class, ExternalMessageAttachment.class, manager);
	}

	public ExternalMessage add(HttpServletRequest req, HttpServletResponse res, URIParser uriParser, User user, Document doc, Element element, QueueSlot queueSlot, boolean postedByManager) throws SQLException, IOException {

		List<ValidationError> errors = new ArrayList<>();

		req = parseRequest(req, errors);

		try {
			String message = ValidationUtils.validateParameter("externalmessage", req, true, 1, 65535, StringPopulator.getPopulator(), errors);

			List<ExternalMessageAttachment> attachments = getAttachments(req, user, errors);

			Integer quotedMessageID = ValidationUtils.validateParameter("quotedMessageID", req, false, PositiveStringIntegerPopulator.getPopulator(), errors);
			ExternalMessage quotedMessage = null;

			if (quotedMessageID != null) {

				HighLevelQuery<ExternalMessage> query = new HighLevelQuery<>(ExternalMessage.QUEUE_SLOT_RELATION);
				query.addParameter(messageIDParamFactory.getParameter(quotedMessageID));

				quotedMessage = messageDAO.get(query);

				if (quotedMessage == null || !quotedMessage.getQueueSlot().getQueueSlotID().equals(queueSlot.getQueueSlotID()) || quotedMessage.isPostedByManager() == postedByManager) {

					errors.add(new ValidationError("quotedMessageID", ValidationErrorType.InvalidFormat));
				}
			}

			if (errors.isEmpty()) {

				log.info("User " + user + " adding external message for flowinstance " + queueSlot);

				ExternalMessage externalMessage = new ExternalMessage();

				externalMessage.setQueueSlot(queueSlot);
				externalMessage.setPoster(user);
				externalMessage.setMessage(message);
				externalMessage.setAdded(TimeUtils.getCurrentTimestamp());
				externalMessage.setAttachments(attachments);
				externalMessage.setPostedByManager(postedByManager);
				externalMessage.setQuotedMessage(quotedMessage);

				messageDAO.add(externalMessage);

				return externalMessage;
			}

			XMLUtils.append(doc, element, errors);

			return null;

		} finally {

			if (req instanceof MultipartRequest) {

				((MultipartRequest) req).deleteFiles();
			}
		}

	}

	@Override
	protected Field getQueueSlotRelation() {

		return ExternalMessage.QUEUE_SLOT_RELATION;
	}

	@Override
	protected String getTypeLogName() {

		return "external";
	}

}
