package com.nordicpeak.flowengine.queue.query;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.w3c.dom.Document;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.beans.BasePaymentProduct;
import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.interfaces.PaymentProduct;
import com.nordicpeak.flowengine.interfaces.PaymentQuery;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesBaseQuery;
import com.nordicpeak.flowengine.queue.beans.Queue;

@Table(name = "queue_queries")
@XMLElement
public class QueueQuery extends FixedAlternativesBaseQuery implements PaymentQuery {

	public static final Field QUEUE_RELATION = ReflectionUtils.getField(QueueQuery.class, "queue");

	private static final Map<Integer, Integer> ALTERNATIVE_CONVERSION_MAP = Collections.singletonMap(1, 1);

	private static final long serialVersionUID = -842191226937409416L;

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryID;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String acceptText;

	@DAOManaged
	@WebPopulate(maxLength = 255)
	@XMLElement
	private String invoiceLineText;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private String paymentRequiredText;

	@DAOManaged
	@WebPopulate(maxLength = 50)
	@XMLElement
	private String alreadyMemberText;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean showCommentField;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean hideTitle;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean allowNextStepIfAlreadyMember;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<QueueQueryInstance> instances;

	@DAOManaged(columnName = "queueID")
	@ManyToOne
	@XMLElement
	private Queue queue;

	private QueueAlternative alternative;

	@Override
	public Integer getQueryID() {

		return queryID;
	}

	public List<QueueQueryInstance> getInstances() {

		return instances;
	}

	public void setInstances(List<QueueQueryInstance> instances) {

		this.instances = instances;
	}

	public Queue getQueue() {

		return queue;
	}

	public void setQueue(Queue queue) {

		this.queue = queue;
	}

	public void setQueryID(Integer queryID) {

		this.queryID = queryID;
	}

	public String getInvoiceLineText() {

		return invoiceLineText;
	}

	public void setInvoiceLineText(String invoiceLineText) {

		this.invoiceLineText = invoiceLineText;
	}

	public String getPaymentRequiredText() {

		return paymentRequiredText;
	}

	public void setPaymentRequiredText(String paymentRequiredText) {

		this.paymentRequiredText = paymentRequiredText;
	}

	public String getAlreadyMemberText() {

		return alreadyMemberText;
	}

	public void setAlreadyMemberText(String alreadyMemberText) {

		this.alreadyMemberText = alreadyMemberText;
	}

	@Override
	public String toString() {

		if (this.queryDescriptor != null) {

			return queryDescriptor.getName() + " (queryID: " + queryID + ")";
		}

		return "QueueQuery (queryID: " + queryID + ")";
	}

	@Override
	public String getXSDTypeName() {

		return "QueueQuery" + queryID;
	}

	@Override
	public void toXSD(Document doc) {

		//TODO missing attribute Accepted
		//QueueQuerys xml doesnt validate against xsd
		toXSD(doc, 1);
	}

	@Override
	public List<? extends ImmutableAlternative> getAlternatives() {

		return Collections.singletonList(alternative);
	}

	@Override
	public String getFreeTextAlternative() {

		return null;
	}

	@Override
	public Map<Integer, Integer> getAlternativeConversionMap() {

		return ALTERNATIVE_CONVERSION_MAP;
	}

	public QueueAlternative getAlternative() {

		return alternative;
	}

	public void setAlternative(QueueAlternative alternative) {

		this.alternative = alternative;
	}

	public String getAcceptText() {

		return acceptText;
	}

	public void setAcceptText(String acceptText) {

		this.acceptText = acceptText;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<>();

		description = XMLValidationUtils.validateParameter("description", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		acceptText = XMLValidationUtils.validateParameter("acceptText", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		invoiceLineText = XMLValidationUtils.validateParameter("invoiceLineText", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		paymentRequiredText = XMLValidationUtils.validateParameter("paymentRequiredText", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		alreadyMemberText = XMLValidationUtils.validateParameter("alreadyMemberText", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);

		showCommentField = xmlParser.getPrimitiveBoolean("showCommentField");
		hideTitle = xmlParser.getPrimitiveBoolean("hideTitle");
		allowNextStepIfAlreadyMember = xmlParser.getPrimitiveBoolean("allowNextStepIfAlreadyMember");

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}

	}

	public boolean showCommentField() {

		return showCommentField;
	}

	public void setShowCommentField(boolean showCommentField) {

		this.showCommentField = showCommentField;
	}

	public boolean isHideTitle() {

		return hideTitle;
	}

	public void setHideTitle(boolean hideTitle) {

		this.hideTitle = hideTitle;
	}

	public boolean isAllowNextStepIfAlreadyMember() {

		return allowNextStepIfAlreadyMember;
	}

	public void setAllowNextStepIfAlreadyMember(boolean allowNextStepIfAlreadyMember) {

		this.allowNextStepIfAlreadyMember = allowNextStepIfAlreadyMember;
	}

	@Override
	public List<? extends PaymentProduct> getPaymentProducts() {

		if (queue.getPrice() != null && queue.getPrice() > 0) {

			return Collections.singletonList(new BasePaymentProduct(queue.getPrice(), invoiceLineText));
		}

		return Collections.emptyList();
	}

}
