package com.nordicpeak.flowengine.queue.query;

import java.lang.reflect.Field;
import java.util.Collections;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLUtils;

import com.nordicpeak.flowengine.beans.BaseInvoiceLine;
import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.interfaces.InvoiceLine;
import com.nordicpeak.flowengine.interfaces.PaymentQueryInstance;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.SubmitCheck;
import com.nordicpeak.flowengine.managers.FlowInstanceManager;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativeQueryUtils;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesQueryInstance;

@Table(name = "queue_query_instances")
@XMLElement
public class QueueQueryInstance extends BaseQueryInstance implements FixedAlternativesQueryInstance, PaymentQueryInstance, SubmitCheck {

	private static final long serialVersionUID = -7761759005604863873L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(QueueQueryInstance.class, "query");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;

	@DAOManaged
	@XMLElement
	private String comment;

	@DAOManaged
	@XMLElement
	private boolean accepted;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private QueueQuery query;

	private ValidationError submitValidationError;

	public Integer getQueryInstanceID() {

		return queryInstanceID;
	}

	public void setQueryInstanceID(Integer queryInstanceID) {

		this.queryInstanceID = queryInstanceID;
	}

	public String getComment() {

		return comment;
	}

	public void setComment(String freeTextAlternativeValue) {

		this.comment = freeTextAlternativeValue;
	}

	@Override
	public QueueQuery getQuery() {

		return query;
	}

	public void setQuery(QueueQuery query) {

		this.query = query;
	}

	@Override
	public void reset(MutableAttributeHandler attributeHandler) {

		super.reset(attributeHandler);

		this.comment = null;
		this.accepted = false;
	}

	public boolean isAccepted() {

		return accepted;
	}

	public void setAccepted(boolean accepted) {

		this.accepted = accepted;
	}

	@Override
	public String toString() {

		return this.getClass().getSimpleName() + " (queryInstanceID=" + queryInstanceID + ")";
	}

	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {

		Element element = getBaseExportXML(doc);

		XMLUtils.appendNewElement(doc, element, "Comment", comment);
		XMLUtils.appendNewElement(doc, element, "Accepted", accepted);

		FixedAlternativeQueryUtils.appendExportXMLAlternatives(doc, element, this);

		return element;
	}

	@Override
	public List<? extends ImmutableAlternative> getAlternatives() {

		if (accepted) {

			return query.getAlternatives();
		}

		return null;
	}

	@Override
	public String getFreeTextAlternativeValue() {

		return null;
	}

	public void defaultQueryValues() {

	}

	@Override
	public List<? extends InvoiceLine> getInvoiceLines() {

		if (accepted && query.getQueue().getPrice() != null && query.getQueue().getPrice() > 0) {

			String invoiceLineText = query.getInvoiceLineText();
			
			if(invoiceLineText == null) {
				
				invoiceLineText = "";
			}
			
			return Collections.singletonList(new BaseInvoiceLine(1, query.getQueue().getPrice(), invoiceLineText, ""));
		}

		return null;
	}

	@Override
	public boolean isValidForSubmit(MutableAttributeHandler attributeHandler, User poster, QueryHandler queryHandler, FlowInstanceManager flowInstanceManager) throws Exception {

		return queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), QueueQueryProviderModule.class).isValidQueueQueryInstance(this, poster);
	}

	public ValidationError getSubmitValidationError() {

		return submitValidationError;
	}

	public void setSubmitValidationError(ValidationError submitValidationError) {

		this.submitValidationError = submitValidationError;
	}

}
