package com.nordicpeak.flowengine.randombookingnumber.cruds;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.utils.crud.IntegerBeanIDParser;
import se.unlogic.hierarchy.core.utils.crud.ModularCRUD;
import se.unlogic.standardutils.bool.BooleanUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.CRUDDAO;
import se.unlogic.standardutils.populators.BooleanPopulator;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.validation.ValidationUtils;

import com.nordicpeak.flowengine.randombookingnumber.RandomBookingNumberGeneratorModule;
import com.nordicpeak.flowengine.randombookingnumber.beans.RandomBookingInterval;
import com.nordicpeak.flowengine.randombookingnumber.beans.RandomBookingNumber;

public class RandomBookingIntervalCRUD extends ModularCRUD<RandomBookingInterval, Integer, User, RandomBookingNumberGeneratorModule> {

	public RandomBookingIntervalCRUD(CRUDDAO<RandomBookingInterval, Integer> crudDAO, RandomBookingNumberGeneratorModule callback) {

		super(IntegerBeanIDParser.getInstance(), crudDAO, new AnnotatedRequestPopulator<>(RandomBookingInterval.class), "Interval", "interval", "/", callback);
	}

	@Override
	protected void appendAllBeans(Document doc, Element listTypeElement, User user, HttpServletRequest req, URIParser uriParser, List<ValidationError> validationError) throws SQLException {

		List<RandomBookingInterval> intervals = getAllBeans(user, req, uriParser);

		if (!CollectionUtils.isEmpty(intervals)) {

			Element intervalsElement = XMLUtils.appendNewElement(doc, listTypeElement, this.typeElementPluralName);

			for (RandomBookingInterval interval : intervals) {

				Element intervalElement = XMLUtils.append(doc, intervalsElement, interval);

				try {

					checkDeleteAccess(interval, user, req, uriParser);

				} catch (Exception e) {

					XMLUtils.appendNewElement(doc, intervalElement, "noDeleteAccess");
				}
			}
		}
	}

	@Override
	protected RandomBookingInterval populateFromAddRequest(HttpServletRequest req, User user, URIParser uriParser) throws Exception {

		RandomBookingInterval interval = super.populateFromAddRequest(req, user, uriParser);

		List<ValidationError> validationErrors = new ArrayList<>();

		Integer range = ValidationUtils.validateParameter("range", req, true, PositiveStringIntegerPopulator.getPopulator(), validationErrors);

		if (range != null) {

			List<RandomBookingNumber> numbers = new ArrayList<>(range);

			for (int i = 0; i < range; i++) {

				RandomBookingNumber number = new RandomBookingNumber(i + 1, true);

				numbers.add(number);
			}

			interval.setNumbers(numbers);
		}

		if (!validationErrors.isEmpty()) {

			throw new ValidationException(validationErrors);
		}

		return interval;
	}

	@Override
	protected RandomBookingInterval populateFromUpdateRequest(RandomBookingInterval interval, HttpServletRequest req, User user, URIParser uriParser) throws Exception {

		interval = super.populateFromUpdateRequest(interval, req, user, uriParser);

		List<ValidationError> validationErrors = new ArrayList<>();

		for (RandomBookingNumber number : interval.getNumbers()) {

			boolean enabled = BooleanUtils.valueOf(ValidationUtils.validateParameter(number.getNumberID() + "-enabled", req, false, BooleanPopulator.getPopulator(), validationErrors));
			String description = ValidationUtils.validateParameter(number.getNumberID() + "-description", req, false, 1, 255, validationErrors);

			number.setEnabled(enabled);
			number.setDescription(description);
		}

		if (!validationErrors.isEmpty()) {

			throw new ValidationException(validationErrors);
		}

		return interval;
	}

	@Override
	protected ForegroundModuleResponse beanAdded(RandomBookingInterval interval, HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		res.sendRedirect(req.getContextPath() + callback.getFullAlias() + "/updateinterval/" + interval.getIntervalID());
		return null;
	}

	@Override
	protected void checkDeleteAccess(RandomBookingInterval interval, User user, HttpServletRequest req, URIParser uriParser) throws AccessDeniedException, URINotFoundException, SQLException {

		super.checkDeleteAccess(interval, user, req, uriParser);

		if (interval.getMappings() != null) {

			throw new AccessDeniedException("You are not allowed to delete an interval that's currently in use on booking slots");
		}
	}

}