package com.nordicpeak.flowengine.randombookingnumber.daos;

import java.lang.reflect.Field;
import java.sql.SQLException;
import java.util.List;

import javax.sql.DataSource;

import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOFactory;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;

import com.nordicpeak.flowengine.randombookingnumber.beans.RandomBookingNumberMapping;

public class RandomBookingNumberMappingDAO extends AnnotatedDAO<RandomBookingNumberMapping> {

	private final QueryParameterFactory<RandomBookingNumberMapping, Integer> bookingIDParamFactory;

	public RandomBookingNumberMappingDAO(DataSource dataSource, Class<RandomBookingNumberMapping> beanClass, AnnotatedDAOFactory daoFactory) {

		super(dataSource, beanClass, daoFactory);

		bookingIDParamFactory = this.getParamFactory(RandomBookingNumberMapping.FIELD_BOOKING_ID, Integer.class);
	}

	public RandomBookingNumberMapping getByBookingID(Integer bookingID, Field... relations) throws SQLException {

		HighLevelQuery<RandomBookingNumberMapping> query = new HighLevelQuery<>();

		query.addParameter(bookingIDParamFactory.getParameter(bookingID));

		query.addRelations(RandomBookingNumberMapping.FIELD_NUMBER);

		if (relations != null) {

			query.addRelations(relations);
		}

		return this.get(query);
	}

	public List<RandomBookingNumberMapping> getByBookingIDs(List<Integer> bookingIDs) throws SQLException {

		HighLevelQuery<RandomBookingNumberMapping> query = new HighLevelQuery<>();

		query.addParameter(bookingIDParamFactory.getWhereInParameter(bookingIDs));

		query.addRelations(RandomBookingNumberMapping.FIELD_NUMBER);

		return this.getAll(query);
	}

	public Integer deleteByBookingID(Integer bookingID) throws SQLException {

		HighLevelQuery<RandomBookingNumberMapping> query = new HighLevelQuery<>();

		query.addParameter(bookingIDParamFactory.getParameter(bookingID));

		return this.delete(query);
	}

}
