package com.nordicpeak.flowengine.remotegeometryendpointprovider;

import java.awt.Color;
import java.io.Serializable;

import se.unlogic.standardutils.json.JsonObject;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;

import com.vividsolutions.jts.geom.Geometry;

@XMLElement(name = "Geometry")
public class RemoteGeometry extends GeneratedElementable implements Serializable {

	private static final long serialVersionUID = 7472938374915576195L;

	@XMLElement
	private String objectID;

	@XMLElement
	private String name;

	@XMLElement
	private String description;
	
	@XMLElement
	private boolean hideDescription;

	@XMLElement
	private String wktGeometry;

	@XMLElement
	private String iconURL;

	@XMLElement
	private String selectedIconURL;

	@XMLElement
	private boolean selectable;

	@XMLElement
	private String color;

	@XMLElement
	private String selectedColor;

	@XMLElement
	private Integer price;

	private Geometry geometry;

	public RemoteGeometry(String objectID, String name, String wktGeometry, Geometry geometry) {

		this.objectID = objectID;
		this.name = name;
		this.wktGeometry = wktGeometry;
		this.geometry = geometry;
	}

	public String getObjectID() {

		return objectID;
	}

	public void setObjectID(String objectID) {

		this.objectID = objectID;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public String getDescription() {

		return description;
	}

	public void setDescription(String description) {

		this.description = description;
	}
	
	public boolean isHideDescription() {

		return hideDescription;
	}

	public void setHideDescription(boolean hideDescription) {

		this.hideDescription = hideDescription;
	}

	public String getWktGeometry() {

		return wktGeometry;
	}

	public void setWktGeometry(String wktGeometry) {

		this.wktGeometry = wktGeometry;
	}

	public String getIconURL() {

		return iconURL;
	}

	public void setIconURL(String iconURL) {

		this.iconURL = iconURL;
	}

	public String getSelectedIconURL() {

		return selectedIconURL;
	}

	public void setSelectedIconURL(String selectedIconURL) {

		this.selectedIconURL = selectedIconURL;
	}

	public boolean isSelectable() {

		return selectable;
	}

	public void setSelectable(boolean selectable) {

		this.selectable = selectable;
	}

	public String getColor() {

		return color;
	}

	public void setColor(String color) {

		this.color = color;
	}

	public String getSelectedColor() {

		return selectedColor;
	}

	public void setSelectedColor(String selectedColor) {

		this.selectedColor = selectedColor;
	}

	public Integer getPrice() {

		return price;
	}

	public void setPrice(Integer price) {

		this.price = price;
	}

	public Geometry getGeometry() {

		return geometry;
	}

	public void setGeometry(Geometry geometry) {

		this.geometry = geometry;
	}

	public JsonObject toJson() {

		JsonObject geometry = new JsonObject();
		geometry.putField("objectID", objectID);
		geometry.putField("name", name);
		geometry.putField("wktGeometry", wktGeometry);

		if (!StringUtils.isEmpty(description)) {
			geometry.putField("description", description);
		}
		
		geometry.putField("hideDescription", hideDescription);

		if (!StringUtils.isEmpty(iconURL)) {
			geometry.putField("iconURL", iconURL);
		}

		if (!StringUtils.isEmpty(selectedIconURL)) {
			geometry.putField("selectedIconURL", selectedIconURL);
		}

		geometry.putField("selectable", selectable);

		putColorField(geometry, "color", color);
		putColorField(geometry, "selectedColor", selectedColor);

		if (price != null) {
			geometry.putField("price", price);
		}

		return geometry;

	}

	private void putColorField(JsonObject geometry, String name, String hexColor) {

		if (hexColor != null) {

			try {

				Color color = Color.decode(hexColor);

				JsonObject colorJson = new JsonObject(4);

				colorJson.putField("hex", hexColor);
				colorJson.putField("red", color.getRed());
				colorJson.putField("green", color.getGreen());
				colorJson.putField("blue", color.getBlue());

				geometry.putField(name, colorJson);

			} catch (NumberFormatException e) {}
		}
	}

}
