package com.nordicpeak.flowengine.queries.remoteinfoquery;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.standardutils.annotations.RequiredIfSet;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.queries.basequery.BaseQuery;

@Table(name = "remote_info_queries")
@XMLElement
public class RemoteInfoQuery extends BaseQuery {

	private static final long serialVersionUID = 8732607760189948382L;
	
	public static final Field INSTANCES_RELATION = ReflectionUtils.getField(RemoteInfoQuery.class, "instances");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryID;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean hideTitle;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean hideBackground;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean hideOnEmptyResponse;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean dontSetPopulated;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean setAsAttribute;
	
	@DAOManaged
	@WebPopulate(maxLength = 255)
	@RequiredIfSet(paramNames = "setAsAttribute")
	@XMLElement
	private String attributeName;

	@DAOManaged
	@OneToMany
	@XMLElement
	private List<RemoteInfoQueryInstance> instances;

	@DAOManaged(columnName = "endpointID")
	@ManyToOne(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement
	private RemoteInfoQueryEndpoint endpoint;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private String endpointErrorText;


	public static long getSerialversionuid() {

		return serialVersionUID;
	}

	@Override
	public Integer getQueryID() {

		return queryID;
	}

	public List<RemoteInfoQueryInstance> getInstances() {

		return instances;
	}

	public void setInstances(List<RemoteInfoQueryInstance> instances) {

		this.instances = instances;
	}

	public void setQueryID(int queryID) {

		this.queryID = queryID;
	}

	public void setQueryID(Integer queryID) {

		this.queryID = queryID;
	}

	public boolean isHideTitle() {
		
		return hideTitle;
	}

	public void setHideTitle(boolean hideTitle) {
	
		this.hideTitle = hideTitle;
	}
	
	public boolean isHideBackground() {
	
		return hideBackground;
	}
	
	public void setHideBackground(boolean hideBackground) {
	
		this.hideBackground = hideBackground;
	}
	
	public boolean isDontSetPopulated() {
	
		return dontSetPopulated;
	}
	
	public void setDontSetPopulated(boolean dontSetPopulated) {
	
		this.dontSetPopulated = dontSetPopulated;
	}
	
	public boolean isSetAsAttribute() {
		
		return setAsAttribute;
	}
	
	public void setSetAsAttribute(boolean setAsAttribute) {
	
		this.setAsAttribute = setAsAttribute;
	}
	
	public String getAttributeName() {
	
		return attributeName;
	}
	
	public void setAttributeName(String attributeName) {
	
		this.attributeName = attributeName;
	}

	public RemoteInfoQueryEndpoint getEndpoint() {
		
		return endpoint;
	}

	public void setEndpoint(RemoteInfoQueryEndpoint endpoint) {
	
		this.endpoint = endpoint;
	}

	public String getEndpointErrorText() {
		
		return endpointErrorText;
	}
	
	public void setEndpointErrorText(String endpointErrorText) {
	
		this.endpointErrorText = endpointErrorText;
	}

	@Override
	public String toString() {

		if (this.queryDescriptor != null) {

			return queryDescriptor.getName() + " (queryID: " + queryID + ")";
		}

		return "InfoQuery (queryID: " + queryID + ")";
	}

	@Override
	public String getXSDTypeName() {

		return "InfoQuery" + queryID;
	}

	@Override
	public void toXSD(Document doc) {

		Element complexTypeElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexType");
		complexTypeElement.setAttribute("name", getXSDTypeName());

		Element complexContentElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:complexContent");
		complexTypeElement.appendChild(complexContentElement);

		Element extensionElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:extension");
		extensionElement.setAttribute("base", "Query");
		complexContentElement.appendChild(extensionElement);

		Element sequenceElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:sequence");
		extensionElement.appendChild(sequenceElement);

		Element nameElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		nameElement.setAttribute("name", "Name");
		nameElement.setAttribute("type", "xs:string");
		nameElement.setAttribute("minOccurs", "1");
		nameElement.setAttribute("maxOccurs", "1");
		nameElement.setAttribute("fixed", queryDescriptor.getName());
		sequenceElement.appendChild(nameElement);
		
		Element infoTextElement = doc.createElementNS("http://www.w3.org/2001/XMLSchema", "xs:element");
		infoTextElement.setAttribute("name", "InfoText");
		infoTextElement.setAttribute("type", "xs:string");
		infoTextElement.setAttribute("minOccurs", "1");
		infoTextElement.setAttribute("maxOccurs", "1");
		sequenceElement.appendChild(infoTextElement);

		doc.getDocumentElement().appendChild(complexTypeElement);
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();

		description = XMLValidationUtils.validateParameter("description", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		helpText = XMLValidationUtils.validateParameter("helpText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);

		hideTitle = xmlParser.getPrimitiveBoolean("hideTitle");
		hideBackground = xmlParser.getPrimitiveBoolean("hideBackground");
		hideOnEmptyResponse = xmlParser.getPrimitiveBoolean("hideOnEmptyResponse");
		dontSetPopulated = xmlParser.getPrimitiveBoolean("dontSetPopulated");

		endpointErrorText = XMLValidationUtils.validateParameter("endpointErrorText", xmlParser, false, 1, 65535, StringPopulator.getPopulator(), errors);
		
		attributeName = XMLValidationUtils.validateParameter("attributeName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);

		if (attributeName != null) {

			setAsAttribute = xmlParser.getPrimitiveBoolean("setAsAttribute");
		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	
	public boolean isHideOnEmptyResponse() {
	
		return hideOnEmptyResponse;
	}

	
	public void setHideOnEmptyResponse(boolean hideOnEmptyResponse) {
	
		this.hideOnEmptyResponse = hideOnEmptyResponse;
	}
}
