package com.nordicpeak.flowengine.queries.remotesinglesignquery;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationErrorType;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUD;
import com.nordicpeak.flowengine.queries.remotesinglesignquery.api.RemoteSinglesignQueryEndpoint;

public class RemoteSinglesignQueryCRUD extends BaseQueryCRUD<RemoteSinglesignQuery, RemoteSinglesignQueryProviderModule> {

	public RemoteSinglesignQueryCRUD(AnnotatedDAOWrapper<RemoteSinglesignQuery, Integer> queryDAO, BeanRequestPopulator<RemoteSinglesignQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, RemoteSinglesignQueryProviderModule callback) {

		super(RemoteSinglesignQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);
	}

	@Override
	protected RemoteSinglesignQuery populateFromUpdateRequest(RemoteSinglesignQuery oldQuery, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		RemoteSinglesignQuery query = super.populateFromUpdateRequest(oldQuery, req, user, uriParser);

		List<ValidationError> validationErrors = new ArrayList<ValidationError>();

		this.populateQueryDescriptor((QueryDescriptor) query.getQueryDescriptor(), req, validationErrors);

		String endpointString = req.getParameter("endpointID");

		Integer endpointID = null;

		if (!StringUtils.isEmpty(endpointString)) {

			endpointID = Integer.parseInt(endpointString);

			RemoteSinglesignQueryEndpoint endpoint = callback.getAPIModule().getEndpoint(endpointID);

			if (endpoint == null) {
				
				validationErrors.add(new ValidationError("endpointID", ValidationErrorType.InvalidFormat));
			}
			
			query.setEndpoint(endpoint);

		} else {

			validationErrors.add(new ValidationError("endpointID", ValidationErrorType.RequiredField));
		}

		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}

		return query;
	}

	@Override
	protected void appendUpdateFormData(RemoteSinglesignQuery bean, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {

		super.appendUpdateFormData(bean, doc, updateTypeElement, user, req, uriParser);

		XMLUtils.append(doc, updateTypeElement, "Endpoints", callback.getAPIModule().getEndpoints());
	}

}
