package com.nordicpeak.flowengine.restrictedflowadmin;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;
import javax.xml.transform.TransformerException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.CheckboxSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.GroupMultiListSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextAreaSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.UserMultiListSettingDescriptor;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.Group;
import se.unlogic.hierarchy.core.beans.LinkTag;
import se.unlogic.hierarchy.core.beans.ScriptTag;
import se.unlogic.hierarchy.core.beans.SimpleForegroundModuleResponse;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.exceptions.ModuleConfigurationException;
import se.unlogic.hierarchy.core.exceptions.URINotFoundException;
import se.unlogic.hierarchy.core.handlers.GroupHandler;
import se.unlogic.hierarchy.core.handlers.UserHandler;
import se.unlogic.hierarchy.core.interfaces.AccessInterface;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.ViewFragment;
import se.unlogic.hierarchy.core.interfaces.events.EventHandler;
import se.unlogic.hierarchy.core.interfaces.modules.Module;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.GenericCRUD;
import se.unlogic.hierarchy.core.utils.HierarchyAnnotatedDAOFactory;
import se.unlogic.hierarchy.core.utils.ModuleUtils;
import se.unlogic.hierarchy.core.utils.ModuleViewFragmentTransformer;
import se.unlogic.hierarchy.core.utils.ViewFragmentModule;
import se.unlogic.hierarchy.core.utils.ViewFragmentUtils;
import se.unlogic.hierarchy.core.utils.crud.MultipartRequestFilter;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;
import se.unlogic.hierarchy.foregroundmodules.staticcontent.StaticContentModule;
import se.unlogic.standardutils.annotations.SplitOnLineBreak;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AdvancedAnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.dao.querys.ObjectQuery;
import se.unlogic.standardutils.db.DBUtils;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.enums.Order;
import se.unlogic.standardutils.json.JsonArray;
import se.unlogic.standardutils.json.JsonObject;
import se.unlogic.standardutils.json.JsonUtils;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.standardutils.xml.XMLable;
import se.unlogic.standardutils.xsl.XSLVariableReader;
import se.unlogic.standardutils.xsl.XSLVariableReaderRenamer;
import se.unlogic.webutils.http.HTTPUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;

import com.nordicpeak.flowengine.FlowAdminModule;
import com.nordicpeak.flowengine.beans.Flow;
import com.nordicpeak.flowengine.beans.FlowAdminExtensionShowView;
import com.nordicpeak.flowengine.beans.FlowFamily;
import com.nordicpeak.flowengine.beans.FlowForm;
import com.nordicpeak.flowengine.beans.FlowType;
import com.nordicpeak.flowengine.beans.MessageTemplate;
import com.nordicpeak.flowengine.beans.Status;
import com.nordicpeak.flowengine.cruds.FlowCRUD;
import com.nordicpeak.flowengine.cruds.FlowFormCRUD;
import com.nordicpeak.flowengine.cruds.MessageTemplateCRUD;
import com.nordicpeak.flowengine.dao.FlowEngineDAOFactory;
import com.nordicpeak.flowengine.enums.FlowAdminColumn;
import com.nordicpeak.flowengine.exceptions.flow.FlowNotAvailiableInRequestedFormat;
import com.nordicpeak.flowengine.interfaces.FlowAdminCRUDCallback;
import com.nordicpeak.flowengine.interfaces.FlowAdminFragmentExtensionViewProvider;
import com.nordicpeak.flowengine.interfaces.FlowTypeExtensionProvider;
import com.nordicpeak.flowengine.interfaces.ImmutableFlow;

public class RestrictedFlowAdminModule extends AnnotatedForegroundModule implements FlowAdminFragmentExtensionViewProvider, AccessInterface, FlowAdminCRUDCallback, FlowTypeExtensionProvider, ViewFragmentModule<ForegroundModuleDescriptor> {

	private static final AnnotatedRequestPopulator<FlowTypeRestrictedSettings> FLOW_TYPE_SETTINGS_POPULATOR = new AnnotatedRequestPopulator<>(FlowTypeRestrictedSettings.class);
	private static final AnnotatedRequestPopulator<FlowFamilyRestrictedSettings> FLOW_FAMILY_SETTINGS_POPULATOR = new AnnotatedRequestPopulator<>(FlowFamilyRestrictedSettings.class);
	
	private final List<FlowAdminColumn> ignoreTableColumns = Arrays.asList(FlowAdminColumn.SUBMITTED_INSTANCES, FlowAdminColumn.NOT_SUBMITTED_INSTANCES, FlowAdminColumn.LAST_REVIEWED, FlowAdminColumn.ORGANIZATION);

	@XSLVariable(prefix = "java.")
	private String fileMissing = "File is missing";

	@XSLVariable(prefix = "java.")
	private String eventFlowFamilyUpdatedMessage = "eventFlowFamilyUpdatedMessage";

	@XSLVariable(prefix = "java.")
	private String eventFlowUpdatedMessage = "eventFlowUpdatedMessage";

	@XSLVariable(prefix = "java.")
	private String eventFlowFormAddedMessage = "eventFlowFormAddedMessage";

	@XSLVariable(prefix = "java.")
	private String eventFlowFormUpdatedMessage = "eventFlowFormUpdatedMessage";

	@XSLVariable(prefix = "java.")
	private String eventFlowFormDeletedMessage = "eventFlowFormDeletedMessage";

	@XSLVariable(prefix = "java.")
	private String eventFunctionConfigured = "eventFunctionConfigured";

	@XSLVariable(prefix = "java.")
	private String flowAdminExtensonViewTitle = "flowAdminExtensonViewTitle";

	@ModuleSetting(allowsNull = true)
	@GroupMultiListSettingDescriptor(name = "Global restricted admin groups", description = "Groups allowed to administrate all flows")
	protected List<Integer> adminGroupIDs;

	@ModuleSetting(allowsNull = true)
	@UserMultiListSettingDescriptor(name = "Global restricted admin users", description = "Users allowed to administrate all flows")
	protected List<Integer> adminUserIDs;

	@ModuleSetting(allowsNull = true)
	@SplitOnLineBreak
	@TextAreaSettingDescriptor(name = "Allowed extensions", description = "Full classname of allowed extension modules")
	protected List<String> allowedExtensions;

	@ModuleSetting
	@CheckboxSettingDescriptor(name = "Enable fragment XML debug", description = "Enables debugging of fragment XML")
	private boolean debugFragmentXML;

	protected FlowAdminModule flowAdminModule;

	@InstanceManagerDependency
	protected RestrictedFlowAdminFlowTestModule restrictedFlowAdminFlowTest;

	@InstanceManagerDependency(required = true)
	protected StaticContentModule staticContentModule;

	private FlowRestrictedCRUD flowCRUD;
	private FlowFormCRUD flowFormCRUD;
	private MultipartRequestFilter flowFormCRUDRequestFilter;
	private MessageTemplateCRUD messageTemplateCRUD;

	private AnnotatedDAO<FlowTypeRestrictedSettings> flowTypeSettingsDAO;
	private AnnotatedDAO<FlowFamilyRestrictedSettings> flowFamilySettingsDAO;
	private AnnotatedDAO<RestrictedFlowAdminUserColumnSetting> userColumnSettingDAO;

	private QueryParameterFactory<FlowTypeRestrictedSettings, Integer> flowTypeSettingsFlowTypeIDParamFactory;
	private QueryParameterFactory<FlowFamilyRestrictedSettings, Integer> flowFamilySettingsFlowFamilyIDParamFactory;
	protected QueryParameterFactory<RestrictedFlowAdminUserColumnSetting, Integer> userColumnSettingParamFactory;

	private String anyRestrictedFlowTypeAccessSQL;
	private String anyRestrictedFlowFamilyAccessSQL;

	private ModuleViewFragmentTransformer<ForegroundModuleDescriptor> viewFragmentTransformer;
	private ModuleViewFragmentTransformer<ForegroundModuleDescriptor> flowAdminFragmentExtensionViewFragmentTransformer;

	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {

		viewFragmentTransformer = new ModuleViewFragmentTransformer<>(sectionInterface.getForegroundModuleXSLTCache(), this, sectionInterface.getSystemInterface().getEncoding());
		flowAdminFragmentExtensionViewFragmentTransformer = new ModuleViewFragmentTransformer<>(sectionInterface.getForegroundModuleXSLTCache(), this, sectionInterface.getSystemInterface().getEncoding());

		super.init(moduleDescriptor, sectionInterface, dataSource);

		if (!systemInterface.getInstanceHandler().addInstance(RestrictedFlowAdminModule.class, this)) {

			throw new RuntimeException("Unable to register module in global instance handler using key " + RestrictedFlowAdminModule.class.getSimpleName() + ", another instance is already registered using this key.");
		}
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		super.createDAOs(dataSource);

		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, RestrictedFlowAdminModule.class.getName(), new XMLDBScriptProvider(getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		flowTypeSettingsDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(FlowTypeRestrictedSettings.class);
		flowFamilySettingsDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(FlowFamilyRestrictedSettings.class);

		flowTypeSettingsFlowTypeIDParamFactory = flowTypeSettingsDAO.getParamFactory("flowTypeID", Integer.class);
		flowFamilySettingsFlowFamilyIDParamFactory = flowFamilySettingsDAO.getParamFactory("flowFamilyID", Integer.class);

		FlowEngineDAOFactory flowEngineDAOFactory = new FlowEngineDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler());

		AdvancedAnnotatedDAOWrapper<Flow, Integer> flowDAOWrapper = flowEngineDAOFactory.getFlowDAO().getAdvancedWrapper("flowID", Integer.class);
		flowDAOWrapper.getAddQuery().addRelations(Flow.FLOW_FAMILY_RELATION, Flow.STATUSES_RELATION, Status.DEFAULT_STATUS_MAPPINGS_RELATION, Flow.TAGS_RELATION, Flow.CHECKS_RELATION, FlowFamily.ALIASES_RELATION);
		flowDAOWrapper.getUpdateQuery().addRelations(Flow.FLOW_FAMILY_RELATION, Flow.TAGS_RELATION, Flow.CHECKS_RELATION, FlowFamily.ALIASES_RELATION);

		flowCRUD = new FlowRestrictedCRUD(flowDAOWrapper, this);

		AnnotatedDAOWrapper<FlowForm, Integer> flowFormDAOWrapper = flowEngineDAOFactory.getFlowFormDAO().getWrapper("flowFormID", Integer.class);
		flowFormDAOWrapper.addRelations(FlowForm.FLOW_RELATION, Flow.FLOW_TYPE_RELATION, FlowType.ALLOWED_ADMIN_GROUPS_RELATION, FlowType.ALLOWED_ADMIN_USERS_RELATION);
		flowFormDAOWrapper.setUseRelationsOnGet(true);

		flowFormCRUD = new FlowFormCRUD(flowFormDAOWrapper, this);

		if (flowFormCRUDRequestFilter != null) {
			flowFormCRUD.addRequestFilter(flowFormCRUDRequestFilter);
		}

		{
			StringBuilder sql = new StringBuilder("SELECT a.flowTypeID FROM " + flowTypeSettingsDAO.getTableName() + " a");
			sql.append(" LEFT JOIN flow_type_restricted_flow_admin_access_users u ON a.flowTypeID = u.flowTypeID AND u.userID = ?");
			sql.append(" LEFT JOIN flow_type_restricted_flow_admin_access_groups g ON a.flowTypeID = g.flowTypeID AND g.groupID IN($groups)");
			sql.append(" WHERE u.flowTypeID IS NOT NULL OR g.flowTypeID IS NOT NULL");

			anyRestrictedFlowTypeAccessSQL = sql.toString();
		}

		{
			StringBuilder sql = new StringBuilder("SELECT a.flowFamilyID FROM " + flowFamilySettingsDAO.getTableName() + " a");
			sql.append(" LEFT JOIN flow_family_restricted_flow_admin_access_users u ON a.flowFamilyID = u.flowFamilyID AND u.userID = ?");
			sql.append(" LEFT JOIN flow_family_restricted_flow_admin_access_groups g ON a.flowFamilyID = g.flowFamilyID AND g.groupID IN($groups)");
			sql.append(" WHERE u.flowFamilyID IS NOT NULL OR g.flowFamilyID IS NOT NULL");

			anyRestrictedFlowFamilyAccessSQL = sql.toString();
		}

		HierarchyAnnotatedDAOFactory normalDAOFactory = new HierarchyAnnotatedDAOFactory(dataSource, systemInterface.getUserHandler(), systemInterface.getGroupHandler(), false, false, false);

		AnnotatedDAO<MessageTemplate> messageTemplateDAO = normalDAOFactory.getDAO(MessageTemplate.class);
		AnnotatedDAOWrapper<MessageTemplate, Integer> messageTemplateDAOWrapper = messageTemplateDAO.getWrapper(Integer.class);
		messageTemplateDAOWrapper.setUseRelationsOnGet(true);
		messageTemplateDAOWrapper.addRelations(MessageTemplate.FLOW_FAMILY_RELATION);

		messageTemplateCRUD = new MessageTemplateCRUD(messageTemplateDAOWrapper, this);
		userColumnSettingDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(RestrictedFlowAdminUserColumnSetting.class);
		userColumnSettingParamFactory = userColumnSettingDAO.getParamFactory("userID", Integer.class);
	}

	@Override
	protected void moduleConfigured() throws Exception {

		viewFragmentTransformer.setDebugXML(debugFragmentXML);
		flowAdminFragmentExtensionViewFragmentTransformer.setDebugXML(debugFragmentXML);

		XSLVariableReader variableReader = ModuleUtils.getXSLVariableReader(moduleDescriptor, sectionInterface.getSystemInterface());

		if (variableReader != null) {

			Map<String, String> map = new HashMap<>();
			map.put("scripts", "updateflowsettingsscripts");
			map.put("links", "updateflowsettingslinks");

			List<ScriptTag> updateFlowSettingsScriptTags = ModuleUtils.getScripts(new XSLVariableReaderRenamer(variableReader, map), sectionInterface, getStaticContentPrefix(), moduleDescriptor);
			List<LinkTag> updateFlowSettingsLinkTags = ModuleUtils.getLinks(new XSLVariableReaderRenamer(variableReader, map), sectionInterface, getStaticContentPrefix(), moduleDescriptor);

			flowAdminFragmentExtensionViewFragmentTransformer.modifyScriptsAndLinks(true, null, updateFlowSettingsScriptTags, updateFlowSettingsLinkTags);
		}
	}

	@InstanceManagerDependency(required = true)
	public void setFlowAdminModule(FlowAdminModule flowAdminModule) {

		if (flowAdminModule == null && this.flowAdminModule != null) {

			this.flowAdminModule.removeFlowTypeExtensionProvider(this);
			this.flowAdminModule.removeFragmentExtensionViewProvider(this);

			flowFormCRUD.removeRequestFilter(flowFormCRUDRequestFilter);
			flowFormCRUDRequestFilter = null;
		}

		this.flowAdminModule = flowAdminModule;

		if (flowAdminModule != null) {

			flowAdminModule.addFlowTypeExtensionProvider(this);
			flowAdminModule.addFragmentExtensionViewProvider(this);

			flowFormCRUDRequestFilter = new MultipartRequestFilter(flowAdminModule);
			flowFormCRUD.addRequestFilter(flowFormCRUDRequestFilter);
		}
	}

	@Override
	public void unload() throws Exception {

		if (flowAdminModule != null) {

			setFlowAdminModule(null);
		}

		systemInterface.getInstanceHandler().removeInstance(RestrictedFlowAdminModule.class, this);

		super.unload();
	}

	private FlowTypeRestrictedSettings getFlowTypeRestrictedSettings(Integer flowTypeID) throws SQLException {

		HighLevelQuery<FlowTypeRestrictedSettings> query = new HighLevelQuery<>();

		query.addParameter(flowTypeSettingsFlowTypeIDParamFactory.getParameter(flowTypeID));

		return flowTypeSettingsDAO.get(query);
	}

	protected FlowFamilyRestrictedSettings getFlowFamilyRestrictedSettings(Integer flowFamilyID) throws SQLException {

		HighLevelQuery<FlowFamilyRestrictedSettings> query = new HighLevelQuery<>();

		query.addParameter(flowFamilySettingsFlowFamilyIDParamFactory.getParameter(flowFamilyID));

		return flowFamilySettingsDAO.get(query);
	}

	@Override
	public ForegroundModuleResponse defaultMethod(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return list(req, res, user, uriParser, (List<ValidationError>) null);
	}

	public ForegroundModuleResponse list(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, ValidationError validationError) throws ModuleConfigurationException, SQLException {

		return list(req, res, user, uriParser, CollectionUtils.getGenericSingletonList(validationError));
	}

	@Override
	public ForegroundModuleResponse list(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, List<ValidationError> validationErrors) throws ModuleConfigurationException, SQLException {

		log.info("User " + user + " listing flows");

		Document doc = this.createDocument(req, uriParser, user);

		Element listFlowsElement = doc.createElement("ListFlows");

		doc.getDocumentElement().appendChild(listFlowsElement);

		if (validationErrors != null) {
			XMLUtils.append(doc, listFlowsElement, validationErrors);
		}
		
		XMLUtils.append(doc, listFlowsElement, getUserSettings(user));

		return new SimpleForegroundModuleResponse(doc, this.getDefaultBreadcrumb());
	}
	
	private List<RestrictedFlowAdminUserColumnSetting> getUserSettings(User user) throws SQLException {

		HighLevelQuery<RestrictedFlowAdminUserColumnSetting> userSettingsQuery = new HighLevelQuery<>();
		
		userSettingsQuery.addParameter(userColumnSettingParamFactory.getParameter(user.getUserID()));
		userSettingsQuery.addOrderByCriteria(userColumnSettingDAO.getOrderByCriteria("columnIndex", Order.ASC));
		
		return userColumnSettingDAO.getAll(userSettingsQuery);
	}
	
	private void saveUserSettings(User user, List<RestrictedFlowAdminUserColumnSetting> settings) throws Exception {

		TransactionHandler transactionHandler = null;

		try {
			transactionHandler = userColumnSettingDAO.createTransaction();
			
			
			HighLevelQuery<RestrictedFlowAdminUserColumnSetting> deleteQuery = new HighLevelQuery<>();
			deleteQuery.addParameter(userColumnSettingParamFactory.getParameter(user.getUserID()));
			
			userColumnSettingDAO.delete(deleteQuery, transactionHandler);
			userColumnSettingDAO.addAll(settings, transactionHandler, null);

			transactionHandler.commit();
			
		}finally {

			TransactionHandler.autoClose(transactionHandler);
		}
	}
	
	@WebPublic(requireLogin = true, toLowerCase = true)
	public ForegroundModuleResponse saveUserSettings(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		log.info("User " + user + " saving flow admin column settings");

		res.setCharacterEncoding(systemInterface.getEncoding());
		res.setContentType(JsonUtils.getContentType());

		PrintWriter writer = res.getWriter();
		JsonObject jsonResponse = new JsonObject();
		
		List<RestrictedFlowAdminUserColumnSetting> userSettings = populateUserSettings(user, req);

		if (!userSettings.isEmpty()) {

			saveUserSettings(user, userSettings);	
			jsonResponse.putField("saved", "true");			

		}

		writer.print(jsonResponse.toJson());
		writer.flush();
		return null;
	}
	
	private List<RestrictedFlowAdminUserColumnSetting> populateUserSettings(User user, HttpServletRequest req) {
		
		List<RestrictedFlowAdminUserColumnSetting> userColumnSettings = new ArrayList<>(FlowAdminColumn.values().length);

		for (FlowAdminColumn column : FlowAdminColumn.values()) {
			
			
			if((!flowAdminModule.getUseCategories() && column == FlowAdminColumn.CATEGORY) || ignoreTableColumns.contains(column)) {
				continue;
			}
			
			RestrictedFlowAdminUserColumnSetting userColumnSetting = new RestrictedFlowAdminUserColumnSetting();
			
			userColumnSetting.setColumn(column);
			
			userColumnSetting.setColumnIndex(NumberUtils.toInt(req.getParameter(column.getName() + "-order")));
			
			if(userColumnSetting.getColumnIndex() == null || userColumnSetting.getColumnIndex() < 0) {
				return null;
			}
			
			userColumnSetting.setVisible(Boolean.parseBoolean(req.getParameter(column.getName()+ "-visibility")));
			userColumnSetting.setUserID(user.getUserID());
			
			
			userColumnSettings.add(userColumnSetting);
		}
	
		return userColumnSettings;
	}

	@WebPublic(alias = "flowdata")
	public ForegroundModuleResponse getFlowData(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		try {

			log.info("Sending flows to user " + user);

			JsonObject responseJSON = new JsonObject(1);
			JsonArray flowsJSONArray = new JsonArray();

			responseJSON.putField("rows", flowsJSONArray);

			if (hasAnyAccess(user)) {

				Collection<Flow> flows = flowAdminModule.getCachedFlows();

				if (!AccessUtils.checkAccess(user, this)) {

					//Check access and append flows
					for (Flow flow : flows) {

						if (flow.isLatestVersion() && hasAccess(user, flow, flow.getFlowFamily())) {

							JsonArray flowJSONArray = getFlowJSONArray(flow, flows);

							flowsJSONArray.addNode(flowJSONArray);

						}
					}

				} else {

					for (Flow flow : flows) {

						if (flow.isLatestVersion()) {

							JsonArray flowJSONArray = getFlowJSONArray(flow, flows);

							flowsJSONArray.addNode(flowJSONArray);
						}
					}
				}
			}

			HTTPUtils.sendReponse(responseJSON.toJson(), JsonUtils.getContentType(), res);

		} catch (IOException e) {

			log.warn("Error sending flow data to " + user, e);

		}

		return null;
	}

	private JsonArray getFlowJSONArray(Flow flow, Collection<Flow> allFlows) {

		int versionCount = 0;
		boolean published = false;
		boolean external = false;

		FlowFamily flowFamily = flow.getFlowFamily();

		for (Flow currentFlow : allFlows) {

			if (currentFlow.getFlowFamily().equals(flowFamily)) {

				versionCount++;

				if (!published && currentFlow.isEnabled() && currentFlow.isPublished()) {

					published = true;
				}

				if (!currentFlow.isInternal()) {

					external = true;
				}
			}
		}

		JsonArray flowJSONArray = new JsonArray();

		flowJSONArray.addNode(flow.getFlowID());
		flowJSONArray.addNode(flow.isPublished() ? "published" : "unpublished");
		flowJSONArray.addNode(flowAdminModule.getFlowIconJSON(flow));
		flowJSONArray.addNode(flowAdminModule.getFlowNameJSON(flow, external));
		flowJSONArray.addNode(flowAdminModule.getFlowTypeJSON(flow));
		flowJSONArray.addNode(flow.getCategory() != null ? flow.getCategory().getName() : "-");
		flowJSONArray.addNode(versionCount);
		flowJSONArray.addNode(""); //submittedInstanceCount
		flowJSONArray.addNode(""); //notSubmittedInstanceCount
		flowJSONArray.addNode(""); //flowFamilyLastReviewed
		flowJSONArray.addNode(flowFamily.getFlowFamilyID()); //flowfamilyID
		flowJSONArray.addNode(""); //organization
		flowAdminModule.appendExtraFlowListColumns(flowJSONArray, flow);
		flowJSONArray.addNode(""); //flowDeleteJSON
		
		return flowJSONArray;
	}

	private boolean hasAnyAccess(User user) throws SQLException {

		return hasAnyFlowTypeAccess(user) || hasAnyFlowFamilyAccess(user);
	}

	private boolean hasAccess(User user, Flow flow, FlowFamily flowFamily) throws SQLException {

		FlowTypeRestrictedSettings flowTypeSettings = getFlowTypeRestrictedSettings(flow.getFlowType().getFlowTypeID());
		FlowFamilyRestrictedSettings flowFamilySettings = getFlowFamilyRestrictedSettings(flowFamily.getFlowFamilyID());

		return (flowTypeSettings != null && AccessUtils.checkAccess(user, flowTypeSettings)) || (flowFamilySettings != null && AccessUtils.checkAccess(user, flowFamilySettings));
	}

	public void appendFamilyInformation(Document doc, Element flowElement, Flow lastestFlow, Collection<Flow> flows) {

		int versions = 0;
		boolean published = false;
		boolean external = false;

		FlowFamily flowFamily = lastestFlow.getFlowFamily();

		for (Flow flow : flows) {

			if (flow.getFlowFamily().equals(flowFamily)) {

				versions++;

				if (!published && flow.isEnabled() && flow.isPublished()) {
					published = true;
				}

				if (!flow.isInternal()) {
					external = true;
				}
			}
		}

		XMLUtils.appendNewElement(doc, flowElement, "VersionCount", versions);

		if (external) {
			XMLUtils.appendNewElement(doc, flowElement, "HasExternalVersions");
		}

		if (published) {
			XMLUtils.appendNewElement(doc, flowElement, "HasPublishedVersion");
		}
	}

	public boolean hasAnyFlowTypeAccess(User user) throws SQLException {

		Collection<FlowType> flowTypeCache = flowAdminModule.getCachedFlowTypes();

		return hasAnyGlobalAccess(user, flowTypeCache) || hasAnyRestrictedAccess(user, anyRestrictedFlowTypeAccessSQL);

	}

	public boolean hasAnyFlowFamilyAccess(User user) throws SQLException {

		Collection<FlowFamily> flowFamilyCache = flowAdminModule.getCachedFlowFamilies();

		return hasAnyGlobalAccess(user, flowFamilyCache) || hasAnyRestrictedAccess(user, anyRestrictedFlowFamilyAccessSQL);
	}

	private boolean hasAnyGlobalAccess(User user, Collection<?> cache) {

		return AccessUtils.checkAccess(user, this) && !cache.isEmpty();
	}

	private boolean hasAnyRestrictedAccess(User user, String anyRestrictedAccessSQL) throws SQLException {

		String sql = anyRestrictedAccessSQL;

		if (user.getGroups() != null) {

			sql = sql.replace("$groups", DBUtils.getPreparedStatementQuestionMarks(user.getGroups()));

		} else {

			sql = sql.replace("$groups", "NULL");
		}

		ObjectQuery<Integer> query = new ObjectQuery<>(dataSource, sql, IntegerPopulator.getPopulator());
		query.setInt(1, user.getUserID());

		if (user.getGroups() != null) {

			int i = 2;
			for (Group group : user.getGroups()) {
				query.setInt(i++, group.getGroupID());
			}
		}

		return query.executeQuery() != null;
	}

	private boolean hasFlowAdminExtensionAccess(FlowAdminFragmentExtensionViewProvider flowAdminFragmentExtensionViewProvider, User user) {

		if (AccessUtils.checkAccess(user, this)) {
			return true;
		}

		return allowedExtensions != null && allowedExtensions.contains(flowAdminFragmentExtensionViewProvider.getClass().getName());
	}

	@Override
	public boolean hasFlowAccess(User user, Flow flow) {

		FlowFamily flowFamily = flow.getFlowFamily();

		if (flowFamily == null) {

			flowFamily = (FlowFamily) flowAdminModule.getFlow(flow.getFlowID()).getFlowFamily();
		}

		try {

			if (!(hasAccess(user, flow, flowFamily) || AccessUtils.checkAccess(user, this))) {
				return false;
			}

		} catch (SQLException e) {
			throw new RuntimeException(e);
		}

		return getAllowedFlowVersions(flowFamily).contains(flow);
	}

	public Collection<? extends XMLable> getAllowedFlowVersions(FlowFamily flowFamily) {

		List<Flow> allFlows = flowAdminModule.getFlowVersions(flowFamily);
		List<Flow> currentAndLaterFlows = new ArrayList<>(allFlows.size());

		boolean publishedFound = false;

		int i = allFlows.size() - 1;

		while (i >= 0 && i < allFlows.size()) {
			Flow flow = allFlows.get(i);

			if (!publishedFound) {

				if (flow.isPublished()) {
					publishedFound = true;
					continue;
				}

				i--;

			} else {

				currentAndLaterFlows.add(flow);
				i++;
			}

		}

		if (!publishedFound) {

			return allFlows;
		}

		return currentAndLaterFlows;
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse showFlow(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		String validationError = req.getParameter("error");

		if (!StringUtils.isEmpty(validationError)) {

			if (validationError.equals(FlowAdminModule.MAY_NOT_REMOVE_FLOW_FORM_IF_NO_STEPS_VALIDATION_ERROR.getMessageKey())) {

				return flowCRUD.show(req, res, user, uriParser, Collections.singletonList(FlowAdminModule.MAY_NOT_REMOVE_FLOW_FORM_IF_NO_STEPS_VALIDATION_ERROR));

			} else if (validationError.equals(FlowAdminModule.MAY_NOT_ADD_FLOW_FORM_IF_SKIP_OVERVIEW_IS_SET_VALIDATION_ERROR.getMessageKey())) {

				return flowCRUD.show(req, res, user, uriParser, Collections.singletonList(FlowAdminModule.MAY_NOT_ADD_FLOW_FORM_IF_SKIP_OVERVIEW_IS_SET_VALIDATION_ERROR));
			}
		}

		return flowCRUD.show(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse updateFlow(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return flowCRUD.update(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse addFlowForm(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		Flow flow = flowAdminModule.getRequestedFlow(req, user, uriParser);

		if (flow == null) {

			throw new URINotFoundException(uriParser);
		}

		flowFormCRUD.checkFlowTypeAccess(user, flow);

		req.setAttribute("flow", flow);

		return flowFormCRUD.add(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse updateFlowForm(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return flowFormCRUD.update(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse deleteFlowForm(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return flowFormCRUD.delete(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse addMessageTemplate(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return messageTemplateCRUD.add(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse updateMessageTemplate(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return messageTemplateCRUD.update(req, res, user, uriParser);
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse deleteMessageTemplate(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		return messageTemplateCRUD.delete(req, res, user, uriParser);
	}

	public DataSource getDataSource() {

		return dataSource;
	}

	@Override
	public boolean allowsAdminAccess() {

		return false;
	}

	@Override
	public boolean allowsUserAccess() {

		return false;
	}

	@Override
	public boolean allowsAnonymousAccess() {

		return false;
	}

	@Override
	public Collection<Integer> getAllowedGroupIDs() {

		return adminGroupIDs;
	}

	@Override
	public Collection<Integer> getAllowedUserIDs() {

		return adminUserIDs;
	}

	@Override
	public String getTitlePrefix() {

		return this.moduleDescriptor.getName();
	}

	public UserHandler getUserHandler() {

		return systemInterface.getUserHandler();
	}

	public GroupHandler getGroupHandler() {

		return systemInterface.getGroupHandler();
	}

	@Override
	public Document createDocument(HttpServletRequest req, URIParser uriParser, User user) {

		Document doc = XMLUtils.createDomDocument();
		Element documentElement = doc.createElement("Document");
		documentElement.appendChild(RequestUtils.getRequestInfoAsXML(doc, req, uriParser));
		documentElement.appendChild(this.moduleDescriptor.toXML(doc));

		if (user != null) {

			Element userElement = (Element) documentElement.appendChild(user.toXML(doc));

			if (user.getAttributeHandler() != null) {

				userElement.appendChild(user.getAttributeHandler().toXML(doc));
			}
		}

		doc.appendChild(documentElement);

		if (flowAdminModule.getUseCategories()) {
			XMLUtils.appendNewElement(doc, (Element) doc.getFirstChild(), "UseCategories");
		}

		XMLUtils.appendNewElement(doc, (Element) doc.getFirstChild(), "HideSubmittedInstances");
		XMLUtils.appendNewElement(doc, (Element) doc.getFirstChild(), "HideNotSubmittedInstances");
		XMLUtils.appendNewElement(doc, (Element) doc.getFirstChild(), "HideFlowFamilyLastReviewed");
		XMLUtils.appendNewElement(doc, (Element) doc.getFirstChild(), "HideOrganization");
		XMLUtils.appendNewElement(doc, (Element) doc.getFirstChild(), "HideDeleteButton");

		return doc;
	}

	@Override
	public String getFileMissing() {

		return fileMissing;
	}

	public String getEventFlowFamilyUpdatedMessage() {

		return eventFlowFamilyUpdatedMessage;
	}

	public String getEventFlowUpdatedMessage() {

		return eventFlowUpdatedMessage;
	}

	@Override
	public String getEventFlowFormAddedMessage() {

		return eventFlowFormAddedMessage;
	}

	@Override
	public String getEventFlowFormUpdatedMessage() {

		return eventFlowFormUpdatedMessage;
	}

	@Override
	public String getEventFlowFormDeletedMessage() {

		return eventFlowFormDeletedMessage;
	}

	@Override
	public Integer getMaxPDFFormFileSize() {

		return flowAdminModule.getMaxPDFFormFileSize();
	}

	public String getEventFunctionConfigured() {

		return eventFunctionConfigured;
	}

	@Override
	public String getAbsoluteFileURL(URIParser uriParser, Object bean) {

		return flowAdminModule.getAbsoluteFileURL(uriParser, bean);
	}

	@Override
	public String getFlowFormFilePath(FlowForm form) {

		return flowAdminModule.getFlowFormFilePath(form);
	}

	@Override
	public String getFlowFormFilestore() {

		return flowAdminModule.getFlowFormFilestore();
	}

	@Override
	public boolean allowSkipOverviewForFlowForms() {

		return flowAdminModule.allowSkipOverviewForFlowForms();
	}

	@Override
	public boolean deleteFlowFormFile(FlowForm form) {

		return flowAdminModule.deleteFlowFormFile(form);
	}

	@Override
	public void addFlowFamilyEvent(String message, ImmutableFlow flow, User user) {

		flowAdminModule.addFlowFamilyEvent(message, flow, user);
	}

	@Override
	public EventHandler getEventHandler() {

		return flowAdminModule.getEventHandler();
	}

	public Flow getCachedFlow(Integer flowID) {

		return flowAdminModule.getCachedFlow(flowID);
	}

	public String getCkConnectorModuleAlias() {

		return flowAdminModule.getCkConnectorModuleAlias();
	}

	public String getCssPath() {

		return flowAdminModule.getCssPath();
	}

	public boolean requiresTags() {

		return flowAdminModule.requiresTags();
	}

	public FlowFamily getFlowFamilyByAlias(String alias) {

		return flowAdminModule.getFlowFamilyByAlias(alias);
	}

	public Flow getLatestFlowVersion(FlowFamily flowFamily) {

		return flowAdminModule.getLatestFlowVersion(flowFamily);
	}

	public boolean checkAliasForSystemCollision(String alias) {

		return flowAdminModule.checkAliasForSystemCollision(alias);
	}

	public List<FlowAdminFragmentExtensionViewProvider> getFragmentExtensionViewProviders() {

		List<FlowAdminFragmentExtensionViewProvider> extensionProviders = new ArrayList<>(flowAdminModule.getFragmentExtensionViewProviders());

		Iterator<FlowAdminFragmentExtensionViewProvider> it = extensionProviders.iterator();
		while (it.hasNext()) {

			FlowAdminFragmentExtensionViewProvider extension = it.next();

			if (allowedExtensions == null || !allowedExtensions.contains(extension.getClass().getName())) {
				it.remove();
			}
		}

		return extensionProviders;
	}

	public boolean isBlockForeignIDs() {

		return flowAdminModule.isBlockForeignIDs();
	}

	public FlowAdminModule getFlowAdminModule() {

		return flowAdminModule;
	}

	@WebPublic(alias = "icon")
	public ForegroundModuleResponse getFlowIcon(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws SQLException, URINotFoundException {

		return flowAdminModule.getFlowIcon(req, res, user, uriParser);
	}

	@WebPublic(alias = "extension", autoAppendLinks = false, autoAppendScripts = false)
	public ForegroundModuleResponse processFragmentExtensionView(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		Integer flowID;
		Integer extensionModuleID;
		Flow flow;
		FlowAdminFragmentExtensionViewProvider fragmentExtension;

		if (uriParser.size() >= 3 && (flowID = uriParser.getInt(2)) != null && (extensionModuleID = uriParser.getInt(3)) != null && (flow = flowAdminModule.getCachedFlow(flowID)) != null && (fragmentExtension = flowAdminModule.getFragmentExtensionViewProvider(extensionModuleID)) != null) {

			if (!hasFlowAccess(user, flow)) {

				throw new AccessDeniedException("User does not have access to flow type " + flow.getFlowType());
			}

			if (!hasFlowAdminExtensionAccess(fragmentExtension, user)) {

				throw new AccessDeniedException("User does not have access to fragment extension " + fragmentExtension);
			}

			String extensionRequestURL = getFragmentExtensionViewProviderURL(fragmentExtension, flow);

			if (uriParser.size() >= 4 && "static".equals(uriParser.get(4))) {

				return staticContentModule.processRequest((Module<?>) fragmentExtension, fragmentExtension.getModuleDescriptor(), req, res, user, uriParser.getNextLevel(4));
			}

			ViewFragment viewFragment = fragmentExtension.processRequest(extensionRequestURL, flow, req, res, user, uriParser);

			if (res.isCommitted()) {
				return null;
			}

			if (viewFragment == null) {

				redirectToMethod(req, res, "/showflow/" + flow.getFlowID() + "#" + fragmentExtension.getExtensionViewLinkName());
				return null;
			}

			Document doc = createDocument(req, uriParser, user);
			Element updateUserElement = doc.createElement("ViewFragmentExtension");
			doc.getFirstChild().appendChild(updateUserElement);

			updateUserElement.appendChild(viewFragment.toXML(doc));

			SimpleForegroundModuleResponse moduleResponse = new SimpleForegroundModuleResponse(doc);
			ViewFragmentUtils.appendLinksAndScripts(moduleResponse, viewFragment, extensionRequestURL);

			return moduleResponse;
		}

		throw new URINotFoundException(uriParser);
	}

	protected String getFragmentExtensionViewProviderURL(FlowAdminFragmentExtensionViewProvider fragmentExtensionProvider, Flow flow) {

		return getFullAlias() + "/extension/" + flow.getFlowID() + "/" + fragmentExtensionProvider.getModuleID();
	}

	@Override
	public int getPriority() {

		return 0;
	}

	@Override
	public ViewFragment getShowFlowTypeFragment(FlowType flowType, HttpServletRequest req, User user, URIParser uriParser) throws Exception {

		log.info("User " + user + " requesting show restricted flow admin settings for flowType " + flowType);

		FlowTypeRestrictedSettings settings = getFlowTypeRestrictedSettings(flowType.getFlowTypeID());

		Document doc = createDocument(req, uriParser, user);

		Element showElement = doc.createElement("ShowRestrictedFlowTypeSettings");
		doc.getDocumentElement().appendChild(showElement);

		if (settings != null) {

			XMLUtils.append(doc, showElement, settings);

			if (settings.getAllowedRestrictedAdminGroupIDs() != null) {

				XMLUtils.append(doc, showElement, "AllowedRestrictedAdminGroups", getGroupHandler().getGroups(settings.getAllowedRestrictedAdminGroupIDs(), false));
			}

			if (settings.getAllowedRestrictedAdminUserIDs() != null) {

				XMLUtils.append(doc, showElement, "AllowedRestrictedAdminUsers", getUserHandler().getUsers(settings.getAllowedRestrictedAdminUserIDs(), false, true));
			}
		}

		return viewFragmentTransformer.createViewFragment(doc);
	}

	@Override
	public ViewFragment getUpdateFlowTypeFragment(FlowType flowType, HttpServletRequest req, User user, URIParser uriParser, ValidationException validationException) throws Exception {

		log.info("User " + user + " requesting update restricted flow admin settings form for flowType " + flowType);

		FlowTypeRestrictedSettings settings = getFlowTypeRestrictedSettings(flowType.getFlowTypeID());

		Document doc = createDocument(req, uriParser, user);

		Element updateElement = doc.createElement("UpdateRestrictedFlowTypeSettings");
		doc.getDocumentElement().appendChild(updateElement);

		if (settings != null) {

			XMLUtils.append(doc, updateElement, settings);

			if (settings.getAllowedRestrictedAdminGroupIDs() != null) {

				XMLUtils.append(doc, updateElement, "AllowedRestrictedAdminGroups", getGroupHandler().getGroups(settings.getAllowedRestrictedAdminGroupIDs(), false));
			}

			if (settings.getAllowedRestrictedAdminUserIDs() != null) {

				XMLUtils.append(doc, updateElement, "AllowedRestrictedAdminUsers", getUserHandler().getUsers(settings.getAllowedRestrictedAdminUserIDs(), false, true));
			}
		}

		XMLUtils.appendNewElement(doc, updateElement, "FlowAdminAlias", flowAdminModule.getAlias());

		if (validationException != null) {

			XMLUtils.append(doc, updateElement, "ValidationErrors", validationException.getErrors());
		}

		if (req.getMethod().equalsIgnoreCase("POST")) {

			updateElement.appendChild(RequestUtils.getRequestParameters(req, doc));
		}

		return viewFragmentTransformer.createViewFragment(doc);
	}

	@Override
	public void validateUpdateFlowType(FlowType flowType, HttpServletRequest req, User user, URIParser uriParser) throws Exception {

		FlowTypeRestrictedSettings settings = getFlowTypeRestrictedSettings(flowType.getFlowTypeID());

		if (req.getMethod().equalsIgnoreCase("POST")) {

			if (settings == null) {

				settings = new FlowTypeRestrictedSettings();
				settings.setFlowTypeID(flowType.getFlowTypeID());
			}

			FLOW_TYPE_SETTINGS_POPULATOR.populate(settings, req);
		}
	}

	@Override
	public void updateFlowType(FlowType flowType, HttpServletRequest req, User user, URIParser uriParser) throws Exception {

		FlowTypeRestrictedSettings settings = getFlowTypeRestrictedSettings(flowType.getFlowTypeID());

		if (req.getMethod().equalsIgnoreCase("POST")) {

			if (settings == null) {

				settings = new FlowTypeRestrictedSettings();
				settings.setFlowTypeID(flowType.getFlowTypeID());
			}

			FLOW_TYPE_SETTINGS_POPULATOR.populate(settings, req);

			log.info("User " + user + " updated restricted flow admin  settings for flowType " + flowType);

			flowTypeSettingsDAO.addOrUpdate(settings, null);
		}
	}

	@Override
	public ForegroundModuleDescriptor getModuleDescriptor() {

		return moduleDescriptor;
	}

	@Override
	public List<LinkTag> getLinkTags() {

		return null;
	}

	@Override
	public List<ScriptTag> getScriptTags() {

		return null;
	}

	@WebPublic(toLowerCase = true)
	public ForegroundModuleResponse getFlowForm(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		Integer flowFormID;
		Integer flowID;
		Flow flow;

		if (uriParser.size() == 4 && (flowID = uriParser.getInt(2)) != null && (flow = flowCRUD.getBean(flowID, FlowCRUD.SHOW)) != null && (flowFormID = uriParser.getInt(3)) != null) {

			flowCRUD.checkAccess(user, flow);

			if (CollectionUtils.isEmpty(flow.getFlowForms())) {

				log.info("User " + user + " requested flow " + flow.getFlowID() + " which is not availiable in the requested format.");

				throw new FlowNotAvailiableInRequestedFormat(flow.getFlowID());
			}

			for (FlowForm flowForm : flow.getFlowForms()) {

				if (flowForm.getFlowFormID().equals(flowFormID)) {

					flowForm.setFlow(flow);

					return flowAdminModule.sendFlowForm(flowForm, req, res, user, uriParser);
				}
			}
		}

		throw new URINotFoundException(uriParser);
	}

	@Override
	public Integer getProviderID() {

		return moduleDescriptor.getModuleID();
	}

	public RestrictedFlowAdminFlowTestModule getRestrictedFlowAdminFlowTest() {

		return restrictedFlowAdminFlowTest;
	}

	@Override
	public List<String> getAllowedFlowFormFileExtensions() {

		return flowAdminModule.getAllowedFlowFormFileExtensions();
	}

	@Override
	public void addFlowFamilyEvent(String message, FlowFamily flowFamily, User user) {

		flowAdminModule.addFlowFamilyEvent(message, flowFamily, user);
	}

	@Override
	public Flow getRequestedFlow(HttpServletRequest req, User user, URIParser uriParser) throws AccessDeniedException, SQLException {

		return flowCRUD.getRequestedBean(req, null, user, uriParser, GenericCRUD.SHOW);
	}

	@Override
	public ForegroundModuleResponse showFlow(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, List<ValidationError> validationErrors) throws Exception {

		return flowCRUD.show(req, res, user, uriParser, validationErrors);
	}

	@Override
	public String getEventMessageTemplatesAddedMessage() {

		return flowAdminModule.getEventMessageTemplatesAddedMessage();
	}

	@Override
	public String getEventMessageTemplatesUpdatedMessage() {

		return flowAdminModule.getEventMessageTemplatesUpdatedMessage();
	}

	@Override
	public String getEventMessageTemplatesDeletedMessage() {

		return flowAdminModule.getEventMessageTemplatesDeletedMessage();
	}

	public AnnotatedDAO<FlowFamilyRestrictedSettings> getFlowFamilySettingsDAO() {

		return flowFamilySettingsDAO;
	}

	@Override
	public String getExtensionViewTitle() {

		return flowAdminExtensonViewTitle;
	}

	@Override
	public String getExtensionViewLinkName() {

		return "restrictedflowadminsettings";
	}

	@Override
	public int getModuleID() {

		return getModuleDescriptor().getModuleID();
	}

	@Override
	public FlowAdminExtensionShowView getShowView(String extensionRequestURL, Flow flow, HttpServletRequest req, User user, URIParser uriParser) throws TransformerException, SQLException {

		FlowFamily flowFamily = flow.getFlowFamily();

		FlowFamilyRestrictedSettings settings = getFlowFamilyRestrictedSettings(flowFamily.getFlowFamilyID());

		Document doc = createDocument(req, uriParser, user);

		Element showElement = doc.createElement("ShowRestrictedFlowFamilySettings");
		doc.getDocumentElement().appendChild(showElement);

		XMLUtils.appendNewElement(doc, showElement, "extensionRequestURL", extensionRequestURL);

		boolean enabled = false;

		if (settings != null) {

			enabled = true;

			Element settingsElement = XMLUtils.append(doc, showElement, settings);

			if (settings.getAllowedRestrictedAdminGroupIDs() != null) {

				XMLUtils.append(doc, settingsElement, "AllowedRestrictedAdminGroups", getGroupHandler().getGroups(settings.getAllowedRestrictedAdminGroupIDs(), false));
			}

			if (settings.getAllowedRestrictedAdminUserIDs() != null) {

				XMLUtils.append(doc, settingsElement, "AllowedRestrictedAdminUsers", getUserHandler().getUsers(settings.getAllowedRestrictedAdminUserIDs(), false, true));
			}
		}

		return new FlowAdminExtensionShowView(viewFragmentTransformer.createViewFragment(doc, true), enabled);
	}

	@Override
	public ViewFragment processRequest(String extensionRequestURL, Flow flow, HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		String method = uriParser.get(4);

		if ("updateflowsettings".equals(method)) {

			return updateFlowSettingsForm(extensionRequestURL, flow, req, user, uriParser);

		}

		throw new URINotFoundException(uriParser);
	}

	//TODO only allow selecting users who have view access to the module
	private ViewFragment updateFlowSettingsForm(String extensionRequestURL, Flow flow, HttpServletRequest req, User user, URIParser uriParser) throws TransformerException, SQLException {

		FlowFamily flowFamily = flow.getFlowFamily();

		FlowFamilyRestrictedSettings settings = getFlowFamilyRestrictedSettings(flowFamily.getFlowFamilyID());

		List<ValidationError> validationErrors = null;

		if ("POST".equalsIgnoreCase(req.getMethod())) {

			try {

				updateFlowSettings(flow, req, user, flowFamily, settings);

				return null;

			} catch (ValidationException e) {

				validationErrors = CollectionUtils.addAndInstantiateIfNeeded(validationErrors, e.getErrors());
			}
		}

		log.info("User " + user + " requesting update restricted flow admin settings form for flow family " + flowFamily);

		Document doc = createDocument(req, uriParser, user);

		Element updateElement = doc.createElement("UpdateRestrictedFlowFamilySettings");
		doc.getDocumentElement().appendChild(updateElement);

		updateElement.appendChild(flow.toXML(doc));
		XMLUtils.appendNewElement(doc, updateElement, "extensionRequestURL", extensionRequestURL);
		XMLUtils.appendNewElement(doc, updateElement, "FlowAdminAlias", flowAdminModule.getAlias());

		if (settings != null) {

			Element settingsElement = XMLUtils.append(doc, updateElement, settings);

			if (settings.getAllowedRestrictedAdminGroupIDs() != null) {

				XMLUtils.append(doc, settingsElement, "AllowedRestrictedAdminGroups", getGroupHandler().getGroups(settings.getAllowedRestrictedAdminGroupIDs(), false));
			}

			if (settings.getAllowedRestrictedAdminUserIDs() != null) {

				XMLUtils.append(doc, settingsElement, "AllowedRestrictedAdminUsers", getUserHandler().getUsers(settings.getAllowedRestrictedAdminUserIDs(), false, true));
			}
		}

		if (validationErrors != null) {

			XMLUtils.append(doc, updateElement, "ValidationErrors", validationErrors);
			updateElement.appendChild(RequestUtils.getRequestParameters(req, doc));
		}

		return flowAdminFragmentExtensionViewFragmentTransformer.createViewFragment(doc);
	}

	private void updateFlowSettings(Flow flow, HttpServletRequest req, User user, FlowFamily flowFamily, FlowFamilyRestrictedSettings settings) throws ValidationException, SQLException {

		boolean isNewSetting = false;

		if (settings == null) {

			settings = new FlowFamilyRestrictedSettings();
			settings.setFlowFamilyID(flow.getFlowFamily().getFlowFamilyID());

			isNewSetting = true;
		}

		settings = FLOW_FAMILY_SETTINGS_POPULATOR.populate(settings, req);

		boolean anyRestrictedUserOrGroup = !CollectionUtils.isEmpty(settings.getAllowedRestrictedAdminGroupIDs()) || !CollectionUtils.isEmpty(settings.getAllowedRestrictedAdminUserIDs());

		if (!anyRestrictedUserOrGroup && isNewSetting) {

			return;
		}

		if (anyRestrictedUserOrGroup) {

			log.info("User " + user + " updating restricted flow admin settings for flow family " + flowFamily);

			getFlowFamilySettingsDAO().addOrUpdate(settings, null);

		} else if (!isNewSetting) {

			log.info("User " + user + " deleting restricted flow admin settings for flow family " + flowFamily);

			getFlowFamilySettingsDAO().delete(settings);
		}

		flowAdminModule.addFlowFamilyEvent(flowAdminModule.getEventFlowUpdatedMessage(), flow.getFlowFamily(), user);
	}

}
