<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>
	
	<xsl:variable name="updateflowsettingsscripts">
		/js/UserGroupList.js
	</xsl:variable>

	<xsl:variable name="updateflowsettingslinks">
		/css/UserGroupList.css?v=1
	</xsl:variable>
	
	<xsl:template match="Document">
		
		<xsl:choose>
			<xsl:when test="ViewFragmentExtension or ShowRestrictedFlowTypeSettings or UpdateRestrictedFlowTypeSettings or ShowRestrictedFlowFamilySettings or UpdateRestrictedFlowFamilySettings">
			
				<xsl:apply-templates select="ViewFragmentExtension" />
				
				<xsl:apply-templates select="ShowRestrictedFlowTypeSettings" />
				<xsl:apply-templates select="UpdateRestrictedFlowTypeSettings" />
				
				<xsl:apply-templates select="ShowRestrictedFlowFamilySettings" />
				<xsl:apply-templates select="UpdateRestrictedFlowFamilySettings" />
				
			</xsl:when>
			<xsl:otherwise>
			
				<div class="contentitem errands-wrapper flowadmin">
					
					<xsl:apply-templates select="ListFlows" />
					<xsl:apply-templates select="ShowFlow" />
					<xsl:apply-templates select="UpdateFlow" />
					
					<xsl:apply-templates select="UpdateFlowFamily"/>
					
					<xsl:apply-templates select="AddFlowForm" />
					<xsl:apply-templates select="UpdateFlowForm" />
					
					<xsl:apply-templates select="AddMessageTemplate" />
					<xsl:apply-templates select="UpdateMessageTemplate" />
					
				</div>
				
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="ShowRestrictedFlowTypeSettings">
	
		<fieldset>
			<legend>
				<img class="alignmiddle" src="{$imgPath}/lock.png" alt="" />
				<xsl:text>&#x20;</xsl:text>
				<xsl:value-of select="$i18n.FlowType.RestrictedAdminAccess.Title"/>
			</legend>
			
			<xsl:if test="AllowedRestrictedAdminGroups">
				<span class="floatleft bold">
					<xsl:value-of select="$i18n.allowedGroups"/>
				</span>
				
				<xsl:apply-templates select="AllowedRestrictedAdminGroups/group" mode="list"/>
			</xsl:if>
			
			<xsl:if test="AllowedRestrictedAdminUsers">
				<span class="floatleft bold">
					<xsl:value-of select="$i18n.allowedUsers"/>
				</span>
				
				<xsl:apply-templates select="AllowedRestrictedAdminUsers/user" mode="list"/>
			</xsl:if>
			
			<xsl:if test="not(AllowedRestrictedAdminGroups) and not(AllowedRestrictedAdminUsers)">
			
				<span class="floatleft">
					<xsl:value-of select="$i18n.onlyModuleRestrictedAdminAccess"/>
				</span>
			
			</xsl:if>
		</fieldset>
	
	</xsl:template>
	
	<xsl:template match="UpdateRestrictedFlowTypeSettings">
	
		<fieldset class="floatleft full bigmarginbottom">
			<legend><xsl:value-of select="$i18n.FlowType.RestrictedAdminAccess.Title" /></legend>
			
			<xsl:apply-templates select="ValidationErrors/validationError"/>
		
			<p class="margin">
				<xsl:value-of select="$i18n.FlowType.RestrictedAdminAccess.Description" />
			</p>
			
			<label class="floatleft full">
				<xsl:value-of select="$i18n.allowedGroups" />
			</label>
			
			<xsl:call-template name="GroupList">
				<xsl:with-param name="connectorURL">
					<xsl:value-of select="/Document/requestinfo/currentURI"/>
					<xsl:text>/</xsl:text>
					<xsl:value-of select="FlowAdminAlias"/>
					<xsl:text>/allgroups</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="name" select="'restrictedadmingroup'"/>
				<xsl:with-param name="groups" select="AllowedRestrictedAdminGroups" />
			</xsl:call-template>
		
			<label class="floatleft full">
				<xsl:value-of select="$i18n.allowedUsers" />
			</label>
			
			<xsl:call-template name="UserList">
				<xsl:with-param name="connectorURL">
					<xsl:value-of select="/Document/requestinfo/currentURI"/>
					<xsl:text>/</xsl:text>
					<xsl:value-of select="FlowAdminAlias"/>
					<xsl:text>/allusers</xsl:text>
				</xsl:with-param>
				<xsl:with-param name="name" select="'restrictedadminuser'"/>
				<xsl:with-param name="users" select="AllowedRestrictedAdminUsers" />
			</xsl:call-template>
		
		</fieldset>
	
	</xsl:template>
	
	<xsl:template match="ShowFlow">
	
		<xsl:variable name="disableStructureManipulation" select="Flow/flowInstanceCount > 0 or (Flow/published = 'true' and Flow/enabled = 'true')"/>
		
		<xsl:variable name="isInternal">
			<xsl:if test="not(Flow/externalLink)">true</xsl:if>
		</xsl:variable>
		
		<h1>
			<xsl:value-of select="Flow/name"/>
			<xsl:text>&#x20;(</xsl:text>
			<xsl:value-of select="$i18n.flowVersion"/>
			<xsl:text>&#x20;</xsl:text>
			<xsl:value-of select="Flow/version"/>
			<xsl:text>)</xsl:text>
		</h1>
		
		<xsl:apply-templates select="validationError"/>
		
		<a name="baseinfo"/>
		
		<fieldset>
			<legend><xsl:value-of select="$i18n.baseInfo"/></legend>
	
			<div class="floatleft full bigmarginbottom adminicons">

				<div class="floatright">
				
					<xsl:if test="/Document/user/admin = 'true'">
						<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/recacheflow/{Flow/flowID}" title="{$i18n.ReCacheFlow}">
							<img src="{$imgPath}/reload.png" alt="" />
						</a>
					</xsl:if>
				
					<a class="marginleft" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/updateflow/{Flow/flowID}" title="{$i18n.updateFlowBaseInfo.title}">
						<img src="{$imgPath}/pen.png" alt="" />
					</a>
				
				</div>
				
				<label class="floatleft">
					<xsl:value-of select="$i18n.name" />
				</label>
				
				<div class="floatleft clearboth">
					<xsl:value-of select="Flow/name" />
				</div>
			</div>
			
			<xsl:if test="Flow/externalLink">
				
				<div class="floatleft full bigmarginbottom">
				
					<label class="floatleft clearboth">
						<xsl:value-of select="$i18n.externalLink" />
					</label>
					
					<div class="floatleft clearboth">
						<a href="{Flow/externalLink}" target="_blank" title="{$i18n.OpenExternalFlow}" data-icon-after="e"><xsl:value-of select="Flow/externalLink" /></a>
					</div>
				</div>
				
			</xsl:if>
			
			<div class="floatleft min-width-thirtytree bigmarginbottom">
				
				<label class="floatleft">
					<xsl:value-of select="$i18n.icon" />
				</label>
				
				<div class="floatleft clearboth">
					<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{Flow/flowID}?{Flow/IconLastModified}" alt="" />
				</div>
			</div>
			
			<div class="floatleft min-width-thirtytree bigmarginbottom">
				
				<label class="floatleft full">
					<xsl:value-of select="$i18n.status" />
				</label>
				
				<div class="floatleft full">
						<xsl:choose>
						<xsl:when test="Flow/enabled = 'false'">
							<xsl:value-of select="$i18n.disabled" />
						</xsl:when>
						<xsl:when test="Flow/published = 'true'">
							<xsl:value-of select="$i18n.published" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.notPublished" />
						</xsl:otherwise>
					</xsl:choose>
				</div>
			</div>
			
			<div class="floatleft min-width-thirtytree bigmarginbottom">
				<div class="floatleft full">
					<label><xsl:value-of select="$i18n.FlowFamilyID" /></label>
					<div><xsl:value-of select="Flow/FlowFamily/flowFamilyID" /></div>
				</div>
			</div>
			
			<xsl:if test="Flow/publishDate">
				<div class="floatleft min-width-thirtytree">
				
					<div class="floatleft fifty">
						
						<label class="floatleft">
							<xsl:value-of select="$i18n.publishDate" />
						</label>
						
						<div class="floatleft clearboth">
							<xsl:value-of select="Flow/publishDate" />
						</div>
					</div>
					
					<xsl:if test="Flow/unPublishDate">
						<div class="floatleft fifty">
							
							<label class="floatleft">
								<xsl:value-of select="$i18n.unPublishDate" />
							</label>
							
							<div class="floatleft clearboth">
								<xsl:value-of select="Flow/unPublishDate" />
							</div>
						</div>
					</xsl:if>
				</div>
			</xsl:if>
			
			<div class="floatright min-width-thirtytree">
				<div class="floatleft fifty">
					<label><xsl:value-of select="$i18n.FlowID" /></label>
					<div><xsl:value-of select="Flow/flowID" /></div>
				</div>
			</div>
			
			<div class="full clearboth"/>
			
			<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
			
				<div class="floatleft">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'enabled'" />
						<xsl:with-param name="id" select="'enabled'" />
						<xsl:with-param name="element" select="Flow" />
						<xsl:with-param name="disabled" select="'true'" />
					</xsl:call-template>
					
					<label for="enabled">
						<xsl:value-of select="$i18n.enabled" />
					</label>
				</div>
			</div>
			
			<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
			
				<div class="floatleft">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'skipOverview'" />
						<xsl:with-param name="id" select="'skipOverview'" />
						<xsl:with-param name="element" select="Flow" />
						<xsl:with-param name="disabled" select="'true'" />
					</xsl:call-template>
					
					<label for="skipOverview">
						<xsl:value-of select="$i18n.skipOverview" />
					</label>
				</div>
			</div>
			
			<xsl:if test="$isInternal = 'true'">
			
				<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
				
					<div class="floatleft">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'usePreview'" />
							<xsl:with-param name="id" select="'usePreview'" />
							<xsl:with-param name="element" select="Flow" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
						
						<label for="usePreview">
							<xsl:value-of select="$i18n.PreviewEnabled" />
						</label>
					</div>
				</div>
				
				<div class="floatleft min-width-thirtytree bigmarginbottom margintop internal">
				
					<div class="floatleft">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'paymentSupportEnabled'" />
							<xsl:with-param name="id" select="'paymentSupportEnabled'" />
							<xsl:with-param name="element" select="Flow" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
						
						<label for="paymentSupportEnabled">
							<xsl:value-of select="$i18n.PaymentEnabled" />
						</label>
					</div>
				</div>
				
			</xsl:if>
			
			<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
			
				<div class="floatleft">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'requireAuthentication'" />
						<xsl:with-param name="id" select="'requireAuthentication'" />
						<xsl:with-param name="element" select="Flow" />
						<xsl:with-param name="disabled" select="'true'" />
					</xsl:call-template>
					
					<label for="requireAuthentication">
						<xsl:value-of select="$i18n.requirersAuthentication" />
					</label>
				</div>
			</div>
				
			<xsl:if test="ForeignIDsBlocked and Flow/requireAuthentication = 'true'">
				<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
				
					<div class="floatleft">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'allowForeignIDs'" />
							<xsl:with-param name="id" select="'allowForeignIDs'" />
							<xsl:with-param name="element" select="Flow" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
						
						<label for="allowForeignIDs">
							<xsl:value-of select="$i18n.Flow.allowForeignIDs" />
						</label>
					</div>
				</div>
			</xsl:if>
				
			<xsl:if test="$isInternal = 'true'">
				
				<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
				
					<div class="floatleft">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'requireSigning'" />
							<xsl:with-param name="id" select="'requireSigning'" />
							<xsl:with-param name="element" select="Flow" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
						
						<label for="requireSigning">
							<xsl:value-of select="$i18n.requiresSigning" />
						</label>
					</div>
				</div>
				
				<xsl:if test="SupportsSequentialSigning and Flow/requireSigning = 'true'">
					<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
					
						<div class="floatleft">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="name" select="'useSequentialSigning'" />
								<xsl:with-param name="id" select="'useSequentialSigning'" />
								<xsl:with-param name="element" select="Flow" />
								<xsl:with-param name="disabled" select="'true'" />
							</xsl:call-template>
							
							<label for="useSequentialSigning">
								<xsl:value-of select="$i18n.Flow.useSequentialSigning" />
							</label>
						</div>
					</div>
				</xsl:if>
				
				<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
				
					<div class="floatleft">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'hideFromOverview'" />
							<xsl:with-param name="id" select="'hideFromOverview'" />
							<xsl:with-param name="element" select="Flow" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
						
						<label for="hideFromOverview">
							<xsl:value-of select="$i18n.hideFromOverview" />
						</label>
					</div>
				</div>
				
				<xsl:if test="SubmitSurveyEnabled">
					<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
					
						<div class="floatleft">
							<xsl:call-template name="createCheckbox">
								<xsl:with-param name="name" select="'showSubmitSurvey'" />
								<xsl:with-param name="id" select="'showSubmitSurvey'" />
								<xsl:with-param name="element" select="Flow" />
								<xsl:with-param name="disabled" select="'true'" />
							</xsl:call-template>
							
							<label for="showSubmitSurvey">
								<xsl:value-of select="$i18n.showSubmitSurvey" />
							</label>
						</div>
					</div>
				</xsl:if>

				<div class="floatleft min-width-thirtytree bigmarginbottom margintop">
				
					<div class="floatleft">
						<xsl:call-template name="createCheckbox">
							<xsl:with-param name="name" select="'hideSubmitStepText'" />
							<xsl:with-param name="id" select="'hideSubmitStepText'" />
							<xsl:with-param name="element" select="Flow" />
							<xsl:with-param name="disabled" select="'true'" />
						</xsl:call-template>
						
						<label for="hideSubmitStepText">
							<xsl:value-of select="$i18n.hideSubmitStepText" />
						</label>
					</div>
				</div>
			
			</xsl:if>
			
			<div class="floatleft full bigmarginbottom">
				
				<label class="floatleft full">
					<xsl:value-of select="$i18n.shortDescription" />
				</label>
				
				<div class="floatleft full border">
					<div class="padding">
						<xsl:value-of select="Flow/shortDescription" disable-output-escaping="yes"/>
					</div>
				</div>
			</div>
			
			<xsl:if test="Flow/longDescription">
			
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.longDescription" />
					</label>
					
					<div class="floatleft full border">
						<div class="padding">
							<xsl:value-of select="Flow/longDescription" disable-output-escaping="yes"/>	
						</div>
					</div>
				</div>
			
			</xsl:if>
			
			<xsl:if test="$isInternal = 'true'">
			
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.submittedMessage" />
					</label>
					
					<div class="floatleft full border">
						<div class="padding">
							<xsl:value-of select="Flow/submittedMessage" disable-output-escaping="yes"/>
						</div>
					</div>
				</div>
			
			</xsl:if>

			<xsl:if test="Flow/Tags">
			
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.tags" />
					</label>
					
					<div class="floatleft full border">
						<div class="padding">
							<ul>
								<xsl:for-each select="Flow/Tags/tag">
									<li>
										<xsl:value-of select="."/>
									</li>
								</xsl:for-each>
							</ul>
						</div>
					</div>
				</div>
						
			</xsl:if>

			<xsl:if test="Flow/Checks">
			
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.checks" />
					</label>
					
					<div class="floatleft full border">
						<div class="padding">
							<ul>
								<xsl:for-each select="Flow/Checks/check">
									<li>
										<xsl:value-of select="."/>
									</li>
								</xsl:for-each>
							</ul>
						</div>
					</div>
				</div>
						
			</xsl:if>
			
			<xsl:if test="Flow/FlowFamily/Aliases">
			
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.aliases" />
					</label>
					
					<div class="floatleft full border">
						<div class="padding">
							<ul>
								<xsl:for-each select="Flow/FlowFamily/Aliases/Alias">
									<li>
										
										<xsl:variable name="url">
											<xsl:value-of select="'https://'"/>
											<xsl:value-of select="/Document/requestinfo/servername"/>
											<xsl:value-of select="/Document/requestinfo/contextpath"/>
											<xsl:value-of select="'/'"/>
											<xsl:value-of select="."/>
										</xsl:variable>
										
										<a href="{$url}">
											<xsl:value-of select="$url"/>
										</a>
									</li>
								</xsl:for-each>
							</ul>
						</div>
					</div>
				</div>
						
			</xsl:if>
			
			<xsl:if test="Flow/FlowFamily/contactName">
				
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full"><xsl:value-of select="$i18n.contact.title" /></label>
					
					<div class="floatleft full border">
					
						<div class="padding">
					
							<div class="floatleft">
						
								<label class="floatleft full nomargin">
									<xsl:value-of select="$i18n.contact.name" />
								</label>
								
								<div class="floatleft full">
									<xsl:value-of select="Flow/FlowFamily/contactName" />
								</div>
							
							</div>
							
							<xsl:if test="Flow/FlowFamily/contactEmail">
								<div class="floatleft">
							
									<label class="floatleft full nomargin">
										<xsl:value-of select="$i18n.contact.email" />
									</label>
									
									<div class="floatleft full">
										<xsl:value-of select="Flow/FlowFamily/contactEmail" />
									</div>
								
								</div>
							</xsl:if>
							
							<xsl:if test="Flow/FlowFamily/contactPhone">
								<div class="floatleft">
							
									<label class="floatleft full nomargin">
										<xsl:value-of select="$i18n.contact.phone" />
									</label>
									
									<div class="floatleft full">
										<xsl:value-of select="Flow/FlowFamily/contactPhone" />
									</div>
								
								</div>
							</xsl:if>

							<xsl:if test="Flow/FlowFamily/contactWebAddress">
								<div class="floatleft">
							
									<label class="floatleft full nomargin">
										<xsl:value-of select="$i18n.contact.webaddress" />
									</label>
									
									<div class="floatleft full">
										<xsl:value-of select="Flow/FlowFamily/contactWebAddress" />
									</div>
								
								</div>
							</xsl:if>

					
						</div>
					
					</div>
					
				</div>
				
			</xsl:if>
			
			<xsl:if test="Flow/FlowFamily/ownerName">
				
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full"><xsl:value-of select="$i18n.owner.title" /></label>
					
					<div class="floatleft full border">
					
						<div class="padding">
					
							<div class="floatleft">
						
								<label class="floatleft full nomargin">
									<xsl:value-of select="$i18n.owner.name" />
								</label>
								
								<div class="floatleft full">
									<xsl:value-of select="Flow/FlowFamily/ownerName" />
								</div>
							
							</div>
							
							<xsl:if test="Flow/FlowFamily/ownerEmail">
								<div class="floatleft">
							
									<label class="floatleft full nomargin">
										<xsl:value-of select="$i18n.owner.email" />
									</label>
									
									<div class="floatleft full">
										<xsl:value-of select="Flow/FlowFamily/ownerEmail" />
									</div>
								
								</div>
							</xsl:if>
							
						</div>
					
					</div>
					
				</div>
				
			</xsl:if>
			
		</fieldset>
		
		<a name="pdfform"/>
		
		<fieldset>
			<legend><xsl:value-of select="$i18n.FlowForm"/></legend>
			
			<xsl:choose>
				<xsl:when test="Flow/FlowForms/FlowForm">
				
					<div>
						<xsl:apply-templates select="Flow/FlowForms/FlowForm" mode="list"/>
					</div>
				
				</xsl:when>
				<xsl:otherwise>
				
					<xsl:value-of select="$i18n.hasNoFlowForm"/>
					
				</xsl:otherwise>
			</xsl:choose>
			
			<div class="clearboth floatright marginright">
				
				<xsl:choose>
					<xsl:when test="Flow/skipOverview = 'true' and not(AllowSkipOverviewForFlowForms)">
					
						<xsl:value-of select="$i18n.MayNotAddFlowFormIfOverviewSkipIsSet"/>
					
					</xsl:when>
					<xsl:otherwise>
					
						<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/addflowform/{Flow/flowID}" title="{$i18n.addFlowForm.link.title}">
							<xsl:value-of select="$i18n.addFlowForm.link.title"/>
							<img class="marginleft" src="{$imgPath}/add.png" alt="" />
						</a>
						
					</xsl:otherwise>
				</xsl:choose>
				
			</div>
			
			<xsl:if test="FlowTestModule and (Flow/Steps/Step or Flow/FlowForms/FlowForm)">
				
				<div class="floatright marginright clearboth">
					<a href="{FlowTestModule}/overview/{Flow/flowID}" title="{$i18n.testFlow}" target="_blank">
						<xsl:value-of select="$i18n.testFlow"/>
						<img class="marginleft" src="{$imgPath}/play.png" alt="" />
					</a>
				</div>
				
			</xsl:if>
			
		</fieldset>
		
		<xsl:if test="$isInternal = 'true'">
		
			<a name="messagetemplates"/>
		
			<fieldset>
				<legend><xsl:value-of select="$i18n.MessageTemplates.title"/></legend>
				
				<xsl:choose>
					<xsl:when test="Flow/FlowFamily/MessageTemplates">
						
						<table class="full coloredtable sortabletable oep-table" cellspacing="0">
							<thead>
								<tr>
									<th><xsl:value-of select="$i18n.MessageTemplate.name" /></th>
									<th width="37" />
								</tr>
							</thead>
							<tbody>
								
								<xsl:apply-templates select="Flow/FlowFamily/MessageTemplates/MessageTemplate" mode="list"/>
								
							</tbody>
						</table>
						
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.MessageTemplates.noMessageTemplates" />
					</xsl:otherwise>
				</xsl:choose>
				
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/addmessagetemplate/{Flow/flowID}" class="floatright">
					<xsl:value-of select="$i18n.MessageTemplates.add" />
					<img class="marginleft" src="{$imgPath}/add.png" alt="" />
				</a>
				
			</fieldset>
	
		</xsl:if>
		
		<xsl:apply-templates select="ExtensionProvider" />
	
		<a name="versions"/>
	
		<fieldset>
			<legend><xsl:value-of select="$i18n.versions"/></legend>
			
			<p class="nomargin"><xsl:value-of select="$i18n.versions.description"/></p>
	
			<xsl:choose>
				<xsl:when test="FlowVersions">
				
					<table id="flowversionlist" class="full coloredtable sortabletable oep-table" cellspacing="0">
						<thead>	
							<tr>
								<th width="25"></th>
								<th><xsl:value-of select="$i18n.name" /></th>
								
								<xsl:if test="/Document/UseCategories">
									<th><xsl:value-of select="$i18n.flowCategory" /></th>
								</xsl:if>
								
								<th><xsl:value-of select="$i18n.version.title" /></th>
								
								<th width="75"><xsl:value-of select="$i18n.status" /></th>
							</tr>
						</thead>
						<tbody>
							<xsl:apply-templates select="FlowVersions/Flow" mode="list-versions">
								<xsl:with-param name="isInternal" select="$isInternal" />	
							</xsl:apply-templates>
						</tbody>
					</table>

				</xsl:when>
				<xsl:otherwise>
					<p><xsl:value-of select="$i18n.flowHasNoOtherVersions"/></p>
				</xsl:otherwise>
			</xsl:choose>
				
		</fieldset>
		
	</xsl:template>
	
	<xsl:template match="ExtensionProvider">
		
		<fieldset>
			
			<legend><xsl:value-of select="Title"/></legend>
			
			<xsl:value-of select="HTML" disable-output-escaping="yes"/>
			
		</fieldset>
		
	</xsl:template>
	
	<xsl:template match="Flow" mode="list-versions">
		
		<xsl:param name="isInternal" />
			
		<tr>
			<xsl:if test="published = 'false' or enabled = 'false'">
				<xsl:attribute name="class">disabled</xsl:attribute>
			</xsl:if>
			<td class="icon">
				<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}?{IconLastModified}" width="25" alt="" />
			</td>
			<td>
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showflow/{flowID}"><xsl:value-of select="name" /></a>
			</td>
			
			<xsl:if test="/Document/UseCategories">
				<td>
					<xsl:if test="Category">
						<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showflow/{flowID}"><xsl:value-of select="Category/name" /></a>
					</xsl:if>
				</td>
			</xsl:if>
			
			<td>
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showflow/{flowID}"><xsl:value-of select="version" /></a>
			</td>
			<td>
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/showflow/{flowID}">
				
					<xsl:choose>
						<xsl:when test="enabled = 'false'">
							<xsl:value-of select="$i18n.disabled" />
						</xsl:when>
						<xsl:when test="published = 'true'">
							<xsl:value-of select="$i18n.published" />
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$i18n.notPublished" />
						</xsl:otherwise>
					</xsl:choose>
					
				</a>
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template name="flowForm">
		
		<xsl:variable name="isInternal">
			<xsl:if test="not(Flow/externalLink)">true</xsl:if>
		</xsl:variable>
		
		<xsl:if test="not(/Document/UpdateFlow and $isInternal = 'true')">
		
			<div class="floatleft full bigmarginbottom external">
				
				<xsl:if test="/Document/AddFlow">
					<xsl:attribute name="class">floatleft full bigmarginbottom external hidden</xsl:attribute>
				</xsl:if>
				
				<label for="name" class="floatleft full">
					<xsl:value-of select="$i18n.externalLink" />
				</label>
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'externalLink'"/>
						<xsl:with-param name="name" select="'externalLink'"/>
						<xsl:with-param name="element" select="Flow" />
					</xsl:call-template>
				</div>
			</div>
		</xsl:if>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="shortDescription" class="floatleft full">
				<xsl:value-of select="$i18n.shortDescription" />
			</label>
			
			<div class="floatleft full">

				<xsl:call-template name="createTextArea">
					<xsl:with-param name="name" select="'shortDescription'"/>
					<xsl:with-param name="class" select="'flow-ckeditor'"/>
					<xsl:with-param name="element" select="Flow" />
				</xsl:call-template>
				
			</div>
		</div>
		
		<div class="floatleft full bigmarginbottom">
			
			<label for="longDescription" class="floatleft full">
				<xsl:value-of select="$i18n.longDescription" />
			</label>
			
			<div class="floatleft full">

				<xsl:call-template name="createTextArea">
					<xsl:with-param name="name" select="'longDescription'"/>
					<xsl:with-param name="class" select="'flow-ckeditor'"/>
					<xsl:with-param name="element" select="Flow" />
				</xsl:call-template>
				
			</div>
		</div>
		
		<xsl:if test="$isInternal = 'true'">
			
			<div class="floatleft full bigmarginbottom internal">
				
				<label for="submittedMessage" class="floatleft full">
					<xsl:value-of select="$i18n.submittedMessage" />
				</label>
				
				<div class="floatleft full">
	
					<xsl:call-template name="createTextArea">
						<xsl:with-param name="name" select="'submittedMessage'"/>
						<xsl:with-param name="class" select="'flow-ckeditor'"/>
						<xsl:with-param name="element" select="Flow" />
					</xsl:call-template>
					
				</div>
			</div>
		
		</xsl:if>
			
		<xsl:call-template name="initializeFCKEditor">
			<xsl:with-param name="basePath"><xsl:value-of select="/Document/requestinfo/contextpath"/>/static/f/<xsl:value-of select="/Document/module/sectionID"/>/<xsl:value-of select="/Document/module/moduleID"/>/ckeditor/</xsl:with-param>
			<xsl:with-param name="customConfig">config.js</xsl:with-param>
			<xsl:with-param name="editorContainerClass">flow-ckeditor</xsl:with-param>
			<xsl:with-param name="editorHeight">150</xsl:with-param>
			
			<xsl:with-param name="contentsCss">
				<xsl:if test="cssPath">
					<xsl:value-of select="cssPath"/>
				</xsl:if>
			</xsl:with-param>
			
			<xsl:with-param name="filebrowserBrowseUri">
				
				<xsl:choose>
					<xsl:when test="ckConnectorModuleAlias">
						<xsl:text>filemanager/index.html?Connector=</xsl:text>
						<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
						<xsl:text>/connector</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="''"/>
					</xsl:otherwise>
				</xsl:choose>

			</xsl:with-param>
			
			<xsl:with-param name="filebrowserImageBrowseUri">
			
				<xsl:choose>
					<xsl:when test="ckConnectorModuleAlias">
						<xsl:text>filemanager/index.html?Connector=</xsl:text>
						<xsl:value-of select="/Document/requestinfo/contextpath"/><xsl:value-of select="ckConnectorModuleAlias" />
						<xsl:text>/connector</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="''"/>
					</xsl:otherwise>
				</xsl:choose>
			
			</xsl:with-param>
			
		</xsl:call-template>
		
		<div class="floatleft fifty bigmarginbottom paddingright border-box">
			
			<label for="tags" class="floatleft full">
				<xsl:value-of select="$i18n.tags" />
			</label>
			
			<div class="floatleft full">
				
				<xsl:call-template name="createTextArea">
					<xsl:with-param name="name" select="'tags'"/>
					<xsl:with-param name="rows" select="5"/>
					<xsl:with-param name="element" select="Flow/Tags/tag" />
					<xsl:with-param name="separateListValues" select="'true'"/>
				</xsl:call-template>
				
			</div>
		</div>
		
		<div class="paddingleft floatleft fifty bigmarginbottom border-box">
			
			<label for="checks" class="floatleft full">
				<xsl:value-of select="$i18n.checks.title" />
			</label>
			
			<div class="floatleft full">
				
				<xsl:call-template name="createTextArea">
					<xsl:with-param name="name" select="'checks'"/>
					<xsl:with-param name="rows" select="5"/>
					<xsl:with-param name="element" select="Flow/Checks/check" />
					<xsl:with-param name="separateListValues" select="'true'"/>
				</xsl:call-template>
				
			</div>
			
		</div>
		
		<h2 class="floatleft bigmargintop">
			<xsl:value-of select="$i18n.FlowFamily.SharedSettings"/>
		</h2>
		
		<div class="floatleft full bigmarginbottom margintop">
		
			<div class="floatleft full">
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'useLoginHelpLink'" />
					<xsl:with-param name="name" select="'useLoginHelpLink'" />
					<xsl:with-param name="element" select="Flow/FlowFamily" />    
				</xsl:call-template>
				
				<label for="useLoginHelpLink">
					<xsl:value-of select="$i18n.FlowFamily.LoginHelp" />
				</label>
			</div>
			
			<div id="loginhelplink-container" class="floatleft full margintop">
			
				<div class="floatleft forty">
				
					<label for="loginHelpLinkName" class="floatleft full">
						<xsl:value-of select="$i18n.FlowFamily.LoginHelp.Name" />
					</label>
					
					<div class="floatleft full">
		
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'loginHelpLinkName'" />
							<xsl:with-param name="id" select="'loginHelpLinkName'" />
							<xsl:with-param name="element" select="Flow/FlowFamily" />
							<xsl:with-param name="size" select="10" />
						</xsl:call-template>
						
					</div>
				
				</div>
				
				<div class="floatleft forty bigmarginleft">
				
					<label for="loginHelpLinkURL" class="floatleft full">
						<xsl:value-of select="$i18n.FlowFamily.LoginHelp.URL" />
					</label>
					
					<div class="floatleft full">
		
						<xsl:call-template name="createTextField">
							<xsl:with-param name="name" select="'loginHelpLinkURL'" />
							<xsl:with-param name="id" select="'loginHelpLinkURL'" />
							<xsl:with-param name="element" select="Flow/FlowFamily" />
							<xsl:with-param name="size" select="10" />
						</xsl:call-template>
						
					</div>
				
				</div>
				
			</div>
			
			<script type="text/javascript">
				$(function() {
					
					var checkbox = $("#useLoginHelpLink");
					
					var showHideLoginHelpLink = function() {
						
						var checked = checkbox.prop("checked");
						
						$("#loginhelplink-container").toggle(checked).find("input").attr("disabled", !checked);
					};
					
					checkbox.on("change", showHideLoginHelpLink);
					showHideLoginHelpLink();
				});
			</script>
		</div>
		
		<div class="floatleft full bigmarginbottom margintop">
			
			<h3><xsl:value-of select="$i18n.contact.title" /></h3>
			
			<div class="floatleft forty">
				
				<label for="contactName" class="floatleft full">
					<xsl:value-of select="$i18n.contact.name" />
				</label>
				
				<div class="floatleft full">
	
					<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'contactName'" />
						<xsl:with-param name="id" select="'contactName'" />
						<xsl:with-param name="element" select="Flow/FlowFamily" />
						<xsl:with-param name="size" select="10" />
					</xsl:call-template>
					
				</div>
			
			</div>
			
			<div class="floatleft forty bigmarginleft">
				
				<label for="contactEmail" class="floatleft full">
					<xsl:value-of select="$i18n.contact.email" />
				</label>
				
				<div class="floatleft full">
	
					<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'contactEmail'" />
						<xsl:with-param name="id" select="'contactEmail'" />
						<xsl:with-param name="element" select="Flow/FlowFamily" />
						<xsl:with-param name="size" select="10" />
					</xsl:call-template>
					
				</div>
			
			</div>
			
			<div class="floatleft forty">
			
				<label for="contactPhone" class="floatleft full">
					<xsl:value-of select="$i18n.contact.phone" />
				</label>
				
				<div class="floatleft full">
	
					<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'contactPhone'" />
						<xsl:with-param name="id" select="'contactPhone'" />
						<xsl:with-param name="element" select="Flow/FlowFamily" />
						<xsl:with-param name="size" select="10" />
					</xsl:call-template>
					
				</div>
			
			</div>

			<div class="floatleft forty bigmarginleft">
			
				<label for="contactPhone" class="floatleft full">
					<xsl:value-of select="$i18n.contact.webaddress" />
				</label>
				
				<div class="floatleft full">
	
					<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'contactWebAddress'" />
						<xsl:with-param name="id" select="'contactWebAddress'" />
						<xsl:with-param name="element" select="Flow/FlowFamily" />
						<xsl:with-param name="size" select="10" />
					</xsl:call-template>
					
				</div>
			
			</div>

			
		</div>
		
		<div class="floatleft full bigmarginbottom margintop">
			
			<h3><xsl:value-of select="$i18n.owner.title" /></h3>
			
			<div class="floatleft forty">
			
				<label for="ownerName" class="floatleft full">
					<xsl:value-of select="$i18n.owner.name" />
				</label>
				
				<div class="floatleft full">
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'ownerName'" />
						<xsl:with-param name="id" select="'ownerName'" />
						<xsl:with-param name="element" select="Flow/FlowFamily" />
						<xsl:with-param name="size" select="10" />
					</xsl:call-template>
					
				</div>
			
			</div>
			
			<div class="floatleft forty bigmarginleft">
			
				<label for="ownerEmail" class="floatleft full">
					<xsl:value-of select="$i18n.owner.email" />
				</label>
				
				<div class="floatleft full">
				
					<xsl:call-template name="createTextField">
						<xsl:with-param name="name" select="'ownerEmail'" />
						<xsl:with-param name="id" select="'ownerEmail'" />
						<xsl:with-param name="element" select="Flow/FlowFamily" />
						<xsl:with-param name="size" select="10" />
					</xsl:call-template>
					
				</div>
			
			</div>
			
		</div>
		
	</xsl:template>
	
		
	<xsl:template match="ShowRestrictedFlowFamilySettings">
	
		<a name="restrictedflowadminsettings" />
		
		<xsl:choose>
			<xsl:when test="FlowFamilyRestrictedSettings">
			
				<p class="nomargin">
					<xsl:value-of select="$i18n.FlowFamily.RestrictedAdminAccess.Show.Description"/>
				</p>
				
				<xsl:if test="FlowFamilyRestrictedSettings/AllowedRestrictedAdminGroups">
					<span class="floatleft bold">
						<xsl:value-of select="$i18n.allowedGroups"/>
					</span>
					
					<xsl:apply-templates select="FlowFamilyRestrictedSettings/AllowedRestrictedAdminGroups/group" mode="list" />
				</xsl:if>
			
				<xsl:if test="FlowFamilyRestrictedSettings/AllowedRestrictedAdminUsers">
					<span class="floatleft bold">
						<xsl:value-of select="$i18n.allowedUsers"/>
					</span>
					
					<xsl:apply-templates select="FlowFamilyRestrictedSettings/AllowedRestrictedAdminUsers/user" mode="list" />
				</xsl:if>
								
			</xsl:when>
			<xsl:otherwise>
			
				<xsl:value-of select="$i18n.FlowFamily.RestrictedAdminAccess.Show.NoAccess" />
				
			</xsl:otherwise>
		</xsl:choose>
		
		<a href="{/Document/requestinfo/contextpath}{extensionRequestURL}/updateflowsettings" class="floatright">
			<xsl:value-of select="$i18n.FlowFamily.RestrictedAdminAccess.Show.Choose" />
			<img class="marginleft vertical-align-bottom" src="{$imgPath}/pen.png" alt="" />
		</a>
	
	</xsl:template>
	
	<xsl:template match="UpdateRestrictedFlowFamilySettings">
		
		<div id="restrictedflowadminsettings" class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.FlowFamily.RestrictedAdminAccess.Update.Title"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
			</h1>
	
			<xsl:apply-templates select="ValidationErrors/validationError" mode="admin"/>
	
			<form method="post" action="{/Document/requestinfo/contextpath}{extensionRequestURL}/updateflowsettings">

				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.allowedGroups" />
					</label>
									
					<xsl:call-template name="GroupList">
						<xsl:with-param name="connectorURL">
							<xsl:value-of select="/Document/requestinfo/currentURI"/>
							<xsl:text>/</xsl:text>
							<xsl:value-of select="FlowAdminAlias"/>
							<xsl:text>/allgroups</xsl:text>
						</xsl:with-param>
						<xsl:with-param name="name" select="'restrictedadmingroup'"/>
						<xsl:with-param name="groups" select="FlowFamilyRestrictedSettings/AllowedRestrictedAdminGroups" />
					</xsl:call-template>
					
				</div>
				
				<div class="floatleft full bigmarginbottom">
					
					<label class="floatleft full">
						<xsl:value-of select="$i18n.allowedUsers" />
					</label>
					
					<xsl:call-template name="UserList">
						<xsl:with-param name="connectorURL">
							<xsl:value-of select="/Document/requestinfo/currentURI"/>
							<xsl:text>/</xsl:text>
							<xsl:value-of select="FlowAdminAlias"/>
							<xsl:text>/allusers</xsl:text>
						</xsl:with-param>
						<xsl:with-param name="name" select="'restrictedadminuser'"/>
						<xsl:with-param name="users" select="FlowFamilyRestrictedSettings/AllowedRestrictedAdminUsers" />
					</xsl:call-template>
					
				</div>
			
				<div class="floatright">
					<input type="submit" value="{$i18n.FlowFamily.RestrictedAdminAccess.Update.Submit}" />
				</div>
			
			</form>
			
		</div>
		
	</xsl:template>
		
	<xsl:template match="user" mode="list">
		
		<div class="floatleft full marginbottom border">

			<xsl:choose>
				<xsl:when test="enabled='true'">
					<img class="alignbottom" src="{$imgPath}/user.png" alt="" />
				</xsl:when>
				<xsl:otherwise>
					<img class="alignbottom" src="{$imgPath}/user_disabled.png" alt="" />
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:text>&#x20;</xsl:text>
			
			<xsl:value-of select="firstname"/>
			
			<xsl:text>&#x20;</xsl:text>
			
			<xsl:value-of select="lastname"/>
			
			<xsl:if test="username">
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:text>(</xsl:text>
					<xsl:value-of select="username"/>
				<xsl:text>)</xsl:text>
			</xsl:if>
			
		</div>
		
	</xsl:template>
	
	<xsl:template match="group" mode="list">
		
		<div class="floatleft full marginbottom border">

			<xsl:choose>
				<xsl:when test="enabled='true'">
					<img class="alignbottom" src="{$imgPath}/group.png" alt="" />
				</xsl:when>
				<xsl:otherwise>
					<img class="alignbottom" src="{$imgPath}/group_disabled.png" alt="" />
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:text>&#x20;</xsl:text>
			
			<xsl:value-of select="name"/>
		</div>	
		
	</xsl:template>
			
	<xsl:template match="ViewFragmentExtension">
		
		<xsl:value-of select="ViewFragment/HTML" disable-output-escaping="yes"/>
		
	</xsl:template>

</xsl:stylesheet>