package com.nordicpeak.flowengine.evaluators.sendtextfieldsmsevaluator;

import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;

@Table(name = "send_text_field_sms_evaluators")
@XMLElement
public class SendTextFieldSMSEvaluator extends BaseEvaluator {

	private static final long serialVersionUID = 5501896243489595373L;

	@DAOManaged
	@WebPopulate(required = true)
	@XMLElement
	private Integer textFieldID;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean enableStatusFiltering;
	
	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@SimplifiedRelation(table = "send_text_field_sms_evaluator_statuses", remoteValueColumnName = "statusID")
	@WebPopulate(paramName = "statusID")
	@XMLElement(fixCase = true, childName = "statusID")
	private List<Integer> statusIDs;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 65536)
	@XMLElement
	private String smsMessage;

	
	public String getSMSMessage() {

		return smsMessage;
	}

	public void setSMSMessage(String smsMessage) {

		this.smsMessage = smsMessage;
	}


	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		textFieldID = xmlParser.getInteger("textFieldID");
		
		statusIDs = xmlParser.getIntegers("StatusIDs/statusID");
		
		smsMessage = xmlParser.getString("smsMessage");
		
		enableStatusFiltering = xmlParser.getPrimitiveBoolean("enableStatusFiltering");
	}

	
	public Integer getTextFieldID() {
	
		return textFieldID;
	}

	
	public void setTextFieldID(Integer textFieldID) {
	
		this.textFieldID = textFieldID;
	}

	@Override
	public String toString() {

		return evaluatorDescriptor.toString();
	}

	
	public boolean enableStatusFiltering() {
	
		return enableStatusFiltering;
	}

	
	public void setEnableStatusFiltering(boolean enableStatusFiltering) {
	
		this.enableStatusFiltering = enableStatusFiltering;
	}

	
	public List<Integer> getStatusIDs() {
	
		return statusIDs;
	}

	
	public void setStatusIDs(List<Integer> statusIDs) {
	
		this.statusIDs = statusIDs;
	}
}
