package com.nordicpeak.flowengine.evaluators.settextfieldvalueattribute;

import java.sql.SQLException;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.EvaluationResponse;
import com.nordicpeak.flowengine.beans.QueryModification;
import com.nordicpeak.flowengine.enums.ModificationAction;
import com.nordicpeak.flowengine.enums.QueryState;
import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluationProviderModule;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.Evaluator;
import com.nordicpeak.flowengine.interfaces.ImmutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.queries.textfieldquery.TextField;
import com.nordicpeak.flowengine.queries.textfieldquery.TextFieldQuery;
import com.nordicpeak.flowengine.queries.textfieldquery.TextFieldQueryInstance;

public class SetTextFieldValueAttributeEvaluationProviderModule extends BaseEvaluationProviderModule<SetTextFieldValueAttributeEvaluator> {

	protected SetTextFieldValueAttributeEvaluatorCRUD evaluatorCRUD;

	protected AnnotatedDAO<SetTextFieldValueAttributeEvaluator> evaluatorDAO;

	protected QueryParameterFactory<SetTextFieldValueAttributeEvaluator, Integer> evaluatorIDParamFactory;

	@InstanceManagerDependency(required = true)
	protected QueryHandler queryHandler;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, SetTextFieldValueAttributeEvaluationProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		evaluatorDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(SetTextFieldValueAttributeEvaluator.class);
		evaluatorIDParamFactory = evaluatorDAO.getParamFactory("evaluatorID", Integer.class);

		evaluatorCRUD = new SetTextFieldValueAttributeEvaluatorCRUD(SetTextFieldValueAttributeEvaluator.class, evaluatorDAO.getWrapper("evaluatorID", Integer.class), this);
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureEvaluator(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.evaluatorCRUD.update(req, res, user, uriParser);
	}

	@Override
	public EvaluationResponse evaluate(QueryInstance queryInstance, User user, User poster, SetTextFieldValueAttributeEvaluator evaluator, EvaluationCallback callback, boolean hasQueryValidationErrors, MutableAttributeHandler attributeHandler) {

		if (evaluator.isInitialized() || evaluator.getAttributeName() == null) {

			return null;
		}

		if (!(queryInstance instanceof TextFieldQueryInstance)) {

			log.warn("Query instance " + queryInstance + " is not of the type " + TextFieldQueryInstance.class.getName());

			return null;
		}

		TextFieldQueryInstance textFieldQueryInstance = ((TextFieldQueryInstance) queryInstance);

		String oldValue = textFieldQueryInstance.getFieldValue(evaluator.getTextFieldID());

		String attributeValue = attributeHandler.getString(evaluator.getAttributeName());

		if (attributeValue != null) {

			textFieldQueryInstance.setFieldValue(evaluator.getTextFieldID(), attributeValue, attributeHandler);

			evaluator.setInitialized(true);

		} else if (evaluator.getNoAttributeValueFoundMessage() != null) {

			textFieldQueryInstance.setFieldValue(evaluator.getTextFieldID(), evaluator.getNoAttributeValueFoundMessage(), attributeHandler);
		}

		if (!ObjectUtils.compare(oldValue, textFieldQueryInstance.getFieldValue(evaluator.getTextFieldID())) && queryInstance.getQueryInstanceDescriptor().getQueryState() != QueryState.HIDDEN) {

			return new EvaluationResponse(Collections.singletonList(new QueryModification(queryInstance, ModificationAction.RELOAD, attributeHandler)));
		}

		return null;
	}

	@Override
	public Evaluator createEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		SetTextFieldValueAttributeEvaluator evaluator = new SetTextFieldValueAttributeEvaluator();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());

		return evaluator;
	}

	@Override
	public boolean supportsQueryType(Class<? extends Query> queryClass) {

		return TextFieldQuery.class.isAssignableFrom(queryClass);
	}

	@Override
	public void copyEvaluator(MutableEvaluatorDescriptor sourceEvaluatorDescriptor, MutableEvaluatorDescriptor copyEvaluatorDescriptor, Query sourceQuery, Query copyQuery, Map<Integer, ImmutableStatus> statusConversionMap, TransactionHandler transactionHandler) throws SQLException {

		SetTextFieldValueAttributeEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<SetTextFieldValueAttributeEvaluator>(evaluatorIDParamFactory.getParameter(sourceEvaluatorDescriptor.getEvaluatorID())));

		evaluator.setEvaluatorID(copyEvaluatorDescriptor.getEvaluatorID());

		List<TextField> sourceTextFields = ((TextFieldQuery) sourceQuery).getFields();
		List<TextField> copyTextFields = ((TextFieldQuery) copyQuery).getFields();

		if (sourceTextFields != null && copyTextFields != null) {

			int textFieldIndex = 0;

			while (textFieldIndex < sourceTextFields.size()) {

				if (sourceTextFields.get(textFieldIndex).getTextFieldID().equals(evaluator.getTextFieldID())) {

					evaluator.setTextFieldID(copyTextFields.get(textFieldIndex).getTextFieldID());

					break;
				}

				textFieldIndex++;
			}

		}

		this.evaluatorDAO.add(evaluator, transactionHandler, null);
	}

	protected Class<SetTextFieldValueAttributeEvaluator> getEvaluatorClass() {

		return SetTextFieldValueAttributeEvaluator.class;
	}

	protected AnnotatedDAO<SetTextFieldValueAttributeEvaluator> getEvaluatorDAO() {

		return evaluatorDAO;
	}

	protected QueryParameterFactory<SetTextFieldValueAttributeEvaluator, Integer> getEvaluatorIDParameterFactory() {

		return evaluatorIDParamFactory;
	}

	@Override
	public Evaluator getEvaluator(MutableEvaluatorDescriptor descriptor, InstanceMetadata instanceMetadata) throws Throwable {

		SetTextFieldValueAttributeEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<SetTextFieldValueAttributeEvaluator>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())));

		if (evaluator != null) {

			evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());
		}

		return evaluator;
	}

	@Override
	public boolean deleteEvaluator(ImmutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		evaluatorDAO.delete(new HighLevelQuery<SetTextFieldValueAttributeEvaluator>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())), transactionHandler);

		return true;
	}

	public QueryHandler getQueryHandler() {

		return this.queryHandler;
	}

	@Override
	public SetTextFieldValueAttributeEvaluator importEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler, Query query, Map<Integer, ImmutableStatus> statusConversionMap) throws Throwable {

		SetTextFieldValueAttributeEvaluator evaluator = getEvaluatorClass().newInstance();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		evaluator.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(evaluator.getClass())));

		if (evaluator.getTextFieldID() != null && query instanceof TextFieldQuery && ((TextFieldQuery) query).getTextFieldConversionMap() != null) {

			Map<Integer, Integer> conversionMap = ((TextFieldQuery) query).getTextFieldConversionMap();

			Integer newTextFieldID = conversionMap.get(evaluator.getTextFieldID());

			evaluator.setTextFieldID(newTextFieldID);
		}

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		return evaluator;
	}
}
