package com.nordicpeak.flowengine.evaluators.statusoverrideevaluator;

import java.sql.SQLException;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.EventListener;
import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.enums.EventSource;
import se.unlogic.hierarchy.core.enums.EventTarget;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.FlowAdminModule;
import com.nordicpeak.flowengine.FlowBrowserModule;
import com.nordicpeak.flowengine.FlowInstanceAdminModule;
import com.nordicpeak.flowengine.beans.DefaultInstanceMetadata;
import com.nordicpeak.flowengine.beans.EvaluationResponse;
import com.nordicpeak.flowengine.beans.FlowInstance;
import com.nordicpeak.flowengine.beans.FlowInstanceEvent;
import com.nordicpeak.flowengine.beans.RequestMetadata;
import com.nordicpeak.flowengine.beans.Status;
import com.nordicpeak.flowengine.enums.EventType;
import com.nordicpeak.flowengine.enums.QueryState;
import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluationProviderModule;
import com.nordicpeak.flowengine.events.FlowInstanceSaveStatusOverrideCommitedEvent;
import com.nordicpeak.flowengine.events.FlowInstanceSaveStatusOverrideEvent;
import com.nordicpeak.flowengine.events.StatusChangedByManagerEvent;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.Evaluator;
import com.nordicpeak.flowengine.interfaces.ImmutableAlternative;
import com.nordicpeak.flowengine.interfaces.ImmutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableFlow;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowInstance;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryInstance;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.ImmutableStep;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.managers.FlowInstanceManager;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesQuery;
import com.nordicpeak.flowengine.queries.fixedalternativesquery.FixedAlternativesQueryInstance;

public class StatusOverrideEvaluationProviderModule extends BaseEvaluationProviderModule<StatusOverrideEvaluator> {

	protected StatusOverrideEvaluatorCRUD evaluatorCRUD;

	protected AnnotatedDAO<StatusOverrideEvaluator> evaluatorDAO;

	protected QueryParameterFactory<StatusOverrideEvaluator, Integer> evaluatorIDParamFactory;

	@InstanceManagerDependency(required = true)
	protected QueryHandler queryHandler;

	@InstanceManagerDependency(required = true)
	protected FlowAdminModule flowAdminModule;

	@InstanceManagerDependency(required = true)
	protected FlowInstanceAdminModule flowInstanceAdminModule;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, StatusOverrideEvaluationProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		evaluatorDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(StatusOverrideEvaluator.class);
		evaluatorIDParamFactory = evaluatorDAO.getParamFactory("evaluatorID", Integer.class);

		evaluatorCRUD = new StatusOverrideEvaluatorCRUD(StatusOverrideEvaluator.class, evaluatorDAO.getWrapper("evaluatorID", Integer.class), this);
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureEvaluator(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.evaluatorCRUD.update(req, res, user, uriParser);
	}

	public List<? extends ImmutableStatus> getFlowStatuses(Integer flowID) {

		ImmutableFlow flow = flowAdminModule.getFlow(flowID);

		if (flow != null) {

			return flow.getStatuses();
		}

		return null;
	}

	@Override
	public EvaluationResponse evaluate(QueryInstance queryInstance, User user, User poster, StatusOverrideEvaluator evaluator, EvaluationCallback callback, boolean hasQueryValidationErrors, MutableAttributeHandler attributeHandler) {

		return null;
	}

	@Override
	public Evaluator createEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		StatusOverrideEvaluator evaluator = new StatusOverrideEvaluator();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());

		return evaluator;
	}

	@Override
	public boolean supportsQueryType(Class<? extends Query> queryClass) {

		return FixedAlternativesQuery.class.isAssignableFrom(queryClass);
	}

	@Override
	public void copyEvaluator(MutableEvaluatorDescriptor sourceEvaluatorDescriptor, MutableEvaluatorDescriptor copyEvaluatorDescriptor, Query sourceQuery, Query copyQuery, Map<Integer, ImmutableStatus> statusConversionMap, TransactionHandler transactionHandler) throws SQLException {

		StatusOverrideEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<StatusOverrideEvaluator>(evaluatorIDParamFactory.getParameter(sourceEvaluatorDescriptor.getEvaluatorID())));

		evaluator.setEvaluatorID(copyEvaluatorDescriptor.getEvaluatorID());

		if (evaluator.getAlternativeStatusOverrides() != null) {

			List<? extends ImmutableAlternative> sourceAlternatives = ((FixedAlternativesQuery) sourceQuery).getAlternatives();
			List<? extends ImmutableAlternative> copyAlternatives = ((FixedAlternativesQuery) copyQuery).getAlternatives();

			if (sourceAlternatives != null && copyAlternatives != null) {

				for (AlternativeStatusOverride alternativeStatusOverride : evaluator.getAlternativeStatusOverrides()) {

					int alternativeIndex = 0;

					while (alternativeIndex < sourceAlternatives.size()) {

						if (sourceAlternatives.get(alternativeIndex).getAlternativeID().equals(alternativeStatusOverride.getAlternativeID())) {

							alternativeStatusOverride.setAlternativeID(copyAlternatives.get(alternativeIndex).getAlternativeID());

							if (alternativeStatusOverride.getStatusID() != null) {

								ImmutableStatus newStatus = statusConversionMap.get(alternativeStatusOverride.getStatusID());

								if (newStatus != null) {

									alternativeStatusOverride.setStatusID(newStatus.getStatusID());
								}
							}

							break;
						}

						alternativeIndex++;
					}
				}
			}
		}

		this.evaluatorDAO.add(evaluator, transactionHandler, null);
	}

	@Override
	public StatusOverrideEvaluator importEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler, Query query, Map<Integer, ImmutableStatus> statusConversionMap) throws Throwable {

		StatusOverrideEvaluator evaluator = new StatusOverrideEvaluator();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		evaluator.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(evaluator.getClass())));

		if (evaluator.getAlternativeStatusOverrides() != null && query instanceof FixedAlternativesQuery && ((FixedAlternativesQuery) query).getAlternativeConversionMap() != null) {

			Map<Integer, Integer> conversionMap = ((FixedAlternativesQuery) query).getAlternativeConversionMap();

			for (Iterator<AlternativeStatusOverride> it = evaluator.getAlternativeStatusOverrides().iterator(); it.hasNext();) {

				AlternativeStatusOverride alternativeStatusOverride = it.next();

				Integer newAlternativeID = conversionMap.get(alternativeStatusOverride.getAlternativeID());
				ImmutableStatus newStatus = statusConversionMap.get(alternativeStatusOverride.getStatusID());

				if (newAlternativeID == null || newStatus == null) {

					it.remove();
					continue;
				}

				alternativeStatusOverride.setAlternativeID(newAlternativeID);
				alternativeStatusOverride.setStatusID(newStatus.getStatusID());
			}
		}

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		return evaluator;
	}

	protected Class<StatusOverrideEvaluator> getEvaluatorClass() {

		return StatusOverrideEvaluator.class;
	}

	protected AnnotatedDAO<StatusOverrideEvaluator> getEvaluatorDAO() {

		return evaluatorDAO;
	}

	protected QueryParameterFactory<StatusOverrideEvaluator, Integer> getEvaluatorIDParameterFactory() {

		return evaluatorIDParamFactory;
	}

	@Override
	public StatusOverrideEvaluator getEvaluator(MutableEvaluatorDescriptor descriptor, InstanceMetadata instanceMetadata) throws Throwable {

		StatusOverrideEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<StatusOverrideEvaluator>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())));

		if (evaluator != null) {

			evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());
		}

		return evaluator;
	}

	@Override
	public boolean deleteEvaluator(ImmutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		evaluatorDAO.delete(new HighLevelQuery<StatusOverrideEvaluator>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())), transactionHandler);

		return true;
	}

	public QueryHandler getQueryHandler() {

		return this.queryHandler;
	}

	@EventListener(channel = FlowInstance.class, priority = 50)
	public void processEvent(FlowInstanceSaveStatusOverrideEvent event, EventSource eventSource) {

		Status status = getOverrideStatus(event);
		ImmutableStatus previousStatus = event.getFlowInstanceManager().getFlowInstance().getStatus();

		if (status != null && (previousStatus == null || !status.getStatusID().equals(previousStatus.getStatusID()))) {
			
			log.info("Setting override status to " + status + " for event " + event);

			event.setOverrideStatus(status);
		}
	}

	//This event is currently only sent on EventType.UPDATED
	@EventListener(channel = FlowInstance.class, priority = 50)
	public void processEvent(FlowInstanceSaveStatusOverrideCommitedEvent event, EventSource eventSource) throws SQLException {

		Status status = getOverrideStatus(event);
		Status previousStatus = event.getPreviousStatus();

		if (event.isOverrideByManagerEdit() && status != null && !status.getStatusID().equals(previousStatus.getStatusID())) {

			FlowInstance flowInstance = (FlowInstance) event.getFlowInstanceManager().getFlowInstance();
			User user = event.getUser();

			log.info("Sending events for status override from " + previousStatus + " to " + status + " for event " + event);

			FlowInstanceEvent flowInstanceEvent = flowInstanceAdminModule.getFlowInstanceEventGenerator().addFlowInstanceEvent(flowInstance, EventType.STATUS_UPDATED, null, user);

			systemInterface.getEventHandler().sendEvent(FlowInstance.class, new StatusChangedByManagerEvent(flowInstance, flowInstanceEvent, flowInstanceAdminModule.getSiteProfile(flowInstance), previousStatus, user), EventTarget.ALL);
		}
	}

	private Status getOverrideStatus(FlowInstanceSaveStatusOverrideEvent event) {

		String actionID = event.getActionID();
		EventType eventType = event.getEventType();
		RequestMetadata requestMetadata = event.getRequestMetadata();

		FlowInstanceManager instanceManager = event.getFlowInstanceManager();
		ImmutableFlowInstance flowInstance = instanceManager.getFlowInstance();

		for (ImmutableStep step : flowInstance.getFlow().getSteps()) {

			if (step.getQueryDescriptors() != null) {

				for (ImmutableQueryDescriptor queryDescriptor : step.getQueryDescriptors()) {

					if (queryDescriptor.getEvaluatorDescriptors() != null) {

						ImmutableQueryInstance queryInstance = instanceManager.getQueryInstance(queryDescriptor.getQueryID());

						if (queryInstance.getQueryInstanceDescriptor().getQueryState() != QueryState.HIDDEN) {

							for (ImmutableEvaluatorDescriptor evaluatorDescriptor : queryDescriptor.getEvaluatorDescriptors()) {

								if (evaluatorDescriptor.isEnabled() && evaluatorDescriptor.getEvaluatorTypeID().equals(evaluatorTypeID)) {

									if (!(queryInstance instanceof FixedAlternativesQueryInstance)) {

										log.warn("Query instance " + queryInstance + " does not implement interface " + FixedAlternativesQueryInstance.class.getName());
										continue;
									}

									FixedAlternativesQueryInstance fixedAlternativesQueryInstance = (FixedAlternativesQueryInstance) queryInstance;

									List<? extends ImmutableAlternative> alternatives = fixedAlternativesQueryInstance.getAlternatives();

									if (CollectionUtils.isEmpty(alternatives)) {
										continue;
									}

									try {
										StatusOverrideEvaluator evaluator = getEvaluator((MutableEvaluatorDescriptor) evaluatorDescriptor, new DefaultInstanceMetadata(null));

										if (evaluator.getAlternativeStatusOverrides() == null) {
											continue;
										}

										boolean overrideStatus = false;

										// Normal submit
										if (evaluator.isUseForSubmit() && FlowBrowserModule.SUBMIT_ACTION_ID.equals(actionID) && eventType == EventType.SUBMITTED) {
											overrideStatus = true;

											// Manager edit of submitted flow instance
										} else if (evaluator.isUseForManagerEdit() && actionID == null && eventType == EventType.UPDATED && requestMetadata != null && requestMetadata.isManager()) {
											overrideStatus = true;
											event.setOverrideByManagerEdit(true);
										}

										if (overrideStatus) {

											AlternativeStatusOverride alternativeStatusOverride = evaluator.getAlternative(alternatives.get(0).getAlternativeID());

											if (alternativeStatusOverride != null && alternativeStatusOverride.getStatusID() != null) {

												for (ImmutableStatus status : flowInstance.getFlow().getStatuses()) {

													if (status.getStatusID().equals(alternativeStatusOverride.getStatusID())) {

														return (Status) status;
													}
												}
											}
										}

									} catch (Throwable t) {
										log.error("Error getting status override for evaluator " + evaluatorDescriptor, t);
									}
								}
							}
						}
					}
				}
			}
		}

		return null;
	}

}
