package com.nordicpeak.flowengine.evaluators.statusoverrideevaluator;

import java.util.ArrayList;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;

@Table(name = "status_override_evaluators")
@XMLElement
public class StatusOverrideEvaluator extends BaseEvaluator {

	private static final long serialVersionUID = -336493853396860255L;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useForSubmit;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useForManagerEdit;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<AlternativeStatusOverride> alternativeStatusOverrides;

	public boolean isUseForSubmit() {
		return useForSubmit;
	}

	public void setUseForSubmit(boolean useForUser) {
		this.useForSubmit = useForUser;
	}

	public boolean isUseForManagerEdit() {
		return useForManagerEdit;
	}

	public void setUseForManagerEdit(boolean useForManagerEdit) {
		this.useForManagerEdit = useForManagerEdit;
	}

	public List<AlternativeStatusOverride> getAlternativeStatusOverrides() {

		return alternativeStatusOverrides;
	}

	public void setAlternativeStatusOverrides(List<AlternativeStatusOverride> alternativeWeights) {

		this.alternativeStatusOverrides = alternativeWeights;
	}

	public AlternativeStatusOverride getAlternative(Integer alternativeID) {

		for (AlternativeStatusOverride alternativeStatusOverride : alternativeStatusOverrides) {

			if (alternativeStatusOverride.getAlternativeID().equals(alternativeID)) {

				return alternativeStatusOverride;
			}
		}

		return null;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();

		XMLParser submitNode = xmlParser.getNode("useForSubmit");

		if (submitNode != null) {

			useForSubmit = xmlParser.getPrimitiveBoolean("useForSubmit");
			useForManagerEdit = xmlParser.getPrimitiveBoolean("useForManagerEdit");

		} else {

			useForSubmit = true;
			useForManagerEdit = false;
		}

		List<XMLParser> statusNodes = xmlParser.getNodes("AlternativeStatusOverrides/AlternativeStatusOverride");

		if (!CollectionUtils.isEmpty(statusNodes)) {

			alternativeStatusOverrides = new ArrayList<AlternativeStatusOverride>(statusNodes.size());

			for (XMLParser parser : statusNodes) {

				AlternativeStatusOverride alternativeStatusOverride = new AlternativeStatusOverride();

				alternativeStatusOverride.populate(parser);
				alternativeStatusOverride.setEvaluator(this);

				alternativeStatusOverrides.add(alternativeStatusOverride);
			}
		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	@Override
	public String toString() {

		return evaluatorDescriptor.toString();
	}

}
