package com.nordicpeak.flowengine.evaluators.tableattributeevaluator;

import java.sql.SQLException;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.EvaluationResponse;
import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluationProviderModule;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.Evaluator;
import com.nordicpeak.flowengine.interfaces.ImmutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.queries.basetablequery.BaseDropDownAlternative;
import com.nordicpeak.flowengine.queries.basetablequery.BaseTableColumn;
import com.nordicpeak.flowengine.queries.basetablequery.BaseTableQuery;
import com.nordicpeak.flowengine.queries.basetablequery.BaseTableQueryInstance;
import com.nordicpeak.flowengine.queries.basetablequery.ColumnType;
import com.nordicpeak.flowengine.queries.basetablequery.TableRow;
import com.nordicpeak.flowengine.queries.basetablequery.interfaces.TableQueryInstance;

public class TableAttributeEvaluationProviderModule extends BaseEvaluationProviderModule<TableAttributeEvaluator> {

	protected TableAttributeEvaluatorCRUD evaluatorCRUD;

	protected AnnotatedDAO<TableAttributeEvaluator> evaluatorDAO;

	protected QueryParameterFactory<TableAttributeEvaluator, Integer> evaluatorIDParamFactory;

	@XSLVariable(prefix = "java.")
	protected String checkboxLabelTrue;

	@XSLVariable(prefix = "java.")
	protected String checkboxLabelFalse;

	@InstanceManagerDependency(required = true)
	protected QueryHandler queryHandler;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, TableAttributeEvaluationProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		evaluatorDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(TableAttributeEvaluator.class);
		evaluatorIDParamFactory = evaluatorDAO.getParamFactory("evaluatorID", Integer.class);

		evaluatorCRUD = new TableAttributeEvaluatorCRUD(TableAttributeEvaluator.class, evaluatorDAO.getWrapper("evaluatorID", Integer.class), this);
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureEvaluator(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.evaluatorCRUD.update(req, res, user, uriParser);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	@Override
	public EvaluationResponse evaluate(QueryInstance queryInstance, User user, User poster, TableAttributeEvaluator evaluator, EvaluationCallback callback, boolean hasQueryValidationErrors, MutableAttributeHandler attributeHandler) {

		if (!(queryInstance instanceof TableQueryInstance)) {

			log.warn("Query instance " + queryInstance + " is not of the type " + TableQueryInstance.class.getName());

			return null;
		}

		if (evaluator.getColumnID() == null || evaluator.getAttributeName() == null) {

			return null;
		}

		BaseTableQueryInstance tableQueryInstance = (BaseTableQueryInstance) queryInstance;
		List<BaseTableColumn> columns = tableQueryInstance.getQuery().getColumns();

		if (!CollectionUtils.isEmpty(columns)) {

			BaseTableColumn column = CollectionUtils.find(columns, c -> c.getColumnID().equals(evaluator.getColumnID()));

			if (column == null) {

				log.warn("The specified column does no longer exist, aborting evaluation for evaluator " + evaluator);

				return null;
			}

			List<TableRow> rows = tableQueryInstance.getRows();

			if (!CollectionUtils.isEmpty(rows)) {

				StringBuilder attributeStringBuilder = new StringBuilder();

				boolean first = true;

				for (TableRow row : rows) {

					String cellValue = getCellValue(tableQueryInstance, column, row);

					if (!StringUtils.isEmpty(cellValue)) {

						if (!first) {

							attributeStringBuilder.append(", ");
						}

						first = false;

						attributeStringBuilder.append(cellValue);
					}
				}

				attributeHandler.setAttribute(evaluator.getAttributeName(), attributeStringBuilder.toString());

			}
		}

		return null;
	}

	@SuppressWarnings({ "unchecked", "rawtypes" })
	private String getCellValue(BaseTableQueryInstance tableQueryInstance, BaseTableColumn column, TableRow row) {

		String cellValue = tableQueryInstance.getValue(tableQueryInstance.getValues(), row.getRowIdentifier(), column.getColumnID());

		if (column.getColumnType() == ColumnType.DROPDOWN) {

			Integer alternativeID = NumberUtils.toInt(cellValue);

			if (alternativeID != null) {

				BaseDropDownAlternative alternative = column.getDropDownAlternativeByID(alternativeID);

				if (alternative != null) {

					return alternative.getName();
				}
			}

			return null;
		}

		if (column.getColumnType() == ColumnType.CHECKBOX) {

			return Boolean.valueOf(cellValue) ? checkboxLabelTrue : checkboxLabelFalse;
		}

		return cellValue;
	}

	@Override
	public Evaluator createEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		TableAttributeEvaluator evaluator = new TableAttributeEvaluator();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());

		return evaluator;
	}

	@Override
	public boolean supportsQueryType(Class<? extends Query> queryClass) {

		return BaseTableQuery.class.isAssignableFrom(queryClass);
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	@Override
	public void copyEvaluator(MutableEvaluatorDescriptor sourceEvaluatorDescriptor, MutableEvaluatorDescriptor copyEvaluatorDescriptor, Query sourceQuery, Query copyQuery, Map<Integer, ImmutableStatus> statusConversionMap, TransactionHandler transactionHandler) throws SQLException {

		TableAttributeEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<>(evaluatorIDParamFactory.getParameter(sourceEvaluatorDescriptor.getEvaluatorID())));

		evaluator.setEvaluatorID(copyEvaluatorDescriptor.getEvaluatorID());

		List<BaseTableColumn> sourceColumns = ((BaseTableQuery) sourceQuery).getColumns();
		List<BaseTableColumn> copyColumns = ((BaseTableQuery) copyQuery).getColumns();

		if (!CollectionUtils.isEmpty(sourceColumns) && !CollectionUtils.isEmpty(copyColumns)) {

			for (int i = 0; i < sourceColumns.size(); i++) {

				if (sourceColumns.get(i).getColumnID().equals(evaluator.getColumnID())) {

					evaluator.setColumnID(copyColumns.get(i).getColumnID());
				}
			}
		}

		this.evaluatorDAO.add(evaluator, transactionHandler, null);
	}

	protected Class<TableAttributeEvaluator> getEvaluatorClass() {

		return TableAttributeEvaluator.class;
	}

	protected AnnotatedDAO<TableAttributeEvaluator> getEvaluatorDAO() {

		return evaluatorDAO;
	}

	protected QueryParameterFactory<TableAttributeEvaluator, Integer> getEvaluatorIDParameterFactory() {

		return evaluatorIDParamFactory;
	}

	@Override
	public Evaluator getEvaluator(MutableEvaluatorDescriptor descriptor, InstanceMetadata instanceMetadata) throws Throwable {

		TableAttributeEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())));

		if (evaluator != null) {

			evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());
		}

		return evaluator;
	}

	@Override
	public boolean deleteEvaluator(ImmutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		evaluatorDAO.delete(new HighLevelQuery<>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())), transactionHandler);

		return true;
	}

	public QueryHandler getQueryHandler() {

		return this.queryHandler;
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	@Override
	public TableAttributeEvaluator importEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler, Query query, Map<Integer, ImmutableStatus> statusConversionMap) throws Throwable {

		TableAttributeEvaluator evaluator = getEvaluatorClass().newInstance();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		evaluator.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(evaluator.getClass())));

		if (query instanceof BaseTableQuery && ((BaseTableQuery) query).getColumnConversionMap() != null) {

			Map<Integer, Integer> columnConversionMap = ((BaseTableQuery) query).getColumnConversionMap();

			if (evaluator.getColumnID() != null) {

				Integer newTypeColumnID = columnConversionMap.get(evaluator.getColumnID());

				evaluator.setColumnID(newTypeColumnID);
			}
		}

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		return evaluator;
	}

}
