<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
	</xsl:variable>	

	<xsl:variable name="scripts">
		/js/settableweight.js
	</xsl:variable>

	<xsl:template match="Document">

		<div class="contentitem">

			<xsl:apply-templates select="UpdateSetTableWeightEvaluator" />
		</div>

	</xsl:template>

	<xsl:template match="UpdateSetTableWeightEvaluator">

		<h1>
			<xsl:value-of select="$i18n.UpdateEvaluatorDescriptor.title" />
			<xsl:text>&#x20;</xsl:text>
			<xsl:value-of select="SetTableWeightEvaluator/EvaluatorDescriptor/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="SetTableWeightEvaluator" />
			</xsl:call-template>

			<div class="floatleft full bigmarginbottom">

				<label for="weightType" class="floatleft full">
					<xsl:value-of select="$i18n.weightType" />
					<span class="required">*</span>
				</label>

				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'weightType'" />
						<xsl:with-param name="name" select="'weightType'" />
						<xsl:with-param name="element" select="SetTableWeightEvaluator" />
					</xsl:call-template>
				</div>
			</div>

			<div class="floatleft full bigmarginbottom">

				<xsl:variable name="columnCount" select="count(Columns/Column)" />
	
				<label class="floatleft full">
					<xsl:value-of select="$i18n.fields.title" />
				</label>
		
				<xsl:choose>
					<xsl:when test="$columnCount > 1">
						
						<div class="clearboth floatleft marginbottom">
							<xsl:value-of select="$i18n.fields.description" />
						</div>
					
						<xsl:apply-templates select="Columns/Column">
							<xsl:with-param name="queryStateEvaluator" select="SetTableWeightEvaluator" />
						</xsl:apply-templates>
						
					</xsl:when>
					<xsl:when test="$columnCount = 1">
						
						<div class="clearboth floatleft marginbottom">
							<xsl:value-of select="$i18n.fields.single.description" />
						</div>
						
						<xsl:call-template name="createHiddenField">
							<xsl:with-param name="id" select="'columnID'" />
							<xsl:with-param name="name" select="'columnID'" />
							<xsl:with-param name="value" select="Columns/Column/columnID" />
						</xsl:call-template>
						
						<p class="floatleft full bold nomargin"><xsl:value-of select="Columns/Column/name" /></p>
						
					</xsl:when>
					<xsl:otherwise>
					
						<p>
							<xsl:value-of select="$i18n.QueryHasNoColumns" />
						</p>
						
					</xsl:otherwise>
				</xsl:choose>
			
			</div>

			<div class="floatleft full bigmarginbottom">
			
				<label class="floatleft full">
					<xsl:value-of select="$i18n.weightCalculation" />
				</label>				
			
				<div class="floatleft full marginbottom">
	
					<div class="floatleft full">
						<xsl:call-template name="createRadio">
							<xsl:with-param name="id" select="'use-field-value'" />
							<xsl:with-param name="name" select="'evaluationMode'" />
							<xsl:with-param name="value" select="'USE_FIELD_VALUE'" />
							<xsl:with-param name="element" select="SetTableWeightEvaluator" />
							<xsl:with-param name="onclick" select="'showHideSettings();'" />
						</xsl:call-template>
	
						<label for="use-field-value">
							<xsl:value-of select="$i18n.weightCalculation.useFieldWeight" />
						</label>
					</div>
				</div>
	
				<div class="floatleft full marginbottom">
	
					<div class="floatleft full">
						<xsl:call-template name="createRadio">
							<xsl:with-param name="id" select="'use-fixed-value'" />
							<xsl:with-param name="name" select="'evaluationMode'" />
							<xsl:with-param name="value" select="'USE_FIXED_VALUE'" />
							<xsl:with-param name="element" select="SetTableWeightEvaluator" />
							<xsl:with-param name="onclick" select="'showHideSettings();'" />
						</xsl:call-template>
	
						<label for="use-fixed-value">
							<xsl:value-of select="$i18n.weightCalculation.useFixedWeight" />
						</label>
					</div>
				</div>	
	
				<div class="floatleft full marginbottom">
	
					<div class="floatleft full">
						<xsl:call-template name="createRadio">
							<xsl:with-param name="id" select="'use-interval'" />
							<xsl:with-param name="name" select="'evaluationMode'" />
							<xsl:with-param name="value" select="'USE_INTERVALL'" />
							<xsl:with-param name="element" select="SetTableWeightEvaluator" />
							<xsl:with-param name="onclick" select="'showHideSettings();'" />
						</xsl:call-template>
	
						<label for="use-interval">
							<xsl:value-of select="$i18n.weightCalculation.useInterval" />
						</label>
					</div>
				</div>				
			
			</div>

			<div class="floatleft full bigmarginbottom hidden" id="fixed-settings">
			
				<label class="floatleft full">
					<xsl:value-of select="$i18n.fixedWeight.title" />
				</label>
				
				<div class="clearboth floatleft marginbottom">
					<xsl:value-of select="$i18n.fixedWeight.description" />
				</div>			
			
			</div>

			<div class="floatleft full bigmarginbottom hidden" id="interval-settings">
			
				<label class="floatleft full">
					<xsl:value-of select="$i18n.weightInterval.title" />
				</label>
				
				<div class="clearboth floatleft marginbottom">
					<xsl:value-of select="$i18n.weightInterval.description" />
				</div>
				
				<div class="clearboth floatleft marginbottom twenty">
					<xsl:value-of select="$i18n.from" />
					<span class="required">*</span>
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'fromValue'" />
						<xsl:with-param name="name" select="'fromValue'" />
						<xsl:with-param name="element" select="SetTableWeightEvaluator" />
					</xsl:call-template>
				</div>
			
				<div class="clearboth floatleft marginbottom twenty">
					<xsl:value-of select="$i18n.to" />
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'toValue'" />
						<xsl:with-param name="name" select="'toValue'" />
						<xsl:with-param name="element" select="SetTableWeightEvaluator" />
					</xsl:call-template>
				</div>						
			
			</div>

			<div class="clearboth floatleft marginbottom twenty" id="weight-form">
				<xsl:value-of select="$i18n.weight" />
				<span class="required">*</span>
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'weight'" />
					<xsl:with-param name="name" select="'weight'" />
					<xsl:with-param name="element" select="SetTableWeightEvaluator" />
				</xsl:call-template>
			</div>

			<script>
				showHideSettings();
			</script>

			<div class="floatright clearboth">
				<input type="submit" value="{$i18n.submit}" />
			</div>

		</form>

	</xsl:template>

	<xsl:template match="Column">
		<xsl:param name="queryStateEvaluator" />

		<div class="floatleft full marginbottom">

			<div class="floatleft full">
				<xsl:call-template name="createRadio">
					<xsl:with-param name="id">
						<xsl:value-of select="'column'"/>
						<xsl:value-of select="columnID"/>
					</xsl:with-param>				
					<xsl:with-param name="name" select="'columnID'" />
					<xsl:with-param name="value" select="columnID" />
					<xsl:with-param name="element" select="$queryStateEvaluator" />
				</xsl:call-template>

				<label for="column{columnID}">
					<xsl:value-of select="name" />
				</label>
			</div>
			
		</div>

	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'FromValueBiggerThanToValue']">

		<p class="error">
			<xsl:value-of select="$i18n.FromValueBiggerThanToValue" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'ColumnNotFound']">

		<p class="error">
			<xsl:value-of select="$i18n.ColumnNotFound" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
			<xsl:when test="$fieldName = 'weightType'">
				<xsl:value-of select="$i18n.weightType" />
			</xsl:when>
			<xsl:when test="$fieldName = 'weight'">
				<xsl:value-of select="$i18n.weight" />
			</xsl:when>
			<xsl:when test="$fieldName = 'toValue'">
				<xsl:value-of select="$i18n.to" />
			</xsl:when>
			<xsl:when test="$fieldName = 'fromValue'">
				<xsl:value-of select="$i18n.from" />
			</xsl:when>
			<xsl:when test="$fieldName = 'columnID'">
				<xsl:value-of select="$i18n.fields.title" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>