<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1"/>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/jquery/jquery-migrate.js?v=1
	</xsl:variable>

	<xsl:variable name="scripts">
		/js/jquery.blockui.js
		/js/flowengine.helpdialog.js
		/js/flowengine.js?v=4
		/js/flowengine.step-navigator.js
		/js/jquery.expander.min.js
		/js/flowinstancebrowser.js
		/js/jquery.cookie.js
		/js/targetgroupflowbrowser.js?v=5
	</xsl:variable>

	<xsl:variable name="links">
		/css/flowengine.css?v=4
		/css/targetgroupflowbrowser.css?v=7
	</xsl:variable>

	<xsl:template match="ShowFlowTypes">
		
		<xsl:if test="validationError">
			<xsl:apply-templates select="validationError" />
		</xsl:if>
		
		<div class="flow-wrapper">
		
			<script type="text/javascript">
				searchFlowURI = '<xsl:value-of select="/Document/requestinfo/currentURI" />/<xsl:value-of select="/Document/module/alias" />/search';
				resetLastSearchURI = '<xsl:value-of select="/Document/requestinfo/currentURI" />/<xsl:value-of select="/Document/module/alias" />/resetlastsearch';
				userFavouriteModuleURI = '<xsl:value-of select="/Document/requestinfo/contextpath" /><xsl:value-of select="userFavouriteModuleAlias" />';
			</script>
			
			<div class="search-wrapper flowbrowser">
					
				<div class="inner">	
					
					<h2 class="only-mobile"><xsl:value-of select="$i18n.SearchTitle" /></h2>
					
					<xsl:if test="searchDescription">
						<div class="search-description">
							<xsl:value-of select="searchDescription" disable-output-escaping="yes"/>
						</div>
					</xsl:if>
					
					<div class="search-controls-wrapper">
						<input type="text" id="search-field" name="search" class="search-field" autofocus="autofocus" aria-label="{$i18n.SearchTitle}">
							<xsl:if test="searchHints">
								<xsl:attribute name="placeholder"><xsl:value-of select="searchHints" /></xsl:attribute>
							</xsl:if>
							<xsl:if test="lastSearch">
								<xsl:attribute name="value"><xsl:value-of select="lastSearch" /></xsl:attribute>
							</xsl:if>
						</input>
						<span class="search-close-btn" />
						<a href="#" class="btn btn-blue xl search-btn only-desktop"><xsl:value-of select="$i18n.Search" /></a>
						<a href="#" class="btn btn-blue xl search-btn only-tablet-mobile"><span class="search-icon" /></a>
						
						<xsl:if test="recommendedTags/Tag">
							<div class="recommended-searches only-desktop-tablet">
								<xsl:value-of select="$i18n.RecommendedSearches" /><xsl:text>:&#160;</xsl:text>
								<xsl:apply-templates select="recommendedTags/Tag" />
							</div>
						</xsl:if>						
					</div>
				
				</div>
				
				<div class="search-result-wrapper">
				
					<div class="inner">
					
						<a class="search-close-btn" href="#"><xsl:value-of select="$i18n.close" /><xsl:text>&#160;</xsl:text><i>x</i></a>
						
						<h2 class="search-results-title">
							<xsl:value-of select="$i18n.Hits.Prefix" /><xsl:text>"</xsl:text><span class="title" /><xsl:text>"&#160;</xsl:text><xsl:value-of select="$i18n.Hits.Part1" /><xsl:text>&#160;</xsl:text><span class="hits" /><xsl:text>&#160;</xsl:text><xsl:value-of select="$i18n.Hits.Part2" />
						</h2>
						
						<ul class="flow-list" />
					
					</div>
					
				</div>
				
			</div>
			
			<xsl:if test="ClearFilterFunction = 'BOTH' or ClearFilterFunction ='ALL'">
				<div class="only-mobile full">
					<div class="clear-all-filter">
						<a href="#">
							<span class="icon" />
							<span class="text"><xsl:value-of select="$i18n.ResetAllFilters" /></span>
						</a>
					</div>
				</div>
			</xsl:if>
			
			<a href="#" class="btn btn-dark xl hide-filter-btn only-mobile" data-show-text="{$i18n.ShowFilter}" data-hide-text="{$i18n.HideFilter}">
				<span class="text"><xsl:value-of select="$i18n.HideFilter" /></span>
				<xsl:text>&#160;</xsl:text><span class="count"></span>
			</a>
			
			<xsl:variable name="targetGroups" select="TargetGroup[flowFamilyIDs/flowFamilyID]" />
			
			<div class="filters-wrapper">
				
				<div class="inner">
					
					<xsl:if test="ClearFilterFunction = 'BOTH' or ClearFilterFunction ='ALL'">
						<div class="only-desktop-tablet full">
							<div class="clear-all-filter">
								<a href="#">
									<span class="icon" />
									<span class="text"><xsl:value-of select="$i18n.ResetAllFilters" /></span>
								</a>
							</div>
						</div>
					</xsl:if>
			
					<xsl:choose>
						<xsl:when test="PrioritizedFilter = 'TARGETGROUP'">
							<xsl:call-template name="createTargetGroupFilter">
									<xsl:with-param name="targetGroups" select="$targetGroups" />
							</xsl:call-template>
							<xsl:call-template name="createFlowTypeFilter" />
						</xsl:when>
						<xsl:otherwise>
								<xsl:call-template name="createFlowTypeFilter" />
								<xsl:call-template name="createTargetGroupFilter">
									<xsl:with-param name="targetGroups" select="$targetGroups" />
								</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
			
					<div class="only-mobile sorter full">
						
						<span class="btn btn-blue sort-btn filter-list-btn xl">
							<xsl:value-of select="$i18n.Sort" />
							<select>
								<option value="FLOWTYPE"><xsl:value-of select="$i18n.Category" /></option>
								<xsl:if test="$targetGroups">
									<option value="TARGETGROUPS"><xsl:value-of select="$i18n.Group" /></option>
								</xsl:if>
								<option value="ALPHABETICAL"><xsl:value-of select="$i18n.Alphabetical" /></option>
							</select>
						</span>
						
					</div>
					
					<xsl:if test="ClearFilterFunction = 'BOTH' or ClearFilterFunction ='ALL'">
						<a href="#" class="btn btn-red clear-all-filter-btn hidden"><xsl:value-of select="$i18n.BackAndResetAllFilters" /><span /></a>
					</xsl:if>
				
				</div>
				
			</div>
		
			<div class="views-wrapper">
		
				<div class="settings only-desktop-tablet">
	
					<div class="sorter">
						<label for="sort-filter"><xsl:value-of select="$i18n.Sort" />:</label><xsl:text>&#160;&#160;&#160;</xsl:text>
						<select id="sort-filter">
							<option value="FLOWTYPE"><xsl:value-of select="$i18n.Category" /></option>
							<xsl:if test="$targetGroups">
								<option value="TARGETGROUPS"><xsl:value-of select="$i18n.Group" /></option>
							</xsl:if>
							<option value="ALPHABETICAL"><xsl:value-of select="$i18n.Alphabetical" /></option>
						</select>
					</div>
	
					<div class="view-toggler">
						<label><xsl:value-of select="$i18n.View" />:</label><xsl:text>&#160;&#160;&#160;</xsl:text>
						<xsl:choose>
							<xsl:when test="DefaultView = 'LIST'">
								<a href="#" title="{$i18n.ShowList}" class="list selected" tabindex="0"></a>
								<a href="#" title="{$i18n.ShowGrid}" class="grid" tabindex="0"></a>
							</xsl:when>
							<xsl:otherwise>
								<a href="#" title="{$i18n.ShowList}" class="list" tabindex="0"></a>
								<a href="#" title="{$i18n.ShowGrid}" class="grid selected" tabindex="0"></a>
							</xsl:otherwise>
						</xsl:choose>
					</div>
					
				</div>
		
				<script>
					<xsl:choose>
						<xsl:when test="DefaultSorting = 'FLOWTYPE'">
							var defaultSorting = 'FLOWTYPE';
						</xsl:when>
						<xsl:when test="DefaultSorting = 'TARGETGROUPS' and $targetGroups">
							var defaultSorting = 'TARGETGROUPS';
						</xsl:when>
						<xsl:when test="DefaultSorting = 'ALPHABETICAL'">
							var defaultSorting = 'ALPHABETICAL';
						</xsl:when>
						<xsl:otherwise>
							var defaultSorting = 'FLOWTYPE';
						</xsl:otherwise>
					</xsl:choose>				
				</script>
				
				<xsl:if test="ClearFilterFunction = 'BOTH' or ClearFilterFunction ='ALL'">
					<div class="clearfix">
						<a href="#" class="btn btn-red clear-all-filter-btn hidden floatright"><xsl:value-of select="$i18n.ResetAllFilters" /></a>
					</div>
				</xsl:if>
		
				<div class="flowtype-list active-list">
		
					<xsl:choose>
						<xsl:when test="FlowType">
							<xsl:apply-templates select="FlowType" />
						</xsl:when>
						<xsl:otherwise>
							<section>
								<div class="heading-wrapper">
									<h2><xsl:value-of select="$i18n.NoFlowTypesFound"/></h2>
								</div>					
							</section>
						</xsl:otherwise>
					</xsl:choose>
				
				</div>
				
				<div class="alpabetical-list" />
		
				<div class="targetgroup-list" />
		
				<xsl:if test="ClearFilterFunction = 'BOTH' or ClearFilterFunction ='ALL'">
					<a href="#" class="btn btn-red clear-all-filter-btn hidden"><xsl:value-of select="$i18n.BackAndResetAllFilters" /></a>
				</xsl:if>
			
			</div>
		
		</div>
		
	</xsl:template>
	
	<xsl:template name="createTargetGroupFilter">
	
		<xsl:param name="targetGroups" />
	
		<xsl:if test="$targetGroups">
	
			<section data-cookiesuffix="TargetGroups">
				<xsl:attribute name="class">
					<xsl:text>filter-list targetgroups</xsl:text>
					<xsl:choose>
						<xsl:when test="ExpandableFilterState = 'COLLAPSED'"> expandable collapsed default-collapsed</xsl:when>
						<xsl:when test="ExpandableFilterState = 'EXPANDED'"> expandable default-expanded</xsl:when>
					</xsl:choose>
				</xsl:attribute>
				<h2>
					<xsl:choose>
						<xsl:when test="ExpandableFilterState != 'DISABLED'">
							<a href="#" class="toggle-list-btn" data-show-text="{$i18n.ShowGroups}" data-hide-text="{$i18n.HideGroups}"><xsl:value-of select="$i18n.Groups" /></a>
						</xsl:when>
						<xsl:otherwise><span><xsl:value-of select="$i18n.Groups" /></span></xsl:otherwise>
					</xsl:choose>
					<a href="#" class="clear-filter-btn disabled" title="{$i18n.ResetAllFilters}">
						<i class="material-icons" />
					</a>
				</h2>
				<a href="#" class="btn btn-blue xl toggle-list-btn filter-list-btn toggle-btn only-mobile" data-show-text="{$i18n.ShowGroups}" data-hide-text="{$i18n.HideGroups}"><span class="text"><xsl:value-of select="$i18n.ShowGroups" /></span><xsl:text>&#160;</xsl:text>(<span class="count"></span>)</a>
				<ul style="display: none">
					<xsl:apply-templates select="$targetGroups" mode="filter" />
				</ul>
			</section>
		
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template name="createFlowTypeFilter">
	
		<xsl:param name="flowTypes" select="FlowType" />
	
		<xsl:if test="$flowTypes">
		
			<section data-cookiesuffix="FlowTypes">
				<xsl:attribute name="class">
					<xsl:text>filter-list flowtypes</xsl:text>
					<xsl:choose>
						<xsl:when test="ExpandableFilterState = 'COLLAPSED'"> expandable collapsed</xsl:when>
						<xsl:when test="ExpandableFilterState = 'EXPANDED'"> expandable</xsl:when>
					</xsl:choose>
				</xsl:attribute>
				<h2>
					<xsl:choose>
						<xsl:when test="ExpandableFilterState != 'DISABLED'">
							<a href="#" class="toggle-list-btn" data-show-text="{$i18n.ShowCategories}" data-hide-text="{$i18n.HideCategories}"><xsl:value-of select="$i18n.Categories" /></a>
						</xsl:when>
						<xsl:otherwise><span><xsl:value-of select="$i18n.Categories" /></span></xsl:otherwise>
					</xsl:choose>
					<a href="#" class="clear-filter-btn disabled" title="{$i18n.ResetAllFilters}">
						<i class="material-icons" />
					</a>
				</h2>
				<a href="#" class="btn btn-blue xl toggle-list-btn filter-list-btn toggle-btn only-mobile" data-show-text="{$i18n.ShowCategories}" data-hide-text="{$i18n.HideCategories}"><span class="text"><xsl:value-of select="$i18n.ShowCategories" /></span><xsl:text>&#160;</xsl:text>(<span class="count"></span>)</a>
				<ul style="display: none">
					<xsl:apply-templates select="$flowTypes" mode="filter" />
				</ul>
			</section>
		
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="TargetGroup" mode="filter">
		
		<li><a href="#group-{targetGroupID}" data-targetgroupid="{targetGroupID}" title="{$i18n.FilterOn} {name}"><span class="text"><xsl:value-of select="name" /></span><span class="count" /></a></li>
		
	</xsl:template>
	
	<xsl:template match="Tag">
		
		<a href="#"><xsl:value-of select="." /></a>
		
		<xsl:if test="position() != last()">
			<xsl:text>&#160;|&#160;</xsl:text>
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="FlowType" mode="filter">
		
		<xsl:variable name="flowTypeID" select="flowTypeID" />
		
		<xsl:variable name="flowTypeCount" select="count(../Flow[FlowType/flowTypeID = $flowTypeID])" />
		
		<xsl:if test="$flowTypeCount > 0">
		
			<li>
				<a href="#category-{flowTypeID}" data-flowtypeid="{flowTypeID}" title="{$i18n.FilterOn} {name}">
					<xsl:if test="iconColor">
						<style type="text/css">
							.filter-list a[data-flowtypeid='<xsl:value-of select="flowTypeID" />'] .count {
								border-color: rgb(<xsl:value-of select="alphaIconColorRGB" />);
							}
							.filter-list a[data-flowtypeid='<xsl:value-of select="flowTypeID" />'].selected .count, .filter-list:not(.filtered) a[data-flowtypeid='<xsl:value-of select="flowTypeID" />'] .count {
								background-color: <xsl:value-of select="iconColor" />;
							}
						</style>
					</xsl:if>
					<span class="text">
						<xsl:value-of select="name" />
					</span>
					<span class="count">
						
						<xsl:value-of select="$flowTypeCount" />
					</span>
				</a>
			</li>
		
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="FlowType">
		
		<xsl:param name="flowTypeID" select="flowTypeID" />
		<xsl:param name="flows" select="../Flow[FlowType/flowTypeID = $flowTypeID]" />
		<xsl:param name="useCategoryFilter" select="../useCategoryFilter" />
		
		<xsl:variable name="flowCount" select="count($flows)" />
		
		<xsl:if test="$flowCount > 0">
		
			<section id="flowtype_{flowTypeID}" data-flowtypeid="{flowTypeID}" class="flowtype">
				
				<xsl:if test="position() = 1">
					<xsl:attribute name="class">flowtype first</xsl:attribute>
				</xsl:if>
				
				<xsl:variable name="showIcon" select="iconFileName and ../ShowFlowTypeIcon" />
				
				<div class="heading-wrapper">
					
					<xsl:if test="$showIcon">
						<figure>
							<img src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/flowtypeicon/{flowTypeID}" alt="{iconFileName}" />
						</figure>
					</xsl:if>
					<h2>
						<xsl:if test="$showIcon"><xsl:attribute name="class">has-icon</xsl:attribute></xsl:if>
						<xsl:value-of select="name" />
						<xsl:text>&#160;(</xsl:text>
						<span class="count"><xsl:value-of select="$flowCount" /></span>
						<xsl:text>)</xsl:text>
						
						<xsl:if test="../ClearFilterFunction = 'BOTH' or ../ClearFilterFunction = 'PER_FILTER'">
							<a href="#" class="clear-filter-btn">
								<i class="material-icons" />
							</a>
						</xsl:if>
					</h2>
				
					<ul class="flow-list">
						<xsl:apply-templates select="$flows" />
					</ul>
					
					<xsl:if test="$flows and $flowCount > /Document/ShowFlowTypes/popularFlowCount">
						<a href="#" class="show-all-btn" aria-label="{$i18n.ShowAllFlows} {name}"><xsl:value-of select="$i18n.ShowAll" /></a>
						<a href="#" class="show-fewer-btn" aria-label="{$i18n.ShowFewerFlows} {name}"><xsl:value-of select="$i18n.ShowFewer" /></a>
					</xsl:if>
					
				</div>
				
			</section>
		
		</xsl:if>
		
	</xsl:template>
	
	<xsl:template match="Flow">
		
		<xsl:variable name="flowID" select="flowID" />
		<xsl:variable name="flowFamilyID" select="FlowFamily/flowFamilyID" />
		<xsl:variable name="isLoggedIn" select="/Document/ShowFlowTypes/loggedIn" />
		
		<li id="flow_{flowID}" data-flowid="{flowID}" data-flowname="{name}">
			
			<xsl:attribute name="class">
				<xsl:if test="enabled = 'false'">disabled </xsl:if>
				<xsl:if test="popular = 'true'">popular show </xsl:if>
			</xsl:attribute>

			<xsl:for-each select="../TargetGroup[flowFamilyIDs[flowFamilyID = $flowFamilyID]]">
				
				<xsl:call-template name="createHiddenField">
					<xsl:with-param name="name" select="'targetgroup'"  />
					<xsl:with-param name="value" select="targetGroupID"  />
				</xsl:call-template>
				
			</xsl:for-each>	
			
			<xsl:variable name="targetBlank" select="../openExternalFlowsInNewWindow = 'true' and skipOverview = 'true' and externalLink" />
			<xsl:variable name="flowLink">
				<xsl:value-of select="/Document/requestinfo/currentURI" />/<xsl:value-of select="/Document/module/alias" />/overview/<xsl:value-of select="$flowFamilyID" />
			</xsl:variable>
			
			<div class="flow">
				<figure>
					<img alt="" src="{/Document/requestinfo/currentURI}/{/Document/module/alias}/icon/{flowID}?{IconLastModified}" />
				</figure>
				<div>
					<a title="{$i18n.ShowFlow} {name}" aria-label="{$i18n.ShowFlow} {name}" href="{$flowLink}" >
						<xsl:if test="$targetBlank">
							<xsl:attribute name="target">_blank</xsl:attribute>
						</xsl:if>
						<xsl:if test="enabled = 'false'">
							<xsl:attribute name="href">#</xsl:attribute>
						</xsl:if>
						<h2>
							<xsl:value-of select="name" />
							<xsl:if test="$isLoggedIn and /Document/ShowFlowTypes/userFavouriteModuleAlias">
								<i id="flowFamily_{$flowFamilyID}" data-icon-after="*" class="favourite">
									<xsl:if test="not(/Document/ShowFlowTypes/UserFavourite[FlowFamily/flowFamilyID = $flowFamilyID])">
										<xsl:attribute name="class">favourite gray</xsl:attribute>
									</xsl:if>
								</i>
							</xsl:if>
						</h2>
						<div class="icons only-desktop-tablet">
							<xsl:choose>
								<xsl:when test="externalLink">
									<i class="material-icons external-link icon-launch" title="{$i18n.IsExternal}" aria-label="{$i18n.IsExternal}"></i>
								</xsl:when>
								<xsl:when test="Steps/Step">
									<i class="material-icons icon-computer" title="{$i18n.HasFlow}" aria-label="{$i18n.HasFlow}"></i>
								</xsl:when>
							</xsl:choose>
							<xsl:if test="hasPDF = 'true'">
								<i class="material-icons icon-file-download" title="{$i18n.HasPDF}" aria-label="{$i18n.HasPDF}"></i>
							</xsl:if>
							<xsl:if test="not($isLoggedIn) and requireAuthentication = 'true'">
								<i class="material-icons icon-person" title="{$i18n.AuthenticationRequired}" aria-label="{$i18n.AuthenticationRequired}"></i>
							</xsl:if>
						</div>
					</a>
					<div class="description"><xsl:value-of select="shortDescription" disable-output-escaping="yes" /></div>
					<div class="description-info">
						<a href="#" tabindex="0" />
						<div class="description-tooltip"><div><xsl:value-of select="shortDescription" disable-output-escaping="yes" /><div class="marker"></div></div></div>
					</div>
					
					<xsl:if test="enabled = 'false'">
						<div class="disabled-info"><xsl:value-of select="$i18n.FlowDisabled" /></div>
					</xsl:if>
					
				</div>
				
				<a title="{$i18n.ShowFlow} {name}" href="{$flowLink}" class="btn btn-blue btn-inline only-desktop-tablet" aria-hidden="true" tabindex="-1">
					<xsl:if test="$targetBlank">
						<xsl:attribute name="target">_blank</xsl:attribute>
					</xsl:if>
					<xsl:if test="enabled = 'false'">
						<xsl:attribute name="href">#</xsl:attribute>
					</xsl:if>
					<xsl:value-of select="$i18n.ShowFlow" />
					<i class="material-icons icon-arrow-right"></i>
				</a>
				<a title="{$i18n.ShowFlow}" href="{$flowLink}" class="btn btn-blue btn-inline only-mobile" aria-hidden="true" tabindex="-1">
					<xsl:if test="$targetBlank">
						<xsl:attribute name="target">_blank</xsl:attribute>
					</xsl:if>
					<xsl:if test="enabled = 'false'">
						<xsl:attribute name="href">#</xsl:attribute>
					</xsl:if>
					<span class="arrow" />
				</a>
				
			</div>
		</li>
		
	</xsl:template>		
	
</xsl:stylesheet>