<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
		/js/confirmpost.js
	</xsl:variable>	

	<xsl:variable name="scripts">
		/js/treservaintegration.js
	</xsl:variable>

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl"/>

	<xsl:template match="Document">
	
		<xsl:apply-templates select="ShowIntegrationSettings" />
		<xsl:apply-templates select="UpdateIntegrationSettings" />
			
	</xsl:template>
	
	<xsl:template match="ShowIntegrationSettings">
	
		<a name="treservaintegrationsettings" />
		
		<xsl:choose>
			<xsl:when test="IntegrationSettings">
					
				<xsl:value-of select="$i18n.IntegrationEnabled"/>
				<xsl:text>:&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="IntegrationSettings/enabled = 'true'">
						<xsl:value-of select="$i18n.Yes"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.No"/>
					</xsl:otherwise>
				</xsl:choose>
								
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$i18n.NoIntegrationSettings" />
			</xsl:otherwise>
		</xsl:choose>
		
		<a href="{/Document/ModuleURI}/update/{Flow/flowID}" class="floatright">
			<xsl:value-of select="$i18n.UpdateIntegrationSettings" />
			<img class="alignbottom" src="{/Document/StaticContentURL}/pics/pen.png" alt="" />
		</a>
		
		<xsl:if test="IntegrationSettings">
			<a href="{/Document/ModuleURI}/delete/{Flow/flowID}" class="floatright clearboth" onclick="return confirmPost(this.href, '{$i18n.DeleteIntegrationSettings.Confirm}');">
				<xsl:value-of select="$i18n.DeleteIntegrationSettings" />
				<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
			</a>		
		</xsl:if>
	
	</xsl:template>
	
	<xsl:template match="UpdateIntegrationSettings">
		
		<div id="TreservaIntegrationProvider" class="contentitem errands-wrapper border-box">
		
			<h1>
				<xsl:value-of select="$i18n.UpdateIntegrationSettingsTitle"/>
				<xsl:text>:&#x20;</xsl:text>
				<xsl:value-of select="Flow/name"/>
			</h1>
	
			<xsl:apply-templates select="validationException/validationError"/>
	
			<form method="post" action="{/Document/ModuleURI}/update/{Flow/flowID}">
			
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'enabled'" />
						<xsl:with-param name="id" select="'enabled'" />
						<xsl:with-param name="element" select="IntegrationSettings" />       
					</xsl:call-template>
					
					<label for="enabled">
						<xsl:value-of select="$i18n.Enabled" />
					</label>
				</div>
			
				<label for="endpointID" class="floatleft full">
					<xsl:value-of select="$i18n.Endpoint" />
				</label>
				
				<div class="floatleft full">
				
					<xsl:call-template name="createEndpointDropdown" />
				
				</div>
				
				<label for="personNr" class="floatleft full">
					<xsl:value-of select="$i18n.personNr" />
				</label>				
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'personNr'"/>
						<xsl:with-param name="name" select="'personNr'"/>
						<xsl:with-param name="element" select="IntegrationSettings" />          
					</xsl:call-template>
				</div>
				
				<label for="stadsDelId" class="floatleft full">
					<xsl:value-of select="$i18n.stadsDelId" />
					<span id="noAttributeValueFound"><xsl:text> </xsl:text><xsl:value-of select="$i18n.noAttributeValueFound" /></span>
				</label>				
				
				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'stadsDelId'"/>
						<xsl:with-param name="name" select="'stadsDelId'"/>
						<xsl:with-param name="element" select="IntegrationSettings" />          
					</xsl:call-template>
				</div>		
				
				<div class="floatleft full">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'setStadsDelIdFromAttribute'" />
						<xsl:with-param name="id" select="'setStadsDelIdFromAttribute'" />
						<xsl:with-param name="element" select="IntegrationSettings" />       
					</xsl:call-template>
					
					<label for="setStadsDelIdFromAttribute">
						<xsl:value-of select="$i18n.SetStadsDelIdFromAttribute" />
					</label>
				</div>
				
				<div class="floatleft full bigmarginbottom" id="stadsDelIdFromAttributeContainer">
					
					<label for="stadsDelIdAttributeName">
						<xsl:value-of select="$i18n.Attribute.Name" />
					</label>				
					
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'stadsDelIdAttributeName'"/>
						<xsl:with-param name="name" select="'stadsDelIdAttributeName'"/>
						<xsl:with-param name="element" select="IntegrationSettings" />          
					</xsl:call-template>
									
				</div>
							
				<div>
				
					<label for="validCaseDataTypes">
						<xsl:value-of select="$i18n.validCaseDataTypes" />
					</label>
				
					<p>
						<xsl:value-of select="$i18n.validCaseDataTypes.Description" />
					</p>
					
					<xsl:call-template name="createTextArea">
						<xsl:with-param name="id" select="'validCaseDataTypes'"/>
						<xsl:with-param name="name" select="'validCaseDataTypes'"/>
						<xsl:with-param name="rows" select="3"/>
						<xsl:with-param name="separateListValues" select="'true'"/>
						<xsl:with-param name="element" select="IntegrationSettings/validCaseDataTypes/validCaseDataType" />
					</xsl:call-template>
					
				</div>
			
				<div class="full floatleft bigmargintop">
					<h2><xsl:value-of select="$i18n.Parameters" /></h2>
				</div>
			
				<table id="param-table" class="full coloredtable ">
					<thead>
						<tr>
							<th><xsl:value-of select="$i18n.Name" /></th>
							<th><xsl:value-of select="$i18n.Value" /></th>
							<th width="16px"></th>
						</tr>
					</thead>
					<tbody>
					
						<xsl:choose>
							<xsl:when test="requestparameters">
							
								<xsl:apply-templates select="requestparameters/parameter[name = 'parameterID']/value" mode="parameter"/>
							
							</xsl:when>
							<xsl:otherwise>
							
								<xsl:apply-templates select="IntegrationSettings/Parameters/Parameter"/>
							
							</xsl:otherwise>
						</xsl:choose>					
					
					</tbody>
				</table>
				
				<div class="floatright">
					<a onclick="addParameter();">
						<xsl:value-of select="$i18n.AddParameter" />
						<img class="alignbottom" src="{/Document/StaticContentURL}/pics/add.png" alt="" />
					</a>
				</div>			
								
				<div class="floatleft full bigmarginbottom">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'commentEnabled'" />
						<xsl:with-param name="id" select="'commentEnabled'" />
						<xsl:with-param name="element" select="IntegrationSettings" />       
					</xsl:call-template>
					
					<label for="commentEnabled">
						<xsl:value-of select="$i18n.CommentEnabled" />
					</label>
				</div>
				
				<div id="commentContainer" class="bigmarginbottom">
					
					<label for="commentName" class="floatleft full">
						<xsl:value-of select="$i18n.CommentName" />
					</label>				
					
					<div class="floatleft full">
						<xsl:call-template name="createTextField">
							<xsl:with-param name="id" select="'commentName'"/>
							<xsl:with-param name="name" select="'commentName'"/>
							<xsl:with-param name="element" select="IntegrationSettings" />          
						</xsl:call-template>
					</div>	
									
					<label for="commentValue" class="floatleft full">
						<xsl:value-of select="$i18n.CommentValue" />
					</label>	
					
					<div class="floatleft full paddingtop">
						<xsl:call-template name="createTextArea">
							<xsl:with-param name="id" select="'commentValue'"/>
							<xsl:with-param name="name" select="'commentValue'"/>
							<xsl:with-param name="element" select="IntegrationSettings" />          
						</xsl:call-template>
					</div>					
				
				</div>
				
				<div class="floatleft full bigmargintop minaIFOArendeSettingContainer">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'autoAssignManager'" />
						<xsl:with-param name="id" select="'autoAssignManager'" />
						<xsl:with-param name="element" select="IntegrationSettings" />
						<xsl:with-param name="class" select="'minaIFOArendeSetting'" />
					</xsl:call-template>
					
					<label for="autoAssignManager">
						<xsl:value-of select="$i18n.autoAssignManager" />
					</label>
				</div>
				
				<div class="floatleft full bigmargintop minaIFOArendeSettingContainer">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'duplicateCheckEnabled'" />
						<xsl:with-param name="id" select="'duplicateCheckEnabled'" />
						<xsl:with-param name="element" select="IntegrationSettings" />
						<xsl:with-param name="class" select="'minaIFOArendeSetting'" />
					</xsl:call-template>
					
					<label for="duplicateCheckEnabled">
						<xsl:value-of select="$i18n.duplicateCheckEnabled" />
					</label>
				</div>
				
				<div class="floatleft full bigmargintop minaIFOArendeSettingContainer">
					<xsl:call-template name="createCheckbox">
						<xsl:with-param name="name" select="'decisionModuleEnabled'" />
						<xsl:with-param name="id" select="'decisionModuleEnabled'" />
						<xsl:with-param name="element" select="IntegrationSettings" />
						<xsl:with-param name="class" select="'minaIFOArendeSetting'" />
					</xsl:call-template>
					
					<label for="decisionModuleEnabled">
						<xsl:value-of select="$i18n.decisionModuleEnabled" />
					</label>
				</div>
				
				<div id="decisionMessageTemplateContainer" class="bigmarginbottom">
					
					<label for="decisionMessageTemplate" class="floatleft full">
						<xsl:value-of select="$i18n.decisionMessageTemplate" />
					</label>				
					
					<div class="floatleft full">
						<xsl:call-template name="createTextArea">
							<xsl:with-param name="id" select="'decisionMessageTemplate'"/>
							<xsl:with-param name="name" select="'decisionMessageTemplate'"/>
							<xsl:with-param name="element" select="IntegrationSettings" />          
						</xsl:call-template>
					</div>
					
					<xsl:call-template name="decisionMessageTemplateTagTable" />	
					
				</div>
				
				<div class="clearboth marginbottom">
					<br/>
				</div>
				
				<div class="floatleft full bigmargintop bigmarginbottom">
		
					<h2><xsl:value-of select="$i18n.Notifications"/></h2>
				
					<xsl:call-template name="notificationEmail">
						<xsl:with-param name="toggleField" select="'sendExistingApplicationErrorEmail'" />
						<xsl:with-param name="addressesField" select="'existingApplicationErrorEmailAddresses'" />
						<xsl:with-param name="toggleLabel" select="$i18n.Notifications.ExistingApplicationErrorEmail" />
						<xsl:with-param name="addressesLabel" select="$i18n.Notifications.ExistingApplicationErrorEmail.EmailAddresses" />
						<xsl:with-param name="addresses" select="IntegrationSettings/ExistingApplicationErrorEmailAddresses/address" />
					</xsl:call-template>
					
					<xsl:call-template name="notificationEmail">
						<xsl:with-param name="toggleField" select="'sendProtectedPersonErrorEmail'" />
						<xsl:with-param name="addressesField" select="'protectedPersonErrorEmailAddresses'" />
						<xsl:with-param name="toggleLabel" select="$i18n.Notifications.ProtectedPersonErrorEmail" />
						<xsl:with-param name="addressesLabel" select="$i18n.Notifications.ProtectedPersonErrorEmail.EmailAddresses" />
						<xsl:with-param name="addresses" select="IntegrationSettings/ProtectedPersonErrorEmailAddresses/address" />
					</xsl:call-template>
					
					<xsl:call-template name="notificationEmail">
						<xsl:with-param name="toggleField" select="'sendUnknownErrorEmail'" />
						<xsl:with-param name="addressesField" select="'unknownErrorEmailAddresses'" />
						<xsl:with-param name="toggleLabel" select="$i18n.Notifications.UnknownErrorEmail" />
						<xsl:with-param name="addressesLabel" select="$i18n.Notifications.UnknownErrorEmail.EmailAddresses" />
						<xsl:with-param name="addresses" select="IntegrationSettings/UnknownErrorEmailAddresses/address" />
					</xsl:call-template>

					<xsl:if test="MaxRetryCount > 0">

						<xsl:call-template name="notificationEmail">
							<xsl:with-param name="toggleField" select="'sendMaxRetriesExceededEmail'" />
							<xsl:with-param name="addressesField" select="'maxRetriesExceededEmailAddresses'" />
							<xsl:with-param name="toggleLabel" select="$i18n.Notifications.MaxRetriesExceededEmail" />
							<xsl:with-param name="addressesLabel" select="$i18n.Notifications.MaxRetriesExceededEmail.EmailAddresses" />
							<xsl:with-param name="addresses" select="IntegrationSettings/MaxRetriesExceededEmailAddresses/address" />
						</xsl:call-template>
					
					</xsl:if>
					
					<div id="noManagerToAutoAssignEmailContainer" class="minaIFOArendeSettingContainer">
					
						<xsl:call-template name="notificationEmail">
							<xsl:with-param name="toggleField" select="'sendNoManagerToAutoAssignEmail'" />
							<xsl:with-param name="addressesField" select="'noManagerToAutoAssignEmailAddresses'" />
							<xsl:with-param name="toggleLabel" select="$i18n.Notifications.NoManagerToAutoAssignEmail" />
							<xsl:with-param name="addressesLabel" select="$i18n.Notifications.NoManagerToAutoAssignEmail.EmailAddresses" />
							<xsl:with-param name="addresses" select="IntegrationSettings/NoManagerToAutoAssignEmailAddresses/address" />
							<xsl:with-param name="class" select="'minaIFOArendeSetting'" />
						</xsl:call-template>
						
					</div>
										
				</div>
			
				<div class="floatright clearboth bigmargintop">
					<input type="submit" value="{$i18n.SaveChanges}" />
				</div>
			
			</form>
		
			<div style="display: none;">
				
				<table>
					<tr id="parameter-template">
						<td>
							<input type="text" name="name" class="full"/>
						</td>
						<td>
							<input type="text" name="value" class="full"/>
						</td>
						<td>
							<input type="hidden" name="parameterID"/>
							
							<a onclick="deleteParameter(this)">
								<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
							</a>				
						</td>
					</tr>
				</table>
				
			</div>		
		
		</div>

	</xsl:template>
	
	<xsl:template match="Parameter">
		
		<tr id="parameter-{parameterID}">
			<td>
				<input type="text" name="name-{parameterID}" value="{name}" class="full"/>
			</td>
			<td>
				<input type="text" name="value-{parameterID}" value="{value}" class="full"/>
			</td>
			<td>
				<input type="hidden" name="parameterID" value="{parameterID}"/>
				
				<a onclick="deleteParameter(this)">
					<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
				</a>				
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template match="value" mode="parameter">
		
 		<xsl:variable name="parameterID" select="."/>
		
		<xsl:variable name="nameParam" select="concat('name-', $parameterID)"/>
		
		<xsl:variable name="valueParam" select="concat('value-', $parameterID)"/>
		
		<tr id="parameter-{$parameterID}">
 			<td>
				<input type="text" name="name-{$parameterID}" value="{../../parameter[name = $nameParam]/value}" class="full"/>
			</td>
			<td>
				<input type="text" name="value-{$parameterID}" value="{../../parameter[name = $valueParam]/value}" class="full"/>
			</td>
			<td>
				<input type="hidden" name="parameterID" value="{$parameterID}"/>
				
				<a onclick="deleteParameter(this)">
					<img class="alignbottom" src="{/Document/StaticContentURL}/pics/delete.png" alt="" />
				</a>				
			</td>
		</tr>
	
	</xsl:template>
	
	<xsl:template name="notificationEmail">
		<xsl:param name="toggleField" />
		<xsl:param name="addressesField" />
		<xsl:param name="toggleLabel" />
		<xsl:param name="addressesLabel" />
		<xsl:param name="addresses" />
		<xsl:param name="class" select="''" />
	
		<div class="notification-email">
		
			<div>
			
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="name" select="$toggleField" />
					<xsl:with-param name="id" select="$toggleField" />
					<xsl:with-param name="element" select="IntegrationSettings" />
					<xsl:with-param name="class" select="concat('notification-email-toggle ', $class)" />
				</xsl:call-template>
				
				<label class="marginright" for="{$toggleField}">
					<xsl:value-of select="$toggleLabel" />
				</label>
			</div>
			
			<div class="notification-email-text">
			
				<xsl:if test="not(validationException/validationError/fieldName = $addressesField)">
					<xsl:attribute name="class">notification-email-text hidden</xsl:attribute>
				</xsl:if>
			
				<div>
				
					<label for="{$addressesField}">
						<xsl:value-of select="$addressesLabel" />
					</label>
					
					<xsl:call-template name="createTextArea">
						<xsl:with-param name="id" select="$addressesField"/>
						<xsl:with-param name="name" select="$addressesField"/>
						<xsl:with-param name="rows" select="5"/>
						<xsl:with-param name="separateListValues" select="'true'"/>
						<xsl:with-param name="element" select="$addresses" />
						<xsl:with-param name="class" select="$class" />
					</xsl:call-template>
				</div>
			</div>
		</div>
			
	</xsl:template>
	
	<xsl:template name="createEndpointDropdown">

		<xsl:variable name="requestparameters" select="requestparameters" />
		<xsl:variable name="selectedValue" select="IntegrationSettings/Endpoint/endpointID" />
		
		<select id="endpointID" name="endpointID">

			<xsl:variable name="paramValue" select="$requestparameters/parameter[name='endpointID']/value" />

			<xsl:for-each select="Endpoints/Endpoint">
				<option value="{endpointID}">
					
					<xsl:if test="hasMinaIFOArendeConfiguration">
						<xsl:attribute name="data-has-mina-ifo-arende-configuration">true</xsl:attribute>
					</xsl:if>
				
					<xsl:choose>
						<xsl:when test="$requestparameters">
							<xsl:if test="$paramValue = endpointID">
								<xsl:attribute name="selected">selected</xsl:attribute>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test="endpointID = $selectedValue">
								<xsl:attribute name="selected">selected</xsl:attribute>
							</xsl:if>
						</xsl:otherwise>
					</xsl:choose>

					<xsl:value-of select="name" />

				</option>
				
			</xsl:for-each>

		</select>

	</xsl:template>
	
	<xsl:template name="decisionMessageTemplateTagTable">
	
		<div class="floatleft margintop half">
	
			<table class="full border">
				<tr>
					<th>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Header"/>
					</th>
					<th>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Header.Value"/>
					</th>
				</tr>
				<tr>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Number"/>
					</td>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Number.Value"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Reason"/>
					</td>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Reason.Value"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Date"/>
					</td>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Date.Value"/>
					</td>
				</tr>
				<tr>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Manager"/>
					</td>
					<td>
						<xsl:value-of select="$i18n.decisionMessageTemplate.Tags.Manager.Value"/>
					</td>
				</tr>
			</table>
		
		</div>
	
	</xsl:template>	
	
	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.validation.tooLong" />
					</xsl:when>														
					<xsl:otherwise>
						<xsl:value-of select="$i18n.validation.unknownError" />
					</xsl:otherwise>
				</xsl:choose>
				
				<xsl:text>&#x20;</xsl:text>
				
				<xsl:choose>
					<xsl:when test="displayName">
						<xsl:value-of select="displayName"/>
					</xsl:when>
					<xsl:when test="fieldName = 'endpointID'">
						<xsl:value-of select="$i18n.Endpoint"/>
					</xsl:when>
					<xsl:when test="fieldName = 'personNr'">
						<xsl:value-of select="$i18n.personNr"/>
					</xsl:when>
					<xsl:when test="fieldName = 'stadsDelId'">
						<xsl:value-of select="$i18n.stadsDelId"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'commentName'">
						<xsl:value-of select="$i18n.CommentName"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'commentValue'">
						<xsl:value-of select="$i18n.CommentValue"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'stadsDelIdAttributeName'">
						<xsl:value-of select="$i18n.Attribute.Name"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'validCaseDataTypes'">
						<xsl:value-of select="$i18n.validCaseDataTypes"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'autoAssignManager'">
						<xsl:value-of select="$i18n.autoAssignManager"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'decisionMessageTemplate'">
						<xsl:value-of select="$i18n.decisionMessageTemplate"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'existingApplicationErrorEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.ExistingApplicationErrorEmail.EmailAddresses"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'protectedPersonErrorEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.ProtectedPersonErrorEmail.EmailAddresses"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'unknownErrorEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.UnknownErrorEmail.EmailAddresses"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'maxRetriesExceededEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.MaxRetriesExceededEmail.EmailAddresses"/>
					</xsl:when>								
					<xsl:when test="fieldName = 'noManagerToAutoAssignEmailAddresses'">
						<xsl:value-of select="$i18n.Notifications.NoManagerToAutoAssignEmail.EmailAddresses"/>
					</xsl:when>								
					<xsl:otherwise>
						<xsl:value-of select="fieldName"/>
					</xsl:otherwise>
				</xsl:choose>			
			</p>
		</xsl:if>
		
		<xsl:if test="messageKey">
			<p class="error">
				<xsl:value-of select="$i18n.validation.unknownFault" />
			</p>
		</xsl:if>
		
	</xsl:template>	
	
</xsl:stylesheet>