package com.nordicpeak.flowengine.evaluators.settextfieldvalueparameter;


import java.util.ArrayList;
import java.util.List;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.beans.QueryModification;
import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.EvaluationEventListener;
import com.nordicpeak.flowengine.interfaces.EvaluationHandler;
import com.nordicpeak.flowengine.interfaces.ParameterEvaluator;
import com.nordicpeak.flowengine.interfaces.QueryInstance;

@Table(name = "set_textfield_value_param_evaluators")
@XMLElement
public class SetTextFieldValueParameterEvaluator extends BaseEvaluator implements EvaluationEventListener, ParameterEvaluator {
	
	private static final long serialVersionUID = 1129410235430246625L;

	@DAOManaged
	@WebPopulate(required = true)
	@XMLElement
	private Integer textFieldID;
	
	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement(cdata = true)
	private String paramName;
	
	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String noParamValueFoundMessage;
	
	private boolean initialized;
	
	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {
		
		List<ValidationError> errors = new ArrayList<ValidationError>();
		
		textFieldID = XMLValidationUtils.validateParameter("textFieldID", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);
		
		paramName = XMLValidationUtils.validateParameter("paramName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		
		noParamValueFoundMessage = XMLValidationUtils.validateParameter("noParamValueFoundMessage", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		
		if (!errors.isEmpty()) {
			
			throw new ValidationException(errors);
		}
	}
	
	@Override
	public String toString() {
		
		return evaluatorDescriptor.toString();
	}
	
	@Override
	public boolean forceAjaxPosting() {
		
		return true;
	}
	
	@Override
	public boolean requiresInitialization() {
		
		return true;
	}
	
	public Integer getTextFieldID() {
		
		return textFieldID;
	}
	
	public void setTextFieldID(Integer textFieldID) {
		
		this.textFieldID = textFieldID;
	}
	
	@Override
	public String getParamName() {
		
		return paramName;
	}
	
	public void setParamName(String expression) {
		
		this.paramName = expression;
	}
	
	public String getNoParamValueFoundMessage() {
		
		return noParamValueFoundMessage;
	}
	
	public void setNoParamValueFoundMessage(String invalidExpressionMessage) {
		
		this.noParamValueFoundMessage = invalidExpressionMessage;
	}

	@Override
	public boolean supportsEvent(Object event) {

		return false;
	}

	@Override
	public List<QueryModification> processEvent(Object event, QueryInstance queryInstance, User user, User poster, EvaluationCallback callback, EvaluationHandler evaluationHandler) {

		return null;
	}

	
	public boolean isInitialized() {
	
		return initialized;
	}

	
	public void setInitialized(boolean initialized) {
	
		this.initialized = initialized;
	}
}
