package com.nordicpeak.flowengine.evaluators.urlparameterfilter;

import java.util.Map;
import java.util.Map.Entry;
import java.util.concurrent.ConcurrentHashMap;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.FilterChain;
import se.unlogic.hierarchy.filtermodules.AnnotatedFilterModule;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.webutils.http.SessionUtils;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.FlowBrowserModule;
import com.nordicpeak.flowengine.FlowFamilyAliasFilterModule;
import com.nordicpeak.flowengine.beans.Flow;
import com.nordicpeak.flowengine.interfaces.ParameterEvaluator;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.managers.MutableFlowInstanceManager;

public class URLParameterFilterModule extends AnnotatedFilterModule {

	public static final String PARAM_MAP_SESSION_ATTRIBUTE = URLParameterFilterModule.class.getName() + ".flowParamMap";

	@InstanceManagerDependency(required = true)
	protected QueryHandler queryHandler;

	@InstanceManagerDependency(required = true)
	protected FlowFamilyAliasFilterModule flowFamilyAliasFilterModule;

	@InstanceManagerDependency(required = true)
	protected FlowBrowserModule flowBrowserModule;

	@Override
	public void doFilter(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser, FilterChain filterChain) throws Exception {

		Map<String, String[]> reqParamMap = req.getParameterMap();

		if (!reqParamMap.isEmpty()) {

			ConcurrentHashMap<String, String> flowParamMap = null;

			for (Entry<String, String[]> entry : reqParamMap.entrySet()) {

				if (entry.getKey().startsWith("flowParam")) {

					if (flowParamMap == null) {

						flowParamMap = new ConcurrentHashMap<>();
					}

					flowParamMap.put(entry.getKey(), StringUtils.substring(entry.getValue()[0], 255));

					if (flowParamMap.size() == 20) {

						break;
					}
				}
			}

			if (flowParamMap != null) {

				Map<String, String> currentFlowParamMap = getCurrentFlowParamMap(req);

				if (!flowParamMap.equals(currentFlowParamMap)) {

					if (currentFlowParamMap != null) {

						closeCurrentSessionFlowInstanceManager(req, uriParser, user);
					}

					log.info("Adding " + flowParamMap.size() + " parameters to session of user " + user);

					SessionUtils.setAttribute(PARAM_MAP_SESSION_ATTRIBUTE, flowParamMap, req);
				}
			}
		}

		filterChain.doFilter(req, res, user, uriParser);
	}

	@SuppressWarnings("unchecked")
	private Map<String, String> getCurrentFlowParamMap(HttpServletRequest req) {

		Object currentFlowParamObject = SessionUtils.getAttribute(PARAM_MAP_SESSION_ATTRIBUTE, req);

		if (currentFlowParamObject instanceof Map) {

			return (Map<String, String>) currentFlowParamObject;
		}

		return null;
	}

	private void closeCurrentSessionFlowInstanceManager(HttpServletRequest req, URIParser uriParser, User user) {

		if (ObjectUtils.containsNull(flowFamilyAliasFilterModule, flowBrowserModule)) {

			return;
		}

		Integer flowFamilyID = flowFamilyAliasFilterModule.getFlowFamilyIDFromAliasCache(uriParser);

		if (flowFamilyID != null) {

			Flow flow = flowBrowserModule.getLatestPublishedFlowVersion(flowFamilyID);

			if (flow != null) {

				MutableFlowInstanceManager flowInstanceManager = flowBrowserModule.getMutableFlowInstanceManagerFromSession(flow.getFlowID(), null, req.getSession(false));

				if (flowInstanceManager != null && flowInstanceManager.getEvaluators(ParameterEvaluator.class) != null) {

					log.info("User " + user + " has expired parameters in session, closing flow instance manager " + flowInstanceManager);

					flowInstanceManager.close(queryHandler);
				}
			}
		}
	}

}
