package com.nordicpeak.flowengine.queries.unsecuremultisignquery;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import com.nordicpeak.flowengine.beans.SigningParty;
import com.nordicpeak.flowengine.interfaces.ColumnExportableQueryInstance;
import com.nordicpeak.flowengine.interfaces.MultiSignQueryinstance;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;
import com.nordicpeak.flowengine.queries.checkboxquery.CheckboxQueryInstance;

import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.object.ObjectUtils;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLUtils;

@Table(name = "unsecure_multi_sign_query_instances")
@XMLElement
public class UnsecureMultiSignQueryInstance extends BaseQueryInstance implements MultiSignQueryinstance, ColumnExportableQueryInstance {

	private static final long serialVersionUID = 2847121037559137804L;

	public static final Field QUERY_RELATION = ReflectionUtils.getField(CheckboxQueryInstance.class, "query");

	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;

	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private UnsecureMultiSignQuery query;

	@DAOManaged
	@XMLElement
	private String firstname;

	@DAOManaged
	@XMLElement
	private String lastname;

	@DAOManaged
	@XMLElement
	private String email;
	
	@DAOManaged
	@XMLElement
	private String mobilePhone;

	public Integer getQueryInstanceID() {

		return queryInstanceID;
	}

	public void setQueryInstanceID(Integer queryInstanceID) {

		this.queryInstanceID = queryInstanceID;
	}

	@Override
	public void reset(MutableAttributeHandler attributeHandler) {

		this.firstname = null;
		this.lastname = null;
		this.email = null;
		this.mobilePhone = null;
		
		if (query.isSetAsAttribute()) {
			
			resetAttribute(attributeHandler);
		}

		super.reset(attributeHandler);
	}

	public void resetAttribute(MutableAttributeHandler attributeHandler) {
		
		attributeHandler.removeAttribute(query.getAttributeName() + ".firstname");
		attributeHandler.removeAttribute(query.getAttributeName() + ".lastname");
		attributeHandler.removeAttribute(query.getAttributeName() + ".email");
		attributeHandler.removeAttribute(query.getAttributeName() + ".mobilePhone");
	}
	
	public void setAttribute(MutableAttributeHandler attributeHandler) {
		
		attributeHandler.setAttribute(query.getAttributeName() + ".firstname", firstname);
		attributeHandler.setAttribute(query.getAttributeName() + ".lastname", lastname);
		attributeHandler.setAttribute(query.getAttributeName() + ".email", email);
		attributeHandler.setAttribute(query.getAttributeName() + ".mobilePhone", mobilePhone);
	}

	public void copyQueryValues() {

	}

	@Override
	public String toString() {

		return "UnsecureMultiSignQueryInstance (queryInstanceID=" + queryInstanceID + ")";
	}

	@Override
	public UnsecureMultiSignQuery getQuery() {

		return query;
	}

	public void setQuery(UnsecureMultiSignQuery query) {

		this.query = query;
	}

	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {

		Element element = getBaseExportXML(doc);

		XMLUtils.appendNewCDATAElement(doc, element, "Firstname", firstname);
		XMLUtils.appendNewCDATAElement(doc, element, "Lastname", lastname);
		XMLUtils.appendNewCDATAElement(doc, element, "Email", email);
		XMLUtils.appendNewCDATAElement(doc, element, "MobilePhone", mobilePhone);

		return element;
	}

	public String getFirstname() {

		return firstname;
	}

	public void setFirstname(String firstname) {

		this.firstname = firstname;
	}

	public String getLastname() {

		return lastname;
	}

	public void setLastname(String lastname) {

		this.lastname = lastname;
	}

	public String getEmail() {

		return email;
	}

	public void setEmail(String email) {

		this.email = email;
	}
	
	public String getMobilePhone() {
		
		return mobilePhone;
	}
	
	
	public void setMobilePhone(String mobilePhone) {
		
		this.mobilePhone = mobilePhone;
	}
	
	public boolean isEmpty() {
		return ObjectUtils.isNull(firstname, lastname, email, mobilePhone);
	}
	
	@Override
	public List<? extends SigningParty> getSigningParties() {

		if (getQueryInstanceDescriptor().isPopulated()) {
		
			return Collections.singletonList(new SigningParty(firstname, lastname, email, mobilePhone, getQuery().isSetMultipartsAsOwners()));
		}
		
		return null;
	}

	@Override
	public List<String> getColumnLabels(QueryHandler queryHandler) {

		UnsecureMultiSignQueryProviderModule queryProvider = queryHandler.getQueryProvider(getQueryInstanceDescriptor().getQueryDescriptor().getQueryTypeID(), UnsecureMultiSignQueryProviderModule.class);

		List<String> labels = new ArrayList<String>();

		labels.add(getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + queryProvider.getExportFirstName());
		labels.add(getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + queryProvider.getExportLastName());
		labels.add(getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + queryProvider.getExportEmail());
		labels.add(getQueryInstanceDescriptor().getQueryDescriptor().getName() + ": " + queryProvider.getExportMobilePhone());

		return labels;
	}

	@Override
	public List<String> getColumnValues() {

		List<String> values = new ArrayList<String>();
		
		values.add(getFirstname());
		values.add(getLastname());
		values.add(getEmail());
		values.add(getMobilePhone());

		return values;
	}
}
