package com.nordicpeak.flowengine.evaluators.useraddressquerystateevaluator;

import java.util.ArrayList;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;

import com.nordicpeak.flowengine.evaluators.basequerystateevaluator.BaseQueryStateEvaluator;

@Table(name = "user_address_query_state_evaluators")
@XMLElement
public class UserAddressQueryStateEvaluator extends BaseQueryStateEvaluator {

	private static final long serialVersionUID = 7582032280793947029L;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean invert;

	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<Address> addresses;

	private boolean initialized;

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		super.populate(xmlParser);

		List<ValidationError> errors = new ArrayList<ValidationError>(1);

		invert = xmlParser.getPrimitiveBoolean("invert");

		List<XMLParser> addressNodes = xmlParser.getNodes("Addresses/Address");

		if (!CollectionUtils.isEmpty(addressNodes)) {

			addresses = new ArrayList<Address>(addressNodes.size());

			for (XMLParser parser : addressNodes) {

				Address Address = new Address();

				Address.populate(parser);
				Address.setEvaluator(this);

				addresses.add(Address);
			}
		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	public boolean isInverted() {

		return invert;
	}

	public void setInvert(boolean invert) {

		this.invert = invert;
	}

	public List<Address> getAddresses() {

		return addresses;
	}

	public void setAddresses(List<Address> addresses) {

		this.addresses = addresses;
	}

	public boolean containsAddress(Address address) {

		return addresses != null && addresses.contains(address);
	}

	@Override
	public boolean requiresInitialization() {

		return true;
	}

	public boolean isInitialized() {

		return initialized;
	}

	public void setInitialized(boolean initialized) {

		this.initialized = initialized;
	}

}
