package com.nordicpeak.flowengine.queries.usertreequery;

import java.util.ArrayList;
import java.util.List;

import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.InstanceManagerDependency;
import se.unlogic.hierarchy.core.annotations.ModuleSetting;
import se.unlogic.hierarchy.core.annotations.TextFieldSettingDescriptor;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.usergrouplist.UserGroupListConnector;
import se.unlogic.hierarchy.foregroundmodules.AnnotatedForegroundModule;

import com.nordicpeak.listuserprovider.ListParameter;
import com.nordicpeak.listuserprovider.ListUser;
import com.nordicpeak.listuserprovider.ListUserHandler;
import com.nordicpeak.listuserprovider.ListUserProvider;
import com.nordicpeak.listuserprovider.SimpleListUser;

public class UserHandlerListUserProvider extends AnnotatedForegroundModule implements ListUserProvider {
	
	@ModuleSetting
	@TextFieldSettingDescriptor(name = "Provider ID", description = "The unique identifier for this provider.", required = true)
	protected String providerID = getClass().getName();
	
	protected UserGroupListConnector userGroupListConnector;
	
	protected ListUserHandler listUserHandler;
	
	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {
		
		super.init(moduleDescriptor, sectionInterface, dataSource);
		
		this.userGroupListConnector = new UserGroupListConnector(systemInterface);
	}
	
	@Override
	public void update(ForegroundModuleDescriptor descriptor, DataSource dataSource) throws Exception {
		
		if (listUserHandler != null) {
			listUserHandler.removeUserListProvider(this);
		}
		
		super.update(descriptor, dataSource);
		
		if (listUserHandler != null) {
			listUserHandler.addUserListProvider(this);
		}
	}
	
	@Override
	public void unload() throws Exception {
		
		if (listUserHandler != null) {
			listUserHandler.removeUserListProvider(this);
		}
		
		super.unload();
	}
	
	@InstanceManagerDependency
	public void setListUserHandler(ListUserHandler listUserHandler) {
		
		if (listUserHandler != null) {
			
			listUserHandler.addUserListProvider(this);
			
		} else if (this.listUserHandler != null) {
			
			this.listUserHandler.removeUserListProvider(this);
		}
		
		this.listUserHandler = listUserHandler;
	}
	
	@Override
	public String getListName() {
		
		return moduleDescriptor.getDescription();
	}
	
	@Override
	public String getListID() {
		
		return providerID;
	}
	
	@Override
	public ListUser getListUser(String providerUserID) {
		
		User user = getUser(providerUserID);
		
		if (user == null) {
			return null;
		}
		
		return new SimpleListUser(user);
	}
	
	@Override
	public User getUser(String providerUserID) {
		
		return systemInterface.getUserHandler().getUser(Integer.parseInt(providerUserID), false, true);
	}
	
	@Override
	public List<ListUser> searchUsers(Integer flowID, String searchString, List<? extends ListParameter> filterParameters, User user) throws Exception {
		
		List<User> users = userGroupListConnector.getUsers(searchString, user);
		
		if (users == null) {
			return null;
		}
		
		List<ListUser> storedListUsers = new ArrayList<ListUser>(users.size());
		
		for (User user2 : users) {
			storedListUsers.add(new SimpleListUser(user2));
		}
		
		return storedListUsers;
	}
	
	@Override
	public List<ListUser> getUsers(Integer flowID, List<? extends ListParameter> filterParameters) throws Exception {
		
		return null;
	}
	
}
