package com.nordicpeak.flowengine.queries.userlistquery;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.BeanRequestPopulator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.QueryDescriptor;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUD;
import com.nordicpeak.flowengine.queries.userlistquery.beans.UserListQuery;
import com.nordicpeak.flowengine.queries.userlistquery.enums.UserSourceType;
import com.nordicpeak.listuserprovider.ListUserProvider;

public class UserListQueryCRUD extends BaseQueryCRUD<UserListQuery, UserListQueryProviderModule> {

	protected AnnotatedDAOWrapper<UserListQuery, Integer> queryDAO;

	public UserListQueryCRUD(AnnotatedDAOWrapper<UserListQuery, Integer> queryDAO, BeanRequestPopulator<UserListQuery> populator, String typeElementName, String typeLogName, String listMethodAlias, UserListQueryProviderModule callback) {

		super(UserListQuery.class, queryDAO, populator, typeElementName, typeLogName, listMethodAlias, callback);

		this.queryDAO = queryDAO;
	}

	@Override
	protected void appendUpdateFormData(UserListQuery query, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {

		super.appendUpdateFormData(query, doc, updateTypeElement, user, req, uriParser);

		Element providersElement = XMLUtils.appendNewElement(doc, updateTypeElement, "Providers");

		for (ListUserProvider provider : callback.getUserListProviders()) {

			Element providerElement = XMLUtils.appendNewElement(doc, providersElement, "Provider");

			XMLUtils.appendNewElement(doc, providerElement, "Name", provider.getListName());
			XMLUtils.appendNewElement(doc, providerElement, "ID", provider.getListID());
		}

		if (query.getUserSourceType() != null && query.getUserSourceType() == UserSourceType.LIST_USER_PROVIDER && !StringUtils.isEmpty(query.getProviderIdentifier()) && callback.getUserListProvider(query.getProviderIdentifier()) == null) {

			Element providerElement = XMLUtils.appendNewElement(doc, providersElement, "Provider");

			XMLUtils.appendNewElement(doc, providerElement, "Name", callback.getMissingUserListProvider());
			XMLUtils.appendNewElement(doc, providerElement, "ID", query.getProviderIdentifier());
		}
	}

	@Override
	protected UserListQuery populateFromUpdateRequest(UserListQuery bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		UserListQuery query = super.populateFromUpdateRequest(bean, req, user, uriParser);

		List<ValidationError> validationErrors = new ArrayList<>();

		this.populateQueryDescriptor((QueryDescriptor) query.getQueryDescriptor(), req, validationErrors);

		validateMinAndMax(query.getMinSelectedUsers(), query.getMaxSelectedUsers(), validationErrors);

		if (!validationErrors.isEmpty()) {
			throw new ValidationException(validationErrors);
		}

		return query;
	}

	public static void validateMinAndMax(Integer minSelected, Integer maxSelected, List<ValidationError> validationErrors) {

		if (minSelected != null) {

			if (maxSelected != null && (minSelected > maxSelected || maxSelected < minSelected)) {
				validationErrors.add(new ValidationError("MinSelectedBiggerThanMaxSelected"));
			}

		}

	}

}
