package com.nordicpeak.flowengine.queries.userlistquery;

import java.io.IOException;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.annotations.XSLVariable;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.exceptions.AccessDeniedException;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.SectionInterface;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.hierarchy.core.interfaces.modules.descriptors.ForegroundModuleDescriptor;
import se.unlogic.hierarchy.core.utils.AccessUtils;
import se.unlogic.hierarchy.core.utils.FCKUtils;
import se.unlogic.hierarchy.core.utils.usergrouplist.UserGroupListConnector;
import se.unlogic.standardutils.arrays.ArrayUtils;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.dao.querys.ArrayListQuery;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.numbers.NumberUtils;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.RequestUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;
import se.unlogic.webutils.url.URLRewriter;

import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.QueryResponse;
import com.nordicpeak.flowengine.enums.QueryState;
import com.nordicpeak.flowengine.interfaces.ImmutableFlowFamily;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MultiSigningQueryProvider;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.interfaces.MutableQueryInstanceDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryContentFilter;
import com.nordicpeak.flowengine.interfaces.QueryInstance;
import com.nordicpeak.flowengine.interfaces.QueryRequestProcessor;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryCRUDCallback;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryProviderModule;
import com.nordicpeak.flowengine.queries.checkboxquery.validationerrors.TooFewAlternativesSelectedValidationError;
import com.nordicpeak.flowengine.queries.checkboxquery.validationerrors.TooManyAlternativesSelectedValidationError;
import com.nordicpeak.flowengine.queries.userlistquery.beans.NoCitizenIDValidationError;
import com.nordicpeak.flowengine.queries.userlistquery.beans.StoredListUser;
import com.nordicpeak.flowengine.queries.userlistquery.beans.UserListParameter;
import com.nordicpeak.flowengine.queries.userlistquery.beans.UserListQuery;
import com.nordicpeak.flowengine.queries.userlistquery.beans.UserListQueryInstance;
import com.nordicpeak.flowengine.queries.userlistquery.enums.UserSourceType;
import com.nordicpeak.flowengine.utils.JTidyUtils;
import com.nordicpeak.flowengine.utils.TextTagReplacer;
import com.nordicpeak.listuserprovider.ListUser;
import com.nordicpeak.listuserprovider.ListUserHandler;
import com.nordicpeak.listuserprovider.ListUserProvider;

public class UserListQueryProviderModule extends BaseQueryProviderModule<UserListQueryInstance> implements BaseQueryCRUDCallback, MultiSigningQueryProvider, ListUserHandler {

	@XSLVariable(prefix = "java.")
	private String missingProvider = "Missing";

	private AnnotatedDAO<UserListQuery> queryDAO;
	private AnnotatedDAO<UserListQueryInstance> queryInstanceDAO;

	private UserListQueryCRUD queryCRUD;

	private QueryParameterFactory<UserListQuery, Integer> queryIDParamFactory;
	private QueryParameterFactory<UserListQueryInstance, Integer> queryInstanceIDParamFactory;

	protected UserGroupListConnector userGroupListConnector;
	
	private ConcurrentHashMap<String, ListUserProvider> userListProviders = new ConcurrentHashMap<>();

	@Override
	public void init(ForegroundModuleDescriptor moduleDescriptor, SectionInterface sectionInterface, DataSource dataSource) throws Exception {

		super.init(moduleDescriptor, sectionInterface, dataSource);

		if (!systemInterface.getInstanceHandler().addInstance(ListUserHandler.class, this)) {

			throw new RuntimeException("Unable to register module " + moduleDescriptor + " in global instance handler using key " + ListUserHandler.class.getSimpleName() + ", another instance is already registered using this key.");
		}
	}

	@Override
	public void unload() throws Exception {

		systemInterface.getInstanceHandler().removeInstance(ListUserHandler.class, this);

		super.unload();
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, UserListQueryProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		SimpleAnnotatedDAOFactory daoFactory = new SimpleAnnotatedDAOFactory(dataSource);

		queryDAO = daoFactory.getDAO(UserListQuery.class);
		queryInstanceDAO = daoFactory.getDAO(UserListQueryInstance.class);

		queryCRUD = new UserListQueryCRUD(queryDAO.getWrapper(Integer.class), new AnnotatedRequestPopulator<>(UserListQuery.class), "UserListQuery", "query", null, this);

		queryIDParamFactory = queryDAO.getParamFactory("queryID", Integer.class);
		queryInstanceIDParamFactory = queryInstanceDAO.getParamFactory("queryInstanceID", Integer.class);
		
		userGroupListConnector = new UserGroupListConnector(systemInterface);
	}

	@Override
	public Query createQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {

		UserListQuery query = new UserListQuery();

		query.setQueryID(descriptor.getQueryID());

		this.queryDAO.add(query, transactionHandler, null);

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public Query importQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap, QueryContentFilter contentFilter) throws Throwable {

		UserListQuery query = new UserListQuery();

		query.setQueryID(descriptor.getQueryID());

		query.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(query.getClass())));

		contentFilter.filterHTML(query);

		this.queryDAO.add(query, transactionHandler, null);

		return query;
	}

	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, boolean extraData) throws SQLException {

		UserListQuery query = this.getQuery(descriptor.getQueryID());

		if (query == null) {

			return null;
		}

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public Query getQuery(MutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		UserListQuery query = this.getQuery(descriptor.getQueryID(), transactionHandler);

		if (query == null) {

			return null;
		}

		query.init(descriptor, getFullAlias() + "/config/" + descriptor.getQueryID());

		return query;
	}

	@Override
	public QueryInstance getQueryInstance(MutableQueryInstanceDescriptor descriptor, String instanceManagerID, HttpServletRequest req, User user, User poster, InstanceMetadata instanceMetadata) throws SQLException {

		UserListQueryInstance queryInstance;

		//Check if we should create a new instance or get an existing one
		if (descriptor.getQueryInstanceID() == null) {

			queryInstance = new UserListQueryInstance();

		} else {

			queryInstance = getQueryInstance(descriptor.getQueryInstanceID());

			if (queryInstance == null) {

				return null;
			}
		}

		queryInstance.setQuery(getQuery(descriptor.getQueryDescriptor().getQueryID()));

		if (queryInstance.getQuery() == null) {

			return null;
		}

		if (req != null) {

			FCKUtils.setAbsoluteFileUrls(queryInstance.getQuery(), RequestUtils.getFullContextPathURL(req) + ckConnectorModuleAlias);

			URLRewriter.setAbsoluteLinkUrls(queryInstance.getQuery(), req, true);
		}

		queryInstance.getQuery().scanAttributeTags();

		TextTagReplacer.replaceTextTags(queryInstance.getQuery(), instanceMetadata.getSiteProfile());

		queryInstance.set(descriptor);

		//If this is a new query instance copy the default values
		if (descriptor.getQueryInstanceID() == null) {

			//TODO remove this automatic pre selection in the future if possible
			// If provider is FlowManagersListUserProvider then pre-select current user
			ListUserProvider provider = getListUserProvider(queryInstance.getQuery());
			ImmutableFlowFamily flowFamily = descriptor.getQueryDescriptor().getStep().getFlow().getFlowFamily();

			if (poster != null && provider != null && provider.getClass().getSimpleName().equals("FlowManagersListUserProvider") && flowFamily.getManagerAccess(poster) != null) {

				ListUser listUser = provider.getListUser(poster.getUserID().toString());

				if (listUser != null) {

					List<StoredListUser> storedListUsers = new ArrayList<StoredListUser>();
					storedListUsers.add(new StoredListUser(listUser));

					queryInstance.setUsers(storedListUsers);
				}
			}
		}

		return queryInstance;
	}

	private UserListQuery getQuery(Integer queryID) throws SQLException {

		HighLevelQuery<UserListQuery> query = new HighLevelQuery<>();

		query.addParameter(queryIDParamFactory.getParameter(queryID));

		return queryDAO.get(query);
	}

	private UserListQuery getQuery(Integer queryID, TransactionHandler transactionHandler) throws SQLException {

		HighLevelQuery<UserListQuery> query = new HighLevelQuery<>();

		query.addParameter(queryIDParamFactory.getParameter(queryID));

		return queryDAO.get(query, transactionHandler);
	}

	private UserListQueryInstance getQueryInstance(Integer queryInstanceID) throws SQLException {

		HighLevelQuery<UserListQueryInstance> query = new HighLevelQuery<>(UserListQueryInstance.QUERY_RELATION);

		query.addParameter(queryInstanceIDParamFactory.getParameter(queryInstanceID));

		return queryInstanceDAO.get(query);
	}

	@Override
	public QueryResponse getFormHTML(UserListQueryInstance queryInstance, HttpServletRequest req, User user, User poster, List<ValidationError> validationErrors, boolean enableAjaxPosting, String queryRequestURL, InstanceRequestMetadata requestMetadata, AttributeHandler attributeHandler) throws Throwable {

		if (queryInstance.getUsers() == null && queryInstance.getSearchParameters() != null) {

			queryInstance.setUsers(getUsers(queryInstance, queryInstance.getSearchParameters()));
		}

		return super.getFormHTML(queryInstance, req, user, poster, validationErrors, enableAjaxPosting, queryRequestURL, requestMetadata, attributeHandler);
	}

	@Override
	public void save(UserListQueryInstance queryInstance, TransactionHandler transactionHandler, InstanceRequestMetadata requestMetadata) throws Throwable {

		if (queryInstance.getQueryInstanceID() == null || !queryInstance.getQueryInstanceID().equals(queryInstance.getQueryInstanceDescriptor().getQueryInstanceID())) {

			queryInstance.setQueryInstanceID(queryInstance.getQueryInstanceDescriptor().getQueryInstanceID());

			this.queryInstanceDAO.add(queryInstance, transactionHandler, null);

		} else {

			this.queryInstanceDAO.update(queryInstance, transactionHandler, null);
		}
	}

	@Override
	public void populate(UserListQueryInstance queryInstance, HttpServletRequest req, User user, User poster, boolean allowPartialPopulation, MutableAttributeHandler attributeHandler, InstanceRequestMetadata requestMetadata) throws ValidationException {

		Integer queryID = queryInstance.getQuery().getQueryID();

		List<ValidationError> validationErrors = new ArrayList<>();

		String userFieldName = "q" + queryID + "_user";

		String[] providerUserIDs = req.getParameterValues(userFieldName);

		List<StoredListUser> storedListUsers = null;

		if (!ArrayUtils.isEmpty(providerUserIDs)) {

			storedListUsers = new ArrayList<>(providerUserIDs.length);

			for (String providerUserID : providerUserIDs) {

				StoredListUser storedListUser = null;

				if(queryInstance.getQuery().getUserSourceType() == UserSourceType.LIST_USER_PROVIDER) {
					
					ListUserProvider provider = getUserListProvider(queryInstance.getQuery().getProviderIdentifier());

					if (provider != null) {

						ListUser listUser = provider.getListUser(providerUserID);

						if (listUser != null) {

							storedListUser = new StoredListUser(listUser);
						}
					}
					
				}else if(queryInstance.getQuery().getUserSourceType() == UserSourceType.GROUPS) {
					
					Integer userID = NumberUtils.toInt(providerUserID);
					
					if(userID != null) {
						
						User selectedUser = systemInterface.getUserHandler().getUser(userID, true, true);

						if(selectedUser != null && AccessUtils.checkGroupAccess(selectedUser, queryInstance.getQuery().getGroupIDs())) {
							
							storedListUser = new StoredListUser(selectedUser);
						}
					}
				}
				
				if (storedListUser == null) {

					validationErrors.add(new ValidationError("InvalidUser"));

				} else {

					storedListUsers.add(storedListUser);
				}
			}
		}

		//If partial population is allowed and the user has not selected any alternatives, skip validation
		if (allowPartialPopulation) {

			if (CollectionUtils.isEmpty(storedListUsers)) {

				queryInstance.reset(attributeHandler);

			} else {

				queryInstance.setUsers(storedListUsers);
				queryInstance.getQueryInstanceDescriptor().setPopulated(true);
			}

			return;
		}

		//Check if this query is required or if the user has selected any alternatives anyway
		if (queryInstance.getQueryInstanceDescriptor().getQueryState() == QueryState.VISIBLE_REQUIRED || !CollectionUtils.isEmpty(storedListUsers)) {

			if (!CollectionUtils.isEmpty(storedListUsers) && queryInstance.getQuery().getMinSelectedUsers() != null && storedListUsers.size() < queryInstance.getQuery().getMinSelectedUsers()) {

				validationErrors.add(new TooFewAlternativesSelectedValidationError(storedListUsers.size(), queryInstance.getQuery().getMinSelectedUsers()));

			} else if (!CollectionUtils.isEmpty(storedListUsers) && queryInstance.getQuery().getMaxSelectedUsers() != null && storedListUsers.size() > queryInstance.getQuery().getMaxSelectedUsers()) {

				validationErrors.add(new TooManyAlternativesSelectedValidationError(storedListUsers.size(), queryInstance.getQuery().getMaxSelectedUsers()));

			} else if (queryInstance.getQueryInstanceDescriptor().getQueryState() == QueryState.VISIBLE_REQUIRED && CollectionUtils.isEmpty(storedListUsers)) {

				validationErrors.add(new ValidationError("RequiredQuery"));
			}

			if (queryInstance.getQuery().requiresMultipartSigning() && !CollectionUtils.isEmpty(storedListUsers)) {

				for (StoredListUser listUser : storedListUsers) {

					if (StringUtils.isEmpty(listUser.getCitizenIdentifier())) {

						validationErrors.add(new NoCitizenIDValidationError(listUser));
					}
				}
			}
		}

		if (!validationErrors.isEmpty()) {

			throw new ValidationException(validationErrors);
		}

		queryInstance.setUsers(storedListUsers);
		queryInstance.getQueryInstanceDescriptor().setPopulated(!CollectionUtils.isEmpty(storedListUsers));

		if (queryInstance.getQuery().isSetAsAttribute()) {

			queryInstance.resetAttribute(attributeHandler);
			queryInstance.setAttribute(attributeHandler);
		}
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureQuery(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.queryCRUD.update(req, res, user, uriParser);
	}

	@Override
	public boolean deleteQuery(ImmutableQueryDescriptor descriptor, TransactionHandler transactionHandler) throws SQLException {

		UserListQuery query = getQuery(descriptor.getQueryID());

		if (query == null) {

			return false;
		}

		this.queryDAO.delete(query, transactionHandler);

		return true;
	}

	@Override
	public boolean deleteQueryInstance(ImmutableQueryInstanceDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		UserListQueryInstance queryInstance = this.getQueryInstance(descriptor.getQueryInstanceID());

		if (queryInstance == null) {

			return false;
		}

		this.queryInstanceDAO.delete(queryInstance, transactionHandler);

		return true;
	}

	@Override
	public String getTitlePrefix() {

		return this.moduleDescriptor.getName();
	}

	@Override
	public void copyQuery(MutableQueryDescriptor sourceQueryDescriptor, MutableQueryDescriptor copyQueryDescriptor, TransactionHandler transactionHandler, Map<Integer, ImmutableStatus> statusConversionMap) throws SQLException {

		UserListQuery query = getQuery(sourceQueryDescriptor.getQueryID(), transactionHandler);

		query.setQueryID(copyQueryDescriptor.getQueryID());

		queryDAO.add(query, transactionHandler, null);
	}

	@Override
	protected void appendPDFData(Document doc, Element showQueryValuesElement, UserListQueryInstance queryInstance, AttributeHandler attributeHandler) {

		super.appendPDFData(doc, showQueryValuesElement, queryInstance, attributeHandler);

		if (queryInstance.getQuery().getDescription() != null) {

			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "Description", JTidyUtils.getXHTML(queryInstance.getQuery().getDescription(attributeHandler), systemInterface.getEncoding()));
			XMLUtils.appendNewCDATAElement(doc, showQueryValuesElement, "isHTMLDescription", queryInstance.getQuery().getDescription().contains("<") && queryInstance.getQuery().getDescription().contains(">"));
		}

		XMLUtils.appendNewElement(doc, doc.getDocumentElement(), "StaticContent", "classpath://" + getClass().getPackage().getName().replace('.', '/') + "/staticcontent");
	}

	@Override
	protected Class<UserListQueryInstance> getQueryInstanceClass() {

		return UserListQueryInstance.class;
	}

	@Override
	public void addUserListProvider(ListUserProvider userListProvider) {

		if (userListProviders.containsKey(userListProvider.getListID())) {

			log.error("UserListProvider \"" + userListProvider.getListName() + "\" (ID= " + userListProvider.getListID() + ") is already registered");
			return;
		}

		userListProviders.put(userListProvider.getListID(), userListProvider);

		log.info("UserListQueryDataProvider " + userListProvider.getListName() + " registered");
	}

	@Override
	public boolean removeUserListProvider(ListUserProvider userListProvider) {

		boolean removed = userListProviders.remove(userListProvider.getListID(), userListProvider);

		if (removed) {
			log.info("UserListQueryDataProvider " + userListProvider.getListName() + " unregistered");
		}

		return removed;
	}

	@Override
	public ListUserProvider getUserListProvider(String id) {

		return userListProviders.get(id);
	}

	@Override
	public Collection<ListUserProvider> getUserListProviders() {

		return userListProviders.values();
	}

	public String getMissingUserListProvider() {

		return missingProvider;
	}

	public ListUserProvider getListUserProvider(UserListQuery query) {

		if (!StringUtils.isEmpty(query.getProviderIdentifier())) {

			ListUserProvider provider = userListProviders.get(query.getProviderIdentifier());

			if (provider != null) {

				return provider;
			}

			log.warn("UserListQueryDataProvider " + query.getProviderIdentifier() + " not found");
		}

		return null;
	}

	@Override
	public QueryRequestProcessor getQueryRequestProcessor(UserListQueryInstance queryInstance, HttpServletRequest req, User user, User poster, URIParser uriParser, InstanceRequestMetadata requestMetadata) throws IOException {

		if(queryInstance.getQuery().getUserSourceType() != null) {
			
			if(queryInstance.getQuery().getUserSourceType() == UserSourceType.LIST_USER_PROVIDER) {
				
				ListUserProvider provider = getListUserProvider(queryInstance.getQuery());

				if (provider != null) {

					return new UserListQueryRequestProcessor(provider, queryInstance, systemInterface.getEncoding());
				}

			} else if (queryInstance.getQuery().getUserSourceType() == UserSourceType.GROUPS){
				
				if(queryInstance.getQuery().getGroupIDs() != null) {
					
					return new UserListQueryRequestProcessor(systemInterface.getUserHandler(), queryInstance, systemInterface.getEncoding());
				}
				
			} else {
				
				throw new RuntimeException("Unknown enum value " + queryInstance.getQuery().getUserSourceType());
			}
		}
		
		return null;
	}

	public List<StoredListUser> getUsers(UserListQueryInstance queryInstance, List<UserListParameter> searchParameters) {

		ListUserProvider provider = getListUserProvider(queryInstance.getQuery());

		if (provider != null) {

			try {
				List<ListUser> listUsers = provider.getUsers(queryInstance.getQueryInstanceDescriptor().getQueryDescriptor().getStep().getFlow().getFlowID(), searchParameters);

				if (listUsers != null) {

					List<StoredListUser> storedListUsers = new ArrayList<>(listUsers.size());

					for (ListUser listUser : listUsers) {

						storedListUsers.add(new StoredListUser(listUser));
					}

					return storedListUsers;
				}

			} catch (Exception e) {

				log.error("Error getting users from provider " + provider, e);
			}
		}

		return null;
	}

	@Override
	public List<Integer> getQueryInstanceIDs(String citizenIdentifier) throws SQLException {

		ArrayListQuery<Integer> query = new ArrayListQuery<>(queryInstanceDAO.getDataSource(), "SELECT i.queryInstanceID FROM " + queryInstanceDAO.getTableName() + " i " + "INNER JOIN (" + "SELECT queryID FROM " + queryDAO.getTableName() + " WHERE useForMultipartSigning = true" + ") q ON q.queryID = i.queryID " + "INNER JOIN userlist_query_users u ON u.queryInstanceID = i.queryInstanceID " + "WHERE u.citizenIdentifier = ?", IntegerPopulator.getPopulator());
		query.setString(1, citizenIdentifier);

		return query.executeQuery();
	}
	
	@WebPublic(alias = "groups")
	public ForegroundModuleResponse getGroups(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Throwable {

		if(this.flowAdminModule == null || !AccessUtils.checkAccess(user, flowAdminModule.getModuleDescriptor())) {
			
			throw new AccessDeniedException("User does not have access to list groups via this module");
		}
		
		return userGroupListConnector.getGroups(req, res, user, uriParser);
	}
}
