package com.nordicpeak.flowengine.queries.userlistquery.beans;

import java.io.Serializable;
import java.lang.reflect.Field;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.attributes.AttributeHandler;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.GeneratedElementable;
import se.unlogic.standardutils.xml.XMLElement;

import com.nordicpeak.flowengine.utils.CitizenIdentifierUtils;
import com.nordicpeak.listuserprovider.ListUser;

@Table(name = "userlist_query_users")
@XMLElement(name = "user")
public class StoredListUser extends GeneratedElementable implements Comparable<StoredListUser>, Serializable {

	private static final long serialVersionUID = 5707451931598194780L;

	public static final Field QUERY_INSTANCE_RELATION = ReflectionUtils.getField(StoredListUser.class, "queryInstance");

	@DAOManaged
	@Key
	@XMLElement(name = "userID")
	private String providerUserID;

	@DAOManaged
	@XMLElement
	private String firstname;

	@DAOManaged
	@XMLElement
	private String lastname;

	@DAOManaged
	@XMLElement
	private String username;

	@DAOManaged
	@XMLElement
	private String citizenIdentifier;

	@DAOManaged
	@XMLElement
	private String email;

	@DAOManaged
	@XMLElement
	private String phone;

	@DAOManaged(columnName = "queryInstanceID")
	@Key
	@ManyToOne
	private UserListQueryInstance queryInstance;

	public StoredListUser() {}

	public StoredListUser(User user) {

		providerUserID = user.getUserID().toString();
		firstname = user.getFirstname();
		lastname = user.getLastname();
		email = user.getEmail();
		username = user.getUsername();

		AttributeHandler attributeHandler = user.getAttributeHandler();

		if (attributeHandler != null) {

			citizenIdentifier = CitizenIdentifierUtils.getUserOrManagerCitizenIdentifier(user);
			phone = attributeHandler.getString("mobilePhone");
		}
	}

	public StoredListUser(ListUser listUser) {

		this.providerUserID = listUser.getProviderUserID();
		this.firstname = listUser.getFirstname();
		this.lastname = listUser.getLastname();
		this.username = listUser.getUsername();
		this.citizenIdentifier = listUser.getCitizenIdentifier();
		this.email = listUser.getEmail();
		this.phone = listUser.getPhone();
	}

	public String getFirstname() {

		return firstname;
	}

	public void setFirstname(String firstname) {

		this.firstname = firstname;
	}

	public String getLastname() {

		return lastname;
	}

	public void setLastname(String lastname) {

		this.lastname = lastname;
	}

	public String getProviderUserID() {

		return providerUserID;
	}

	public void setProviderUserID(String providerUserID) {

		this.providerUserID = providerUserID;
	}

	public String getCitizenIdentifier() {

		return citizenIdentifier;
	}

	public void setCitizenIdentifier(String citizenIdentifier) {

		this.citizenIdentifier = citizenIdentifier;
	}

	public String getEmail() {

		return email;
	}

	public void setEmail(String email) {

		this.email = email;
	}

	public String getPhone() {

		return phone;
	}

	public void setPhone(String phone) {

		this.phone = phone;
	}

	public String getUsername() {

		return username;
	}

	public void setUsername(String username) {

		this.username = username;
	}

	public UserListQueryInstance getQueryInstance() {

		return queryInstance;
	}

	public void setQueryInstance(UserListQueryInstance queryInstance) {

		this.queryInstance = queryInstance;
	}

	@Override
	public int hashCode() {

		final int prime = 31;
		int result = 1;
		result = prime * result + ((citizenIdentifier == null) ? 0 : citizenIdentifier.hashCode());
		result = prime * result + ((providerUserID == null) ? 0 : providerUserID.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {

		if (this == obj) {
			return true;
		}
		if (obj == null) {
			return false;
		}
		if (getClass() != obj.getClass()) {
			return false;
		}
		StoredListUser other = (StoredListUser) obj;
		if (citizenIdentifier == null) {
			if (other.citizenIdentifier != null) {
				return false;
			}
		} else if (!citizenIdentifier.equals(other.citizenIdentifier)) {
			return false;
		}
		if (providerUserID == null) {
			if (other.providerUserID != null) {
				return false;
			}
		} else if (!providerUserID.equals(other.providerUserID)) {
			return false;
		}
		return true;
	}

	@Override
	public int compareTo(StoredListUser o) {

		int comparison = firstname.compareToIgnoreCase(o.getFirstname());

		if (comparison != 0) {
			return comparison;
		}

		return lastname.compareToIgnoreCase(o.getLastname());
	}
	
	@Override
	public String toString(){
		
		if(username == null){
		
			return firstname + " " + lastname;
			
		}else{
			
			return firstname + " " + lastname + " (" + username + ")";
		}
	}

}
