package com.nordicpeak.flowengine.queries.userlistquery.beans;

import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.Set;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.string.StringUtils;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.InstanceRequestMetadata;
import com.nordicpeak.flowengine.beans.SigningParty;
import com.nordicpeak.flowengine.interfaces.MultiSignQueryinstance;
import com.nordicpeak.flowengine.interfaces.QueryHandler;
import com.nordicpeak.flowengine.interfaces.QueryRequestProcessor;
import com.nordicpeak.flowengine.interfaces.UserValueQueryInstance;
import com.nordicpeak.flowengine.interfaces.UserValuesQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryInstance;
import com.nordicpeak.flowengine.queries.basequery.BaseQueryUtils;
import com.nordicpeak.flowengine.queries.userlistquery.UserListQueryProviderModule;
import com.nordicpeak.listuserprovider.ListUserProvider;

@Table(name = "userlist_query_instances")
@XMLElement
public class UserListQueryInstance extends BaseQueryInstance implements UserValueQueryInstance, UserValuesQueryInstance, MultiSignQueryinstance {
	
	private static final long serialVersionUID = -7761759005604863873L;
	
	public static final Field QUERY_RELATION = ReflectionUtils.getField(UserListQueryInstance.class, "query");
	
	@DAOManaged
	@Key
	@XMLElement
	private Integer queryInstanceID;
	
	@DAOManaged(columnName = "queryID")
	@ManyToOne
	@XMLElement
	private UserListQuery query;
	
	@DAOManaged
	@OneToMany(autoGet = true, autoAdd = true, autoUpdate = true)
	@XMLElement(fixCase = true)
	private List<StoredListUser> users;
	
	@DAOManaged
	@OneToMany(autoGet = true, autoAdd = true, autoUpdate = true)
	private List<UserListParameter> searchParameters;
	
	public Integer getQueryInstanceID() {
		
		return queryInstanceID;
	}
	
	public void setQueryInstanceID(Integer queryInstanceID) {
		
		this.queryInstanceID = queryInstanceID;
	}
	
	@Override
	public UserListQuery getQuery() {
		
		return query;
	}
	
	public List<StoredListUser> getUsers() {
		
		return users;
	}
	
	public void setUsers(List<StoredListUser> users) {
		
		this.users = users;
	}
	
	public void setQuery(UserListQuery query) {
		
		this.query = query;
	}
	
	public void setAttribute(MutableAttributeHandler attributeHandler) {

		if(users != null){
			
			attributeHandler.setAttribute(query.getAttributeName(), StringUtils.toCommaSeparatedString(users));
		}
	}
	
	@Override
	public void reset(MutableAttributeHandler attributeHandler) {
		
		users = null;
		
		super.reset(attributeHandler);
		
		resetAttribute(attributeHandler);
	}
	
	public void resetAttribute(MutableAttributeHandler attributeHandler) {

		attributeHandler.removeAttribute(query.getAttributeName());
	}
	
	@Override
	public QueryRequestProcessor getQueryRequestProcessor(HttpServletRequest req, User user, User poster, URIParser uriParser, QueryHandler queryHandler, InstanceRequestMetadata requestMetadata) throws Exception {
		
		return BaseQueryUtils.getGenericQueryInstanceProvider(this.getClass(), queryHandler, queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID()).getQueryRequestProcessor(this, req, user, poster, uriParser, requestMetadata);
	}
	
	@Override
	public Element toXML(Document doc) {
		
		Element element = XMLGenerator.toXML(this, doc);
		
		return element;
	}
	
	@Override
	public String toString() {
		
		return getClass().getSimpleName() + " (queryInstanceID=" + queryInstanceID + ")";
	}
	
	@Override
	public Element toExportXML(Document doc, QueryHandler queryHandler) throws Exception {
		
		Element element = getBaseExportXML(doc);
		
		if(users != null){
			
			for(StoredListUser user : users){
				
				Element userElement = doc.createElement("User");
				
				XMLUtils.appendNewElement(doc, userElement, "UserID", user.getProviderUserID());
				XMLUtils.appendNewCDATAElement(doc, userElement, "Username", user.getUsername());
				XMLUtils.appendNewCDATAElement(doc, userElement, "Firstname", user.getFirstname());
				XMLUtils.appendNewCDATAElement(doc, userElement, "Lastname", user.getLastname());
				XMLUtils.appendNewElement(doc, userElement, "CitizenIdentifier", user.getCitizenIdentifier());
				XMLUtils.appendNewElement(doc, userElement, "Email", user.getEmail());
				XMLUtils.appendNewElement(doc, userElement, "Phone", user.getPhone());
				
				element.appendChild(userElement);
			}
		}
		
		return element;
	}
	
	public List<UserListParameter> getSearchParameters() {
		
		if (searchParameters == null) {
			return null;
		}
		
		return Collections.unmodifiableList(searchParameters);
	}
	
	public void setSearchParameters(Set<UserListParameter> searchParameters, QueryHandler queryHandler) {
		
		if (searchParameters != null) {
			
			this.searchParameters = new ArrayList<UserListParameter>(searchParameters);
			
		} else {
			
			this.searchParameters = null;
		}
		
		users = null;
		
		UserListQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), UserListQueryProviderModule.class);
		users = queryProviderModule.getUsers(this, this.searchParameters);
	}
	
	@Override
	public User getUserValue(QueryHandler queryHandler) {
		
		if (!CollectionUtils.isEmpty(users)) {
			
			UserListQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), UserListQueryProviderModule.class);
			ListUserProvider provider = queryProviderModule.getUserListProvider(query.getProviderIdentifier());
			
			if (provider != null) {
				
				return provider.getUser(users.get(0).getProviderUserID());
			}
		}
		
		return null;
	}
	
	@Override
	public Collection<User> getUserValues(QueryHandler queryHandler) {
		
		if (!CollectionUtils.isEmpty(users)) {
			
			UserListQueryProviderModule queryProviderModule = queryHandler.getQueryProvider(queryInstanceDescriptor.getQueryDescriptor().getQueryTypeID(), UserListQueryProviderModule.class);
			ListUserProvider provider = queryProviderModule.getUserListProvider(query.getProviderIdentifier());
			
			if (provider != null) {
				
				List<User> systemUsers = new ArrayList<User>(users.size());
				
				for (StoredListUser storedListUser : users) {
					
					User user = provider.getUser(storedListUser.getProviderUserID());
					
					if (user != null) {
						systemUsers.add(user);
					}
				}
				
				return systemUsers;
			}
		}
		
		return null;
	}

	@Override
	public List<? extends SigningParty> getSigningParties() {
		
		if (!getQuery().requiresMultipartSigning()) {
			return null;
		}
		
		if (users == null) {
			return null;
		}
		
		List<SigningParty> signingParties = new ArrayList<SigningParty>();
		
		for (StoredListUser user : users) {
			
			signingParties.add(new SigningParty(user.getFirstname(), user.getLastname(), user.getEmail(), user.getPhone(), user.getCitizenIdentifier(), getQuery().isSetMultipartsAsOwners()));
		}
		
		return signingParties;
	}
}
