<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/ckeditor/ckeditor.js
		/ckeditor/adapters/jquery.js
		/ckeditor/init.js
	</xsl:variable>
	
	<xsl:variable name="links">
		/css/usertreequery.css
	</xsl:variable>

	<xsl:template match="Document">

		<div id="UserTreeQueryProvider" class="contentitem">

			<xsl:apply-templates select="validationError" />
			<xsl:apply-templates select="UpdateUserTreeQuery" />

		</div>

	</xsl:template>

	<xsl:template match="UpdateUserTreeQuery">

		<h1>
			<xsl:value-of select="$i18n.UpdateQuery" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="UserTreeQuery/QueryDescriptor/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form id="updateUserTreeQueryForm" name="queryAdminForm" method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="UserTreeQuery" />
			</xsl:call-template>
			
			<div class="floatleft full bigmarginbottom">

				<label for="providerIdentifier">
					<xsl:value-of select="$i18n.ProviderIdentifier" />
				</label>

				<div class="floatleft full">
					<xsl:call-template name="createDropdown">
						<xsl:with-param name="id" select="'providerIdentifier'" />
						<xsl:with-param name="name" select="'providerIdentifier'" />
						<xsl:with-param name="labelElementName" select="'Name'" />
						<xsl:with-param name="valueElementName" select="'ID'" />
						<xsl:with-param name="element" select="Providers/Provider" />
						<xsl:with-param name="selectedValue" select="UserTreeQuery/providerIdentifier" />
					</xsl:call-template>
				</div>

			</div>
			
			<div class="floatleft full bigmarginbottom">

				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'onlyAllowSelectingLeafs'" />
					<xsl:with-param name="name" select="'onlyAllowSelectingLeafs'" />
					<xsl:with-param name="value" select="'true'" />
					<xsl:with-param name="element" select="UserTreeQuery" />
				</xsl:call-template>
				
				<label for="onlyAllowSelectingLeafs">
					<xsl:value-of select="$i18n.OnlyAllowSelectingLeafs" />
				</label>
			</div>
			
			<div class="floatleft full bigmarginbottom">

				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'requireEmail'" />
					<xsl:with-param name="name" select="'requireEmail'" />
					<xsl:with-param name="value" select="'true'" />
					<xsl:with-param name="element" select="UserTreeQuery" />
				</xsl:call-template>
				
				<label for="requireEmail">
					<xsl:value-of select="$i18n.RequireEmail" />
				</label>
			</div>
			
			<div class="floatleft full bigmarginbottom">

				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'showCitizenIdentifier'" />
					<xsl:with-param name="name" select="'showCitizenIdentifier'" />
					<xsl:with-param name="value" select="'true'" />
					<xsl:with-param name="element" select="UserTreeQuery" />
				</xsl:call-template>
				
				<label for="showCitizenIdentifier">
					<xsl:value-of select="$i18n.ShowCitizenIdentifier" />
				</label>
			</div>
			
			<div class="floatleft full bigmarginbottom">

				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'showContactInformation'" />
					<xsl:with-param name="name" select="'showContactInformation'" />
					<xsl:with-param name="value" select="'true'" />
					<xsl:with-param name="element" select="UserTreeQuery" />
				</xsl:call-template>
				
				<label for="showContactInformation">
					<xsl:value-of select="$i18n.ShowContactInformation" />
				</label>
			</div>
			
			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>

		</form>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'UpdateFailedUserTreeQueryNotFound']">

		<p class="error">
			<xsl:value-of select="$i18n.UserTreeQueryNotFound" />
		</p>

	</xsl:template>
	
	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
			<xsl:when test="$fieldName = 'providerIdentifier'">
				<xsl:value-of select="$i18n.ProviderIdentifier" />
			</xsl:when>
			<xsl:when test="$fieldName = 'onlyAllowSelectingLeafs'">
				<xsl:value-of select="$i18n.OnlyAllowSelectingLeafs" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>