package com.nordicpeak.flowengine.queries.usertreequery.beans;

import java.io.Serializable;
import java.lang.reflect.Field;
import java.util.ArrayList;
import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Key;
import se.unlogic.standardutils.dao.annotations.ManyToOne;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.reflection.ReflectionUtils;
import se.unlogic.standardutils.xml.Elementable;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.standardutils.xml.XMLUtils;

@Table(name = "usertree_query_nodes")
@XMLElement
public class TreeNode extends LinkedHashMap<String, TreeNode> implements Elementable, Serializable, Comparable<TreeNode> {

	private static final long serialVersionUID = 7634780772195411122L;

	public static final Field QUERY_INSTANCE_RELATION = ReflectionUtils.getField(TreeNode.class, "queryInstanceID");

	@DAOManaged(columnName = "value")
	@Key
	@XMLElement
	private String key;

	@DAOManaged
	@XMLElement
	private String name;

	@DAOManaged
	@Key
	@ManyToOne
	private UserTreeQueryInstance queryInstanceID;

	@DAOManaged
	@XMLElement
	private String parentNodeKey;

	@DAOManaged
	@XMLElement
	private boolean folder = true;

	@XMLElement
	private String icon;

	private TreeNode parent;

	public TreeNode() {};

	public TreeNode(String name, String key) {
		super();

		this.key = key;
		this.name = name;
	}

	public TreeNode(TreeNode otherNode) {

		key = otherNode.getKey();
		name = otherNode.getName();
		folder = otherNode.isFolder();
	};

	public TreeNode put(TreeNode node) {

		return put(node.getKey(), node);
	}

	@Override
	public TreeNode put(String key, TreeNode node) {

		node.setParent(this);
		return super.put(key, node);
	}
	
	public TreeNode remove(TreeNode node) {

		super.remove(node.getKey());
		node.setParent(null);

		return node;
	}
	
	public TreeNode remove(String key) {

		TreeNode node = super.remove(key);

		if (node != null) {

			node.setParent(null);
		}

		return node;
	}

	@Override
	public TreeNode remove(Object key) {

		throw new RuntimeException("Wrong key type");
	}

	public TreeNode getParent() {

		return parent;
	}

	protected void setParent(TreeNode parent) {

		this.parent = parent;

		if (parent == null) {

			parentNodeKey = null;

		} else {

			parentNodeKey = parent.getKey();
		}
	}

	public String getParentNodeKey() {

		return parentNodeKey;
	}

	public String getKey() {

		return key;
	}

	public void setKey(String id) {

		this.key = id;
	}

	public String getName() {

		return name;
	}

	public void setName(String name) {

		this.name = name;
	}

	public UserTreeQueryInstance getQueryInstance() {

		return queryInstanceID;
	}

	public void setQueryInstance(UserTreeQueryInstance queryInstance) {

		this.queryInstanceID = queryInstance;
	}

	public boolean isFolder() {

		return folder;
	}

	public void setFolder(boolean folder) {

		this.folder = folder;
	}

	public String getIcon() {

		return icon;
	}

	public void setIcon(String icon) {

		this.icon = icon;
	}

	@Override
	public Element toXML(Document doc) {

		Element element = XMLGenerator.toXML(this, doc);

		if (!isEmpty()) {

			List<TreeNode> children = new ArrayList<TreeNode>(values());

			Collections.sort(children);

			XMLUtils.append(doc, element, "Children", children);
		}

		return element;
	}

	public TreeNode find(String key) {

		if (this.key.equals(key)) {
			return this;
		}

		TreeNode node = get(key);

		if (node != null) {
			return node;
		}

		for (TreeNode subNode : values()) {

			node = subNode.find(key);

			if (node != null) {
				return node;
			}
		}

		return null;
	}

	public void fillMap(Map<String, TreeNode> treeMap) {

		for (Map.Entry<String, TreeNode> entry : entrySet()) {
			treeMap.put(entry.getKey(), entry.getValue());
		}

		for (TreeNode subNode : values()) {
			subNode.fillMap(treeMap);
		}
	}

	public TreeNode getDirectParentsTree() {

		TreeNode newNode = new TreeNode(this);

		if (parent != null) {

			newNode.setParent(parent.getDirectParentsTree());
		}

		return newNode;
	}

	public List<TreeNode> getDirectParents() {

		List<TreeNode> nodes = new ArrayList<TreeNode>();

		TreeNode node = getDirectParentsTree();

		while (node != null) {

			nodes.add(node);
			node = node.getParent();
		}

		return nodes;
	}

	@Override
	public int compareTo(TreeNode o) {

		if (isFolder() == o.isFolder()) {

			return name.compareToIgnoreCase(o.getName());

		} else {

			return isFolder() ? -1 : 1;
		}
	}

}
