package com.nordicpeak.flowengine.evaluators.dynamicweightquerystateevaluator;

import java.math.BigDecimal;
import java.sql.SQLException;
import java.util.Collections;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.EvaluationResponse;
import com.nordicpeak.flowengine.enums.QueryState;
import com.nordicpeak.flowengine.evaluators.basequerystateevaluator.BaseQueryStateEvaluationProviderModule;
import com.nordicpeak.flowengine.interfaces.CitizenIdentifierQueryInstance;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.Evaluator;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.MutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryInstance;

public class DynamicWeightQueryStateEvaluationProviderModule extends BaseQueryStateEvaluationProviderModule<DynamicWeightQueryStateEvaluator> {

	protected DynamicWeightQueryStateEvaluatorCRUD evaluatorCRUD;

	protected AnnotatedDAO<DynamicWeightQueryStateEvaluator> evaluatorDAO;

	protected QueryParameterFactory<DynamicWeightQueryStateEvaluator, Integer> evaluatorIDParamFactory;

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, DynamicWeightQueryStateEvaluationProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		evaluatorDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(DynamicWeightQueryStateEvaluator.class);
		AnnotatedDAOWrapper<DynamicWeightQueryStateEvaluator, Integer> evaluatorDAOWrapper = evaluatorDAO.getWrapper("evaluatorID", Integer.class);

		evaluatorDAOWrapper.addRelation(DynamicWeightQueryStateEvaluator.VALUE_RELATION);
		evaluatorDAOWrapper.setUseRelationsOnGet(true);
		evaluatorDAOWrapper.setUseRelationsOnUpdate(true);
		evaluatorDAOWrapper.setUseRelationsOnAdd(true);

		evaluatorIDParamFactory = evaluatorDAO.getParamFactory("evaluatorID", Integer.class);

		evaluatorCRUD = new DynamicWeightQueryStateEvaluatorCRUD(DynamicWeightQueryStateEvaluator.class, evaluatorDAOWrapper, this);
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureEvaluator(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.evaluatorCRUD.update(req, res, user, uriParser);
	}

	@Override
	protected Class<DynamicWeightQueryStateEvaluator> getEvaluatorClass() {

		return DynamicWeightQueryStateEvaluator.class;
	}

	@Override
	public boolean supportsQueryType(Class<? extends Query> queryClass) {

		return true;
	}

	protected boolean supportsQueryInstance(QueryInstance queryInstance) {

		return true;
	}

	@Override
	protected AnnotatedDAO<DynamicWeightQueryStateEvaluator> getEvaluatorDAO() {

		return evaluatorDAO;
	}

	@Override
	protected QueryParameterFactory<DynamicWeightQueryStateEvaluator, Integer> getEvaluatorIDParameterFactory() {

		return evaluatorIDParamFactory;
	}

	@Override
	public void copyEvaluator(MutableEvaluatorDescriptor sourceEvaluatorDescriptor, MutableEvaluatorDescriptor copyEvaluatorDescriptor, Query sourceQuery, Query copyQuery, Map<Integer, ImmutableStatus> statusConversionMap, TransactionHandler transactionHandler) throws SQLException {

		DynamicWeightQueryStateEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<>(evaluatorIDParamFactory.getParameter(sourceEvaluatorDescriptor.getEvaluatorID())));

		evaluator.setEvaluatorID(copyEvaluatorDescriptor.getEvaluatorID());

		resetValueIDAndAddEvaluator(transactionHandler, evaluator);

	}

	@Override
	public DynamicWeightQueryStateEvaluator importEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler, Query query, Map<Integer, ImmutableStatus> statusConversionMap) throws Throwable {

		DynamicWeightQueryStateEvaluator evaluator = importEvaluatorDescriptor(descriptor, transactionHandler, query, statusConversionMap);

		resetValueIDAndAddEvaluator(transactionHandler, evaluator);

		return evaluator;
	}

	private void resetValueIDAndAddEvaluator(TransactionHandler transactionHandler, DynamicWeightQueryStateEvaluator evaluator) throws SQLException {

		if(evaluator.getDynamicWeightQueryStateEvaluatorValueList() != null) {
			
			for (DynamicWeightQueryStateEvaluatorValues evaluatorValues : evaluator.getDynamicWeightQueryStateEvaluatorValueList()) {
				
				evaluatorValues.setValueID(null);
			}
		}
		

		this.evaluatorDAO.add(evaluator, transactionHandler, null);
	}

	@Override
	protected List<Integer> getTargetQueryIDs(DynamicWeightQueryStateEvaluator evaluator, EvaluationCallback callback) {

		return Collections.singletonList(callback.getQueryInstance().getQueryInstanceDescriptor().getQueryDescriptor().getQueryID());
	}

	@Override
	public EvaluationResponse evaluate(QueryInstance queryInstance, User user, User poster, DynamicWeightQueryStateEvaluator evaluator, EvaluationCallback callback, boolean hasQueryValidationErrors, MutableAttributeHandler attributeHandler) {

		if (getTargetQueryIDs(evaluator, callback) == null) {

			return null;
		}

		if (!supportsQueryInstance(queryInstance)) {

			log.warn("Query instance " + queryInstance + " is not supported for evaluator " + evaluatorDescriptor);

			return null;
		}

		if (hasQueryValidationErrors && !(queryInstance instanceof CitizenIdentifierQueryInstance && ((CitizenIdentifierQueryInstance) queryInstance).getCitizenIdentifier() != null)) {

			return restoreDefaultQueryStates(queryInstance, evaluator, callback, attributeHandler);
		}

		BigDecimal calculatedValue = evaluator.getCurrentWeight();

		if (calculatedValue != null && compareCalculatedValue(calculatedValue, evaluator)) {

			return applyEvaluatorQueryStates(queryInstance, evaluator, callback, attributeHandler);
		}

		return restoreDefaultQueryStates(queryInstance, evaluator, callback, attributeHandler);
	}

	private boolean compareCalculatedValue(BigDecimal calculatedValue, DynamicWeightQueryStateEvaluator evaluator) {

		for (DynamicWeightQueryStateEvaluatorValues value : evaluator.getDynamicWeightQueryStateEvaluatorValueList()) {
			BigDecimal fromValue = BigDecimal.valueOf(value.getFromValue());
			BigDecimal toValue = BigDecimal.valueOf(value.getToValue());
			if (calculatedValue.compareTo(fromValue) >= 0 && calculatedValue.compareTo(toValue) <= 0) {
				return true;
			}

		}
		return false;
	}

	@Override
	public Evaluator createEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		DynamicWeightQueryStateEvaluator evaluator = getEvaluatorClass().newInstance();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());
		evaluator.setQueryState(QueryState.VISIBLE);

		getEvaluatorDAO().add(evaluator, transactionHandler, null);

		evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());

		return evaluator;
	}

}
