package com.nordicpeak.flowengine.evaluators.settextfieldweightevaluator;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.standardutils.dao.AnnotatedDAOWrapper;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLUtils;
import se.unlogic.webutils.http.URIParser;
import se.unlogic.webutils.populators.annotated.AnnotatedRequestPopulator;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluatorCRUD;
import com.nordicpeak.flowengine.interfaces.MutableQueryDescriptor;
import com.nordicpeak.flowengine.queries.textfieldquery.TextField;
import com.nordicpeak.flowengine.queries.textfieldquery.TextFieldQuery;

public class SetTextFieldWeightEvaluatorCRUD extends BaseEvaluatorCRUD<SetTextFieldWeightEvaluator, SetTextFieldWeightEvaluationProviderModule> {

	private static final AnnotatedRequestPopulator<SetTextFieldWeightEvaluator> POPULATOR = new AnnotatedRequestPopulator<SetTextFieldWeightEvaluator>(SetTextFieldWeightEvaluator.class);

	public SetTextFieldWeightEvaluatorCRUD(Class<SetTextFieldWeightEvaluator> beanClass, AnnotatedDAOWrapper<SetTextFieldWeightEvaluator, Integer> evaluatorDAO, SetTextFieldWeightEvaluationProviderModule callback) {

		super(beanClass, evaluatorDAO, POPULATOR, "SetTextFieldWeightEvaluator", "set text field weight evaluator", null, callback);
	}

	@Override
	protected void appendUpdateFormData(SetTextFieldWeightEvaluator bean, Document doc, Element updateTypeElement, User user, HttpServletRequest req, URIParser uriParser) throws Exception {

		super.appendUpdateFormData(bean, doc, updateTypeElement, user, req, uriParser);

		TextFieldQuery query = (TextFieldQuery) callback.getQueryHandler().getQuery((MutableQueryDescriptor) bean.getEvaluatorDescriptor().getQueryDescriptor(), false);

		List<TextField> fields = query.getFields();

		if (fields != null) {

			Element fieldsElement = doc.createElement("TextFields");
			updateTypeElement.appendChild(fieldsElement);

			for (TextField field : fields) {

				Element fieldElement = doc.createElement("TextField");
				fieldsElement.appendChild(fieldElement);

				XMLUtils.appendNewElement(doc, fieldElement, "fieldID", field.getTextFieldID());
				XMLUtils.appendNewCDATAElement(doc, fieldElement, "name", field.getLabel());
			}

		}

	}

	@Override
	protected SetTextFieldWeightEvaluator populateFromUpdateRequest(SetTextFieldWeightEvaluator bean, HttpServletRequest req, User user, URIParser uriParser) throws ValidationException, Exception {

		SetTextFieldWeightEvaluator evaluator = super.populateFromUpdateRequest(bean, req, user, uriParser);
		
		List<ValidationError> errors = new ArrayList<ValidationError>();

		if(evaluator.getEvaluationMode() == EvaluationMode.USE_INTERVALL){
			
			if (bean.getFromValue() != null && bean.getToValue() != null && bean.getFromValue() > bean.getToValue()) {

				errors.add(new ValidationError("FromValueBiggerThanToValue"));
			}
		}
		

		Integer textFieldID = bean.getTextFieldID();

		boolean found = false;

		TextFieldQuery query = (TextFieldQuery) callback.getQueryHandler().getQuery((MutableQueryDescriptor) bean.getEvaluatorDescriptor().getQueryDescriptor(), false);

		if (query.getFields() != null) {

			for (TextField field : query.getFields()) {

				if (field.getTextFieldID().equals(textFieldID)) {

					found = true;
					break;
				}
			}

		}

		if (!found) {

			errors.add(new ValidationError("TextFieldNotFound"));
		}

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
		
		return evaluator;
	}

}
