package com.nordicpeak.flowengine.evaluators.settextfieldweightfromapievaluator;

import java.util.ArrayList;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.PositiveStringIntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;
import com.nordicpeak.flowengine.evaluators.weightapi.interfaces.WeightAPIEvaluator;

@Table(name = "set_textfield_weight_from_api_evaluators")
@XMLElement
public class SetTextFieldWeightFromAPIEvaluator extends BaseEvaluator implements WeightAPIEvaluator {

	private static final long serialVersionUID = -336493853396860255L;

	@DAOManaged
	@WebPopulate(required = true)
	@XMLElement
	private Integer textFieldID;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String weightType;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String sourceName;

	public String getWeightType() {

		return weightType;
	}

	public void setWeightType(String weightType) {
		this.weightType = weightType;
	}

	@Override
	public String getSourceName() {
		return sourceName;
	}

	public void setSourceName(String sourceName) {
		this.sourceName = sourceName;
	}

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();

		textFieldID = XMLValidationUtils.validateParameter("textFieldID", xmlParser, false, PositiveStringIntegerPopulator.getPopulator(), errors);

		weightType = XMLValidationUtils.validateParameter("weightType", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		sourceName = XMLValidationUtils.validateParameter("sourceName", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	@Override
	public String toString() {
		return evaluatorDescriptor.toString();
	}

	@Override
	public boolean forceAjaxPosting() {
		return true;
	}

	public Integer getTextFieldID() {
		return textFieldID;
	}

	public void setTextFieldID(Integer textFieldID) {
		this.textFieldID = textFieldID;
	}
}
