<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
	</xsl:variable>	

	<xsl:variable name="scripts">
		/js/setweightbyageevaluator.js
	</xsl:variable>

	<xsl:template match="Document">

		<div class="contentitem">

			<xsl:apply-templates select="UpdateSetWeightByAgeEvaluator" />
		</div>

	</xsl:template>

	<xsl:template match="UpdateSetWeightByAgeEvaluator">
	
		<xsl:variable name="evaluator" select="SetWeightByAgeEvaluator" />

		<h1>
			<xsl:value-of select="$i18n.UpdateEvaluatorDescriptor.title" />
			<xsl:text>&#x20;</xsl:text>
			<xsl:value-of select="$evaluator/EvaluatorDescriptor/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />
		
		<p><xsl:value-of select="$i18n.description" /></p>

		<form method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="createCommonFieldsForm">
				<xsl:with-param name="element" select="$evaluator" />
			</xsl:call-template>

			<div class="clearboth floatleft marginbottom">
	
				<label class="floatleft full">
					<xsl:value-of select="$i18n.age.title" />
				</label>
			
				<br/>
			
				<xsl:value-of select="$i18n.age.description" />
			</div>
			
			<div class="clearboth floatleft marginbottom twenty">
				<xsl:value-of select="$i18n.minAge" />
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'minAge'" />
					<xsl:with-param name="name" select="'minAge'" />
					<xsl:with-param name="element" select="$evaluator" />
				</xsl:call-template>
			</div>
		
			<div class="clearboth floatleft marginbottom twenty">
				<xsl:value-of select="$i18n.maxAge" />
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'maxAge'" />
					<xsl:with-param name="name" select="'maxAge'" />
					<xsl:with-param name="element" select="$evaluator" />
				</xsl:call-template>
			</div>
			
			<div class="floatleft full">
		
				<label>
					<xsl:value-of select="$i18n.calculationMode.title" />
				</label>
				
				<br/>
				
				<xsl:value-of select="$i18n.calculationMode.description" />
			</div>	
				
			<div class="floatleft full marginbottom">
	
				<div class="floatleft full">
					<xsl:call-template name="createRadio">
						<xsl:with-param name="id" select="'calculateBasedOnYearOnly'" />
						<xsl:with-param name="name" select="'calculateBasedOnYearOnly'" />
						<xsl:with-param name="value" select="'true'" />
						<xsl:with-param name="element" select="$evaluator" />
					</xsl:call-template>
	
					<label for="calculateBasedOnYearOnly">
						<xsl:value-of select="$i18n.calculateBasedOnYearOnly" />
					</label>
				</div>
			</div>
	
			<div class="floatleft full marginbottom">
	
				<div class="floatleft full">
					<xsl:call-template name="createRadio">
						<xsl:with-param name="id" select="'calculateBasedOnFullDate'" />
						<xsl:with-param name="name" select="'calculateBasedOnYearOnly'" />
						<xsl:with-param name="value" select="'false'" />
						<xsl:with-param name="element" select="$evaluator" />
					</xsl:call-template>
	
					<label for="calculateBasedOnFullDate">
						<xsl:value-of select="$i18n.calculateBasedOnFullDate" />
					</label>
				</div>
			</div>

			<div class="floatleft full bigmarginbottom">

				<label for="weightType" class="floatleft full">
					<xsl:value-of select="$i18n.weightType" />
					<span class="required">*</span>
				</label>

				<div class="floatleft full">
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'weightType'" />
						<xsl:with-param name="name" select="'weightType'" />
						<xsl:with-param name="element" select="$evaluator" />
					</xsl:call-template>
				</div>
			</div>
			
			<div class="clearboth floatleft marginbottom twenty" id="weight-form">
				<xsl:value-of select="$i18n.weight" />
				<span class="required">*</span>
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'weight'" />
					<xsl:with-param name="name" select="'weight'" />
					<xsl:with-param name="element" select="$evaluator" />
				</xsl:call-template>
			</div>
					
			<div class="floatleft full marginbottom">
	
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'setAttributeIfAgeInRange'" />
					<xsl:with-param name="name" select="'setAttributeIfAgeInRange'" />
					<xsl:with-param name="value" select="'true'" />
					<xsl:with-param name="element" select="$evaluator" />
				</xsl:call-template>
	
				<label for="setAttributeIfAgeInRange">
					<xsl:value-of select="$i18n.attribute.setIfAgeInRange" />
				</label>
				
			</div>		
			
			<div class="floatleft full" id="attributeFields">
			
				<div class="marginbottom">
					<xsl:value-of select="$i18n.attribute.name" />
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'attributeName'" />
						<xsl:with-param name="name" select="'attributeName'" />
						<xsl:with-param name="element" select="$evaluator" />
					</xsl:call-template>
				</div>
			
				<div class="marginbottom">
					<xsl:value-of select="$i18n.attribute.value" />
					<xsl:call-template name="createTextField">
						<xsl:with-param name="id" select="'attributeValue'" />
						<xsl:with-param name="name" select="'attributeValue'" />
						<xsl:with-param name="element" select="$evaluator" />
					</xsl:call-template>
				</div>
				
			</div>

			<div class="floatright clearboth">
				<input type="submit" value="{$i18n.submit}" />
			</div>

		</form>

	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'MinAgeBiggerThanMaxAge']">

		<p class="error">
			<xsl:value-of select="$i18n.validation.MinAgeBiggerThanMaxAge" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="validationError[messageKey = 'NoAgeRangeSpecified']">

		<p class="error">
			<xsl:value-of select="$i18n.validation.NoAgeRangeSpecified" />
		</p>
		
	</xsl:template>
	
	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
			<xsl:when test="$fieldName = 'weightType'">
				<xsl:value-of select="$i18n.weightType" />
			</xsl:when>
			<xsl:when test="$fieldName = 'weight'">
				<xsl:value-of select="$i18n.weight" />
			</xsl:when>
			<xsl:when test="$fieldName = 'minAge'">
				<xsl:value-of select="$i18n.minAge" />
			</xsl:when>
			<xsl:when test="$fieldName = 'maxAge'">
				<xsl:value-of select="$i18n.maxAge" />
			</xsl:when>			
			<xsl:when test="$fieldName = 'attributeName'">
				<xsl:value-of select="$i18n.attribute.name" />
			</xsl:when>
			<xsl:when test="$fieldName = 'attributeValue'">
				<xsl:value-of select="$i18n.attribute.value" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>