package com.nordicpeak.flowengine.evaluators.setweightbydateevaluator;

import java.math.BigDecimal;
import java.sql.SQLException;
import java.util.Calendar;
import java.util.List;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.sql.DataSource;

import se.unlogic.hierarchy.core.annotations.WebPublic;
import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.ForegroundModuleResponse;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.AnnotatedDAO;
import se.unlogic.standardutils.dao.HighLevelQuery;
import se.unlogic.standardutils.dao.QueryParameterFactory;
import se.unlogic.standardutils.dao.SimpleAnnotatedDAOFactory;
import se.unlogic.standardutils.dao.TransactionHandler;
import se.unlogic.standardutils.db.tableversionhandler.TableVersionHandler;
import se.unlogic.standardutils.db.tableversionhandler.UpgradeResult;
import se.unlogic.standardutils.db.tableversionhandler.XMLDBScriptProvider;
import se.unlogic.standardutils.enums.EnumUtils;
import se.unlogic.standardutils.enums.Month;
import se.unlogic.standardutils.xml.XMLGenerator;
import se.unlogic.webutils.http.URIParser;

import com.nordicpeak.flowengine.beans.EvaluationResponse;
import com.nordicpeak.flowengine.beans.QueryModification;
import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluationProviderModule;
import com.nordicpeak.flowengine.evaluators.setweightevaluator.SetWeightEvaluationEvent;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.Evaluator;
import com.nordicpeak.flowengine.interfaces.ImmutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.ImmutableStatus;
import com.nordicpeak.flowengine.interfaces.InstanceMetadata;
import com.nordicpeak.flowengine.interfaces.MutableEvaluatorDescriptor;
import com.nordicpeak.flowengine.interfaces.Query;
import com.nordicpeak.flowengine.interfaces.QueryInstance;

public class SetWeightByDateEvaluationProviderModule extends BaseEvaluationProviderModule<SetWeightByDateEvaluator> {

	protected SetWeightByDateEvaluatorCRUD evaluatorCRUD;

	protected AnnotatedDAO<SetWeightByDateEvaluator> evaluatorDAO;

	protected QueryParameterFactory<SetWeightByDateEvaluator, Integer> evaluatorIDParamFactory;

	@Override
	public boolean supportsQueryType(Class<? extends Query> queryClass) {

		return true;
	}

	@Override
	protected void createDAOs(DataSource dataSource) throws Exception {

		//Automatic table version handling
		UpgradeResult upgradeResult = TableVersionHandler.upgradeDBTables(dataSource, SetWeightByDateEvaluationProviderModule.class.getName(), new XMLDBScriptProvider(this.getClass().getResourceAsStream("DB script.xml")));

		if (upgradeResult.isUpgrade()) {

			log.info(upgradeResult.toString());
		}

		evaluatorDAO = new SimpleAnnotatedDAOFactory(dataSource).getDAO(SetWeightByDateEvaluator.class);
		evaluatorIDParamFactory = evaluatorDAO.getParamFactory("evaluatorID", Integer.class);

		evaluatorCRUD = new SetWeightByDateEvaluatorCRUD(SetWeightByDateEvaluator.class, evaluatorDAO.getWrapper("evaluatorID", Integer.class), this);
	}

	@WebPublic(alias = "config")
	public ForegroundModuleResponse configureEvaluator(HttpServletRequest req, HttpServletResponse res, User user, URIParser uriParser) throws Exception {

		return this.evaluatorCRUD.update(req, res, user, uriParser);
	}

	@Override
	public EvaluationResponse evaluate(QueryInstance queryInstance, User user, User poster, SetWeightByDateEvaluator evaluator, EvaluationCallback callback, boolean hasQueryValidationErrors, MutableAttributeHandler attributeHandler) {
		
		if (evaluator.isInitialized()) {
			
			return null;
		}
		
		evaluator.setInitialized(true);
		
		BigDecimal weight = BigDecimal.ZERO;

		if (dateIntervalContainsToday(evaluator)) {

			weight = BigDecimal.valueOf(evaluator.getWeight());
		}

		List<QueryModification> queryModifications = callback.sendEvent(new SetWeightEvaluationEvent(evaluator.getEvaluatorID(), evaluator.getWeightType(), weight, attributeHandler), false);

		if (queryModifications != null) {

			return new EvaluationResponse(queryModifications);
		}

		return null;
	}

	private boolean dateIntervalContainsToday(SetWeightByDateEvaluator evaluator) {

		Calendar calendar = Calendar.getInstance();
		
		Month month = EnumUtils.toEnum(Month.values(), calendar.get(Calendar.MONTH));

		if (!CollectionUtils.contains(evaluator.getMonths(), month)) {

			return false;
		}

		int dayOfMonth = calendar.get(Calendar.DAY_OF_MONTH);

		if ((evaluator.getMaxDayOfMonth() != null && dayOfMonth > evaluator.getMaxDayOfMonth()) || (evaluator.getMinDayOfMonth() != null && dayOfMonth < evaluator.getMinDayOfMonth())) {

			return false;
		}

		return true;
	}

	@Override
	public Evaluator createEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		SetWeightByDateEvaluator evaluator = new SetWeightByDateEvaluator();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());

		return evaluator;
	}

	@Override
	public void copyEvaluator(MutableEvaluatorDescriptor sourceEvaluatorDescriptor, MutableEvaluatorDescriptor copyEvaluatorDescriptor, Query sourceQuery, Query copyQuery, Map<Integer, ImmutableStatus> statusConversionMap, TransactionHandler transactionHandler) throws SQLException {

		SetWeightByDateEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<SetWeightByDateEvaluator>(evaluatorIDParamFactory.getParameter(sourceEvaluatorDescriptor.getEvaluatorID())));

		evaluator.setEvaluatorID(copyEvaluatorDescriptor.getEvaluatorID());

		this.evaluatorDAO.add(evaluator, transactionHandler, null);
	}

	protected Class<SetWeightByDateEvaluator> getEvaluatorClass() {

		return SetWeightByDateEvaluator.class;
	}

	protected AnnotatedDAO<SetWeightByDateEvaluator> getEvaluatorDAO() {

		return evaluatorDAO;
	}

	protected QueryParameterFactory<SetWeightByDateEvaluator, Integer> getEvaluatorIDParameterFactory() {

		return evaluatorIDParamFactory;
	}

	@Override
	public Evaluator getEvaluator(MutableEvaluatorDescriptor descriptor, InstanceMetadata instanceMetadata) throws Throwable {

		SetWeightByDateEvaluator evaluator = evaluatorDAO.get(new HighLevelQuery<SetWeightByDateEvaluator>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())));

		if (evaluator != null) {

			evaluator.init(descriptor, getFullAlias() + "/config/" + descriptor.getEvaluatorID());
		}

		return evaluator;
	}

	@Override
	public boolean deleteEvaluator(ImmutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler) throws Throwable {

		evaluatorDAO.delete(new HighLevelQuery<SetWeightByDateEvaluator>(evaluatorIDParamFactory.getParameter(descriptor.getEvaluatorID())), transactionHandler);

		return true;
	}

	@Override
	public SetWeightByDateEvaluator importEvaluator(MutableEvaluatorDescriptor descriptor, TransactionHandler transactionHandler, Query query, Map<Integer, ImmutableStatus> statusConversionMap) throws Throwable {

		SetWeightByDateEvaluator evaluator = getEvaluatorClass().newInstance();

		evaluator.setEvaluatorID(descriptor.getEvaluatorID());

		evaluator.populate(descriptor.getImportParser().getNode(XMLGenerator.getElementName(evaluator.getClass())));

		this.evaluatorDAO.add(evaluator, transactionHandler, null);

		return evaluator;
	}

}
