package com.nordicpeak.flowengine.evaluators.setweightbygroupevaluator;

import java.util.ArrayList;
import java.util.List;

import se.unlogic.standardutils.annotations.NoDuplicates;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.SimplifiedRelation;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.IntegerPopulator;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;

@Table(name = "set_weight_by_group_evaluators")
@XMLElement
public class SetWeightByGroupEvaluator extends BaseEvaluator {

	private static final long serialVersionUID = 9147248763136420215L;

	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean invert;

	@DAOManaged
	@OneToMany(autoGet = true, autoAdd = true, autoUpdate = true)
	@SimplifiedRelation(table = "set_weight_by_group_evaluator_groups", remoteValueColumnName = "groupID")
	@NoDuplicates
	@WebPopulate(paramName = "group")
	@XMLElement(fixCase = true, childName = "groupID")
	private List<Integer> groupIDs;

	@DAOManaged
	@WebPopulate(required = true, maxLength = 255)
	@XMLElement
	private String weightType;

	@DAOManaged
	@WebPopulate(required = true, populator = IntegerPopulator.class)
	@XMLElement
	private Integer weight;

	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();

		invert = xmlParser.getPrimitiveBoolean("invert");

		weightType = XMLValidationUtils.validateParameter("weightType", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		weight = XMLValidationUtils.validateParameter("weight", xmlParser, false, IntegerPopulator.getPopulator(), errors);

		if (!errors.isEmpty()) {

			throw new ValidationException(errors);
		}
	}

	@Override
	public String toString() {
		return evaluatorDescriptor.toString();
	}

	@Override
	public boolean requiresInitialization() {
		return true;
	}

	public String getWeightType() {
		return weightType;
	}

	public void setWeightType(String weightType) {
		this.weightType = weightType;
	}

	public Integer getWeight() {
		return weight;
	}

	public void setWeight(Integer weight) {
		this.weight = weight;
	}

	public boolean isInverted() {
		return invert;
	}

	public void setInvert(boolean invert) {
		this.invert = invert;
	}

	public List<Integer> getGroupIDs() {
		return groupIDs;
	}

	public void setGroupIDs(List<Integer> groupIDs) {
		this.groupIDs = groupIDs;
	}

}
