package com.nordicpeak.flowengine.evaluators.setweightevaluator;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;

import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.collections.CollectionUtils;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.OneToMany;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.evaluators.baseevaluator.BaseEvaluator;

@Table(name = "set_weight_evaluators")
@XMLElement
public class SetWeightEvaluator extends BaseEvaluator {

	private static final long serialVersionUID = -336493853396860255L;

	@DAOManaged
	@WebPopulate(required=true, maxLength=255)
	@XMLElement
	private String weightType;
	
	@DAOManaged
	@WebPopulate
	@XMLElement
	private boolean useOnlyHighestWeight;
	
	@DAOManaged
	@OneToMany(autoAdd = true, autoGet = true, autoUpdate = true)
	@XMLElement(fixCase=true)
	private List<AlternativeWeight> alternativeWeights;

	
	public String getWeightType() {
	
		return weightType;
	}

	
	public void setWeightType(String weightType) {
	
		this.weightType = weightType;
	}

	
	public List<AlternativeWeight> getAlternativeWeights() {
	
		return alternativeWeights;
	}

	
	public void setAlternativeWeights(List<AlternativeWeight> alternativeWeights) {
	
		this.alternativeWeights = alternativeWeights;
	}


	public BigDecimal getWeight(Integer alternativeID) {

		for(AlternativeWeight alternativeWeight : alternativeWeights){
			
			if(alternativeWeight.getAlternativeID().equals(alternativeID)){
				
				return alternativeWeight.getWeight();
			}
		}
		
		return null;
	}
	
	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		List<ValidationError> errors = new ArrayList<ValidationError>();

		weightType = XMLValidationUtils.validateParameter("weightType", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		useOnlyHighestWeight = xmlParser.getPrimitiveBoolean("useOnlyHighestWeight");
		
		List<XMLParser> weightNodes = xmlParser.getNodes("AlternativeWeights/AlternativeWeight");
		
		if(!CollectionUtils.isEmpty(weightNodes)){
			
			alternativeWeights = new ArrayList<AlternativeWeight>(weightNodes.size());
			
			for(XMLParser parser : weightNodes){
				
				AlternativeWeight alternativeWeight = new AlternativeWeight();

				alternativeWeight.populate(parser);

				alternativeWeight.setEvaluator(this);

				alternativeWeights.add(alternativeWeight);
			}
		}
		
		if(!errors.isEmpty()){

			throw new ValidationException(errors);
		}
	}
	
	@Override
	public String toString() {

		return evaluatorDescriptor.toString();
	}


	@Override
	public boolean forceAjaxPosting() {

		return true;
	}


	@Override
	public boolean requiresInitialization() {

		return true;
	}


	
	public boolean isUseOnlyHighestWeight() {
	
		return useOnlyHighestWeight;
	}


	
	public void setUseOnlyHighestWeight(boolean useOnlyHighestWeight) {
	
		this.useOnlyHighestWeight = useOnlyHighestWeight;
	}
}
