<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:exsl="http://exslt.org/common">
	<xsl:output method="html" version="4.0" encoding="ISO-8859-1" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/Common.xsl" />

	<xsl:include href="classpath://se/unlogic/hierarchy/core/utils/xsl/CKEditor.xsl" />

	<xsl:variable name="scripts">
		/utils/flowfamilylist/staticcontent/js/FlowFamilyList.js
		/js/WeightAPIAdmin.js
	</xsl:variable>

	<xsl:variable name="links">
		/css/weightapiadmin.css?v=1
		/utils/flowfamilylist/staticcontent/css/FlowFamilyList.css?v=1
	</xsl:variable>

	<xsl:variable name="globalscripts">
		/jquery/jquery.js?v=1
		/js/confirmpost.js
	</xsl:variable>

	<xsl:template match="Document">

		<div class="contentitem alternativelistprovider errands-wrapper">

			<xsl:apply-templates select="ListAPISources" />
			<xsl:apply-templates select="ShowAPISource" />
			<xsl:apply-templates select="AddAPISource" />
			<xsl:apply-templates select="UpdateAPISource" />
			<xsl:apply-templates select="ShowAPISourceEvents" />
			<xsl:apply-templates select="ShowSourceFlowUsage" />

		</div>

	</xsl:template>

	<xsl:template match="ListAPISources">

		<h1>
			<xsl:value-of select="$i18n.ListAPISources" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />
		<xsl:apply-templates select="validationError" />

		<p>
			<xsl:value-of select="$i18n.ListAPISources.Description" />
		</p>

		<xsl:choose>
			<xsl:when test="not(APISources/APISource)">

				<span>
					<strong>
						<xsl:value-of select="$i18n.ListAPISources.NoListsFound" />
					</strong>
				</span>

			</xsl:when>
			<xsl:otherwise>

				<table class="full coloredtable sortabletable oep-table">
					<thead class="sortable">
						<tr>
							<xsl:call-template name="ListTableColumns" />
						</tr>
					</thead>
					<tbody>

						<xsl:apply-templates select="APISources/APISource" mode="list" />

					</tbody>
				</table>

			</xsl:otherwise>
		</xsl:choose>

		<div class="floatright marginright bigmargintop">
			<a class="btn btn-green btn-inline" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/add" title="{$i18n.Add}">
				<xsl:value-of select="$i18n.Add" />
			</a>
		</div>

	</xsl:template>

	<xsl:template name="ListTableColumns">

		<th>
			<xsl:value-of select="$i18n.Name" />
		</th>
		<th>
			<xsl:value-of select="$i18n.URL" />
		</th>
		<th></th>

	</xsl:template>

	<xsl:template match="APISource" mode="list">

		<xsl:variable name="name" select="name" />

		<tr>
			<td data-title="{$i18n.Name}" class="twenty vertical-align-top">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/show/{sourceID}">
					<xsl:value-of select="name" />
				</a>
			</td>
			<td data-title="{$i18n.URL}" class="word-break">
				<xsl:value-of select="url" />
			</td>
			<td class="vertical-align-top icons">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/usage/{sourceID}" title="{$i18n.FlowUsage.Button}">
					<img class="alignbottom" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/magnifying_glass.png" alt="" />
				</a>

				<a class="marginleft" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/update/{sourceID}" title="{$i18n.UpdateAPISource}: {name}">
					<img class="alignbottom" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/pen.png" alt="" />
				</a>

				<a class="marginleft" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/delete/{sourceID}" onclick="return confirmHyperlinkPost(this)" title="{$i18n.DeleteAPISource}: {name}">
					<img class="alignbottom" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/delete.png" alt="" />
				</a>
			</td>
		</tr>

	</xsl:template>

	<xsl:template match="ShowAPISource">

		<div class="floatright">

			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/usage/{APISource/sourceID}" title="{$i18n.FlowUsage.Button}">
				<img class="alignbottom" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/magnifying_glass.png" alt="" />
			</a>

			<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/update/{APISource/sourceID}" title="{$i18n.UpdateAPISource}">
				<img class="alignbottom" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/pen.png" alt="" />
			</a>

			<a class="marginleft" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/delete/{APISource/sourceID}"
				onclick="return confirmHyperlinkPost(this)" title="{$i18n.DeleteAPISource}">
				<img class="alignbottom" src="{/Document/requestinfo/contextpath}/static/f/{/Document/module/sectionID}/{/Document/module/moduleID}/pics/delete.png" alt="" />
			</a>

		</div>

		<h1>
			<xsl:value-of select="$i18n.Show" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />
		<xsl:apply-templates select="validationError" />

		<div class="marginbottom">
			<strong>
				<xsl:value-of select="$i18n.URL" />
			</strong>
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/url" />
		</div>

		<div class="marginbottom">
			<strong>
				<xsl:value-of select="$i18n.Encoding" />
			</strong>
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/encoding" />
		</div>

		<div class="marginbottom">
			<strong>
				<xsl:value-of select="$i18n.Username" />
			</strong>
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/username" />
		</div>

		<div class="marginbottom">
			<strong>
				<xsl:value-of select="$i18n.Password" />
			</strong>
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/password" />
		</div>

		<fieldset>
			<legend>
				<xsl:value-of select="$i18n.Events.Title" />
			</legend>

			<p class="nomargin">
				<xsl:value-of select="$i18n.Events.Description" />
			</p>

			<xsl:choose>
				<xsl:when test="Events/APISourceEvent">

					<table class="full coloredtable sortabletable oep-table" cellspacing="0">
						<thead>
							<tr>
								<th>
									<xsl:value-of select="$i18n.Events.message" />
								</th>
								<th>
									<xsl:value-of select="$i18n.Events.poster" />
								</th>
								<th>
									<xsl:value-of select="$i18n.Events.added" />
								</th>
							</tr>
						</thead>
						<tbody>

							<xsl:apply-templates select="Events/APISourceEvent" mode="list" />

						</tbody>
					</table>

				</xsl:when>
				<xsl:otherwise>
					<p>
						<xsl:value-of select="$i18n.Events.NoEvents" />
					</p>
				</xsl:otherwise>
			</xsl:choose>

			<div class="floatright marginright">
				<a href="{/Document/requestinfo/currentURI}/{/Document/module/alias}/events/{APISource/sourceID}" title="{$i18n.Events.ShowAll}">
					<xsl:value-of select="$i18n.Events.ShowAll" />
				</a>
			</div>

		</fieldset>

		<a class="btn btn-blue floatright margintop" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}">
			<xsl:value-of select="$i18n.Back" />
		</a>

	</xsl:template>

	<xsl:template match="AddAPISource">

		<h1>
			<xsl:value-of select="$i18n.Add" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form name="apiSourceForm" method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="editAPISource" />

			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.Add}" />
			</div>

		</form>

	</xsl:template>

	<xsl:template match="UpdateAPISource">

		<h1>
			<xsl:value-of select="$i18n.Update" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />

		<form name="apiSourceForm" method="post" action="{/Document/requestinfo/uri}">

			<xsl:call-template name="editAPISource" />

			<div class="floatright margintop clearboth">
				<input type="submit" value="{$i18n.SaveChanges}" />
			</div>

		</form>

	</xsl:template>

	<xsl:template name="editAPISource">

		<div class="floatleft full bigmarginbottom">
			<label for="name" class="floatleft required">
				<xsl:value-of select="$i18n.Name" />
			</label>

			<p class="floatleft full error tiny">
				<xsl:value-of select="$i18n.Update.Description" />
			</p>

			<div class="floatleft full">
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'name'" />
					<xsl:with-param name="name" select="'name'" />
					<xsl:with-param name="title" select="$i18n.Name" />
					<xsl:with-param name="element" select="APISource" />
				</xsl:call-template>
			</div>
		</div>

		<div class="floatleft full bigmarginbottom">
			<label for="url" class="floatleft required">
				<xsl:value-of select="$i18n.URL" />
			</label>
			<div class="floatleft full">
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'url'" />
					<xsl:with-param name="name" select="'url'" />
					<xsl:with-param name="title" select="$i18n.URL" />
					<xsl:with-param name="element" select="APISource" />
				</xsl:call-template>
			</div>

			<xsl:call-template name="tagTable" />
		</div>

		<fieldset class="floatleft full bigmarginbottom">

			<legend>
				<xsl:value-of select="$i18n.Authorization.Title" />
			</legend>

			<div name="flowfamilies" class="floatleft full bigmarginbottom">
				<xsl:call-template name="createCheckbox">
					<xsl:with-param name="id" select="'useAccessRestriction'" />
					<xsl:with-param name="name" select="'useAccessRestriction'" />
					<xsl:with-param name="element" select="APISource" />
				</xsl:call-template>

				<label for="useAccessRestriction">
					<xsl:value-of select="$i18n.Authorization.activate" />
				</label>
			</div>
			<div id="flowfamiliesList">

				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="APISource/useAccessRestriction = 'true'">floatleft bigmarginright</xsl:when>
						<xsl:otherwise>floatleft bigmarginright hidden</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>

				<label class="floatleft full">
					<xsl:value-of select="$i18n.Authorization.allowedFlowFamilies" />
				</label>

				<xsl:call-template name="FlowFamilyList">
					<xsl:with-param name="connectorURL">
						<xsl:value-of select="/Document/requestinfo/currentURI" />
						<xsl:text>/</xsl:text>
						<xsl:value-of select="/Document/module/alias" />
						<xsl:text>/flowfamily/</xsl:text>
						<xsl:value-of select="Flow/flowID" />
					</xsl:with-param>
					<xsl:with-param name="name" select="'flowfamily'" />
					<xsl:with-param name="flowfamilylist" select="FlowFamilyList" />
				</xsl:call-template>

			</div>

		</fieldset>

		<div class="floatleft full bigmarginbottom">
			<label for="encoding" class="floatleft clearboth">
				<xsl:value-of select="$i18n.Encoding" />
			</label>

			<div class="floatleft full">
				<xsl:call-template name="createDropdown">
					<xsl:with-param name="id" select="'encoding'" />
					<xsl:with-param name="name" select="'encoding'" />
					<xsl:with-param name="selectedValue" select="APISource/encoding" />
					<xsl:with-param name="element" select="AllowedEncodings/Encoding" />
					<xsl:with-param name="simple" select="true()" />
				</xsl:call-template>
			</div>
		</div>

		<h2>
			<xsl:value-of select="$i18n.Authentication" />
		</h2>

		<div class="floatleft full bigmarginbottom">
			<label for="username" class="floatleft">
				<xsl:value-of select="$i18n.Username" />
			</label>
			<div class="floatleft full">
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'username'" />
					<xsl:with-param name="name" select="'username'" />
					<xsl:with-param name="title" select="$i18n.Username" />
					<xsl:with-param name="element" select="APISource" />
				</xsl:call-template>
			</div>
		</div>

		<div class="floatleft full bigmarginbottom">
			<label for="password" class="floatleft">
				<xsl:value-of select="$i18n.Password" />
			</label>
			<div class="floatleft full">
				<xsl:call-template name="createTextField">
					<xsl:with-param name="id" select="'password'" />
					<xsl:with-param name="name" select="'password'" />
					<xsl:with-param name="title" select="$i18n.Password" />
					<xsl:with-param name="element" select="APISource" />
				</xsl:call-template>
			</div>
		</div>

	</xsl:template>

	<xsl:template name="tagTable">

		<div class="floatleft margintop full">

			<p>
				<xsl:value-of select="$i18n.Tags.description.part1" />
			</p>
			<p>
				<xsl:value-of select="$i18n.Tags.description.part2" />
			</p>
			<p>
				<xsl:value-of select="$i18n.Tags.description.part3" />
			</p>

			<table class="full border">
				<tr>
					<th>
						<xsl:value-of select="$i18n.Tag" />
					</th>
					<th>
						<xsl:value-of select="$i18n.Tag.description" />
					</th>
				</tr>
				<tr>
					<td>
						<xsl:text>$user.firstname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.UserFirstname" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$user.lastname</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.UserLastname" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$user.email</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.UserEmail" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$user.username</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.UserUsername" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$user.userID</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.UserUserID" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$user.attribute{citizenIdentifier}</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.UserCitizenIdentifier" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$attribute{attributnamn}</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.Attribute" />
					</td>
				</tr>
				<tr>
					<td>
						<xsl:text>$fieldValue</xsl:text>
					</td>
					<td>
						<xsl:value-of select="$i18n.Tags.FieldValue" />
					</td>
				</tr>
			</table>

		</div>

	</xsl:template>

	<xsl:template match="ShowSourceFlowUsage">

		<h1>
			<xsl:value-of select="$i18n.FlowUsage.Title" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="APISource/name" />
		</h1>

		<xsl:apply-templates select="validationException/validationError" />
		<xsl:apply-templates select="validationError" />

		<xsl:choose>
			<xsl:when test="not(Evaluators/Flow)">

				<span>
					<xsl:value-of select="$i18n.Show.UsedInFlows.NotUsed" />
				</span>

			</xsl:when>
			<xsl:otherwise>

				<table class="coloredtable sortabletable oep-table">
					<thead class="sortable">
						<tr>
							<th>
								<xsl:value-of select="$i18n.Show.UsedInFlows.FlowName" />
							</th>
							<th>
								<xsl:value-of select="$i18n.Show.UsedInFlows.FlowVersion" />
							</th>
							<th>
								<xsl:value-of select="$i18n.Show.UsedInFlows.StepAndQueries" />
							</th>
						</tr>
					</thead>
					<tbody>

						<xsl:apply-templates select="Evaluators/Flow" />

					</tbody>
				</table>

			</xsl:otherwise>
		</xsl:choose>

		<a class="btn btn-blue floatright margintop" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}">
			<xsl:value-of select="$i18n.Back" />
		</a>

	</xsl:template>

	<xsl:template match="Flow">

		<tr>
			<td class="paddingright" data-title="{$i18n.Show.UsedInFlows.FlowName}">
				<xsl:value-of select="name" />
			</td>
			<td class="paddingright" data-title="{$i18n.Show.UsedInFlows.FlowVersion}">
				<xsl:value-of select="version" />
			</td>
			<td data-title="{$i18n.Show.UsedInFlows.StepAndQueries}">

				<xsl:apply-templates select="Step/Query" />

			</td>
		</tr>

	</xsl:template>

	<xsl:template match="Query">

		<div class="full">
			<xsl:value-of select="../name" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="QueryDescriptor/name" />
			<xsl:text>:&#160;</xsl:text>
			<xsl:value-of select="EvaluatorDescriptor/name" />
		</div>

	</xsl:template>

	<xsl:template match="ShowAPISourceEvents">

		<h1>
			<xsl:value-of select="$i18n.Events.Full.Title" />
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="APISource/name" />
		</h1>

		<p class="nomargin">
			<xsl:value-of select="$i18n.Events.Full.Description" />
		</p>

		<xsl:choose>
			<xsl:when test="Events/APISourceEvent">

				<table class="full coloredtable sortabletable oep-table flowfamilyeventstable" cellspacing="0">
					<thead>
						<tr>
							<th>
								<xsl:value-of select="$i18n.Events.message" />
							</th>
							<th>
								<xsl:value-of select="$i18n.Events.poster" />
							</th>
							<th>
								<xsl:value-of select="$i18n.Events.added" />
							</th>
						</tr>
					</thead>
					<tbody>

						<xsl:apply-templates select="Events/APISourceEvent" mode="list" />

					</tbody>
				</table>

			</xsl:when>
			<xsl:otherwise>

				<p>
					<xsl:value-of select="$i18n.Events.NoEvents" />
				</p>

			</xsl:otherwise>
		</xsl:choose>

		<a class="btn btn-blue floatright margintop" href="{/Document/requestinfo/currentURI}/{/Document/module/alias}">
			<xsl:value-of select="$i18n.Back" />
		</a>

	</xsl:template>

	<xsl:template match="APISourceEvent" mode="list">

		<tr>
			<td>
				<xsl:value-of select="message" />
			</td>
			<td>
				<xsl:call-template name="PrintAdminPostedBy">
					<xsl:with-param name="poster" select="poster" />
				</xsl:call-template>
			</td>
			<td>
				<xsl:value-of select="added" />
			</td>
		</tr>

	</xsl:template>

	<xsl:template name="PrintAdminPostedBy">
		<xsl:param name="poster" />

		<xsl:choose>

			<xsl:when test="$poster">
				<xsl:call-template name="printUser">
					<xsl:with-param name="user" select="$poster" />
				</xsl:call-template>
			</xsl:when>

			<xsl:otherwise>
				<xsl:value-of select="$i18n.RemovedUser" />
			</xsl:otherwise>

		</xsl:choose>

	</xsl:template>

	<xsl:template name="printUser">
		<xsl:param name="user" />

		<xsl:value-of select="$user/firstname" />
		<xsl:text>&#160;</xsl:text>
		<xsl:value-of select="$user/lastname" />

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'DeleteFailedAPISourceNotFound' or messageKey = 'UpdateFailedAPISourceNotFound']">

		<p class="error">
			<xsl:value-of select="$i18n.Validation.APISourceNotFound" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'UnableToDeleteAPISourceInUse']">

		<p class="error">
			<xsl:value-of select="$i18n.Validation.UnableToDeleteAPISourceInUse" />
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey='FlowFamilyInUseValidationError']">
		<p class="error">
			<xsl:value-of select="$i18n.ValidationError.FlowFamilyInUseValidationError" />
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="FlowFamily/FlowFamilyName" />
			<!-- <xsl:text>&#160;</xsl:text> <xsl:value-of select="$i18n.ValidationError.FlowFamilyInUseValidationError.Part2" /> -->
		</p>
	</xsl:template>

	<xsl:template match="validationError[messageKey = 'APISourceNameAlreadyInUse']">

		<p class="error">
			<xsl:value-of select="$i18n.Validation.APISourceNameAlreadyInUse" />
			<xsl:text> </xsl:text>
			<xsl:value-of select="APISource/name" />
			<xsl:text>!</xsl:text>
		</p>

	</xsl:template>

	<xsl:template match="validationError[messageKey = 'InvalidURL']">

		<p class="error">
			<xsl:value-of select="$i18n.Validation.InvalidURL" />
		</p>

	</xsl:template>

	<xsl:template match="validationError">
		<xsl:if test="fieldName and validationErrorType and not(messageKey)">
			<p class="error">
				<xsl:choose>
					<xsl:when test="validationErrorType='RequiredField'">
						<xsl:value-of select="$i18n.Validation.requiredField" />
					</xsl:when>
					<xsl:when test="validationErrorType='InvalidFormat'">
						<xsl:value-of select="$i18n.Validation.invalidFormat" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooShort'">
						<xsl:value-of select="$i18n.Validation.tooShort" />
					</xsl:when>
					<xsl:when test="validationErrorType='TooLong'">
						<xsl:value-of select="$i18n.Validation.tooLong" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.Validation.unknownFault" />
					</xsl:otherwise>
				</xsl:choose>

				<xsl:text>&#x20;</xsl:text>

				<xsl:choose>
					<xsl:when test="fieldName = 'url'">
						<xsl:value-of select="$i18n.URL" />
					</xsl:when>
					<xsl:when test="fieldName = 'username'">
						<xsl:value-of select="$i18n.Username" />
					</xsl:when>
					<xsl:when test="fieldName = 'password'">
						<xsl:value-of select="$i18n.Password" />
					</xsl:when>
					<xsl:when test="fieldName = 'encoding'">
						<xsl:value-of select="$i18n.Encoding" />
					</xsl:when>
					<xsl:when test="fieldName = 'flowfamilyID'">
						<xsl:value-of select="$i18n.EnabledFlow" />
					</xsl:when>
					<xsl:when test="fieldName = 'name'">
						<xsl:value-of select="$i18n.Name" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="fieldName" />
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>

		<xsl:if test="messageKey">
			<p class="error">
				<xsl:choose>
					<xsl:when test="messageKey='DummyKey'">
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$i18n.Validation.unknownFault" />
					</xsl:otherwise>
				</xsl:choose>
			</p>
		</xsl:if>

	</xsl:template>

	<xsl:template match="fieldName">

		<xsl:variable name="fieldName" select="." />

		<xsl:choose>
			<xsl:when test="$fieldName = 'url'">
				<xsl:value-of select="$i18n.URL" />
			</xsl:when>
			<xsl:when test="$fieldName = 'encoding'">
				<xsl:value-of select="$i18n.Encoding" />
			</xsl:when>
			<xsl:when test="$fieldName = 'username'">
				<xsl:value-of select="$i18n.Username" />
			</xsl:when>
			<xsl:when test="$fieldName = 'password'">
				<xsl:value-of select="$i18n.Password" />
			</xsl:when>
			<xsl:when test="$fieldName = 'enabledFlow'">
				<xsl:value-of select="$i18n.EnabledFlow" />
			</xsl:when>
			<xsl:when test="$fieldName = 'flowFamilyID'">
				<xsl:value-of select="$i18n.FlowFamilyID" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$fieldName" />
			</xsl:otherwise>
		</xsl:choose>

	</xsl:template>

</xsl:stylesheet>