package com.nordicpeak.flowengine.evaluators.weightquerystateevaluator;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import se.unlogic.hierarchy.core.beans.User;
import se.unlogic.hierarchy.core.interfaces.attributes.MutableAttributeHandler;
import se.unlogic.standardutils.annotations.WebPopulate;
import se.unlogic.standardutils.dao.annotations.DAOManaged;
import se.unlogic.standardutils.dao.annotations.Table;
import se.unlogic.standardutils.populators.StringPopulator;
import se.unlogic.standardutils.validation.ValidationError;
import se.unlogic.standardutils.validation.ValidationException;
import se.unlogic.standardutils.xml.XMLElement;
import se.unlogic.standardutils.xml.XMLParser;
import se.unlogic.standardutils.xml.XMLValidationUtils;

import com.nordicpeak.flowengine.beans.EvaluationResponse;
import com.nordicpeak.flowengine.beans.QueryModification;
import com.nordicpeak.flowengine.evaluators.calculatequerystateevaluator.CalculatedQueryStateEvaluator;
import com.nordicpeak.flowengine.evaluators.setweightevaluator.SetWeightEvaluationEvent;
import com.nordicpeak.flowengine.interfaces.EvaluationCallback;
import com.nordicpeak.flowengine.interfaces.EvaluationEventListener;
import com.nordicpeak.flowengine.interfaces.EvaluationHandler;
import com.nordicpeak.flowengine.interfaces.QueryInstance;

@Table(name = "weight_query_state_evaluators")
@XMLElement
public class WeightQueryStateEvaluator extends CalculatedQueryStateEvaluator implements EvaluationEventListener{

	private static final long serialVersionUID = -1383195490043894435L;
	
	@DAOManaged
	@WebPopulate(required = true, maxLength=255)
	@XMLElement
	private String weightType;

	private HashMap<Integer, BigDecimal> weightSourceMap;
	
	@Override
	public void populate(XMLParser xmlParser) throws ValidationException {

		super.populate(xmlParser);
		
		List<ValidationError> errors = new ArrayList<ValidationError>(1);
		
		weightType = XMLValidationUtils.validateParameter("weightType", xmlParser, false, 1, 255, StringPopulator.getPopulator(), errors);
		
		if(!errors.isEmpty()) {
			
			throw new ValidationException(errors);
		}
		
	}

	@Override
	public boolean supportsEvent(Object event) {

		if(event instanceof SetWeightEvaluationEvent){
			
			return true;
		}
		
		return false;
	}

	@Override
	public List<QueryModification> processEvent(Object event, QueryInstance queryInstance, User user, User poster, EvaluationCallback callback, EvaluationHandler evaluationHandler) {

		SetWeightEvaluationEvent weightEvent = (SetWeightEvaluationEvent) event;
		
		if(this.weightType != null && weightEvent.getWeightType().equalsIgnoreCase(weightType)){
			
			if(weightSourceMap == null){
				
				weightSourceMap = new HashMap<Integer, BigDecimal>();
			}
						
			this.weightSourceMap.put(weightEvent.getSourceID(), weightEvent.getWeight());
			
			EvaluationResponse response = super.evaluate(queryInstance, user, poster, callback, evaluationHandler, false, weightEvent.getAttributeHandler());
			
			if(response != null){
				
				return response.getModifications();
			}
		}
		
		return null;
	}

	@Override
	public EvaluationResponse evaluate(QueryInstance queryInstance, User user, User poster, EvaluationCallback callback, EvaluationHandler evaluationHandler, boolean hasQueryValidationErrors, MutableAttributeHandler attributeHandler) {

		return null;
	}

	public BigDecimal getCurrentWeight() {
		
		if (weightSourceMap != null) {
			
			BigDecimal totalWeight = BigDecimal.ZERO;
			
			for (BigDecimal weight : weightSourceMap.values()) {
				
				totalWeight = totalWeight.add(weight);
			}
			
			return totalWeight;
		}
		
		return null;
	}
	
}
